
DROP TABLE va_admin_privileges;
CREATE TABLE va_admin_privileges (
  [privilege_id]  COUNTER  NOT NULL,
  [is_hidden] INTEGER,
  [support_privilege] INTEGER,
  [privilege_name] VARCHAR(64)
  ,PRIMARY KEY (privilege_id));



DROP TABLE va_admin_privileges_settings;
CREATE TABLE va_admin_privileges_settings (
  [privilege_id] INTEGER NOT NULL,
  [block_name] VARCHAR(64) NOT NULL,
  [permission] INTEGER
  ,PRIMARY KEY (privilege_id,block_name));



DROP TABLE va_admins;
CREATE TABLE va_admins (
  [admin_id]  COUNTER  NOT NULL,
  [admin_name] VARCHAR(255),
  [nickname] VARCHAR(32),
  [admin_alias] VARCHAR(16),
  [privilege_id] INTEGER,
  [is_hidden] INTEGER,
  [email] VARCHAR(255),
  [login] VARCHAR(64),
  [password] VARCHAR(32),
  [personal_image] VARCHAR(255),
  [signature] LONGTEXT,
  [last_order_id] INTEGER,
  [exported_order_id] INTEGER,
  [exported_order_fields] LONGTEXT,
  [last_user_id] INTEGER,
  [exported_user_id] INTEGER,
  [exported_user_fields] LONGTEXT,
  [imported_user_fields] LONGTEXT,
  [exported_item_fields] LONGTEXT,
  [imported_item_fields] LONGTEXT,
  [edited_item_fields] LONGTEXT,
  [last_visit_date] DATETIME,
  [is_generate_big_image] INTEGER,
  [is_generate_small_image] INTEGER
  ,PRIMARY KEY (admin_id));

CREATE INDEX va_admins_login ON va_admins (login);
CREATE INDEX va_admins_password ON va_admins (password);


DROP TABLE va_ads_assigned;
CREATE TABLE va_ads_assigned (
  [item_id] INTEGER NOT NULL,
  [category_id] INTEGER NOT NULL
  ,PRIMARY KEY (item_id,category_id));



DROP TABLE va_ads_categories;
CREATE TABLE va_ads_categories (
  [category_id]  COUNTER  NOT NULL,
  [language_code] VARCHAR(2),
  [parent_category_id] INTEGER,
  [alias_category_id] INTEGER,
  [category_path] VARCHAR(255),
  [category_name] VARCHAR(255),
  [friendly_url] VARCHAR(255),
  [category_order] INTEGER,
  [allowed_view] INTEGER,
  [allowed_post] INTEGER,
  [short_description] LONGTEXT,
  [full_description] LONGTEXT,
  [image_small] VARCHAR(255),
  [image_large] VARCHAR(255),
  [total_views] INTEGER,
  [total_ads] INTEGER,
  [total_subcategories] INTEGER
  ,PRIMARY KEY (category_id));

CREATE INDEX va_ads_categories_category_path ON va_ads_categories (category_path);
CREATE INDEX va_ads_categories_friendly_url ON va_ads_categories (friendly_url);
CREATE INDEX va_ads_categories_parent_ca_1 ON va_ads_categories (parent_category_id);


DROP TABLE va_ads_features;
CREATE TABLE va_ads_features (
  [feature_id]  COUNTER  NOT NULL,
  [item_id] INTEGER,
  [group_id] INTEGER,
  [feature_name] VARCHAR(255),
  [feature_value] VARCHAR(255)
  ,PRIMARY KEY (feature_id));

CREATE INDEX va_ads_features_group_id ON va_ads_features (group_id);
CREATE INDEX va_ads_features_item_id ON va_ads_features (item_id);


DROP TABLE va_ads_features_default;
CREATE TABLE va_ads_features_default (
  [feature_id]  COUNTER  NOT NULL,
  [type_id] INTEGER,
  [group_id] INTEGER,
  [feature_name] VARCHAR(50),
  [feature_value] LONGTEXT
  ,PRIMARY KEY (feature_id));

CREATE INDEX va_ads_features_default_group_id ON va_ads_features_default (group_id);
CREATE INDEX va_ads_features_default_ite_2 ON va_ads_features_default (type_id);


DROP TABLE va_ads_features_groups;
CREATE TABLE va_ads_features_groups (
  [group_id]  COUNTER  NOT NULL,
  [group_order] INTEGER,
  [group_name] VARCHAR(255)
  ,PRIMARY KEY (group_id));



DROP TABLE va_ads_images;
CREATE TABLE va_ads_images (
  [image_id]  COUNTER  NOT NULL,
  [item_id] INTEGER,
  [image_small] VARCHAR(255),
  [small_width] INTEGER,
  [small_height] INTEGER,
  [image_large] VARCHAR(255),
  [image_title] VARCHAR(255),
  [image_description] LONGTEXT
  ,PRIMARY KEY (image_id));

CREATE INDEX va_ads_images_item_id ON va_ads_images (item_id);


DROP TABLE va_ads_items;
CREATE TABLE va_ads_items (
  [item_id]  COUNTER  NOT NULL,
  [type_id] INTEGER,
  [language_code] VARCHAR(2),
  [item_title] VARCHAR(50),
  [friendly_url] VARCHAR(255),
  [item_order] INTEGER,
  [user_id] INTEGER,
  [admin_id] INTEGER,
  [date_start] DATETIME,
  [date_end] DATETIME,
  [date_added] DATETIME,
  [date_updated] DATETIME,
  [image_small] VARCHAR(255),
  [image_large] VARCHAR(255),
  [is_hot] INTEGER,
  [hot_description] LONGTEXT,
  [short_description] LONGTEXT,
  [full_description] LONGTEXT,
  [price] FLOAT,
  [quantity] INTEGER,
  [availability] VARCHAR(255),
  [location_info] LONGTEXT,
  [location_city] VARCHAR(128),
  [location_state] VARCHAR(8),
  [location_country] VARCHAR(4),
  [is_approved] INTEGER,
  [is_compared] INTEGER,
  [total_views] INTEGER
  ,PRIMARY KEY (item_id));

CREATE INDEX va_ads_items_friendly_url ON va_ads_items (friendly_url);
CREATE INDEX va_ads_items_item_title ON va_ads_items (item_title);
CREATE INDEX va_ads_items_type_id ON va_ads_items (type_id);


DROP TABLE va_ads_properties;
CREATE TABLE va_ads_properties (
  [property_id]  COUNTER  NOT NULL,
  [item_id] INTEGER,
  [property_name] VARCHAR(255),
  [property_value] LONGTEXT
  ,PRIMARY KEY (property_id));

CREATE INDEX va_ads_properties_item_id ON va_ads_properties (item_id);


DROP TABLE va_ads_properties_default;
CREATE TABLE va_ads_properties_default (
  [property_id]  COUNTER  NOT NULL,
  [type_id] INTEGER,
  [property_name] VARCHAR(255),
  [property_value] LONGTEXT
  ,PRIMARY KEY (property_id));

CREATE INDEX va_ads_properties_default_i_3 ON va_ads_properties_default (type_id);


DROP TABLE va_ads_types;
CREATE TABLE va_ads_types (
  [type_id]  COUNTER  NOT NULL,
  [type_name] VARCHAR(50)
  ,PRIMARY KEY (type_id));



DROP TABLE va_allowed_cell_phones;
CREATE TABLE va_allowed_cell_phones (
  [cell_phone_id]  COUNTER  NOT NULL,
  [cell_phone_number] VARCHAR(32)
  ,PRIMARY KEY (cell_phone_id));

CREATE INDEX va_allowed_cell_phones_cell_4 ON va_allowed_cell_phones (cell_phone_number);


DROP TABLE va_articles;
CREATE TABLE va_articles (
  [article_id]  COUNTER  NOT NULL,
  [language_code] VARCHAR(2),
  [article_date] DATETIME,
  [date_end] DATETIME,
  [article_title] VARCHAR(255),
  [friendly_url] VARCHAR(255),
  [article_template] VARCHAR(255),
  [article_order] INTEGER,
  [author_name] VARCHAR(255),
  [author_email] VARCHAR(255),
  [author_url] VARCHAR(255),
  [author_remote_address] VARCHAR(255),
  [created_user_id] INTEGER,
  [created_admin_id] INTEGER,
  [updated_user_id] INTEGER,
  [updated_admin_id] INTEGER,
  [status_id] INTEGER,
  [is_html] INTEGER,
  [allowed_rate] VARCHAR(50),
  [is_hot] INTEGER,
  [link_url] VARCHAR(255),
  [download_url] VARCHAR(255),
  [is_link_direct] VARCHAR(255),
  [date_added] VARCHAR(255),
  [date_updated] VARCHAR(255),
  [keywords] LONGTEXT,
  [hot_description] LONGTEXT,
  [short_description] LONGTEXT,
  [full_description] LONGTEXT,
  [notes] LONGTEXT,
  [total_views] INTEGER,
  [total_votes] INTEGER,
  [total_points] INTEGER,
  [rating] FLOAT,
  [total_clicks] INTEGER,
  [image_small] VARCHAR(255),
  [image_small_alt] VARCHAR(255),
  [image_large] VARCHAR(255),
  [image_large_alt] VARCHAR(255),
  [meta_title] VARCHAR(255),
  [meta_keywords] VARCHAR(255),
  [meta_description] VARCHAR(255)
  ,PRIMARY KEY (article_id));

CREATE INDEX va_articles_friendly_url ON va_articles (friendly_url);
CREATE INDEX va_articles_status_id ON va_articles (status_id);


DROP TABLE va_articles_assigned;
CREATE TABLE va_articles_assigned (
  [article_id] INTEGER NOT NULL,
  [category_id] INTEGER NOT NULL
  ,PRIMARY KEY (article_id,category_id));



DROP TABLE va_articles_categories;
CREATE TABLE va_articles_categories (
  [category_id]  COUNTER  NOT NULL,
  [language_code] VARCHAR(2),
  [parent_category_id] INTEGER,
  [alias_category_id] INTEGER,
  [category_path] VARCHAR(255),
  [category_name] VARCHAR(255),
  [friendly_url] VARCHAR(255),
  [category_order] INTEGER,
  [articles_list_template] VARCHAR(255),
  [articles_details_template] VARCHAR(255),
  [articles_order_column] VARCHAR(50),
  [articles_order_direction] VARCHAR(50),
  [article_list_fields] LONGTEXT,
  [article_details_fields] LONGTEXT,
  [article_required_fields] LONGTEXT,
  [moderators_ids] VARCHAR(255),
  [is_hot] INTEGER,
  [allowed_view] INTEGER,
  [allowed_post] INTEGER,
  [allowed_rate] INTEGER,
  [short_description] LONGTEXT,
  [full_description] LONGTEXT,
  [image_small] VARCHAR(255),
  [image_small_alt] VARCHAR(255),
  [image_large] VARCHAR(255),
  [image_large_alt] VARCHAR(255),
  [is_rss] INTEGER,
  [rss_limit] INTEGER,
  [rss_on_breadcrumb] INTEGER,
  [rss_on_list] INTEGER,
  [meta_title] VARCHAR(255),
  [meta_keywords] VARCHAR(255),
  [meta_description] VARCHAR(255),
  [total_views] INTEGER,
  [total_articles] INTEGER,
  [total_subcategories] INTEGER
  ,PRIMARY KEY (category_id));

CREATE INDEX va_articles_categories_cate_5 ON va_articles_categories (category_path);
CREATE INDEX va_articles_categories_frie_6 ON va_articles_categories (friendly_url);
CREATE INDEX va_articles_categories_pare_7 ON va_articles_categories (parent_category_id);


DROP TABLE va_articles_images;
CREATE TABLE va_articles_images (
  [image_id]  COUNTER  NOT NULL,
  [article_id] INTEGER,
  [image_name] VARCHAR(255),
  [image_title] VARCHAR(255),
  [image_width] VARCHAR(255),
  [image_height] VARCHAR(255),
  [image_alt] VARCHAR(255),
  [image_align] VARCHAR(255),
  [date_added] DATETIME
  ,PRIMARY KEY (image_id));

CREATE INDEX va_articles_images_article_id ON va_articles_images (article_id);


DROP TABLE va_articles_related;
CREATE TABLE va_articles_related (
  [article_id] INTEGER NOT NULL,
  [related_id] INTEGER NOT NULL,
  [related_order] INTEGER
  ,PRIMARY KEY (article_id,related_id));



DROP TABLE va_articles_reviews;
CREATE TABLE va_articles_reviews (
  [review_id]  COUNTER  NOT NULL,
  [article_id] INTEGER,
  [recommended] INTEGER,
  [approved] INTEGER,
  [rating] INTEGER,
  [summary] LONGTEXT,
  [user_name] VARCHAR(255),
  [remote_address] VARCHAR(255),
  [date_added] DATETIME,
  [comments] LONGTEXT
  ,PRIMARY KEY (review_id));

CREATE INDEX va_articles_reviews_article_id ON va_articles_reviews (article_id);


DROP TABLE va_articles_statuses;
CREATE TABLE va_articles_statuses (
  [status_id]  COUNTER  NOT NULL,
  [status_name] VARCHAR(255),
  [status_description] VARCHAR(255),
  [is_shown] INTEGER,
  [status_icon] VARCHAR(255),
  [status_style] VARCHAR(255),
  [allowed_view] INTEGER
  ,PRIMARY KEY (status_id));



DROP TABLE va_authors;
CREATE TABLE va_authors (
  [author_id]  COUNTER  NOT NULL,
  [author_name] VARCHAR(255),
  [friendly_url] VARCHAR(50),
  [short_description] LONGTEXT,
  [full_description] LONGTEXT
  ,PRIMARY KEY (author_id));

CREATE INDEX va_authors_friendly_url ON va_authors (friendly_url);


DROP TABLE va_banned_contents;
CREATE TABLE va_banned_contents (
  [content_id]  COUNTER  NOT NULL,
  [content_text] VARCHAR(255)
  ,PRIMARY KEY (content_id));



DROP TABLE va_banners;
CREATE TABLE va_banners (
  [banner_id]  COUNTER  NOT NULL,
  [banner_rank] INTEGER,
  [banner_title] VARCHAR(255),
  [show_title] INTEGER,
  [image_src] VARCHAR(255),
  [image_alt] VARCHAR(255),
  [html_text] LONGTEXT,
  [target_url] VARCHAR(255),
  [is_new_window] INTEGER,
  [is_active] INTEGER,
  [show_on_ssl] INTEGER,
  [max_impressions] INTEGER,
  [max_clicks] INTEGER,
  [expiry_date] DATETIME,
  [total_impressions] INTEGER,
  [total_clicks] INTEGER
  ,PRIMARY KEY (banner_id));

CREATE INDEX va_banners_is_active ON va_banners (is_active);
CREATE INDEX va_banners_max_clicks ON va_banners (max_clicks);
CREATE INDEX va_banners_max_impressions ON va_banners (max_impressions);


DROP TABLE va_banners_assigned;
CREATE TABLE va_banners_assigned (
  [banner_id] INTEGER NOT NULL,
  [group_id] INTEGER NOT NULL
  ,PRIMARY KEY (banner_id,group_id));



DROP TABLE va_banners_clicks;
CREATE TABLE va_banners_clicks (
  [click_id]  COUNTER  NOT NULL,
  [banner_id] INTEGER,
  [user_id] INTEGER,
  [remote_address] VARCHAR(50),
  [click_date] DATETIME
  ,PRIMARY KEY (click_id));

CREATE INDEX va_banners_clicks_banner_id ON va_banners_clicks (banner_id);
CREATE INDEX va_banners_clicks_click_date ON va_banners_clicks (click_date);
CREATE INDEX va_banners_clicks_user_id ON va_banners_clicks (user_id);


DROP TABLE va_banners_groups;
CREATE TABLE va_banners_groups (
  [group_id]  COUNTER  NOT NULL,
  [group_name] VARCHAR(128),
  [group_desc] LONGTEXT,
  [is_active] INTEGER
  ,PRIMARY KEY (group_id));

CREATE INDEX va_banners_groups_is_active ON va_banners_groups (is_active);


DROP TABLE va_black_ips;
CREATE TABLE va_black_ips (
  [ip_address] VARCHAR(32) NOT NULL,
  [address_action] INTEGER,
  [address_notes] VARCHAR(255)
  ,PRIMARY KEY (ip_address));



DROP TABLE va_bookmarks;
CREATE TABLE va_bookmarks (
  [bookmark_id]  COUNTER  NOT NULL,
  [title] VARCHAR(50),
  [url] VARCHAR(255),
  [admin_id] INTEGER,
  [image_path] VARCHAR(255),
  [is_start_page] INTEGER,
  [is_popup] INTEGER,
  [notes] VARCHAR(255)
  ,PRIMARY KEY (bookmark_id));

CREATE INDEX va_bookmarks_admin_id ON va_bookmarks (admin_id);
CREATE INDEX va_bookmarks_bookmark_id ON va_bookmarks (bookmark_id);


DROP TABLE va_categories;
CREATE TABLE va_categories (
  [category_id]  COUNTER  NOT NULL,
  [parent_category_id] INTEGER,
  [category_path] VARCHAR(255),
  [category_name] VARCHAR(255),
  [friendly_url] VARCHAR(255),
  [category_order] INTEGER,
  [is_showing] INTEGER,
  [allowed_post] INTEGER,
  [show_sub_products] INTEGER,
  [short_description] LONGTEXT,
  [full_description] LONGTEXT,
  [image] VARCHAR(255),
  [image_alt] VARCHAR(255),
  [image_large] VARCHAR(255),
  [image_large_alt] VARCHAR(255),
  [list_template] VARCHAR(128),
  [details_template] VARCHAR(128),
  [meta_title] VARCHAR(255),
  [meta_keywords] VARCHAR(255),
  [meta_description] VARCHAR(255),
  [total_views] INTEGER,
  [admin_id_added_by] INTEGER,
  [admin_id_modified_by] INTEGER,
  [date_added] DATETIME,
  [date_modified] DATETIME
  ,PRIMARY KEY (category_id));

CREATE INDEX va_categories_category_path ON va_categories (category_path);
CREATE INDEX va_categories_friendly_url ON va_categories (friendly_url);
CREATE INDEX va_categories_parent_category_id ON va_categories (parent_category_id);


DROP TABLE va_cc_expiry_years;
CREATE TABLE va_cc_expiry_years (
  [expiry_year] INTEGER NOT NULL
  ,PRIMARY KEY (expiry_year));



DROP TABLE va_cc_start_years;
CREATE TABLE va_cc_start_years (
  [start_year] INTEGER NOT NULL
  ,PRIMARY KEY (start_year));



DROP TABLE va_change_types;
CREATE TABLE va_change_types (
  [type_id]  COUNTER  NOT NULL,
  [type_name] VARCHAR(255)
  ,PRIMARY KEY (type_id));



DROP TABLE va_companies;
CREATE TABLE va_companies (
  [company_id]  COUNTER  NOT NULL,
  [company_name] VARCHAR(255),
  [image_small] VARCHAR(50),
  [image_large] VARCHAR(50),
  [address_info] LONGTEXT,
  [phone_number] VARCHAR(32),
  [fax_number] VARCHAR(32),
  [site_url] VARCHAR(128),
  [contact_email] VARCHAR(128),
  [short_description] LONGTEXT,
  [full_description] LONGTEXT
  ,PRIMARY KEY (company_id));



DROP TABLE va_countries;
CREATE TABLE va_countries (
  [country_code] VARCHAR(4) NOT NULL,
  [country_iso_number] VARCHAR(4),
  [country_order] INTEGER,
  [country_name] VARCHAR(64),
  [currency_code] VARCHAR(4)
  ,PRIMARY KEY (country_code));



DROP TABLE va_coupons;
CREATE TABLE va_coupons (
  [coupon_id]  COUNTER  NOT NULL,
  [order_id] INTEGER,
  [order_item_id] INTEGER,
  [coupon_code] VARCHAR(64),
  [coupon_title] VARCHAR(255),
  [is_active] INTEGER,
  [discount_type] INTEGER,
  [discount_amount] FLOAT,
  [discount_tax_free] INTEGER,
  [free_postage] INTEGER,
  [tax_free] INTEGER,
  [items_all] INTEGER,
  [items_ids] LONGTEXT,
  [users_ids] LONGTEXT,
  [minimum_amount] FLOAT,
  [expiry_date] DATETIME,
  [is_exclusive] INTEGER,
  [quantity_limit] INTEGER,
  [coupon_uses] INTEGER
  ,PRIMARY KEY (coupon_id));

CREATE INDEX va_coupons_coupon_code ON va_coupons (coupon_code);
CREATE INDEX va_coupons_order_id ON va_coupons (order_id);
CREATE INDEX va_coupons_order_item_id ON va_coupons (order_item_id);


DROP TABLE va_credit_cards;
CREATE TABLE va_credit_cards (
  [credit_card_id]  COUNTER  NOT NULL,
  [credit_card_code] VARCHAR(32),
  [credit_card_name] VARCHAR(64)
  ,PRIMARY KEY (credit_card_id));



DROP TABLE va_currencies;
CREATE TABLE va_currencies (
  [currency_id]  COUNTER  NOT NULL,
  [is_default] INTEGER,
  [currency_code] VARCHAR(4),
  [currency_value] VARCHAR(16),
  [currency_title] VARCHAR(64),
  [currency_image] VARCHAR(255),
  [currency_image_active] VARCHAR(255),
  [exchange_rate] FLOAT,
  [symbol_left] VARCHAR(32),
  [symbol_right] VARCHAR(32)
  ,PRIMARY KEY (currency_id));

CREATE INDEX va_currencies_currency_code ON va_currencies (currency_code);


DROP TABLE va_custom_blocks;
CREATE TABLE va_custom_blocks (
  [block_id]  COUNTER  NOT NULL,
  [block_name] VARCHAR(128),
  [block_notes] LONGTEXT,
  [block_title] VARCHAR(255),
  [block_path] VARCHAR(255),
  [block_desc] LONGTEXT
  ,PRIMARY KEY (block_id));



DROP TABLE va_features;
CREATE TABLE va_features (
  [feature_id]  COUNTER  NOT NULL,
  [item_id] INTEGER,
  [group_id] INTEGER,
  [feature_name] VARCHAR(255),
  [feature_value] VARCHAR(255)
  ,PRIMARY KEY (feature_id));

CREATE INDEX va_features_group_id ON va_features (group_id);
CREATE INDEX va_features_item_id ON va_features (item_id);


DROP TABLE va_features_default;
CREATE TABLE va_features_default (
  [feature_id]  COUNTER  NOT NULL,
  [item_type_id] INTEGER,
  [group_id] INTEGER,
  [feature_name] VARCHAR(50),
  [feature_value] LONGTEXT
  ,PRIMARY KEY (feature_id));

CREATE INDEX va_features_default_group_id ON va_features_default (group_id);
CREATE INDEX va_features_default_item_type_id ON va_features_default (item_type_id);


DROP TABLE va_features_groups;
CREATE TABLE va_features_groups (
  [group_id]  COUNTER  NOT NULL,
  [group_order] INTEGER,
  [group_name] VARCHAR(255)
  ,PRIMARY KEY (group_id));



DROP TABLE va_forum;
CREATE TABLE va_forum (
  [thread_id]  COUNTER  NOT NULL,
  [forum_id] INTEGER,
  [user_id] INTEGER,
  [user_name] VARCHAR(64),
  [user_email] VARCHAR(128),
  [remote_address] VARCHAR(32),
  [topic] VARCHAR(255),
  [friendly_url] VARCHAR(255),
  [description] LONGTEXT,
  [email_notification] INTEGER,
  [views] INTEGER,
  [replies] INTEGER,
  [date_added] DATETIME,
  [date_modified] DATETIME,
  [thread_updated] DATETIME,
  [admin_id_added_by] INTEGER,
  [admin_id_modified_by] INTEGER,
  [last_post_added] DATETIME,
  [last_post_user_id] INTEGER,
  [last_post_admin_id] INTEGER,
  [last_post_message_id] INTEGER
  ,PRIMARY KEY (thread_id));

CREATE INDEX va_forum_forum_id ON va_forum (forum_id);
CREATE INDEX va_forum_friendly_url ON va_forum (friendly_url);


DROP TABLE va_forum_categories;
CREATE TABLE va_forum_categories (
  [category_id]  COUNTER  NOT NULL,
  [category_name] VARCHAR(255),
  [friendly_url] VARCHAR(255),
  [category_order] INTEGER,
  [short_description] LONGTEXT,
  [full_description] LONGTEXT,
  [allowed_view] INTEGER
  ,PRIMARY KEY (category_id));

CREATE INDEX va_forum_categories_friendly_url ON va_forum_categories (friendly_url);


DROP TABLE va_forum_list;
CREATE TABLE va_forum_list (
  [forum_id]  COUNTER  NOT NULL,
  [category_id] INTEGER,
  [forum_name] VARCHAR(255),
  [friendly_url] VARCHAR(255),
  [forum_order] INTEGER,
  [short_description] LONGTEXT,
  [full_description] LONGTEXT,
  [small_image] VARCHAR(255),
  [large_image] VARCHAR(255),
  [date_added] DATETIME,
  [threads_number] INTEGER,
  [messages_number] INTEGER,
  [last_post_added] DATETIME,
  [last_post_user_id] INTEGER,
  [last_post_admin_id] INTEGER,
  [last_post_thread_id] INTEGER,
  [last_post_message_id] INTEGER,
  [allowed_view] INTEGER,
  [allowed_view_topics] INTEGER,
  [allowed_view_topic] INTEGER,
  [allowed_post_topics] INTEGER,
  [allowed_post_replies] INTEGER
  ,PRIMARY KEY (forum_id));

CREATE INDEX va_forum_list_friendly_url ON va_forum_list (friendly_url);


DROP TABLE va_forum_messages;
CREATE TABLE va_forum_messages (
  [message_id]  COUNTER  NOT NULL,
  [thread_id] INTEGER,
  [admin_id] INTEGER,
  [user_name] VARCHAR(64),
  [user_email] VARCHAR(128),
  [remote_address] VARCHAR(32),
  [message_text] LONGTEXT,
  [date_added] DATETIME,
  [date_modified] DATETIME,
  [user_id] INTEGER,
  [admin_id_modified_by] INTEGER
  ,PRIMARY KEY (message_id));



DROP TABLE va_forum_moderators;
CREATE TABLE va_forum_moderators (
  [admin_id] INTEGER NOT NULL,
  [forum_id] INTEGER NOT NULL,
  [is_default_forum] INTEGER
  ,PRIMARY KEY (admin_id,forum_id));



DROP TABLE va_global_settings;
CREATE TABLE va_global_settings (
  [setting_type] VARCHAR(32) NOT NULL,
  [setting_name] VARCHAR(64) NOT NULL,
  [setting_value] LONGTEXT
  ,PRIMARY KEY (setting_type,setting_name));



DROP TABLE va_header_links;
CREATE TABLE va_header_links (
  [menu_id]  COUNTER  NOT NULL,
  [layout_id] INTEGER,
  [parent_menu_id] INTEGER,
  [menu_path] VARCHAR(255),
  [menu_title] VARCHAR(255),
  [menu_url] VARCHAR(255),
  [menu_target] VARCHAR(32),
  [menu_image] VARCHAR(255),
  [menu_image_active] VARCHAR(255),
  [menu_order] INTEGER,
  [show_non_logged] INTEGER,
  [show_logged] INTEGER
  ,PRIMARY KEY (menu_id));

CREATE INDEX va_header_links_parent_menu_id ON va_header_links (parent_menu_id);


DROP TABLE va_issue_numbers;
CREATE TABLE va_issue_numbers (
  [issue_number] INTEGER NOT NULL
  ,PRIMARY KEY (issue_number));



DROP TABLE va_item_types;
CREATE TABLE va_item_types (
  [item_type_id]  COUNTER  NOT NULL,
  [item_type_name] VARCHAR(50),
  [is_gift_voucher] INTEGER,
  [is_bundle] INTEGER,
  [is_user] INTEGER,
  [affiliate_commission_type] INTEGER,
  [affiliate_commission_amount] FLOAT,
  [merchant_fee_type] INTEGER,
  [merchant_fee_amount] FLOAT
  ,PRIMARY KEY (item_type_id));



DROP TABLE va_items;
CREATE TABLE va_items (
  [item_id]  COUNTER  NOT NULL,
  [item_name] VARCHAR(255),
  [friendly_url] VARCHAR(255),
  [item_order] INTEGER,
  [item_type_id] INTEGER,
  [issue_date] DATETIME,
  [language_code] VARCHAR(4),
  [manufacturer_id] INTEGER,
  [manufacturer_code] VARCHAR(255),
  [author_id] INTEGER,
  [template_name] VARCHAR(255),
  [hide_add_list] INTEGER,
  [hide_add_details] INTEGER,
  [features] LONGTEXT,
  [short_description] LONGTEXT,
  [full_desc_type] INTEGER,
  [full_description] LONGTEXT,
  [is_special_offer] INTEGER,
  [special_offer] LONGTEXT,
  [notes] LONGTEXT,
  [small_image] VARCHAR(255),
  [small_image_alt] VARCHAR(255),
  [big_image] VARCHAR(255),
  [big_image_alt] VARCHAR(255),
  [super_image] VARCHAR(255),
  [preview_url] VARCHAR(255),
  [preview_width] INTEGER,
  [preview_height] INTEGER,
  [specification] VARCHAR(255),
  [buying_price] FLOAT,
  [price] FLOAT,
  [trade_price] FLOAT,
  [is_price_edit] INTEGER,
  [properties_price] FLOAT,
  [tax_free] INTEGER,
  [weight] FLOAT,
  [stock_level] INTEGER,
  [use_stock_level] INTEGER,
  [hide_out_of_stock] INTEGER,
  [disable_out_of_stock] INTEGER,
  [shipping_in_stock] INTEGER,
  [shipping_out_stock] INTEGER,
  [shipping_rule_id] INTEGER,
  [shipping_cost] FLOAT,
  [is_sales] INTEGER,
  [sales_price] FLOAT,
  [trade_sales] FLOAT,
  [discount_percent] FLOAT,
  [is_recurring] INTEGER,
  [recurring_period] INTEGER,
  [recurring_interval] INTEGER,
  [recurring_payments_total] INTEGER,
  [recurring_start_date] DATETIME,
  [recurring_end_date] DATETIME,
  [affiliate_commission_type] INTEGER,
  [affiliate_commission_amount] FLOAT,
  [merchant_fee_type] INTEGER,
  [merchant_fee_amount] FLOAT,
  [downloadable] INTEGER,
  [download_period] INTEGER,
  [download_path] LONGTEXT,
  [download_show_terms] INTEGER,
  [download_terms_text] LONGTEXT,
  [generate_serial] INTEGER,
  [serial_period] INTEGER,
  [activations_number] INTEGER,
  [is_showing] INTEGER,
  [is_approved] INTEGER,
  [is_compared] INTEGER,
  [buy_link] VARCHAR(255),
  [total_views] INTEGER,
  [votes] INTEGER,
  [points] INTEGER,
  [rating] FLOAT,
  [meta_title] VARCHAR(255),
  [meta_keywords] VARCHAR(255),
  [meta_description] VARCHAR(255),
  [mail_notify] INTEGER,
  [mail_to] VARCHAR(255),
  [mail_from] VARCHAR(64),
  [mail_cc] VARCHAR(255),
  [mail_bcc] VARCHAR(255),
  [mail_reply_to] VARCHAR(64),
  [mail_return_path] VARCHAR(64),
  [mail_type] INTEGER,
  [mail_subject] VARCHAR(255),
  [mail_body] LONGTEXT,
  [sms_notify] INTEGER,
  [sms_recipient] VARCHAR(255),
  [sms_originator] VARCHAR(64),
  [sms_message] LONGTEXT,
  [user_id] INTEGER,
  [admin_id_added_by] INTEGER,
  [admin_id_modified_by] INTEGER,
  [date_added] DATETIME,
  [date_modified] DATETIME
  ,PRIMARY KEY (item_id));

CREATE INDEX va_items_friendly_url ON va_items (friendly_url);
CREATE INDEX va_items_is_approved ON va_items (is_approved);
CREATE INDEX va_items_is_showing ON va_items (is_showing);
CREATE INDEX va_items_item_name ON va_items (item_name);
CREATE INDEX va_items_language_code ON va_items (language_code);
CREATE INDEX va_items_price ON va_items (price);
CREATE INDEX va_items_sales_price ON va_items (sales_price);
CREATE INDEX va_items_trade_price ON va_items (trade_price);
CREATE INDEX va_items_trade_sales ON va_items (trade_sales);
CREATE INDEX va_items_user_id ON va_items (user_id);


DROP TABLE va_items_accessories;
CREATE TABLE va_items_accessories (
  [item_id] INTEGER NOT NULL,
  [accessory_id] INTEGER NOT NULL,
  [accessory_order] INTEGER
  ,PRIMARY KEY (item_id,accessory_id));



DROP TABLE va_items_categories;
CREATE TABLE va_items_categories (
  [item_id] INTEGER NOT NULL,
  [category_id] INTEGER NOT NULL
  ,PRIMARY KEY (item_id,category_id));



DROP TABLE va_items_downloads;
CREATE TABLE va_items_downloads (
  [download_id]  COUNTER  NOT NULL,
  [order_id] INTEGER,
  [user_id] INTEGER,
  [order_item_id] INTEGER,
  [item_id] INTEGER,
  [download_notes] VARCHAR(255),
  [download_path] VARCHAR(255),
  [activated] INTEGER,
  [max_downloads] INTEGER,
  [download_added] DATETIME,
  [download_expiry] DATETIME
  ,PRIMARY KEY (download_id));

CREATE INDEX va_items_downloads_item_id ON va_items_downloads (item_id);
CREATE INDEX va_items_downloads_order_id ON va_items_downloads (order_id);
CREATE INDEX va_items_downloads_order_item_id ON va_items_downloads (order_item_id);
CREATE INDEX va_items_downloads_user_id ON va_items_downloads (user_id);


DROP TABLE va_items_downloads_statistic;
CREATE TABLE va_items_downloads_statistic (
  [download_id] INTEGER,
  [order_item_id] INTEGER,
  [remote_address] VARCHAR(32),
  [downloaded_date] DATETIME
);

CREATE INDEX va_items_downloads_statisti_8 ON va_items_downloads_statistic (download_id);
CREATE INDEX va_items_downloads_statisti_9 ON va_items_downloads_statistic (downloaded_date);
CREATE INDEX va_items_downloads_statisti_10 ON va_items_downloads_statistic (order_item_id);
CREATE INDEX va_items_downloads_statisti_11 ON va_items_downloads_statistic (remote_address);


DROP TABLE va_items_images;
CREATE TABLE va_items_images (
  [image_id]  COUNTER  NOT NULL,
  [item_id] INTEGER,
  [image_small] VARCHAR(255),
  [small_width] INTEGER,
  [small_height] INTEGER,
  [image_large] VARCHAR(255),
  [image_title] VARCHAR(255),
  [image_description] LONGTEXT
  ,PRIMARY KEY (image_id));

CREATE INDEX va_items_images_item_id ON va_items_images (item_id);


DROP TABLE va_items_prices;
CREATE TABLE va_items_prices (
  [price_id]  COUNTER  NOT NULL,
  [item_id] INTEGER,
  [is_active] INTEGER,
  [min_quantity] INTEGER,
  [max_quantity] INTEGER,
  [price] FLOAT,
  [user_type_id] INTEGER,
  [discount_action] INTEGER,
  [properties_discount] FLOAT
  ,PRIMARY KEY (price_id));

CREATE INDEX va_items_prices_item_id ON va_items_prices (item_id);
CREATE INDEX va_items_prices_user_type_id ON va_items_prices (user_type_id);


DROP TABLE va_items_properties;
CREATE TABLE va_items_properties (
  [property_id]  COUNTER  NOT NULL,
  [property_type_id] INTEGER,
  [item_type_id] INTEGER,
  [item_id] INTEGER,
  [sub_item_id] INTEGER,
  [additional_price] FLOAT,
  [property_order] INTEGER,
  [property_name] VARCHAR(255),
  [property_description] LONGTEXT,
  [property_style] LONGTEXT,
  [use_on_list] INTEGER,
  [use_on_details] INTEGER,
  [use_on_checkout] INTEGER,
  [use_on_second] INTEGER,
  [control_type] VARCHAR(16),
  [control_style] VARCHAR(255),
  [control_code] LONGTEXT,
  [onchange_code] LONGTEXT,
  [onclick_code] LONGTEXT,
  [required] INTEGER,
  [start_html] LONGTEXT,
  [middle_html] LONGTEXT,
  [before_control_html] LONGTEXT,
  [after_control_html] LONGTEXT,
  [end_html] LONGTEXT
  ,PRIMARY KEY (property_id));

CREATE INDEX va_items_properties_item_id ON va_items_properties (item_id);
CREATE INDEX va_items_properties_item_type_id ON va_items_properties (item_type_id);
CREATE INDEX va_items_properties_propert_12 ON va_items_properties (property_type_id);
CREATE INDEX va_items_properties_sub_item_id ON va_items_properties (sub_item_id);


DROP TABLE va_items_properties_values;
CREATE TABLE va_items_properties_values (
  [item_property_id]  COUNTER  NOT NULL,
  [property_id] INTEGER,
  [sub_item_id] INTEGER,
  [property_value] VARCHAR(255),
  [manufacturer_code] VARCHAR(64),
  [download_period] INTEGER,
  [download_path] VARCHAR(255),
  [buying_price] FLOAT,
  [additional_price] FLOAT,
  [percentage_price] FLOAT,
  [additional_weight] FLOAT,
  [use_stock_level] VARCHAR(50),
  [stock_level] INTEGER,
  [hide_out_of_stock] INTEGER,
  [hide_value] INTEGER,
  [is_default_value] INTEGER
  ,PRIMARY KEY (item_property_id));

CREATE INDEX va_items_properties_values__13 ON va_items_properties_values (hide_value);
CREATE INDEX va_items_properties_values__14 ON va_items_properties_values (property_id);
CREATE INDEX va_items_properties_values__15 ON va_items_properties_values (sub_item_id);


DROP TABLE va_items_related;
CREATE TABLE va_items_related (
  [item_id] INTEGER,
  [related_id] INTEGER,
  [related_order] INTEGER
);

CREATE INDEX va_items_related_item_id ON va_items_related (item_id);
CREATE INDEX va_items_related_related_id ON va_items_related (related_id);


DROP TABLE va_items_serials;
CREATE TABLE va_items_serials (
  [serial_id]  COUNTER  NOT NULL,
  [item_id] INTEGER,
  [serial_number] VARCHAR(128),
  [used] INTEGER
  ,PRIMARY KEY (serial_id));

CREATE INDEX va_items_serials_item_id ON va_items_serials (item_id);


DROP TABLE va_languages;
CREATE TABLE va_languages (
  [language_code] VARCHAR(2) NOT NULL,
  [language_order] INTEGER,
  [language_name] VARCHAR(255),
  [show_for_user] INTEGER,
  [language_image] VARCHAR(128),
  [currency_code] VARCHAR(4)
  ,PRIMARY KEY (language_code));



DROP TABLE va_layouts;
CREATE TABLE va_layouts (
  [layout_id]  COUNTER  NOT NULL,
  [layout_name] VARCHAR(64),
  [top_menu_type] INTEGER,
  [style_name] VARCHAR(64),
  [scheme_name] VARCHAR(64),
  [templates_dir] VARCHAR(255),
  [admin_templates_dir] VARCHAR(255)
  ,PRIMARY KEY (layout_id));



DROP TABLE va_manuals_articles;
CREATE TABLE va_manuals_articles (
  [article_id]  COUNTER  NOT NULL,
  [manual_id] INTEGER,
  [parent_article_id] INTEGER,
  [alias_article_id] INTEGER,
  [article_path] VARCHAR(255),
  [article_title] VARCHAR(255),
  [friendly_url] VARCHAR(255),
  [article_order] INTEGER,
  [section_number] VARCHAR(255),
  [image_small] VARCHAR(255),
  [image_small_alt] VARCHAR(255),
  [image_large] VARCHAR(255),
  [image_large_alt] VARCHAR(255),
  [short_description] LONGTEXT,
  [full_description] LONGTEXT,
  [allowed_view] INTEGER,
  [shown_in_contents] INTEGER,
  [meta_title] VARCHAR(255),
  [meta_keywords] VARCHAR(255),
  [meta_description] VARCHAR(255),
  [date_added] DATETIME,
  [date_modified] DATETIME,
  [admin_id_added_by] INTEGER,
  [admin_id_modified_by] INTEGER
  ,PRIMARY KEY (article_id));

CREATE INDEX va_manuals_articles_alias_a_16 ON va_manuals_articles (alias_article_id);
CREATE INDEX va_manuals_articles_article_path ON va_manuals_articles (article_path);
CREATE INDEX va_manuals_articles_friendly_url ON va_manuals_articles (friendly_url);
CREATE INDEX va_manuals_articles_manual_id ON va_manuals_articles (manual_id);
CREATE INDEX va_manuals_articles_parent__17 ON va_manuals_articles (parent_article_id);


DROP TABLE va_manuals_categories;
CREATE TABLE va_manuals_categories (
  [category_id]  COUNTER  NOT NULL,
  [category_name] VARCHAR(255),
  [friendly_url] VARCHAR(255),
  [category_order] INTEGER,
  [short_description] LONGTEXT,
  [full_description] LONGTEXT,
  [allowed_view] INTEGER,
  [meta_title] VARCHAR(255),
  [meta_keywords] VARCHAR(255),
  [meta_description] VARCHAR(255),
  [date_added] DATETIME,
  [date_modified] DATETIME,
  [admin_id_added_by] INTEGER,
  [admin_id_modified_by] INTEGER
  ,PRIMARY KEY (category_id));

CREATE INDEX va_manuals_categories_frien_18 ON va_manuals_categories (friendly_url);


DROP TABLE va_manuals_list;
CREATE TABLE va_manuals_list (
  [manual_id]  COUNTER  NOT NULL,
  [category_id] INTEGER,
  [alias_manual_id] INTEGER,
  [manual_order] INTEGER,
  [manual_title] VARCHAR(255),
  [friendly_url] VARCHAR(255),
  [short_description] LONGTEXT,
  [full_description] LONGTEXT,
  [allowed_view] INTEGER,
  [meta_title] VARCHAR(255),
  [meta_keywords] VARCHAR(255),
  [meta_description] VARCHAR(255),
  [date_added] DATETIME,
  [date_modified] DATETIME,
  [admin_id_added_by] INTEGER,
  [admin_id_modified_by] INTEGER
  ,PRIMARY KEY (manual_id));

CREATE INDEX va_manuals_list_alias_manual_id ON va_manuals_list (alias_manual_id);
CREATE INDEX va_manuals_list_category_id ON va_manuals_list (category_id);
CREATE INDEX va_manuals_list_friendly_url ON va_manuals_list (friendly_url);


DROP TABLE va_manufacturers;
CREATE TABLE va_manufacturers (
  [manufacturer_id]  COUNTER  NOT NULL,
  [manufacturer_name] VARCHAR(255),
  [friendly_url] VARCHAR(255),
  [affiliate_code] VARCHAR(255),
  [short_description] LONGTEXT,
  [full_description] LONGTEXT,
  [image_small] VARCHAR(255),
  [image_small_alt] VARCHAR(255),
  [image_large] VARCHAR(255),
  [image_large_alt] VARCHAR(255)
  ,PRIMARY KEY (manufacturer_id));

CREATE INDEX va_manufacturers_friendly_url ON va_manufacturers (friendly_url);


DROP TABLE va_menus;
CREATE TABLE va_menus (
  [menu_id]  COUNTER  NOT NULL,
  [menu_title] VARCHAR(255),
  [menu_name] VARCHAR(128),
  [menu_notes] LONGTEXT,
  [show_title] INTEGER
  ,PRIMARY KEY (menu_id));



DROP TABLE va_menus_items;
CREATE TABLE va_menus_items (
  [menu_item_id]  COUNTER  NOT NULL,
  [menu_id] INTEGER,
  [parent_menu_item_id] INTEGER,
  [menu_path] VARCHAR(255),
  [menu_title] VARCHAR(255),
  [menu_url] VARCHAR(255),
  [menu_target] VARCHAR(32),
  [menu_image] VARCHAR(255),
  [menu_image_active] VARCHAR(255),
  [menu_prefix] VARCHAR(255),
  [menu_prefix_active] VARCHAR(255),
  [menu_order] INTEGER,
  [show_non_logged] INTEGER,
  [show_logged] INTEGER
  ,PRIMARY KEY (menu_item_id));

CREATE INDEX va_menus_items_menu_id ON va_menus_items (menu_id);
CREATE INDEX va_menus_items_parent_menu__19 ON va_menus_items (parent_menu_item_id);


DROP TABLE va_newsletters;
CREATE TABLE va_newsletters (
  [newsletter_id]  COUNTER  NOT NULL,
  [newsletter_date] DATETIME,
  [newsletter_subject] VARCHAR(255),
  [newsletter_body] LONGTEXT,
  [mail_type] INTEGER,
  [mail_from] VARCHAR(128),
  [mail_reply_to] VARCHAR(128),
  [mail_return_path] VARCHAR(128),
  [mailing_start] DATETIME,
  [mailing_end] DATETIME,
  [emails_left] INTEGER,
  [emails_sent] INTEGER,
  [is_active] INTEGER,
  [is_sent] INTEGER,
  [is_prepared] INTEGER,
  [users_recipients] LONGTEXT,
  [admins_recipients] LONGTEXT,
  [subscribed_recipients] LONGTEXT,
  [orders_recipients] LONGTEXT,
  [added_by] INTEGER,
  [added_date] DATETIME,
  [edited_by] INTEGER,
  [edited_date] DATETIME
  ,PRIMARY KEY (newsletter_id));



DROP TABLE va_newsletters_emails;
CREATE TABLE va_newsletters_emails (
  [email_id]  COUNTER  NOT NULL,
  [newsletter_id] INTEGER,
  [user_email] VARCHAR(128),
  [user_name] VARCHAR(128)
  ,PRIMARY KEY (email_id));

CREATE INDEX va_newsletters_emails_newsl_20 ON va_newsletters_emails (newsletter_id);


DROP TABLE va_newsletters_users;
CREATE TABLE va_newsletters_users (
  [email_id]  COUNTER  NOT NULL,
  [email] VARCHAR(50),
  [date_added] DATETIME
  ,PRIMARY KEY (email_id));

CREATE INDEX va_newsletters_users_email ON va_newsletters_users (email);


DROP TABLE va_order_custom_properties;
CREATE TABLE va_order_custom_properties (
  [property_id]  COUNTER  NOT NULL,
  [payment_id] INTEGER,
  [property_order] INTEGER,
  [property_name] VARCHAR(255),
  [property_description] LONGTEXT,
  [default_value] LONGTEXT,
  [property_style] VARCHAR(255),
  [property_type] INTEGER,
  [property_show] INTEGER,
  [tax_free] INTEGER,
  [control_type] VARCHAR(16),
  [control_style] VARCHAR(255),
  [control_code] LONGTEXT,
  [onchange_code] LONGTEXT,
  [onclick_code] LONGTEXT,
  [required] INTEGER,
  [before_name_html] LONGTEXT,
  [after_name_html] LONGTEXT,
  [before_control_html] LONGTEXT,
  [after_control_html] LONGTEXT,
  [validation_regexp] LONGTEXT,
  [regexp_error] LONGTEXT,
  [options_values_sql] LONGTEXT
  ,PRIMARY KEY (property_id));

CREATE INDEX va_order_custom_properties__21 ON va_order_custom_properties (payment_id);


DROP TABLE va_order_custom_values;
CREATE TABLE va_order_custom_values (
  [property_value_id]  COUNTER  NOT NULL,
  [property_id] INTEGER,
  [property_value] VARCHAR(255),
  [property_price] FLOAT,
  [property_weight] FLOAT,
  [hide_value] INTEGER,
  [is_default_value] INTEGER
  ,PRIMARY KEY (property_value_id));

CREATE INDEX va_order_custom_values_prop_22 ON va_order_custom_values (property_id);


DROP TABLE va_order_statuses;
CREATE TABLE va_order_statuses (
  [status_id]  COUNTER  NOT NULL,
  [status_name] VARCHAR(64),
  [is_user_cancel] INTEGER,
  [allow_user_cancel] INTEGER,
  [is_dispatch] INTEGER,
  [is_list] INTEGER,
  [show_for_user] INTEGER,
  [paid_status] INTEGER,
  [commission_action] INTEGER,
  [download_activation] INTEGER,
  [download_notify] INTEGER,
  [item_notify] INTEGER,
  [mail_notify] INTEGER,
  [mail_to] VARCHAR(255),
  [mail_from] VARCHAR(64),
  [mail_cc] VARCHAR(255),
  [mail_bcc] VARCHAR(255),
  [mail_reply_to] VARCHAR(64),
  [mail_return_path] VARCHAR(64),
  [mail_type] INTEGER,
  [mail_subject] VARCHAR(255),
  [mail_body] LONGTEXT,
  [sms_notify] INTEGER,
  [sms_recipient] VARCHAR(255),
  [sms_originator] VARCHAR(64),
  [sms_message] LONGTEXT
  ,PRIMARY KEY (status_id));



DROP TABLE va_orders;
CREATE TABLE va_orders (
  [order_id]  COUNTER  NOT NULL,
  [parent_order_id] INTEGER,
  [transaction_id] VARCHAR(128),
  [user_id] INTEGER,
  [user_type_id] INTEGER,
  [payment_id] INTEGER,
  [success_message] VARCHAR(255),
  [pending_message] VARCHAR(50),
  [error_message] VARCHAR(255),
  [visit_id] INTEGER,
  [remote_address] VARCHAR(32),
  [initial_ip] VARCHAR(32),
  [cookie_ip] VARCHAR(32),
  [affiliate_code] VARCHAR(64),
  [affiliate_user_id] INTEGER,
  [keywords] VARCHAR(255),
  [coupons_ids] LONGTEXT,
  [currency_code] VARCHAR(4),
  [currency_rate] FLOAT,
  [order_status] INTEGER,
  [total_buying] FLOAT,
  [total_merchants_commission] FLOAT,
  [total_affiliate_commission] FLOAT,
  [goods_total] FLOAT,
  [goods_taxable] FLOAT,
  [total_quantity] INTEGER,
  [weight_total] FLOAT,
  [total_discount] FLOAT,
  [total_discount_tax] FLOAT,
  [shipping_type_id] INTEGER,
  [shipping_type_desc] VARCHAR(255),
  [shipping_cost] FLOAT,
  [shipping_taxable] INTEGER,
  [shipping_tracking_id] VARCHAR(64),
  [shipping_expecting_date] DATETIME,
  [properties_total] FLOAT,
  [properties_taxable] FLOAT,
  [tax_name] VARCHAR(255),
  [tax_percent] FLOAT,
  [tax_total] FLOAT,
  [processing_fee] FLOAT,
  [order_total] FLOAT,
  [name] VARCHAR(128),
  [first_name] VARCHAR(64),
  [last_name] VARCHAR(64),
  [company_id] INTEGER,
  [company_name] VARCHAR(128),
  [email] VARCHAR(128),
  [address1] VARCHAR(255),
  [address2] VARCHAR(255),
  [city] VARCHAR(128),
  [province] VARCHAR(128),
  [state_code] VARCHAR(8),
  [zip] VARCHAR(16),
  [country_code] VARCHAR(8),
  [phone] VARCHAR(32),
  [daytime_phone] VARCHAR(32),
  [evening_phone] VARCHAR(32),
  [cell_phone] VARCHAR(32),
  [fax] VARCHAR(32),
  [delivery_name] VARCHAR(128),
  [delivery_first_name] VARCHAR(64),
  [delivery_last_name] VARCHAR(64),
  [delivery_company_id] INTEGER,
  [delivery_company_name] VARCHAR(128),
  [delivery_email] VARCHAR(128),
  [delivery_address1] VARCHAR(255),
  [delivery_address2] VARCHAR(255),
  [delivery_city] VARCHAR(128),
  [delivery_province] VARCHAR(128),
  [delivery_state_code] VARCHAR(8),
  [delivery_zip] VARCHAR(16),
  [delivery_country_code] VARCHAR(8),
  [delivery_phone] VARCHAR(32),
  [delivery_daytime_phone] VARCHAR(32),
  [delivery_evening_phone] VARCHAR(32),
  [delivery_cell_phone] VARCHAR(32),
  [delivery_fax] VARCHAR(32),
  [cc_name] VARCHAR(90),
  [cc_first_name] VARCHAR(64),
  [cc_last_name] VARCHAR(64),
  [cc_number] VARCHAR(32),
  [cc_start_date] DATETIME,
  [cc_expiry_date] DATETIME,
  [cc_type] INTEGER,
  [cc_issue_number] INTEGER,
  [cc_security_code] VARCHAR(32),
  [pay_without_cc] LONGTEXT,
  [order_placed_date] DATETIME,
  [modified_date] DATETIME,
  [is_placed] INTEGER,
  [is_exported] INTEGER,
  [is_call_center] INTEGER,
  [is_recurring] INTEGER
  ,PRIMARY KEY (order_id));

CREATE INDEX va_orders_affiliate_code ON va_orders (affiliate_code);
CREATE INDEX va_orders_affiliate_user_id ON va_orders (affiliate_user_id);
CREATE INDEX va_orders_currency_code ON va_orders (currency_code);
CREATE INDEX va_orders_email ON va_orders (email);
CREATE INDEX va_orders_first_name ON va_orders (first_name);
CREATE INDEX va_orders_goods_total ON va_orders (goods_total);
CREATE INDEX va_orders_keywords ON va_orders (keywords);
CREATE INDEX va_orders_last_name ON va_orders (last_name);
CREATE INDEX va_orders_name ON va_orders (name);
CREATE INDEX va_orders_order_placed_date ON va_orders (order_placed_date);
CREATE INDEX va_orders_order_status ON va_orders (order_status);
CREATE INDEX va_orders_parent_order_id ON va_orders (parent_order_id);
CREATE INDEX va_orders_payment_id ON va_orders (payment_id);
CREATE INDEX va_orders_shipping_tracking_id ON va_orders (shipping_tracking_id);
CREATE INDEX va_orders_shipping_type_id ON va_orders (shipping_type_id);
CREATE INDEX va_orders_total_buying ON va_orders (total_buying);
CREATE INDEX va_orders_user_id ON va_orders (user_id);
CREATE INDEX va_orders_user_type_id ON va_orders (user_type_id);
CREATE INDEX va_orders_visit_id ON va_orders (visit_id);


DROP TABLE va_orders_events;
CREATE TABLE va_orders_events (
  [event_id]  COUNTER  NOT NULL,
  [order_id] INTEGER,
  [admin_id] INTEGER,
  [status_id] INTEGER,
  [order_items] LONGTEXT,
  [event_date] DATETIME,
  [event_name] VARCHAR(64),
  [event_description] LONGTEXT
  ,PRIMARY KEY (event_id));

CREATE INDEX va_orders_events_admin_id ON va_orders_events (admin_id);
CREATE INDEX va_orders_events_order_id ON va_orders_events (order_id);
CREATE INDEX va_orders_events_status_id ON va_orders_events (status_id);


DROP TABLE va_orders_items;
CREATE TABLE va_orders_items (
  [order_item_id]  COUNTER  NOT NULL,
  [parent_order_item_id] INTEGER,
  [order_id] INTEGER,
  [user_id] INTEGER,
  [user_type_id] INTEGER,
  [item_id] INTEGER,
  [item_user_id] INTEGER,
  [affiliate_user_id] INTEGER,
  [parent_item_id] INTEGER,
  [item_type_id] INTEGER,
  [manufacturer_code] VARCHAR(255),
  [coupons_ids] LONGTEXT,
  [item_status] INTEGER,
  [item_name] VARCHAR(255),
  [item_properties] LONGTEXT,
  [buying_price] FLOAT,
  [real_price] FLOAT,
  [discount_amount] FLOAT,
  [affiliate_commission] FLOAT,
  [merchant_commission] FLOAT,
  [price] FLOAT,
  [tax_free] INTEGER,
  [tax_percent] FLOAT,
  [weight] FLOAT,
  [quantity] INTEGER,
  [downloadable] INTEGER,
  [shipping_tracking_id] VARCHAR(128),
  [shipping_expecting_date] DATETIME,
  [is_recurring] INTEGER,
  [recurring_period] INTEGER,
  [recurring_interval] INTEGER,
  [recurring_payments_total] INTEGER,
  [recurring_payments_made] INTEGER,
  [recurring_payments_failed] INTEGER,
  [recurring_end_date] DATETIME,
  [recurring_last_payment] DATETIME,
  [recurring_next_payment] DATETIME,
  [recurring_plan_payment] DATETIME,
  [is_subscription] INTEGER,
  [subscription_period] INTEGER,
  [subscription_interval] INTEGER,
  [subscription_suspend] INTEGER
  ,PRIMARY KEY (order_item_id));

CREATE INDEX va_orders_items_affiliate_u_23 ON va_orders_items (affiliate_user_id);
CREATE INDEX va_orders_items_item_id ON va_orders_items (item_id);
CREATE INDEX va_orders_items_item_status ON va_orders_items (item_status);
CREATE INDEX va_orders_items_item_type ON va_orders_items (item_type_id);
CREATE INDEX va_orders_items_item_user_id ON va_orders_items (item_user_id);
CREATE INDEX va_orders_items_order_id ON va_orders_items (order_id);
CREATE INDEX va_orders_items_parent_item_id ON va_orders_items (parent_item_id);
CREATE INDEX va_orders_items_parent_orde_24 ON va_orders_items (parent_order_item_id);
CREATE INDEX va_orders_items_price ON va_orders_items (price);
CREATE INDEX va_orders_items_subscription_id ON va_orders_items (user_type_id);
CREATE INDEX va_orders_items_user_id ON va_orders_items (user_id);


DROP TABLE va_orders_items_properties;
CREATE TABLE va_orders_items_properties (
  [item_property_id]  COUNTER  NOT NULL,
  [order_id] INTEGER,
  [order_item_id] INTEGER,
  [property_id] INTEGER,
  [property_values_ids] LONGTEXT,
  [property_name] VARCHAR(255),
  [property_value] LONGTEXT,
  [additional_price] FLOAT,
  [additional_weight] FLOAT
  ,PRIMARY KEY (item_property_id));

CREATE INDEX va_orders_items_properties__25 ON va_orders_items_properties (order_id);
CREATE INDEX va_orders_items_properties__26 ON va_orders_items_properties (order_item_id);
CREATE INDEX va_orders_items_properties__27 ON va_orders_items_properties (property_id);


DROP TABLE va_orders_items_serials;
CREATE TABLE va_orders_items_serials (
  [serial_id]  COUNTER  NOT NULL,
  [order_id] INTEGER,
  [user_id] INTEGER,
  [order_item_id] INTEGER,
  [item_id] INTEGER,
  [serial_number] VARCHAR(128),
  [activated] INTEGER,
  [activations_number] INTEGER,
  [serial_added] DATETIME,
  [serial_expiry] DATETIME
  ,PRIMARY KEY (serial_id));

CREATE INDEX va_orders_items_serials_item_id ON va_orders_items_serials (item_id);
CREATE INDEX va_orders_items_serials_order_id ON va_orders_items_serials (order_id);
CREATE INDEX va_orders_items_serials_ord_28 ON va_orders_items_serials (order_item_id);
CREATE INDEX va_orders_items_serials_ser_29 ON va_orders_items_serials (serial_number);
CREATE INDEX va_orders_items_serials_user_id ON va_orders_items_serials (user_id);


DROP TABLE va_orders_notes;
CREATE TABLE va_orders_notes (
  [note_id]  COUNTER  NOT NULL,
  [order_id] INTEGER,
  [note_title] VARCHAR(255),
  [note_details] LONGTEXT,
  [show_for_user] INTEGER,
  [date_added] DATETIME,
  [date_updated] DATETIME
  ,PRIMARY KEY (note_id));

CREATE INDEX va_orders_notes_order_id ON va_orders_notes (order_id);


DROP TABLE va_orders_properties;
CREATE TABLE va_orders_properties (
  [order_property_id]  COUNTER  NOT NULL,
  [order_id] INTEGER,
  [property_id] INTEGER,
  [property_order] INTEGER,
  [property_type] INTEGER,
  [property_name] VARCHAR(255),
  [property_value] LONGTEXT,
  [property_price] FLOAT,
  [property_weight] FLOAT,
  [tax_free] INTEGER
  ,PRIMARY KEY (order_property_id));

CREATE INDEX va_orders_properties_order_id ON va_orders_properties (order_id);
CREATE INDEX va_orders_properties_order__30 ON va_orders_properties (order_property_id);
CREATE INDEX va_orders_properties_property_id ON va_orders_properties (property_id);
CREATE INDEX va_orders_properties_proper_31 ON va_orders_properties (property_name);


DROP TABLE va_orders_serials_activations;
CREATE TABLE va_orders_serials_activations (
  [activation_id]  COUNTER  NOT NULL,
  [serial_id] INTEGER,
  [order_id] INTEGER,
  [remote_address] VARCHAR(32),
  [generation_key] VARCHAR(255),
  [activation_key] LONGTEXT,
  [date_added] DATETIME
  ,PRIMARY KEY (activation_id));

CREATE INDEX va_orders_serials_activatio_32 ON va_orders_serials_activations (order_id);
CREATE INDEX va_orders_serials_activatio_33 ON va_orders_serials_activations (serial_id);


DROP TABLE va_page_settings;
CREATE TABLE va_page_settings (
  [layout_id] INTEGER NOT NULL,
  [page_name] VARCHAR(32) NOT NULL,
  [setting_name] VARCHAR(64) NOT NULL,
  [setting_order] INTEGER,
  [setting_value] LONGTEXT
  ,PRIMARY KEY (layout_id,page_name,setting_name));



DROP TABLE va_pages;
CREATE TABLE va_pages (
  [page_id]  COUNTER  NOT NULL,
  [page_code] VARCHAR(16),
  [page_title] VARCHAR(255),
  [friendly_url] VARCHAR(255),
  [page_url] VARCHAR(255),
  [page_order] INTEGER,
  [is_showing] INTEGER,
  [link_in_footer] INTEGER,
  [is_html] INTEGER,
  [page_type] INTEGER,
  [page_path] VARCHAR(255),
  [page_body] LONGTEXT,
  [meta_title] VARCHAR(255),
  [meta_keywords] VARCHAR(255),
  [meta_description] VARCHAR(255)
  ,PRIMARY KEY (page_id));

CREATE INDEX va_pages_friendly_url ON va_pages (friendly_url);
CREATE INDEX va_pages_is_showing ON va_pages (is_showing);
CREATE INDEX va_pages_link_in_footer ON va_pages (link_in_footer);
CREATE INDEX va_pages_page_code ON va_pages (page_code);


DROP TABLE va_payment_parameters;
CREATE TABLE va_payment_parameters (
  [parameter_id]  COUNTER  NOT NULL,
  [payment_id] INTEGER,
  [parameter_name] VARCHAR(255),
  [parameter_type] VARCHAR(16),
  [parameter_source] VARCHAR(255),
  [not_passed] INTEGER
  ,PRIMARY KEY (parameter_id));



DROP TABLE va_payment_systems;
CREATE TABLE va_payment_systems (
  [payment_id]  COUNTER  NOT NULL,
  [payment_name] VARCHAR(255),
  [payment_info] LONGTEXT,
  [payment_notes] LONGTEXT,
  [payment_url] VARCHAR(255),
  [processing_time] INTEGER,
  [processing_fee] FLOAT,
  [fee_type] INTEGER,
  [fee_min_goods] FLOAT,
  [fee_max_goods] FLOAT,
  [submit_method] VARCHAR(4),
  [recurring_method] INTEGER,
  [is_advanced] INTEGER,
  [advanced_url] VARCHAR(255),
  [advanced_php_lib] VARCHAR(255),
  [success_status_id] INTEGER,
  [pending_status_id] INTEGER,
  [failure_status_id] INTEGER,
  [failure_action] INTEGER,
  [is_active] INTEGER,
  [is_default] INTEGER,
  [is_call_center] INTEGER
  ,PRIMARY KEY (payment_id));



DROP TABLE va_polls;
CREATE TABLE va_polls (
  [poll_id]  COUNTER  NOT NULL,
  [poll_type] INTEGER,
  [question] LONGTEXT,
  [is_active] INTEGER,
  [date_added] DATETIME,
  [total_votes] INTEGER
  ,PRIMARY KEY (poll_id));



DROP TABLE va_polls_options;
CREATE TABLE va_polls_options (
  [poll_option_id]  COUNTER  NOT NULL,
  [poll_id] INTEGER,
  [option_description] LONGTEXT,
  [is_default_value] INTEGER
  ,PRIMARY KEY (poll_option_id));

CREATE INDEX va_polls_options_poll_id ON va_polls_options (poll_id);


DROP TABLE va_polls_votes;
CREATE TABLE va_polls_votes (
  [poll_id] INTEGER,
  [poll_option_id] INTEGER,
  [remote_address] VARCHAR(32),
  [date_added] DATETIME
);

CREATE INDEX va_polls_votes_poll_id ON va_polls_votes (poll_id);
CREATE INDEX va_polls_votes_poll_option_id ON va_polls_votes (poll_option_id);
CREATE INDEX va_polls_votes_remote_address ON va_polls_votes (remote_address);


DROP TABLE va_quotes;
CREATE TABLE va_quotes (
  [quote_id]  COUNTER  NOT NULL,
  [user_id] INTEGER,
  [user_name] VARCHAR(255),
  [user_email] VARCHAR(255),
  [order_id] INTEGER,
  [quoted_price] FLOAT,
  [quote_status_id] INTEGER,
  [quoted_by_admin_id] INTEGER,
  [is_paid] INTEGER,
  [is_closed] INTEGER,
  [date_added] DATETIME,
  [date_due] DATETIME,
  [request_summary] LONGTEXT,
  [request_description] LONGTEXT
  ,PRIMARY KEY (quote_id));

CREATE INDEX va_quotes_is_paid ON va_quotes (is_paid);
CREATE INDEX va_quotes_order_id ON va_quotes (order_id);
CREATE INDEX va_quotes_quote_id ON va_quotes (quote_id);
CREATE INDEX va_quotes_quote_status_id ON va_quotes (quote_status_id);
CREATE INDEX va_quotes_quoted_by_admin_id ON va_quotes (quoted_by_admin_id);
CREATE INDEX va_quotes_user_id ON va_quotes (user_id);


DROP TABLE va_quotes_features;
CREATE TABLE va_quotes_features (
  [feature_id]  COUNTER  NOT NULL,
  [quote_id] INTEGER,
  [feature_description] LONGTEXT,
  [price] FLOAT,
  [date_due] DATETIME
  ,PRIMARY KEY (feature_id));

CREATE INDEX va_quotes_features_feature_id ON va_quotes_features (feature_id);
CREATE INDEX va_quotes_features_quote_id ON va_quotes_features (quote_id);


DROP TABLE va_quotes_history;
CREATE TABLE va_quotes_history (
  [quote_id] INTEGER,
  [quote_status_id_old] INTEGER,
  [quote_status_id_new] INTEGER,
  [action] VARCHAR(255),
  [date_added] DATETIME,
  [admin_id] INTEGER
);

CREATE INDEX va_quotes_history_admin_id ON va_quotes_history (admin_id);
CREATE INDEX va_quotes_history_quote_id ON va_quotes_history (quote_id);


DROP TABLE va_quotes_statuses;
CREATE TABLE va_quotes_statuses (
  [quote_status_id]  COUNTER  NOT NULL,
  [quote_status] VARCHAR(255),
  [start_tag] VARCHAR(255),
  [end_tag] VARCHAR(255),
  [image_path] VARCHAR(255),
  [notes] LONGTEXT
  ,PRIMARY KEY (quote_status_id));

CREATE INDEX va_quotes_statuses_quote_st_34 ON va_quotes_statuses (quote_status_id);


DROP TABLE va_release_changes;
CREATE TABLE va_release_changes (
  [change_id]  COUNTER  NOT NULL,
  [release_id] INTEGER,
  [change_type_id] INTEGER,
  [change_date] DATETIME,
  [change_desc] LONGTEXT,
  [is_showing] INTEGER
  ,PRIMARY KEY (change_id));

CREATE INDEX va_release_changes_release_id ON va_release_changes (release_id);


DROP TABLE va_release_types;
CREATE TABLE va_release_types (
  [type_id]  COUNTER  NOT NULL,
  [type_name] VARCHAR(255)
  ,PRIMARY KEY (type_id));



DROP TABLE va_releases;
CREATE TABLE va_releases (
  [release_id]  COUNTER  NOT NULL,
  [item_id] INTEGER,
  [release_type_id] INTEGER,
  [release_date] DATETIME,
  [release_title] VARCHAR(255),
  [version] VARCHAR(32),
  [release_desc] LONGTEXT,
  [download_type] INTEGER,
  [path_to_file] VARCHAR(255),
  [is_showing] INTEGER,
  [show_on_index] INTEGER
  ,PRIMARY KEY (release_id));

CREATE INDEX va_releases_item_id ON va_releases (item_id);


DROP TABLE va_reviews;
CREATE TABLE va_reviews (
  [review_id]  COUNTER  NOT NULL,
  [item_id] INTEGER,
  [recommended] INTEGER,
  [approved] INTEGER,
  [rating] INTEGER,
  [summary] VARCHAR(255),
  [user_name] VARCHAR(255),
  [remote_address] VARCHAR(32),
  [date_added] DATETIME,
  [comments] LONGTEXT
  ,PRIMARY KEY (review_id));

CREATE INDEX va_reviews_approved ON va_reviews (approved);
CREATE INDEX va_reviews_item_id ON va_reviews (item_id);
CREATE INDEX va_reviews_recommended ON va_reviews (recommended);


DROP TABLE va_saved_carts;
CREATE TABLE va_saved_carts (
  [cart_id]  COUNTER  NOT NULL,
  [user_id] INTEGER,
  [cart_name] VARCHAR(255),
  [cart_total] FLOAT,
  [cart_added] DATETIME
  ,PRIMARY KEY (cart_id));

CREATE INDEX va_saved_carts_user_id ON va_saved_carts (user_id);


DROP TABLE va_saved_items;
CREATE TABLE va_saved_items (
  [cart_item_id]  COUNTER  NOT NULL,
  [item_id] INTEGER,
  [cart_id] INTEGER,
  [user_id] INTEGER,
  [item_name] VARCHAR(255),
  [quantity] INTEGER,
  [price] FLOAT,
  [date_added] DATETIME
  ,PRIMARY KEY (cart_item_id));

CREATE INDEX va_saved_items_cart_id ON va_saved_items (cart_id);
CREATE INDEX va_saved_items_item_id ON va_saved_items (item_id);
CREATE INDEX va_saved_items_user_id ON va_saved_items (user_id);


DROP TABLE va_saved_items_properties;
CREATE TABLE va_saved_items_properties (
  [item_property_id]  COUNTER  NOT NULL,
  [cart_item_id] INTEGER,
  [cart_id] INTEGER,
  [property_id] INTEGER,
  [property_value] LONGTEXT,
  [property_values_ids] LONGTEXT
  ,PRIMARY KEY (item_property_id));

CREATE INDEX va_saved_items_properties_b_35 ON va_saved_items_properties (cart_item_id);
CREATE INDEX va_saved_items_properties_b_36 ON va_saved_items_properties (cart_id);
CREATE INDEX va_saved_items_properties_p_37 ON va_saved_items_properties (property_id);


DROP TABLE va_search_engines;
CREATE TABLE va_search_engines (
  [engine_id]  COUNTER  NOT NULL,
  [engine_name] VARCHAR(64),
  [keywords_parameter] VARCHAR(32),
  [referer_regexp] LONGTEXT,
  [user_agent_regexp] LONGTEXT,
  [ip_regexp] LONGTEXT
  ,PRIMARY KEY (engine_id));



DROP TABLE va_shipping_modules;
CREATE TABLE va_shipping_modules (
  [shipping_module_id]  COUNTER  NOT NULL,
  [shipping_module_name] VARCHAR(255),
  [module_notes] LONGTEXT,
  [is_external] INTEGER,
  [php_external_lib] VARCHAR(255),
  [external_url] VARCHAR(255),
  [tracking_url] VARCHAR(255),
  [is_active] INTEGER
  ,PRIMARY KEY (shipping_module_id));



DROP TABLE va_shipping_modules_parameters;
CREATE TABLE va_shipping_modules_parameters (
  [parameter_id]  COUNTER  NOT NULL,
  [shipping_module_id] INTEGER,
  [parameter_name] VARCHAR(255),
  [parameter_source] LONGTEXT,
  [not_passed] INTEGER
  ,PRIMARY KEY (parameter_id));

CREATE INDEX va_shipping_modules_paramet_38 ON va_shipping_modules_parameters (shipping_module_id);


DROP TABLE va_shipping_rules;
CREATE TABLE va_shipping_rules (
  [shipping_rule_id]  COUNTER  NOT NULL,
  [shipping_rule_desc] VARCHAR(255),
  [is_country_restriction] INTEGER
  ,PRIMARY KEY (shipping_rule_id));



DROP TABLE va_shipping_rules_countries;
CREATE TABLE va_shipping_rules_countries (
  [shipping_rule_id] INTEGER,
  [country_code] VARCHAR(4)
);

CREATE INDEX va_shipping_rules_countries_39 ON va_shipping_rules_countries (country_code);
CREATE INDEX va_shipping_rules_countries_40 ON va_shipping_rules_countries (shipping_rule_id);


DROP TABLE va_shipping_times;
CREATE TABLE va_shipping_times (
  [shipping_time_id]  COUNTER  NOT NULL,
  [shipping_time_desc] VARCHAR(255),
  [availability_time] INTEGER
  ,PRIMARY KEY (shipping_time_id));



DROP TABLE va_shipping_types;
CREATE TABLE va_shipping_types (
  [shipping_type_id]  COUNTER  NOT NULL,
  [shipping_module_id] INTEGER,
  [shipping_order] INTEGER,
  [shipping_type_code] VARCHAR(64),
  [shipping_type_desc] VARCHAR(255),
  [shipping_time] INTEGER,
  [tare_weight] FLOAT,
  [min_goods_cost] FLOAT,
  [max_goods_cost] FLOAT,
  [min_weight] FLOAT,
  [max_weight] FLOAT,
  [cost_per_order] FLOAT,
  [cost_per_product] FLOAT,
  [cost_per_weight] FLOAT,
  [is_taxable] INTEGER,
  [is_active] INTEGER
  ,PRIMARY KEY (shipping_type_id));

CREATE INDEX va_shipping_types_shipping__41 ON va_shipping_types (shipping_module_id);
CREATE INDEX va_shipping_types_shipping__42 ON va_shipping_types (shipping_type_id);


DROP TABLE va_shipping_types_countries;
CREATE TABLE va_shipping_types_countries (
  [shipping_type_id] INTEGER,
  [country_code] VARCHAR(4)
);

CREATE INDEX va_shipping_types_countries_43 ON va_shipping_types_countries (country_code);
CREATE INDEX va_shipping_types_countries_44 ON va_shipping_types_countries (shipping_type_id);


DROP TABLE va_states;
CREATE TABLE va_states (
  [state_code] VARCHAR(8) NOT NULL,
  [state_name] VARCHAR(64)
  ,PRIMARY KEY (state_code));



DROP TABLE va_support;
CREATE TABLE va_support (
  [support_id]  COUNTER  NOT NULL,
  [user_id] INTEGER,
  [user_name] VARCHAR(64),
  [user_email] VARCHAR(128),
  [affiliate_code] VARCHAR(64),
  [mail_cc] VARCHAR(255),
  [mail_bcc] VARCHAR(255),
  [mail_headers] LONGTEXT,
  [remote_address] VARCHAR(32),
  [identifier] VARCHAR(128),
  [environment] VARCHAR(255),
  [support_product_id] INTEGER,
  [support_type_id] INTEGER,
  [dep_id] INTEGER,
  [summary] VARCHAR(255),
  [description] LONGTEXT,
  [mail_body_text] LONGTEXT,
  [mail_body_html] LONGTEXT,
  [support_status_id] INTEGER,
  [support_priority_id] INTEGER,
  [admin_id_assign_to] INTEGER,
  [admin_id_assign_by] INTEGER,
  [admin_id_added_by] INTEGER,
  [admin_id_modified_by] INTEGER,
  [date_added] DATETIME,
  [date_modified] DATETIME,
  [date_viewed] DATETIME
  ,PRIMARY KEY (support_id));

CREATE INDEX va_support_admin_id_added_by ON va_support (admin_id_added_by);
CREATE INDEX va_support_admin_id_assign_by ON va_support (admin_id_assign_by);
CREATE INDEX va_support_admin_id_assign_to ON va_support (admin_id_assign_to);
CREATE INDEX va_support_admin_id_modified_by ON va_support (admin_id_modified_by);
CREATE INDEX va_support_date_added ON va_support (date_added);
CREATE INDEX va_support_dep_id ON va_support (dep_id);
CREATE INDEX va_support_summary ON va_support (summary);
CREATE INDEX va_support_support_product_id ON va_support (support_product_id);
CREATE INDEX va_support_support_type_id ON va_support (support_type_id);
CREATE INDEX va_support_user_email ON va_support (user_email);
CREATE INDEX va_support_user_id ON va_support (user_id);
CREATE INDEX va_support_user_name ON va_support (user_name);


DROP TABLE va_support_attachments;
CREATE TABLE va_support_attachments (
  [attachment_id]  COUNTER  NOT NULL,
  [support_id] INTEGER,
  [message_id] INTEGER,
  [admin_id] INTEGER,
  [attachment_status] INTEGER,
  [file_name] VARCHAR(255),
  [file_path] VARCHAR(255),
  [date_added] DATETIME
  ,PRIMARY KEY (attachment_id));

CREATE INDEX va_support_attachments_admin_id ON va_support_attachments (admin_id);
CREATE INDEX va_support_attachments_mess_45 ON va_support_attachments (message_id);
CREATE INDEX va_support_attachments_supp_46 ON va_support_attachments (support_id);


DROP TABLE va_support_departments;
CREATE TABLE va_support_departments (
  [dep_id]  COUNTER  NOT NULL,
  [short_title] VARCHAR(255),
  [full_title] VARCHAR(255),
  [signature] LONGTEXT,
  [attachments_dir] VARCHAR(255),
  [attachments_mask] LONGTEXT,
  [incoming_account] LONGTEXT,
  [incoming_type_id] INTEGER,
  [incoming_product_id] INTEGER,
  [outgoing_account] VARCHAR(50),
  [show_for_user] INTEGER
  ,PRIMARY KEY (dep_id));

CREATE INDEX va_support_departments_inco_47 ON va_support_departments (incoming_product_id);
CREATE INDEX va_support_departments_inco_48 ON va_support_departments (incoming_type_id);


DROP TABLE va_support_messages;
CREATE TABLE va_support_messages (
  [message_id]  COUNTER  NOT NULL,
  [support_id] INTEGER,
  [internal] INTEGER,
  [dep_id] INTEGER,
  [support_status_id] INTEGER,
  [admin_id_assign_by] INTEGER,
  [admin_id_assign_to] INTEGER,
  [admin_id_modified_by] INTEGER,
  [subject] VARCHAR(255),
  [message_text] LONGTEXT,
  [mail_body_text] LONGTEXT,
  [mail_body_html] LONGTEXT,
  [reply_to] VARCHAR(255),
  [reply_from] VARCHAR(255),
  [mail_cc] VARCHAR(255),
  [mail_headers] LONGTEXT,
  [date_added] DATETIME,
  [date_viewed] DATETIME,
  [date_modified] DATETIME,
  [is_user_reply] INTEGER,
  [is_html] INTEGER
  ,PRIMARY KEY (message_id));

CREATE INDEX va_support_messages_admin_i_49 ON va_support_messages (admin_id_assign_by);
CREATE INDEX va_support_messages_admin_i_50 ON va_support_messages (admin_id_assign_to);
CREATE INDEX va_support_messages_admin_i_51 ON va_support_messages (admin_id_modified_by);
CREATE INDEX va_support_messages_date_added ON va_support_messages (date_added);
CREATE INDEX va_support_messages_dep_id ON va_support_messages (dep_id);
CREATE INDEX va_support_messages_support_id ON va_support_messages (support_id);
CREATE INDEX va_support_messages_support_52 ON va_support_messages (support_status_id);


DROP TABLE va_support_predefined;
CREATE TABLE va_support_predefined (
  [reply_id]  COUNTER  NOT NULL,
  [subject] VARCHAR(255),
  [body] LONGTEXT,
  [reply_type] VARCHAR(255)
  ,PRIMARY KEY (reply_id));



DROP TABLE va_support_priorities;
CREATE TABLE va_support_priorities (
  [priority_id]  COUNTER  NOT NULL,
  [priority_name] VARCHAR(255),
  [priority_rank] INTEGER,
  [admin_html] LONGTEXT,
  [is_default] INTEGER
  ,PRIMARY KEY (priority_id));



DROP TABLE va_support_products;
CREATE TABLE va_support_products (
  [product_id]  COUNTER  NOT NULL,
  [product_name] VARCHAR(255),
  [show_for_user] INTEGER
  ,PRIMARY KEY (product_id));



DROP TABLE va_support_statuses;
CREATE TABLE va_support_statuses (
  [status_id]  COUNTER  NOT NULL,
  [status_name] VARCHAR(255),
  [show_for_user] INTEGER,
  [status_caption] VARCHAR(255),
  [status_icon] VARCHAR(128),
  [html_start] VARCHAR(255),
  [html_end] VARCHAR(255),
  [is_user_new] INTEGER,
  [is_user_reply] INTEGER,
  [is_operation] INTEGER,
  [is_reassign] INTEGER,
  [is_internal] INTEGER,
  [is_list] INTEGER,
  [is_closed] INTEGER,
  [is_add_knowledge] INTEGER
  ,PRIMARY KEY (status_id));

CREATE INDEX va_support_statuses_status_id ON va_support_statuses (status_id);


DROP TABLE va_support_time_report;
CREATE TABLE va_support_time_report (
  [report_id]  COUNTER  NOT NULL,
  [admin_id] INTEGER,
  [support_id] INTEGER,
  [started_date] DATETIME,
  [report_date] DATETIME,
  [spent_hours] INTEGER
  ,PRIMARY KEY (report_id));

CREATE INDEX va_support_time_report_admin_id ON va_support_time_report (admin_id);
CREATE INDEX va_support_time_report_supp_53 ON va_support_time_report (support_id);


DROP TABLE va_support_types;
CREATE TABLE va_support_types (
  [type_id]  COUNTER  NOT NULL,
  [type_name] VARCHAR(255),
  [show_for_user] INTEGER
  ,PRIMARY KEY (type_id));

CREATE INDEX va_support_types_type_id ON va_support_types (type_id);


DROP TABLE va_support_users_departments;
CREATE TABLE va_support_users_departments (
  [admin_id] INTEGER NOT NULL,
  [dep_id] INTEGER NOT NULL,
  [is_default_dep] INTEGER
  ,PRIMARY KEY (admin_id,dep_id));



DROP TABLE va_support_users_priorities;
CREATE TABLE va_support_users_priorities (
  [user_priority_id]  COUNTER  NOT NULL,
  [priority_id] INTEGER,
  [user_id] INTEGER,
  [user_email] VARCHAR(255)
  ,PRIMARY KEY (user_priority_id));

CREATE INDEX va_support_users_priorities_54 ON va_support_users_priorities (priority_id);
CREATE INDEX va_support_users_priorities_55 ON va_support_users_priorities (user_id);


DROP TABLE va_tax_rates;
CREATE TABLE va_tax_rates (
  [tax_id]  COUNTER  NOT NULL,
  [tax_name] VARCHAR(255),
  [state_code] VARCHAR(8),
  [country_code] VARCHAR(4),
  [tax_percent] FLOAT
  ,PRIMARY KEY (tax_id));



DROP TABLE va_tax_rates_items;
CREATE TABLE va_tax_rates_items (
  [tax_item_id]  COUNTER  NOT NULL,
  [tax_id] INTEGER,
  [item_type_id] INTEGER,
  [tax_percent] FLOAT
  ,PRIMARY KEY (tax_item_id));

CREATE INDEX va_tax_rates_items_item_type_id ON va_tax_rates_items (item_type_id);
CREATE INDEX va_tax_rates_items_tax_id ON va_tax_rates_items (tax_id);


DROP TABLE va_tracking_pages;
CREATE TABLE va_tracking_pages (
  [page_id]  COUNTER  NOT NULL,
  [visit_id] INTEGER,
  [ip_long] INTEGER,
  [ip_text] VARCHAR(32),
  [forwarded_ips] VARCHAR(255),
  [request_uri] VARCHAR(255),
  [request_page] VARCHAR(255),
  [date_added] DATETIME,
  [year_added] INTEGER,
  [month_added] INTEGER,
  [day_added] INTEGER,
  [hour_added] INTEGER,
  [site_id] INTEGER
  ,PRIMARY KEY (page_id));

CREATE INDEX va_tracking_pages_date_added ON va_tracking_pages (date_added);
CREATE INDEX va_tracking_pages_day_added ON va_tracking_pages (day_added);
CREATE INDEX va_tracking_pages_hour_added ON va_tracking_pages (hour_added);
CREATE INDEX va_tracking_pages_ip_long ON va_tracking_pages (ip_long);
CREATE INDEX va_tracking_pages_month_added ON va_tracking_pages (month_added);
CREATE INDEX va_tracking_pages_site_id ON va_tracking_pages (site_id);
CREATE INDEX va_tracking_pages_visit_id ON va_tracking_pages (visit_id);
CREATE INDEX va_tracking_pages_year_added ON va_tracking_pages (year_added);


DROP TABLE va_tracking_visits;
CREATE TABLE va_tracking_visits (
  [visit_id]  COUNTER  NOT NULL,
  [parent_visit_id] INTEGER,
  [visit_number] INTEGER,
  [ip_long] INTEGER,
  [ip_text] VARCHAR(32),
  [forwarded_ips] VARCHAR(50),
  [affiliate_code] VARCHAR(64),
  [keywords] VARCHAR(255),
  [user_agent] VARCHAR(255),
  [request_uri] VARCHAR(255),
  [request_page] VARCHAR(255),
  [referer] VARCHAR(255),
  [referer_host] VARCHAR(255),
  [referer_engine_id] INTEGER,
  [robot_engine_id] INTEGER,
  [date_added] DATETIME,
  [year_added] INTEGER,
  [month_added] INTEGER,
  [week_added] INTEGER,
  [day_added] INTEGER,
  [hour_added] INTEGER,
  [site_id] INTEGER
  ,PRIMARY KEY (visit_id));

CREATE INDEX va_tracking_visits_affiliat_56 ON va_tracking_visits (affiliate_code);
CREATE INDEX va_tracking_visits_date_added ON va_tracking_visits (date_added);
CREATE INDEX va_tracking_visits_day_added ON va_tracking_visits (day_added);
CREATE INDEX va_tracking_visits_hour_added ON va_tracking_visits (hour_added);
CREATE INDEX va_tracking_visits_keyword__57 ON va_tracking_visits (keywords);
CREATE INDEX va_tracking_visits_month_added ON va_tracking_visits (month_added);
CREATE INDEX va_tracking_visits_parent_v_58 ON va_tracking_visits (parent_visit_id);
CREATE INDEX va_tracking_visits_referer__59 ON va_tracking_visits (referer_engine_id);
CREATE INDEX va_tracking_visits_referer_host ON va_tracking_visits (referer_host);
CREATE INDEX va_tracking_visits_remote_i_60 ON va_tracking_visits (ip_long);
CREATE INDEX va_tracking_visits_robot_en_61 ON va_tracking_visits (robot_engine_id);
CREATE INDEX va_tracking_visits_site_id ON va_tracking_visits (site_id);
CREATE INDEX va_tracking_visits_week_added ON va_tracking_visits (week_added);
CREATE INDEX va_tracking_visits_year_added ON va_tracking_visits (year_added);


DROP TABLE va_user_profile_properties;
CREATE TABLE va_user_profile_properties (
  [property_id]  COUNTER  NOT NULL,
  [user_type_id] INTEGER,
  [property_order] INTEGER,
  [property_name] VARCHAR(255),
  [property_description] LONGTEXT,
  [default_value] LONGTEXT,
  [property_style] VARCHAR(255),
  [section_id] INTEGER,
  [property_show] INTEGER,
  [control_type] VARCHAR(16),
  [control_style] VARCHAR(255),
  [control_code] LONGTEXT,
  [onchange_code] LONGTEXT,
  [onclick_code] LONGTEXT,
  [required] INTEGER,
  [before_name_html] LONGTEXT,
  [after_name_html] LONGTEXT,
  [before_control_html] LONGTEXT,
  [after_control_html] LONGTEXT,
  [validation_regexp] LONGTEXT,
  [regexp_error] LONGTEXT,
  [options_values_sql] LONGTEXT
  ,PRIMARY KEY (property_id));

CREATE INDEX va_user_profile_properties__62 ON va_user_profile_properties (user_type_id);


DROP TABLE va_user_profile_sections;
CREATE TABLE va_user_profile_sections (
  [section_id]  COUNTER  NOT NULL,
  [is_active] INTEGER,
  [step_number] INTEGER,
  [section_order] INTEGER,
  [section_name] VARCHAR(64)
  ,PRIMARY KEY (section_id));



DROP TABLE va_user_profile_values;
CREATE TABLE va_user_profile_values (
  [property_value_id]  COUNTER  NOT NULL,
  [property_id] INTEGER,
  [property_value] VARCHAR(255),
  [hide_value] INTEGER,
  [is_default_value] INTEGER
  ,PRIMARY KEY (property_value_id));

CREATE INDEX va_user_profile_values_prop_63 ON va_user_profile_values (property_id);


DROP TABLE va_user_types;
CREATE TABLE va_user_types (
  [type_id]  COUNTER  NOT NULL,
  [type_name] VARCHAR(128),
  [is_default] INTEGER,
  [is_active] INTEGER,
  [is_sms_allowed] INTEGER,
  [show_for_user] INTEGER,
  [price_type] INTEGER,
  [discount_type] INTEGER,
  [discount_amount] FLOAT,
  [affiliate_commission_type] INTEGER,
  [affiliate_commission_amount] FLOAT,
  [merchant_fee_type] INTEGER,
  [merchant_fee_amount] FLOAT,
  [tax_free] INTEGER,
  [coupons_ids] LONGTEXT,
  [is_subscription] INTEGER,
  [is_subscription_recurring] INTEGER,
  [subscription_name] VARCHAR(255),
  [subscription_fee] FLOAT,
  [subscription_period] INTEGER,
  [subscription_interval] INTEGER,
  [subscription_suspend] INTEGER
  ,PRIMARY KEY (type_id));



DROP TABLE va_user_types_settings;
CREATE TABLE va_user_types_settings (
  [type_id] INTEGER NOT NULL,
  [setting_name] VARCHAR(64) NOT NULL,
  [setting_value] VARCHAR(50)
  ,PRIMARY KEY (type_id,setting_name));



DROP TABLE va_users;
CREATE TABLE va_users (
  [user_id]  COUNTER  NOT NULL,
  [user_type_id] INTEGER,
  [is_approved] INTEGER,
  [is_hidden] INTEGER,
  [expiry_date] DATETIME,
  [suspend_date] DATETIME,
  [registration_last_step] INTEGER,
  [registration_total_steps] INTEGER,
  [is_sms_allowed] INTEGER,
  [discount_type] INTEGER,
  [discount_amount] FLOAT,
  [affiliate_commission_type] INTEGER,
  [affiliate_commission_amount] FLOAT,
  [merchant_fee_type] INTEGER,
  [merchant_fee_amount] FLOAT,
  [tax_free] INTEGER,
  [coupons_ids] LONGTEXT,
  [login] VARCHAR(32),
  [password] VARCHAR(32),
  [nickname] VARCHAR(32),
  [affiliate_code] VARCHAR(64),
  [security_question] VARCHAR(255),
  [security_answer] VARCHAR(255),
  [personal_image] VARCHAR(255),
  [short_description] VARCHAR(255),
  [full_description] LONGTEXT,
  [friendly_url] VARCHAR(255),
  [name] VARCHAR(128),
  [first_name] VARCHAR(64),
  [last_name] VARCHAR(64),
  [company_id] INTEGER,
  [company_name] VARCHAR(128),
  [email] VARCHAR(128),
  [address1] VARCHAR(255),
  [address2] VARCHAR(255),
  [city] VARCHAR(128),
  [province] VARCHAR(128),
  [state_code] VARCHAR(8),
  [zip] VARCHAR(16),
  [country_code] VARCHAR(8),
  [phone] VARCHAR(32),
  [daytime_phone] VARCHAR(32),
  [evening_phone] VARCHAR(32),
  [cell_phone] VARCHAR(32),
  [fax] VARCHAR(32),
  [delivery_name] VARCHAR(128),
  [delivery_first_name] VARCHAR(64),
  [delivery_last_name] VARCHAR(64),
  [delivery_company_id] INTEGER,
  [delivery_company_name] VARCHAR(128),
  [delivery_email] VARCHAR(128),
  [delivery_address1] VARCHAR(255),
  [delivery_address2] VARCHAR(255),
  [delivery_city] VARCHAR(128),
  [delivery_province] VARCHAR(128),
  [delivery_state_code] VARCHAR(8),
  [delivery_zip] VARCHAR(16),
  [delivery_country_code] VARCHAR(8),
  [delivery_phone] VARCHAR(32),
  [delivery_daytime_phone] VARCHAR(32),
  [delivery_evening_phone] VARCHAR(32),
  [delivery_cell_phone] VARCHAR(32),
  [delivery_fax] VARCHAR(32),
  [paypal_account] VARCHAR(128),
  [msn_account] VARCHAR(128),
  [icq_number] VARCHAR(32),
  [user_site_url] VARCHAR(255),
  [tax_id] VARCHAR(128),
  [birth_year] INTEGER,
  [birth_month] INTEGER,
  [birth_day] INTEGER,
  [registration_ip] VARCHAR(32),
  [registration_date] DATETIME,
  [modified_ip] VARCHAR(32),
  [modified_date] DATETIME,
  [admin_modified_ip] VARCHAR(32),
  [admin_modified_date] DATETIME,
  [last_logged_ip] VARCHAR(32),
  [last_logged_date] DATETIME,
  [last_visit_ip] VARCHAR(32),
  [last_visit_page] VARCHAR(255),
  [last_visit_date] DATETIME,
  [reset_password_code] VARCHAR(64),
  [reset_password_date] DATETIME
  ,PRIMARY KEY (user_id));

CREATE INDEX va_users_affiliate_code ON va_users (affiliate_code);
CREATE INDEX va_users_company_id ON va_users (company_id);
CREATE INDEX va_users_delivery_company_id ON va_users (delivery_company_id);
CREATE INDEX va_users_email ON va_users (email);
CREATE INDEX va_users_first_name ON va_users (first_name);
CREATE INDEX va_users_last_name ON va_users (last_name);
CREATE INDEX va_users_last_visit_date ON va_users (last_visit_date);
CREATE INDEX va_users_login ON va_users (login);
CREATE INDEX va_users_name ON va_users (name);
CREATE INDEX va_users_nickname ON va_users (nickname);
CREATE INDEX va_users_password ON va_users (password);
CREATE INDEX va_users_reset_password_code ON va_users (reset_password_code);


DROP TABLE va_users_commissions;
CREATE TABLE va_users_commissions (
  [commission_id]  COUNTER  NOT NULL,
  [payment_id] INTEGER,
  [user_id] INTEGER,
  [order_id] INTEGER,
  [order_item_id] INTEGER,
  [commission_amount] FLOAT,
  [commission_action] INTEGER,
  [commission_type] INTEGER,
  [date_added] DATETIME
  ,PRIMARY KEY (commission_id));

CREATE INDEX va_users_commissions_date_added ON va_users_commissions (date_added);
CREATE INDEX va_users_commissions_order_id ON va_users_commissions (order_id);
CREATE INDEX va_users_commissions_order__64 ON va_users_commissions (order_item_id);
CREATE INDEX va_users_commissions_payment_id ON va_users_commissions (payment_id);
CREATE INDEX va_users_commissions_user_id ON va_users_commissions (user_id);


DROP TABLE va_users_files;
CREATE TABLE va_users_files (
  [file_id]  COUNTER  NOT NULL,
  [user_id] INTEGER,
  [file_type] VARCHAR(32),
  [file_name] VARCHAR(255),
  [file_path] VARCHAR(255)
  ,PRIMARY KEY (file_id));

CREATE INDEX va_users_files_user_id ON va_users_files (user_id);


DROP TABLE va_users_payments;
CREATE TABLE va_users_payments (
  [payment_id]  COUNTER  NOT NULL,
  [user_id] INTEGER,
  [is_paid] INTEGER,
  [transaction_id] VARCHAR(128),
  [payment_total] FLOAT,
  [payment_name] VARCHAR(255),
  [payment_notes] LONGTEXT,
  [date_added] DATETIME,
  [date_modified] DATETIME,
  [date_paid] DATETIME,
  [admin_id_added_by] INTEGER,
  [admin_id_modified_by] INTEGER
  ,PRIMARY KEY (payment_id));

CREATE INDEX va_users_payments_date_paid ON va_users_payments (date_paid);
CREATE INDEX va_users_payments_is_paid ON va_users_payments (is_paid);
CREATE INDEX va_users_payments_user_id ON va_users_payments (user_id);


DROP TABLE va_users_properties;
CREATE TABLE va_users_properties (
  [user_property_id]  COUNTER  NOT NULL,
  [user_id] INTEGER,
  [property_id] INTEGER,
  [property_value] LONGTEXT
  ,PRIMARY KEY (user_property_id));

CREATE INDEX va_users_properties_order_id ON va_users_properties (user_id);
CREATE INDEX va_users_properties_property_id ON va_users_properties (property_id);

 UPDATE va_global_settings SET setting_value=1 WHERE setting_type='global' AND setting_name='layout_id';

INSERT INTO [va_admin_privileges] ([privilege_id],[is_hidden],[support_privilege],[privilege_name]) VALUES (1 , NULL , 0 , 'Administrator' ) ;
INSERT INTO [va_admin_privileges] ([privilege_id],[is_hidden],[support_privilege],[privilege_name]) VALUES (2 , NULL , 1 , 'HelpDesk Manager' ) ;


INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'add_admins' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'add_payments' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'add_users' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'admin_users' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'admins_groups' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'admins_hidden' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'admins_login' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'ads' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'articles' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'banned_contents' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'banners' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'black_ips' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'coupons' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'create_orders' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'custom_blocks' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'db_management' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'export_payments' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'export_users' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'filemanager' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'forum' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'import_export' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'import_users' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'layouts' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'manual' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'manufacturers' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'newsletter' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'order_confirmation' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'order_links' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'order_notes' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'order_payment' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'order_profile' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'order_serials' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'order_statuses' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'order_vouchers' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'orders_stats' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'payment_systems' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'polls' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'product_types' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'products_categories' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'products_reviews' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'remove_admins' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'remove_orders' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'remove_payments' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'remove_users' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'sales_orders' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'shipping_methods' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'shipping_rules' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'shipping_times' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'site_settings' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'site_users' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'static_messages' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'static_tables' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'support' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'support_departments' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'support_predefined_reply' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'support_settings' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'support_static_data' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'support_ticket_close' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'support_ticket_edit' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'support_ticket_new' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'support_ticket_reply' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'support_users' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'support_users_priorities' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'support_users_stats' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'tax_rates' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'update_admins' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'update_orders' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'update_payments' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'update_users' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'users_forgot' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'users_groups' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'users_login' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'users_payments' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'visits_report' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (1 , 'web_pages' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'admin_users' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'ads' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'articles' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'banners' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'coupons' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'custom_blocks' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'filemanager' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'forum' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'import_export' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'layouts' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'newsletter' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'order_confirmation' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'order_links' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'order_notes' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'order_profile' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'order_serials' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'order_statuses' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'order_vouchers' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'orders_stats' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'payment_systems' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'polls' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'products_categories' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'products_reviews' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'remove_orders' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'sales_orders' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'site_settings' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'site_users' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'static_messages' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'static_tables' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'support' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'support_departments' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'support_predefined_reply' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'support_settings' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'support_static_data' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'support_ticket_close' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'support_ticket_edit' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'support_ticket_new' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'support_ticket_reply' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'support_users' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'support_users_priorities' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'support_users_stats' , 1 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'tax_rates' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'update_orders' , 0 ) ;
INSERT INTO [va_admin_privileges_settings] ([privilege_id],[block_name],[permission]) VALUES (2 , 'web_pages' , 0 ) ;


INSERT INTO [va_admins] ([admin_id],[admin_name],[nickname],[admin_alias],[privilege_id],[is_hidden],[email],[login],[password],[personal_image],[signature],[last_order_id],[exported_order_id],[exported_order_fields],[last_user_id],[exported_user_id],[exported_user_fields],[imported_user_fields],[exported_item_fields],[imported_item_fields],[edited_item_fields],[last_visit_date],[is_generate_big_image],[is_generate_small_image]) VALUES (1 , 'Site Administrator' , 'admin' , 'SA' , 1 , 0 , 'admin@yoursite.com' , 'admin' , 'admin' , NULL , NULL , NULL , NULL , NULL , 1 , NULL , NULL , NULL , 'i.item_id,i.item_name,i.item_order,i.buying_price,i.features,csv_delimiter,csv_delimiter,related_delimiterrelated_delimiter' , NULL , NULL , NULL , 0 , 0 ) ;




INSERT INTO [va_ads_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[allowed_view],[allowed_post],[short_description],[full_description],[image_small],[image_large],[total_views],[total_ads],[total_subcategories]) VALUES (1 , NULL , 0 , 0 , '0,' , 'Books' , NULL , 1 , 1 , 1 , NULL , NULL , 'images/categories/books.gif' , NULL , NULL , 0 , 0 ) ;
INSERT INTO [va_ads_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[allowed_view],[allowed_post],[short_description],[full_description],[image_small],[image_large],[total_views],[total_ads],[total_subcategories]) VALUES (2 , NULL , 0 , 0 , '0,' , 'Electronics ' , NULL , 2 , 1 , 1 , NULL , NULL , 'images/categories/electronics.gif' , NULL , NULL , 0 , 0 ) ;
INSERT INTO [va_ads_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[allowed_view],[allowed_post],[short_description],[full_description],[image_small],[image_large],[total_views],[total_ads],[total_subcategories]) VALUES (3 , NULL , 0 , 0 , '0,' , 'Computers' , NULL , 3 , 1 , 1 , NULL , NULL , 'images/categories/computers.gif' , NULL , NULL , 0 , 0 ) ;






INSERT INTO [va_ads_features_groups] ([group_id],[group_order],[group_name]) VALUES (1 , 1 , 'General' ) ;
INSERT INTO [va_ads_features_groups] ([group_id],[group_order],[group_name]) VALUES (2 , 2 , 'Sizes' ) ;
INSERT INTO [va_ads_features_groups] ([group_id],[group_order],[group_name]) VALUES (3 , 3 , 'Accessories' ) ;










INSERT INTO [va_ads_types] ([type_id],[type_name]) VALUES (1 , 'Product' ) ;
INSERT INTO [va_ads_types] ([type_id],[type_name]) VALUES (2 , 'Accessory' ) ;




INSERT INTO [va_articles] ([article_id],[language_code],[article_date],[date_end],[article_title],[friendly_url],[article_template],[article_order],[author_name],[author_email],[author_url],[author_remote_address],[created_user_id],[created_admin_id],[updated_user_id],[updated_admin_id],[status_id],[is_html],[allowed_rate],[is_hot],[link_url],[download_url],[is_link_direct],[date_added],[date_updated],[keywords],[hot_description],[short_description],[full_description],[notes],[total_views],[total_votes],[total_points],[rating],[total_clicks],[image_small],[image_small_alt],[image_large],[image_large_alt],[meta_title],[meta_keywords],[meta_description]) VALUES (1 , NULL , '2005-06-10 15:06:00' , NULL , 'Tropical storm watch posted as Arlene moves north' , NULL , NULL , 1 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , NULL , NULL , NULL , NULL , '06.09.2005 18:28:32' , NULL , 'MIAMI, Florida (AP) -- A tropical storm watch was issued Friday for central Louisiana to the Florida Panhandle, where residents are still recovering from last year''s hurricanes' , 'MIAMI, Florida (AP) -- A tropical storm watch was issued Friday for central Louisiana to the Florida Panhandle, where residents are still recovering from last year''s hurricanes' , 'Arlene, the Atlantic hurricane season''s first named tropical storm, was centered about 10 miles south-southeast of the western tip of Cuba at 5 a.m. EDT. It was moving north about 8 mph, and could cross near or over western Cuba as it moved into the Gulf of Mexico, forecasters said.\r\n\r\nWind and rain extended 140 miles to the north and east from the storm''s center.\r\n\r\nArlene had maximum sustained winds of 45 mph. The storm could drop as much as 5 to 10 inches of rain, and possibly cause flooding in western Cuba and tornados in southwest Florida and the Florida Keys, meteorologists said.\r\n\r\n"This is going to be a major rainfall event before and ahead of the storm," said Trisha Wallace, a meteorologist at the National Hurricane Center in Miami.\r\n\r\nThe Cuban government issued a tropical storm warning for the western province of Pinar Del Rio to the capital of Havana. A tropical storm warning was also in effect for the Dry Tortugas, a cluster of islands about 70 miles west of Key West that comprise a U.S. national park. Other than park personnel, there are no permanent residents.\r\n\r\nThe storm was not expected to develop into a hurricane before making landfall, Wallace said.\r\n\r\nHurricane season began June 1 and ends November 30. Last season, Florida was struck by hurricanes Charley, Frances, Ivan and Jeanne; between them, the four storms damaged one out of every five homes in the state. The storms caused about 130 deaths in the United States and are blamed for $22 billion in insured damage.\r\n\r\n' , NULL , 0 , 1 , 4 , 4 , 0 , 'images/big/story3.jpg' , NULL , 'images/big/story3.jpg' , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_articles] ([article_id],[language_code],[article_date],[date_end],[article_title],[friendly_url],[article_template],[article_order],[author_name],[author_email],[author_url],[author_remote_address],[created_user_id],[created_admin_id],[updated_user_id],[updated_admin_id],[status_id],[is_html],[allowed_rate],[is_hot],[link_url],[download_url],[is_link_direct],[date_added],[date_updated],[keywords],[hot_description],[short_description],[full_description],[notes],[total_views],[total_votes],[total_points],[rating],[total_clicks],[image_small],[image_small_alt],[image_large],[image_large_alt],[meta_title],[meta_keywords],[meta_description]) VALUES (2 , NULL , '2005-06-10 15:10:00' , NULL , 'Bolivia names new president' , NULL , NULL , 2 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , NULL , NULL , NULL , NULL , '21.09.2005 14:09:13' , NULL , '(CNN) -- The head of Bolivia''s Supreme Court -- Eduardo Rodriguez -- has been sworn in as interim president to succeed the outgoing Carlos Mesa.' , '(CNN) -- The head of Bolivia''s Supreme Court -- Eduardo Rodriguez -- has been sworn in as interim president to succeed the outgoing Carlos Mesa.' , 'Mesa offered to resign after weeks of crippling street protests that threatened to paralyze the South American country. Troops shot and killed a protester on Thursday.\r\n\r\nThe job of interim president automatically went to Rodriguez after two congressional leaders, who were first and second in line for the post, turned it down.\r\n\r\nElections are expected in the next three to six months. Mesa''s term was to have ended in August 2007. \r\n\r\nCongressional lawmakers met in an emergency session in the historic colonial capital of Sucre Thursday to accept Mesa''s resignation and swear in Rodriguez.\r\n\r\nProtests earlier forced Congress to suspend proceedings as the armed forces chief threatened military intervention. \r\n\r\nHundreds of miners and farmers clashed with riot police outside the whitewashed hall where the session was to have been held.\r\n\r\nThe naming of an interim president meets the protesters'' demand that Mesa step down.\r\n\r\nBut other issues, such as the nationalization of the oil and gas industry and the formation of a new constituent assembly to rewrite the constitution, were still unmet, journalist Noah Rudovsky told CNN.\r\n\r\nHe said it was unclear whether demonstrations would continue. \r\n\r\nWeeks of blockade have nearly paralyzed the capital of La Paz where nearly two million residents live, with gas stations closed, supermarkets empty and drinking water scarce.\r\n\r\n"I think his [the new president''s] job at this point mainly is to bring the nation together if he can to bring an end to the roadblock and to pave the way for a peaceful election within the next three to six months," Rudovsky said.\r\n\r\nThe protesters -- largely members of the country''s Indian population -- also seek a more even distribution of wealth.\r\n\r\nBolivia, with a population of 9 million, has long been one of South America''s poorest countries and a major recipient of international aid.\r\n\r\nThe protests grew after Bolivia''s Congress moved last month to raise taxes on foreign oil companies that have flocked to the country to develop its natural gas reserves -- the second largest in South America after Venezuela.\r\n\r\nThe measure was intended to calm street tensions, but it only unleashed new street protests in a nation where anti-globalization anger is high.\r\n\r\nMesa took office in October 2003 when a bloody popular revolt over free-market economic policies forced his predecessor, former president Gonzalo Sanchez de Lozada, to flee the country.\r\n\r\nBolivia has a history of unrest. \r\n\r\nSince breaking away from Spanish rule in 1825, it has been beset by nearly 200 coups and counter-coups.\r\n\r\n' , NULL , 0 , 1 , 5 , 5 , 0 , 'images/big/story1.jpg' , NULL , 'images/big/story1.jpg' , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_articles] ([article_id],[language_code],[article_date],[date_end],[article_title],[friendly_url],[article_template],[article_order],[author_name],[author_email],[author_url],[author_remote_address],[created_user_id],[created_admin_id],[updated_user_id],[updated_admin_id],[status_id],[is_html],[allowed_rate],[is_hot],[link_url],[download_url],[is_link_direct],[date_added],[date_updated],[keywords],[hot_description],[short_description],[full_description],[notes],[total_views],[total_votes],[total_points],[rating],[total_clicks],[image_small],[image_small_alt],[image_large],[image_large_alt],[meta_title],[meta_keywords],[meta_description]) VALUES (3 , NULL , '2005-06-10 15:12:00' , NULL , 'Hopes raised of Africa debt deal' , NULL , NULL , 3 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , NULL , NULL , NULL , NULL , '21.09.2005 14:09:22' , NULL , 'LONDON, England -- Hopes of an accord on debt relief for poor African nations were raised Friday with reports of an agreement between the United States and Britain on writing off $16.7 billion owed by 18 countries.' , 'LONDON, England -- Hopes of an accord on debt relief for poor African nations were raised Friday with reports of an agreement between the United States and Britain on writing off $16.7 billion owed by 18 countries.' , 'British officials said they were confident the world''s most powerful financial ministers would reach a historic deal at their meeting in London this weekend -- although some differences remain between the Group of Eight (G8) major industrialized nations.\r\n\r\nWith the deadline of the G8 summit in Gleneagles, Scotland, just a month away, finance ministers meeting in London on Friday and Saturday were trying to find common ground.\r\n\r\nIn addition to the United States and Britain, the G8 nations include France, Germany, Italy, Canada, Japan and Russia. \r\n\r\nUK Prime Minister Tony Blair -- current G8 president -- has demanded that poor countries'' debts be cancelled and their aid doubled. He and U.S. President George W. Bush agreed this week in Washington that help on debt should be given only to countries ready to tackle corruption. \r\n\r\nThe New York Times reported that the United States and Britain had reached an agreement on freeing 18 countries, mostly in Africa, from any obligation to pay $16.7 billion in debt.\r\n\r\nThe countries are Benin, Bolivia, Burkina Faso, Ethiopia, Ghana, Guyana, Honduras, Madagascar, Mali, Mauritania, Mozambique, Nicaragua, Niger, Rwanda, Senegal, Tanzania, Uganda and Zambia.\r\n\r\nA significant omission from the list is Nigeria, whose external debt is put at $36 billion. Nigerian President Olusegun Obasanjo was in London this week for talks with Blair.\r\n\r\nThe number of countries to be helped is a sticking point. Blair''s spokesman said earlier this week that about 25 countries would benefit, while charities say 62 countries need urgent debt relief.\r\n\r\nFrance, Germany and Japan have their own proposal that would mean debt relief for only five countries.\r\n\r\nThe New York Times Friday quoted a senior official as saying that U.S. Treasury Secretary John Snow and his British counterpart, Chancellor of the Exchequer Gordon Brown, would present their proposal to a meeting of the finance ministers of seven of the G8 nations on Friday in London.\r\n\r\nThe debts would be written off by the lenders in an effort to allow the debtor countries to start fresh, get their books in order and eventually be able to borrow again for economic development, health, education and social programs, rather than simply to repay existing loans. \r\n\r\nBush had signaled his willingness to go along with writing off the debts in principle, but the United States and Britain had very different approaches to how such a plan would work, the newspaper said.\r\n\r\nBritain wanted the rich nations to take over responsibility for repaying the debts. but Washington wants the loans to be written off entirely by the lenders, the Times said.\r\n\r\nIn the end, said the paper, Britain agreed to the U.S. approach with a promise from Washington to provide additional money to the lenders to make up for the assets they were writing off. \r\n\r\nSub-Saharan Africa has $230 billion in external debt and pays $12 billion a year on servicing the loans, according to the most recent figures from the World Bank, Reuters reported. \r\n\r\nA third of the debt is owed to multilateral lenders like the International Monetary Fund. Britain has said that without 100 percent multilateral debt relief, the poorest countries would pay up to $27.5 billion in principal and interest payments to international organizations between now and 2015. \r\n\r\n"President Bush and Prime Minister Blair made great progress and Gordon Brown and John Snow agreed on an excellent proposal for debt cancellation for many of the poorest countries," Jamie Drummond of DATA, a lobbying group founded by rock star Bono, told The New York Times.\r\n\r\nBono joined European Commission President Jose Manuel Barroso Thursday in an appeal to government leaders to double development aid to Africa and other poor regions over the next 10 years. (Full story)\r\n\r\n"It is no substitute for an overall plan on aid and trade at the G8 summit, but this degree of cooperation should make a historic breakthrough more likely," Drummond said.\r\n\r\nAll of the countries eligible for debt relief have had to show that they have acted to improve governing, ' , NULL , 0 , 0 , 0 , 0 , 0 , 'images/big/story2.jpg' , NULL , 'images/big/story2.jpg' , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_articles] ([article_id],[language_code],[article_date],[date_end],[article_title],[friendly_url],[article_template],[article_order],[author_name],[author_email],[author_url],[author_remote_address],[created_user_id],[created_admin_id],[updated_user_id],[updated_admin_id],[status_id],[is_html],[allowed_rate],[is_hot],[link_url],[download_url],[is_link_direct],[date_added],[date_updated],[keywords],[hot_description],[short_description],[full_description],[notes],[total_views],[total_votes],[total_points],[rating],[total_clicks],[image_small],[image_small_alt],[image_large],[image_large_alt],[meta_title],[meta_keywords],[meta_description]) VALUES (4 , NULL , '2005-06-10 15:20:00' , NULL , 'Brian Johnston' , NULL , NULL , 4 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 1 , NULL , NULL , NULL , NULL , '21.09.2005 13:43:52' , NULL , 'On 16 May 1994, more than 2,000 people crammed into Westminster Abbey to give thanks for the life of a cricket commentator. \r\n\r\nThe then Prime Minister John Major gave an address, two Guardsmen played on fife and drum and the Abbey organ ended proceedings with the theme from Neighbours. \r\n' , 'On 16 May 1994, more than 2,000 people crammed into Westminster Abbey to give thanks for the life of a cricket commentator. \r\n\r\nThe then Prime Minister John Major gave an address, two Guardsmen played on fife and drum and the Abbey organ ended proceedings with the theme from Neighbours. \r\n\r\n' , 'On 16 May 1994, more than 2,000 people crammed into Westminster Abbey to give thanks for the life of a cricket commentator. \r\n\r\nThe then Prime Minister John Major gave an address, two Guardsmen played on fife and drum and the Abbey organ ended proceedings with the theme from Neighbours. \r\n\r\nBrian Johnston was, of course, much more than just a cricket commentator - he was a national institution. \r\n\r\nHe joined the BBC in 1946 after wartime service in the Guards and before that in the family coffee business. \r\n\r\nHe was naturally suited to the ad lib life of radio outside broadcasting and in his early days undertook a variety of assignments in the days when anything outside a studio was something of a novelty. \r\n\r\nJohnston''s first job was to cover the disposal of a bomb discovered in Hyde Park, which he covered from the apparent safety of a ladies'' lavatory. \r\n\r\nHis propensity for awful puns produced the line that he emerged "looking a bit flushed". \r\n\r\nSuch occasions led to his own live spot - Let''s Go Somewhere - on In Town Tonight. \r\n\r\nThe highlights included him riding bareback in the circus, reporting from beneath an express train and from inside a post box at Christmas. \r\n\r\nHis career as a cricket commentator actually began on television. \r\n\r\nHe did not cross to Test Match Special until 1970, when television unceremoniously dropped him in a change of policy, recruiting only former players. \r\n\r\nThe lack of any word from television rankled Brian for the rest of his life, but his arrival at Test Match Special was a true homecoming. \r\n\r\n  Brian would say TMS was "just a bunch of friends going to a Test Match and talking about it" \r\n\r\nPeter Baxter on Johnners  \r\nHis informal style was a complete contrast to John Arlott, but his natural popular appeal brought a new audience to the programme and gave it a new lease of life. \r\n\r\nHe was by this time the BBC''s first cricket correspondent, having made a huge impact while on extended leave in Australia to watch England play in 1958/9. \r\n\r\nThereafter, he was to accompany England tours round the world until his retirement in 1972. \r\n\r\nHowever, retirement from the BBC staff did not end his involvement with Test Match Special. \r\n\r\nIn fact, he was still an integral part of the commentary team at his death in January 1994 at the age of 81. \r\n\r\nEveryone was given a nickname. Scorer Bill Findall became ''the Bearded Wonder''. And to this day, Henry Blofeld and Jonathan Agnew are fondly known as Blowers and Aggers. \r\n\r\nLaughter was never far away with Brian and he will inevitably be remembered for the so-called "leg-over" incident. \r\n\r\n  The famous "leg over" clip from 1991  \r\nDuring the summary of a day''s play at the Oval, Aggers suggested that Ian Botham, in being out hit wicket had failed to "get his leg over." \r\n\r\nBrian fought the giggles manfully for almost half a minute and then dissolved, wheezing helplessly into a large spotted handkerchief. \r\n\r\nWhen asked about Test Match Special, Brian would say that it was "just a bunch of friends going to a Test Match and talking about it." \r\n\r\nAnd with him, it was. \r\n\r\n' , NULL , 0 , 1 , 5 , 5 , 0 , 'images/big/story4.jpg' , NULL , 'images/big/story4.jpg' , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_articles] ([article_id],[language_code],[article_date],[date_end],[article_title],[friendly_url],[article_template],[article_order],[author_name],[author_email],[author_url],[author_remote_address],[created_user_id],[created_admin_id],[updated_user_id],[updated_admin_id],[status_id],[is_html],[allowed_rate],[is_hot],[link_url],[download_url],[is_link_direct],[date_added],[date_updated],[keywords],[hot_description],[short_description],[full_description],[notes],[total_views],[total_votes],[total_points],[rating],[total_clicks],[image_small],[image_small_alt],[image_large],[image_large_alt],[meta_title],[meta_keywords],[meta_description]) VALUES (5 , NULL , '2005-06-10 15:25:00' , NULL , 'Image 1' , NULL , NULL , 1 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 1 , NULL , NULL , NULL , NULL , '07.09.2005 11:46:56' , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 0 , 0 , 'images/big/story1.jpg' , NULL , 'images/big/story1.jpg' , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_articles] ([article_id],[language_code],[article_date],[date_end],[article_title],[friendly_url],[article_template],[article_order],[author_name],[author_email],[author_url],[author_remote_address],[created_user_id],[created_admin_id],[updated_user_id],[updated_admin_id],[status_id],[is_html],[allowed_rate],[is_hot],[link_url],[download_url],[is_link_direct],[date_added],[date_updated],[keywords],[hot_description],[short_description],[full_description],[notes],[total_views],[total_votes],[total_points],[rating],[total_clicks],[image_small],[image_small_alt],[image_large],[image_large_alt],[meta_title],[meta_keywords],[meta_description]) VALUES (6 , NULL , '2005-06-10 15:26:00' , NULL , 'Image 2' , NULL , NULL , 2 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 1 , NULL , NULL , NULL , NULL , '07.09.2005 11:47:13' , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 0 , 0 , 'images/big/story2.jpg' , NULL , 'images/big/story2.jpg' , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_articles] ([article_id],[language_code],[article_date],[date_end],[article_title],[friendly_url],[article_template],[article_order],[author_name],[author_email],[author_url],[author_remote_address],[created_user_id],[created_admin_id],[updated_user_id],[updated_admin_id],[status_id],[is_html],[allowed_rate],[is_hot],[link_url],[download_url],[is_link_direct],[date_added],[date_updated],[keywords],[hot_description],[short_description],[full_description],[notes],[total_views],[total_votes],[total_points],[rating],[total_clicks],[image_small],[image_small_alt],[image_large],[image_large_alt],[meta_title],[meta_keywords],[meta_description]) VALUES (7 , NULL , '2005-06-10 15:27:00' , NULL , 'Image 3' , NULL , NULL , 3 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , NULL , NULL , NULL , '10.06.2005 15:27:42' , '10.06.2005 15:27:42' , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 0 , 0 , 'images/big/story3.jpg' , NULL , 'images/big/story3.jpg' , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_articles] ([article_id],[language_code],[article_date],[date_end],[article_title],[friendly_url],[article_template],[article_order],[author_name],[author_email],[author_url],[author_remote_address],[created_user_id],[created_admin_id],[updated_user_id],[updated_admin_id],[status_id],[is_html],[allowed_rate],[is_hot],[link_url],[download_url],[is_link_direct],[date_added],[date_updated],[keywords],[hot_description],[short_description],[full_description],[notes],[total_views],[total_votes],[total_points],[rating],[total_clicks],[image_small],[image_small_alt],[image_large],[image_large_alt],[meta_title],[meta_keywords],[meta_description]) VALUES (8 , NULL , '2005-06-10 15:27:00' , NULL , 'Image 4' , NULL , NULL , 4 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , NULL , NULL , NULL , '10.06.2005 15:28:04' , '10.06.2005 15:28:04' , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 0 , 0 , 'images/big/story4.jpg' , NULL , 'images/big/story4.jpg' , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_articles] ([article_id],[language_code],[article_date],[date_end],[article_title],[friendly_url],[article_template],[article_order],[author_name],[author_email],[author_url],[author_remote_address],[created_user_id],[created_admin_id],[updated_user_id],[updated_admin_id],[status_id],[is_html],[allowed_rate],[is_hot],[link_url],[download_url],[is_link_direct],[date_added],[date_updated],[keywords],[hot_description],[short_description],[full_description],[notes],[total_views],[total_votes],[total_points],[rating],[total_clicks],[image_small],[image_small_alt],[image_large],[image_large_alt],[meta_title],[meta_keywords],[meta_description]) VALUES (9 , NULL , '2005-06-10 15:55:45' , NULL , 'ACHUKA' , NULL , NULL , 1 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , 'http://www.achuka.co.uk/' , NULL , NULL , NULL , '10.06.2005 15:55:45' , NULL , NULL , NULL , 'Children''s books UK. Independent site with reviews, interviews, news and articles' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_articles] ([article_id],[language_code],[article_date],[date_end],[article_title],[friendly_url],[article_template],[article_order],[author_name],[author_email],[author_url],[author_remote_address],[created_user_id],[created_admin_id],[updated_user_id],[updated_admin_id],[status_id],[is_html],[allowed_rate],[is_hot],[link_url],[download_url],[is_link_direct],[date_added],[date_updated],[keywords],[hot_description],[short_description],[full_description],[notes],[total_views],[total_votes],[total_points],[rating],[total_clicks],[image_small],[image_small_alt],[image_large],[image_large_alt],[meta_title],[meta_keywords],[meta_description]) VALUES (10 , NULL , '2005-06-10 15:56:05' , NULL , 'Ancient Paths' , NULL , NULL , 2 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , 'http://www.literatureclassics.com/ancientpaths/litweb.html' , NULL , NULL , '10.06.2005 15:56:05' , '10.06.2005 15:56:05' , NULL , NULL , NULL , 'Various resources, criticism and research including an annotated timeline of English literature and the historical events shaping it.' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_articles] ([article_id],[language_code],[article_date],[date_end],[article_title],[friendly_url],[article_template],[article_order],[author_name],[author_email],[author_url],[author_remote_address],[created_user_id],[created_admin_id],[updated_user_id],[updated_admin_id],[status_id],[is_html],[allowed_rate],[is_hot],[link_url],[download_url],[is_link_direct],[date_added],[date_updated],[keywords],[hot_description],[short_description],[full_description],[notes],[total_views],[total_votes],[total_points],[rating],[total_clicks],[image_small],[image_small_alt],[image_large],[image_large_alt],[meta_title],[meta_keywords],[meta_description]) VALUES (11 , NULL , '2005-06-10 16:04:11' , NULL , 'BookEnds ' , NULL , NULL , 3 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 1 , 'http://www.bookends.co.uk/' , NULL , NULL , NULL , '10.06.2005 16:04:11' , NULL , NULL , NULL , 'News, reviews, short stories, features, trade news and top tens for the book industry' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_articles] ([article_id],[language_code],[article_date],[date_end],[article_title],[friendly_url],[article_template],[article_order],[author_name],[author_email],[author_url],[author_remote_address],[created_user_id],[created_admin_id],[updated_user_id],[updated_admin_id],[status_id],[is_html],[allowed_rate],[is_hot],[link_url],[download_url],[is_link_direct],[date_added],[date_updated],[keywords],[hot_description],[short_description],[full_description],[notes],[total_views],[total_votes],[total_points],[rating],[total_clicks],[image_small],[image_small_alt],[image_large],[image_large_alt],[meta_title],[meta_keywords],[meta_description]) VALUES (12 , NULL , '2005-06-10 15:56:48' , NULL , 'British Poetry 1780-1910 ' , NULL , NULL , 4 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , 'http://etext.lib.virginia.edu/britpo.html' , NULL , NULL , '10.06.2005 15:56:48' , '10.06.2005 15:56:48' , NULL , NULL , NULL , 'A hypertext archive of scholarly editions: Electronic Text Center, University of Virginia. \r\n' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_articles] ([article_id],[language_code],[article_date],[date_end],[article_title],[friendly_url],[article_template],[article_order],[author_name],[author_email],[author_url],[author_remote_address],[created_user_id],[created_admin_id],[updated_user_id],[updated_admin_id],[status_id],[is_html],[allowed_rate],[is_hot],[link_url],[download_url],[is_link_direct],[date_added],[date_updated],[keywords],[hot_description],[short_description],[full_description],[notes],[total_views],[total_votes],[total_points],[rating],[total_clicks],[image_small],[image_small_alt],[image_large],[image_large_alt],[meta_title],[meta_keywords],[meta_description]) VALUES (13 , NULL , '2005-06-10 15:57:49' , NULL , 'Alan De Smet - Role-Playing Games ' , NULL , NULL , 1 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , 'http://www.highprogrammer.com/alan/gaming/' , NULL , NULL , '10.06.2005 15:57:49' , '10.06.2005 15:57:49' , NULL , NULL , NULL , 'A selection of practical tips for game masters and players of any system, information about some Gaming Conventions, and resources for Amber, Dungeons & Dragons, and Shadowrun. \r\n' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_articles] ([article_id],[language_code],[article_date],[date_end],[article_title],[friendly_url],[article_template],[article_order],[author_name],[author_email],[author_url],[author_remote_address],[created_user_id],[created_admin_id],[updated_user_id],[updated_admin_id],[status_id],[is_html],[allowed_rate],[is_hot],[link_url],[download_url],[is_link_direct],[date_added],[date_updated],[keywords],[hot_description],[short_description],[full_description],[notes],[total_views],[total_votes],[total_points],[rating],[total_clicks],[image_small],[image_small_alt],[image_large],[image_large_alt],[meta_title],[meta_keywords],[meta_description]) VALUES (14 , NULL , '2005-06-10 16:04:20' , NULL , 'GameWyrd ' , NULL , NULL , 2 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 1 , 'http://www.gamewyrd.com/' , NULL , NULL , NULL , '10.06.2005 16:04:20' , NULL , NULL , NULL , 'News and reviews with forums and chatrooms' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_articles] ([article_id],[language_code],[article_date],[date_end],[article_title],[friendly_url],[article_template],[article_order],[author_name],[author_email],[author_url],[author_remote_address],[created_user_id],[created_admin_id],[updated_user_id],[updated_admin_id],[status_id],[is_html],[allowed_rate],[is_hot],[link_url],[download_url],[is_link_direct],[date_added],[date_updated],[keywords],[hot_description],[short_description],[full_description],[notes],[total_views],[total_votes],[total_points],[rating],[total_clicks],[image_small],[image_small_alt],[image_large],[image_large_alt],[meta_title],[meta_keywords],[meta_description]) VALUES (15 , NULL , '2005-06-10 15:58:40' , NULL , 'Land of Shadows ' , NULL , NULL , 3 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , 'http://www.shadowlord.co.uk/' , NULL , NULL , '10.06.2005 15:58:40' , '10.06.2005 15:58:40' , NULL , NULL , NULL , 'Short Introduction to Roleplaying. ' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_articles] ([article_id],[language_code],[article_date],[date_end],[article_title],[friendly_url],[article_template],[article_order],[author_name],[author_email],[author_url],[author_remote_address],[created_user_id],[created_admin_id],[updated_user_id],[updated_admin_id],[status_id],[is_html],[allowed_rate],[is_hot],[link_url],[download_url],[is_link_direct],[date_added],[date_updated],[keywords],[hot_description],[short_description],[full_description],[notes],[total_views],[total_votes],[total_points],[rating],[total_clicks],[image_small],[image_small_alt],[image_large],[image_large_alt],[meta_title],[meta_keywords],[meta_description]) VALUES (16 , NULL , '2005-06-10 15:59:41' , NULL , 'Braintrack University Index -' , NULL , NULL , 1 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , 'http://www.braintrack.com/' , NULL , NULL , '10.06.2005 15:59:41' , '10.06.2005 15:59:41' , NULL , NULL , NULL , 'Index to institutions of higher education throughout the world.' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_articles] ([article_id],[language_code],[article_date],[date_end],[article_title],[friendly_url],[article_template],[article_order],[author_name],[author_email],[author_url],[author_remote_address],[created_user_id],[created_admin_id],[updated_user_id],[updated_admin_id],[status_id],[is_html],[allowed_rate],[is_hot],[link_url],[download_url],[is_link_direct],[date_added],[date_updated],[keywords],[hot_description],[short_description],[full_description],[notes],[total_views],[total_votes],[total_points],[rating],[total_clicks],[image_small],[image_small_alt],[image_large],[image_large_alt],[meta_title],[meta_keywords],[meta_description]) VALUES (17 , NULL , '2005-06-10 16:04:28' , NULL , 'College and University Home Pages' , NULL , NULL , 2 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 1 , 'http://www.fjg.com/research.html' , NULL , NULL , NULL , '10.06.2005 16:04:28' , NULL , NULL , NULL , ' College and University Home Pages - Alphabetical Listing ' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_articles] ([article_id],[language_code],[article_date],[date_end],[article_title],[friendly_url],[article_template],[article_order],[author_name],[author_email],[author_url],[author_remote_address],[created_user_id],[created_admin_id],[updated_user_id],[updated_admin_id],[status_id],[is_html],[allowed_rate],[is_hot],[link_url],[download_url],[is_link_direct],[date_added],[date_updated],[keywords],[hot_description],[short_description],[full_description],[notes],[total_views],[total_votes],[total_points],[rating],[total_clicks],[image_small],[image_small_alt],[image_large],[image_large_alt],[meta_title],[meta_keywords],[meta_description]) VALUES (18 , NULL , '2005-06-10 16:00:27' , NULL , 'International Association for Management Education (AACSB) -' , NULL , NULL , 3 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , 'http://www.aacsb.edu/' , NULL , NULL , '10.06.2005 16:00:27' , '10.06.2005 16:00:27' , NULL , NULL , NULL , 'Accrediting agency for bachelor''s, master''s and doctoral degree programs in business administration and accounting' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_articles] ([article_id],[language_code],[article_date],[date_end],[article_title],[friendly_url],[article_template],[article_order],[author_name],[author_email],[author_url],[author_remote_address],[created_user_id],[created_admin_id],[updated_user_id],[updated_admin_id],[status_id],[is_html],[allowed_rate],[is_hot],[link_url],[download_url],[is_link_direct],[date_added],[date_updated],[keywords],[hot_description],[short_description],[full_description],[notes],[total_views],[total_votes],[total_points],[rating],[total_clicks],[image_small],[image_small_alt],[image_large],[image_large_alt],[meta_title],[meta_keywords],[meta_description]) VALUES (19 , NULL , '2005-06-10 17:18:00' , NULL , 'PHP Applications gathering ' , NULL , NULL , 1 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , NULL , NULL , NULL , '10.06.2005 17:18:26' , '10.06.2005 17:18:26' , NULL , NULL , 'The PHP Quebec Conference team is looking for the best software developed with PHP, MySQL and Apache. Each proposal received by April 29th 29 will be will be reviewed by an experts and members of the PHP Quebec community. ' , 'The PHP Quebec Conference team is looking for the best software developed with PHP, MySQL and Apache. Each proposal received by April 29th 29 will be will be reviewed by an experts and members of the PHP Quebec community. \r\n\r\nThe most useful software will be included on the 2005 PHP Quebec Conference CDROM along with over 25 hours of conference which where given by the leaders behind PHP, MySQL and Apache, as well as regional and international experts at the 2005 PHP Quebec conference. ' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_articles] ([article_id],[language_code],[article_date],[date_end],[article_title],[friendly_url],[article_template],[article_order],[author_name],[author_email],[author_url],[author_remote_address],[created_user_id],[created_admin_id],[updated_user_id],[updated_admin_id],[status_id],[is_html],[allowed_rate],[is_hot],[link_url],[download_url],[is_link_direct],[date_added],[date_updated],[keywords],[hot_description],[short_description],[full_description],[notes],[total_views],[total_votes],[total_points],[rating],[total_clicks],[image_small],[image_small_alt],[image_large],[image_large_alt],[meta_title],[meta_keywords],[meta_description]) VALUES (20 , NULL , '2005-06-10 17:18:00' , NULL , 'MySQL, RedHat and other partners started a new campaign against software patents' , NULL , NULL , 2 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , NULL , NULL , NULL , '10.06.2005 17:19:00' , '10.06.2005 17:19:00' , NULL , NULL , 'In order to boost more awareness of the pending software patent issues in the European UnionMySQL, ISP 1&1, RedHat and other partners started a new portal "http://nosoftwarepatents.com". The site is available in 10 different european languages and explains why software patents are bad, and how they might affect you. ' , 'Under the influence of the patent system and big industry lobbyists, the European Union is on the verge of making a huge mistake: to pass a law that would legalize software patents. \r\n\r\nIf that happens, you will pay dearly. Europe''s software industry will fall victim to unscrupulous extortioners. A cartel of large corporations will crush smaller competitors. Consequently, we will all pay more money for less good and less secure software. You personally, your household, your company, your government, all of us. \r\n\r\nYou''ll know when you get the bill. When someone breaks into your computer, reads your E-mails, and steals the password of your bank account. When your computer crashes every day. When spam doesn''t stop. When prices go up and companies shut down. When people lose their jobs. \r\n\r\n"Chances are that patents on software, common practice in the US and on the brink of being legalised in Europe, in fact stifle innovation. Europe could still alter course." \r\nDeutsche Bank Research \r\n\r\nWithout software patents, Europe could save costs, foster innovation, enhance security, and create jobs. Thanks to Linux and other open-source software, Europe has the chance to gain independence from Microsoft and other large American companies. However, if the EU allows software patents, then that''s the beginning of the end for Linux. Not only for Linux. It''s just a prominent example' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_articles] ([article_id],[language_code],[article_date],[date_end],[article_title],[friendly_url],[article_template],[article_order],[author_name],[author_email],[author_url],[author_remote_address],[created_user_id],[created_admin_id],[updated_user_id],[updated_admin_id],[status_id],[is_html],[allowed_rate],[is_hot],[link_url],[download_url],[is_link_direct],[date_added],[date_updated],[keywords],[hot_description],[short_description],[full_description],[notes],[total_views],[total_votes],[total_points],[rating],[total_clicks],[image_small],[image_small_alt],[image_large],[image_large_alt],[meta_title],[meta_keywords],[meta_description]) VALUES (21 , NULL , '2005-06-10 17:19:00' , NULL , 'PHP Quebec 2005: PHP - MySQL - Apache ' , NULL , NULL , 3 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , NULL , NULL , NULL , '10.06.2005 17:19:19' , '10.06.2005 17:19:19' , NULL , NULL , 'PHP Quebec is proud to present an extended conference in Montreal, Quebec, covering the latest innovations in PHP, MySQL and Apache.' , 'PHP Quebec is proud to present an extended conference in Montreal, Quebec, covering the latest innovations in PHP, MySQL and Apache. From March 30th until April 1st, major AMP contributors will talk about Security, Web Services, PHP 5 and great achievements with PHP in North America. The 4 tracks are available at the PHP Quebec site. \r\n\r\nPHP Certification exams by Zend are included with every admission ticket to the conference. The certification center will also provide MySQL and Linux certification from MySQL AB, LPI and Savoir Faire Linux. The examination center is open to everyone. ' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_articles] ([article_id],[language_code],[article_date],[date_end],[article_title],[friendly_url],[article_template],[article_order],[author_name],[author_email],[author_url],[author_remote_address],[created_user_id],[created_admin_id],[updated_user_id],[updated_admin_id],[status_id],[is_html],[allowed_rate],[is_hot],[link_url],[download_url],[is_link_direct],[date_added],[date_updated],[keywords],[hot_description],[short_description],[full_description],[notes],[total_views],[total_votes],[total_points],[rating],[total_clicks],[image_small],[image_small_alt],[image_large],[image_large_alt],[meta_title],[meta_keywords],[meta_description]) VALUES (22 , NULL , '2005-06-10 17:27:28' , NULL , 'What is eShopping? ' , NULL , NULL , 1 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , NULL , NULL , NULL , '10.06.2005 17:27:28' , '10.06.2005 17:27:28' , NULL , NULL , NULL , 'eShopping contains sites of which the primary focus is to allow the consumer to select and obtain goods and services over the Web. Common examples include: \r\nIntegrated online shopping-cart systems that allow the user to order directly over the Web \r\nOnline shopping-cart systems that allow the user to generate an order form to be sent to the merchant via fax or snail-mail \r\nSimple directories of products and prices that the user can order via mail or phone. \r\nThe key is that the site contains three elements: lists of products for sale, prices, and information on how the consumer can obtain the product from their own h\r\n' , NULL , 4 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_articles] ([article_id],[language_code],[article_date],[date_end],[article_title],[friendly_url],[article_template],[article_order],[author_name],[author_email],[author_url],[author_remote_address],[created_user_id],[created_admin_id],[updated_user_id],[updated_admin_id],[status_id],[is_html],[allowed_rate],[is_hot],[link_url],[download_url],[is_link_direct],[date_added],[date_updated],[keywords],[hot_description],[short_description],[full_description],[notes],[total_views],[total_votes],[total_points],[rating],[total_clicks],[image_small],[image_small_alt],[image_large],[image_large_alt],[meta_title],[meta_keywords],[meta_description]) VALUES (23 , NULL , '2005-06-10 17:28:21' , NULL , 'How to Shop at Our Online Store?' , NULL , NULL , 2 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , NULL , NULL , NULL , '10.06.2005 17:28:21' , '10.06.2005 17:28:21' , NULL , NULL , NULL , 'Read online help please. See Help Section' , NULL , 3 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_articles] ([article_id],[language_code],[article_date],[date_end],[article_title],[friendly_url],[article_template],[article_order],[author_name],[author_email],[author_url],[author_remote_address],[created_user_id],[created_admin_id],[updated_user_id],[updated_admin_id],[status_id],[is_html],[allowed_rate],[is_hot],[link_url],[download_url],[is_link_direct],[date_added],[date_updated],[keywords],[hot_description],[short_description],[full_description],[notes],[total_views],[total_votes],[total_points],[rating],[total_clicks],[image_small],[image_small_alt],[image_large],[image_large_alt],[meta_title],[meta_keywords],[meta_description]) VALUES (24 , NULL , '2005-06-10 17:29:09' , NULL , 'I''ve received an error message stating that my credit card is invalid. What should I do?' , NULL , NULL , 3 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , NULL , NULL , NULL , '10.06.2005 17:29:09' , '10.06.2005 17:29:09' , NULL , NULL , NULL , 'If you see an error message stating that your credit card is invalid, this has most likely happened for one of the following reasons: \r\n1. You have incorrectly entered your credit card number. \r\n2. You have incorrectly entered your CVV code. \r\n3. You have incorrectly entered your expiration date. \r\n4. You have used a cancelled credit card to place your order. \r\n5. Your card is restricted to point-of-sale transactions only (sales where your card is physically scanned). \r\n\r\nPlease double-check your credit card and/or with your bank to ensure that none of these problems have occurred. If you realize that you''ve made a mistake, simply return to the payment option page and enter in the correct information. Continue checking out as normal. \r\n\r\nIf you''re still encountering problems, please contact us. However, at NO point should you ever e-mail us your full credit card number. Your e-mail does not have the same security features in place as the website. If you wish to reference a specific credit card that you already have on file with us, please reference by the order number.\r\n\r\nIf you believe that you have provided us with an incorrect CVV code or expiration date you may send us that corrected information via e-mail referencing by the order number.\r\n\r\nIf you believe that your card was declined due to insufficient funds, but now have those funds available, you may ask that we attempt to charge your credit card again.\r\n\r\nIf you believe that your card is restricted to point-of-sale transactions, you must either contact your bank about removing such restrictions, provide us with a different credit card, or choose a new payment method.\r\n' , NULL , 2 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_articles] ([article_id],[language_code],[article_date],[date_end],[article_title],[friendly_url],[article_template],[article_order],[author_name],[author_email],[author_url],[author_remote_address],[created_user_id],[created_admin_id],[updated_user_id],[updated_admin_id],[status_id],[is_html],[allowed_rate],[is_hot],[link_url],[download_url],[is_link_direct],[date_added],[date_updated],[keywords],[hot_description],[short_description],[full_description],[notes],[total_views],[total_votes],[total_points],[rating],[total_clicks],[image_small],[image_small_alt],[image_large],[image_large_alt],[meta_title],[meta_keywords],[meta_description]) VALUES (25 , NULL , '2005-06-10 17:29:38' , NULL , 'Why is my online confirmation number different from my order number?' , NULL , NULL , 4 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , NULL , NULL , NULL , '10.06.2005 17:29:38' , '10.06.2005 17:29:38' , NULL , NULL , NULL , 'This is due to the internal process we must maintain to properly track your order through the system. Once an order number is assigned you may use it for all future references to that purchase.' , NULL , 1 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;


INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (1 , 1 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (1 , 15 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (1 , 16 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (1 , 17 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (1 , 18 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (1 , 19 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (1 , 20 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (1 , 21 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (1 , 22 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (1 , 23 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (1 , 24 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (1 , 25 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (1 , 26 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (1 , 27 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (1 , 28 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (1 , 29 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (2 , 1 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (2 , 18 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (2 , 19 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (2 , 21 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (2 , 23 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (2 , 29 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (3 , 1 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (3 , 20 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (3 , 28 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (4 , 1 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (4 , 16 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (4 , 23 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (5 , 5 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (6 , 5 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (7 , 5 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (8 , 5 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (9 , 7 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (10 , 7 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (11 , 7 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (12 , 7 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (13 , 8 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (14 , 8 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (15 , 8 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (16 , 10 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (17 , 10 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (18 , 10 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (19 , 6 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (20 , 6 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (21 , 6 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (22 , 4 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (23 , 4 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (24 , 4 ) ;
INSERT INTO [va_articles_assigned] ([article_id],[category_id]) VALUES (25 , 4 ) ;


INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (1 , NULL , 0 , 0 , '0,' , 'News' , NULL , 10 , NULL , NULL , 'article_date' , 'DESC' , 'article_date,article_title,short_description,image_small' , 'article_date,article_title,full_description,image_large' , 'article_date,article_title' , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 4 , 15 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (3 , NULL , 0 , 0 , '0,' , 'Links' , NULL , 7 , NULL , NULL , NULL , NULL , 'article_title,link_url,full_description' , 'full_description' , 'article_title,link_url' , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 7 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (4 , NULL , 0 , 0 , '0,' , 'FAQ' , NULL , 9 , NULL , NULL , NULL , NULL , 'article_title,full_description,image_small' , 'article_title,full_description,image_large' , 'article_title' , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 4 , 0 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (5 , NULL , 0 , 0 , '0,' , 'Image Gallery' , NULL , 5 , NULL , NULL , NULL , NULL , 'article_date,article_title,short_description,image_small' , 'article_date,article_title,full_description,image_large' , 'article_date,article_title' , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 4 , 0 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (6 , NULL , 0 , 0 , '0,' , 'Events' , NULL , 6 , NULL , NULL , NULL , NULL , 'article_date,article_title,short_description,image_small' , 'article_date,article_title,full_description,image_large' , 'article_date,article_title' , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 3 , 0 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (7 , NULL , 3 , 0 , '0,3,' , 'Arts' , NULL , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 4 , 0 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (8 , NULL , 3 , 0 , '0,3,' , 'Games' , NULL , 2 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 3 , 0 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (10 , NULL , 3 , 0 , '0,3,' , 'Reference' , NULL , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 3 , 0 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (11 , NULL , 3 , 0 , '0,3,' , 'Shopping' , NULL , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (12 , NULL , 3 , 0 , '0,3,' , 'World' , NULL , 6 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (13 , NULL , 3 , 0 , '0,3,' , 'Business' , NULL , 7 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (14 , NULL , 3 , 0 , '0,3,' , 'Computers' , NULL , 8 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (15 , NULL , 1 , 0 , '0,1,' , 'Asia' , NULL , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 0 , 0 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (16 , NULL , 1 , 0 , '0,1,' , 'Europe' , NULL , 2 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (17 , NULL , 1 , 0 , '0,1,' , 'U.S.' , NULL , 3 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (18 , NULL , 1 , 0 , '0,1,' , 'WorldWorld' , NULL , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (19 , NULL , 1 , 0 , '0,1,' , 'Business' , NULL , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (20 , NULL , 1 , 0 , '0,1,' , 'Technology' , NULL , 6 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (21 , NULL , 1 , 0 , '0,1,' , 'Science & Space' , NULL , 7 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (22 , NULL , 1 , 0 , '0,1,' , 'Entertainment' , NULL , 8 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (23 , NULL , 1 , 0 , '0,1,' , 'World Sport' , NULL , 9 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (24 , NULL , 1 , 0 , '0,1,' , 'Travel' , NULL , 10 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (25 , NULL , 1 , 0 , '0,1,' , 'Executive' , NULL , 11 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (26 , NULL , 1 , 0 , '0,1,' , 'Education' , NULL , 12 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (27 , NULL , 1 , 0 , '0,1,' , 'Weather' , NULL , 13 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (28 , NULL , 1 , 0 , '0,1,' , 'Special Reports' , NULL , 14 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (29 , NULL , 1 , 0 , '0,1,' , 'Video' , NULL , 15 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO [va_articles_categories] ([category_id],[language_code],[parent_category_id],[alias_category_id],[category_path],[category_name],[friendly_url],[category_order],[articles_list_template],[articles_details_template],[articles_order_column],[articles_order_direction],[article_list_fields],[article_details_fields],[article_required_fields],[moderators_ids],[is_hot],[allowed_view],[allowed_post],[allowed_rate],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt],[is_rss],[rss_limit],[rss_on_breadcrumb],[rss_on_list],[meta_title],[meta_keywords],[meta_description],[total_views],[total_articles],[total_subcategories]) VALUES (30 , NULL , 0 , 0 , '0,' , 'Knowledge Base' , NULL , 11 , NULL , NULL , 'article_order' , 'ASC' , 'article_date,article_title,short_description' , 'article_date,article_title,full_description' , 'article_date,article_title,full_description' , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 0 , 0 ) ;




INSERT INTO [va_articles_related] ([article_id],[related_id],[related_order]) VALUES (1 , 2 , 1 ) ;
INSERT INTO [va_articles_related] ([article_id],[related_id],[related_order]) VALUES (1 , 3 , 2 ) ;
INSERT INTO [va_articles_related] ([article_id],[related_id],[related_order]) VALUES (2 , 1 , 2 ) ;
INSERT INTO [va_articles_related] ([article_id],[related_id],[related_order]) VALUES (2 , 3 , 1 ) ;
INSERT INTO [va_articles_related] ([article_id],[related_id],[related_order]) VALUES (3 , 1 , 2 ) ;
INSERT INTO [va_articles_related] ([article_id],[related_id],[related_order]) VALUES (3 , 2 , 1 ) ;


INSERT INTO [va_articles_reviews] ([review_id],[article_id],[recommended],[approved],[rating],[summary],[user_name],[remote_address],[date_added],[comments]) VALUES (1 , 1 , 1 , 1 , 4 , NULL , 'Author' , '10.1.1.6' , '2005-06-10 15:21:00' , NULL ) ;
INSERT INTO [va_articles_reviews] ([review_id],[article_id],[recommended],[approved],[rating],[summary],[user_name],[remote_address],[date_added],[comments]) VALUES (2 , 4 , 1 , 1 , 5 , NULL , 'test' , '127.0.0.1' , '2005-09-07 10:30:25' , NULL ) ;
INSERT INTO [va_articles_reviews] ([review_id],[article_id],[recommended],[approved],[rating],[summary],[user_name],[remote_address],[date_added],[comments]) VALUES (3 , 2 , 1 , 1 , 5 , NULL , 'test3' , '127.0.0.1' , '2005-09-07 10:30:52' , NULL ) ;
INSERT INTO [va_articles_reviews] ([review_id],[article_id],[recommended],[approved],[rating],[summary],[user_name],[remote_address],[date_added],[comments]) VALUES (4 , 3 , 1 , 1 , 0 , NULL , 'test2' , '127.0.0.1' , '2005-09-07 10:31:13' , NULL ) ;


INSERT INTO [va_articles_statuses] ([status_id],[status_name],[status_description],[is_shown],[status_icon],[status_style],[allowed_view]) VALUES (1 , 'New' , NULL , 1 , NULL , NULL , 1 ) ;
INSERT INTO [va_articles_statuses] ([status_id],[status_name],[status_description],[is_shown],[status_icon],[status_style],[allowed_view]) VALUES (2 , 'Published' , NULL , 1 , NULL , NULL , 1 ) ;
INSERT INTO [va_articles_statuses] ([status_id],[status_name],[status_description],[is_shown],[status_icon],[status_style],[allowed_view]) VALUES (3 , 'Pending' , NULL , 1 , NULL , NULL , 0 ) ;
INSERT INTO [va_articles_statuses] ([status_id],[status_name],[status_description],[is_shown],[status_icon],[status_style],[allowed_view]) VALUES (4 , 'Hidden' , NULL , 1 , NULL , NULL , 0 ) ;


















INSERT INTO [va_categories] ([category_id],[parent_category_id],[category_path],[category_name],[friendly_url],[category_order],[is_showing],[allowed_post],[show_sub_products],[short_description],[full_description],[image],[image_alt],[image_large],[image_large_alt],[list_template],[details_template],[meta_title],[meta_keywords],[meta_description],[total_views],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (1 , 0 , '0,' , 'Books' , '' , 2 , 1 , 0 , 1 , NULL , NULL , 'images/categories/books.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '2007-02-15 17:29:11' ) ;
INSERT INTO [va_categories] ([category_id],[parent_category_id],[category_path],[category_name],[friendly_url],[category_order],[is_showing],[allowed_post],[show_sub_products],[short_description],[full_description],[image],[image_alt],[image_large],[image_large_alt],[list_template],[details_template],[meta_title],[meta_keywords],[meta_description],[total_views],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (2 , 1 , '0,1,' , 'Arts & Photography' , NULL , 1 , 1 , NULL , NULL , '' , '' , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_categories] ([category_id],[parent_category_id],[category_path],[category_name],[friendly_url],[category_order],[is_showing],[allowed_post],[show_sub_products],[short_description],[full_description],[image],[image_alt],[image_large],[image_large_alt],[list_template],[details_template],[meta_title],[meta_keywords],[meta_description],[total_views],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (5 , 0 , '0,' , 'Music and DVD' , '' , 4 , 1 , 0 , 0 , NULL , NULL , 'images/categories/dvd.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '2007-02-15 17:07:13' ) ;
INSERT INTO [va_categories] ([category_id],[parent_category_id],[category_path],[category_name],[friendly_url],[category_order],[is_showing],[allowed_post],[show_sub_products],[short_description],[full_description],[image],[image_alt],[image_large],[image_large_alt],[list_template],[details_template],[meta_title],[meta_keywords],[meta_description],[total_views],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (8 , 1 , '0,1,' , 'Travel' , NULL , 1 , 1 , NULL , NULL , '' , '' , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_categories] ([category_id],[parent_category_id],[category_path],[category_name],[friendly_url],[category_order],[is_showing],[allowed_post],[show_sub_products],[short_description],[full_description],[image],[image_alt],[image_large],[image_large_alt],[list_template],[details_template],[meta_title],[meta_keywords],[meta_description],[total_views],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (11 , 1 , '0,1,' , 'Science Fiction & Fantasy' , NULL , 1 , 1 , NULL , NULL , '' , '' , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_categories] ([category_id],[parent_category_id],[category_path],[category_name],[friendly_url],[category_order],[is_showing],[allowed_post],[show_sub_products],[short_description],[full_description],[image],[image_alt],[image_large],[image_large_alt],[list_template],[details_template],[meta_title],[meta_keywords],[meta_description],[total_views],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (13 , 0 , '0,' , 'Software' , NULL , 1 , 1 , NULL , NULL , '' , '' , 'images/categories/software.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_categories] ([category_id],[parent_category_id],[category_path],[category_name],[friendly_url],[category_order],[is_showing],[allowed_post],[show_sub_products],[short_description],[full_description],[image],[image_alt],[image_large],[image_large_alt],[list_template],[details_template],[meta_title],[meta_keywords],[meta_description],[total_views],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (35 , 0 , '0,' , 'Computers' , NULL , 11 , 1 , NULL , NULL , '' , '' , 'images/categories/computers.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_categories] ([category_id],[parent_category_id],[category_path],[category_name],[friendly_url],[category_order],[is_showing],[allowed_post],[show_sub_products],[short_description],[full_description],[image],[image_alt],[image_large],[image_large_alt],[list_template],[details_template],[meta_title],[meta_keywords],[meta_description],[total_views],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (43 , 0 , '0,' , 'Cell Phones' , '' , 5 , 1 , 0 , 0 , NULL , NULL , 'images/categories/cellphones.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '2007-02-15 16:58:03' ) ;
INSERT INTO [va_categories] ([category_id],[parent_category_id],[category_path],[category_name],[friendly_url],[category_order],[is_showing],[allowed_post],[show_sub_products],[short_description],[full_description],[image],[image_alt],[image_large],[image_large_alt],[list_template],[details_template],[meta_title],[meta_keywords],[meta_description],[total_views],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (47 , 0 , '0,' , 'Amazon''s Books' , '' , 12 , 1 , 0 , 0 , 'This category shows you how to create an affiliate program with Amazon.com' , 'This category shows you how to create an affiliate program with Amazon.com' , 'images/categories/books.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '2007-02-15 17:35:26' ) ;


INSERT INTO [va_cc_expiry_years] ([expiry_year]) VALUES (2006 ) ;
INSERT INTO [va_cc_expiry_years] ([expiry_year]) VALUES (2007 ) ;
INSERT INTO [va_cc_expiry_years] ([expiry_year]) VALUES (2008 ) ;
INSERT INTO [va_cc_expiry_years] ([expiry_year]) VALUES (2009 ) ;
INSERT INTO [va_cc_expiry_years] ([expiry_year]) VALUES (2010 ) ;
INSERT INTO [va_cc_expiry_years] ([expiry_year]) VALUES (2011 ) ;
INSERT INTO [va_cc_expiry_years] ([expiry_year]) VALUES (2012 ) ;


INSERT INTO [va_cc_start_years] ([start_year]) VALUES (2000 ) ;
INSERT INTO [va_cc_start_years] ([start_year]) VALUES (2001 ) ;
INSERT INTO [va_cc_start_years] ([start_year]) VALUES (2002 ) ;
INSERT INTO [va_cc_start_years] ([start_year]) VALUES (2003 ) ;
INSERT INTO [va_cc_start_years] ([start_year]) VALUES (2004 ) ;
INSERT INTO [va_cc_start_years] ([start_year]) VALUES (2005 ) ;
INSERT INTO [va_cc_start_years] ([start_year]) VALUES (2006 ) ;


INSERT INTO [va_change_types] ([type_id],[type_name]) VALUES (1 , 'Bug' ) ;
INSERT INTO [va_change_types] ([type_id],[type_name]) VALUES (2 , 'New Feature' ) ;




INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('AD' , '020' , 3 , 'Andorra' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('AE' , '784' , 3 , 'United Arab Emirates' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('AF' , '004' , 3 , 'Afghanistan' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('AG' , '028' , 3 , 'Antigua and Barbuda' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('AI' , '660' , 3 , 'Anguilla' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('AL' , '008' , 3 , 'Albania' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('AM' , '051' , 3 , 'Armenia' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('AN' , '530' , 2 , 'Netherlands Antilles' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('AO' , '024' , 3 , 'Angola' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('AQ' , '010' , 3 , 'Antarctica' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('AR' , '032' , 3 , 'Argentina' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('AS' , '016' , 3 , 'American Samoa' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('AT' , '040' , 2 , 'Austria EU' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('AU' , '036' , 3 , 'Australia' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('AW' , '533' , 3 , 'Aruba' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('AX' , '248' , 3 , 'Aland Islands' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('AZ' , '031' , 3 , 'Azerbaijan' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('BA' , '070' , 3 , 'Bosnia and Herzegowina' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('BB' , '052' , 3 , 'Barbados' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('BD' , '050' , 3 , 'Bangladesh' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('BE' , '056' , 2 , 'Belgium EU' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('BF' , '854' , 3 , 'Burkina Faso' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('BG' , '100' , 3 , 'Bulgaria' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('BH' , '048' , 3 , 'Bahrain' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('BI' , '108' , 3 , 'Burundi' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('BJ' , '204' , 3 , 'Benin' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('BM' , '060' , 3 , 'Bermuda' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('BN' , '096' , 3 , 'Brunei Darussalam' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('BO' , '068' , 3 , 'Bolivia' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('BR' , '076' , 3 , 'Brazil' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('BS' , '044' , 3 , 'Bahamas' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('BT' , '064' , 3 , 'Bhutan' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('BV' , '074' , 3 , 'Bouvet Island' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('BW' , '072' , 3 , 'Botswana' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('BY' , '112' , 3 , 'Belarus' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('BZ' , '084' , 3 , 'Belize' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('CA' , '124' , 3 , 'Canada' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('CC' , '166' , 3 , 'Cocos (Keeling) Islands' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('CD' , '180' , 3 , 'Congo, the Democratic Republic of the' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('CF' , '140' , 3 , 'Central African Republic' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('CG' , '178' , 3 , 'Congo' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('CH' , '756' , 3 , 'Switzerland' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('CI' , '384' , 3 , 'Cote D''Ivoire' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('CK' , '184' , 3 , 'Cook Islands' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('CL' , '152' , 3 , 'Chile' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('CM' , '120' , 3 , 'Cameroon' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('CN' , '156' , 3 , 'China' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('CO' , '170' , 3 , 'Colombia' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('CR' , '188' , 3 , 'Costa Rica' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('CS' , '891' , 3 , 'Serbia and Montenegro' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('CU' , '192' , 3 , 'Cuba' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('CV' , '132' , 3 , 'Cape Verde' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('CX' , '162' , 3 , 'Christmas Island' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('CY' , '196' , 2 , 'Cyprus EU' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('CZ' , '203' , 2 , 'Czech Republic EU' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('DE' , '276' , 2 , 'Germany EU' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('DJ' , '262' , 3 , 'Djibouti' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('DK' , '208' , 2 , 'Denmark EU' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('DM' , '212' , 3 , 'Dominica' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('DO' , '214' , 3 , 'Dominican Republic' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('DZ' , '012' , 3 , 'Algeria' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('EC' , '218' , 3 , 'Ecuador' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('EE' , '233' , 2 , 'Estonia EU' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('EG' , '818' , 3 , 'Egypt' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('EH' , '732' , 3 , 'Western Sahara' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('ER' , '232' , 3 , 'Eritrea' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('ES' , '724' , 2 , 'Spain EU' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('ET' , '231' , 3 , 'Ethiopia' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('FI' , '246' , 2 , 'Finland EU' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('FJ' , '242' , 3 , 'Fiji' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('FK' , '238' , 3 , 'Falkland Islands (Malvinas)' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('FM' , '583' , 3 , 'Micronesia, Federated States of' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('FO' , '234' , 3 , 'Faroe Islands' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('FR' , '250' , 2 , 'France EU' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('FX' , '249' , 3 , 'France, Metropolitan' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('GA' , '266' , 3 , 'Gabon' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('GB' , '826' , 1 , 'United Kingdom' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('GD' , '308' , 3 , 'Grenada' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('GE' , '268' , 3 , 'Georgia' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('GF' , '254' , 3 , 'French Guiana' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('GG' , '831' , 3 , 'Guernsey' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('GH' , '288' , 3 , 'Ghana' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('GI' , '292' , 3 , 'Gibraltar' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('GL' , '304' , 3 , 'Greenland' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('GM' , '270' , 3 , 'Gambia' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('GN' , '324' , 3 , 'Guinea' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('GP' , '312' , 3 , 'Guadeloupe' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('GQ' , '226' , 3 , 'Equatorial Guinea' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('GR' , '300' , 2 , 'Greece EU' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('GS' , '239' , 3 , 'South Georgia and the South Sandwich Islands' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('GT' , '320' , 3 , 'Guatemala' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('GU' , '316' , 3 , 'Guam' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('GW' , '624' , 3 , 'Guinea-Bissau' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('GY' , '328' , 3 , 'Guyana' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('HK' , '344' , 3 , 'Hong Kong' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('HM' , '334' , 3 , 'Heard and Mc Donald Islands' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('HN' , '340' , 3 , 'Honduras' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('HR' , '191' , 3 , 'Croatia (local name: Hrvatska)' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('HT' , '332' , 3 , 'Haiti' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('HU' , '348' , 2 , 'Hungary EU' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('ID' , '360' , 3 , 'Indonesia' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('IE' , '372' , 2 , 'Ireland EU' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('IL' , '376' , 3 , 'Israel' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('IM' , '833' , 3 , 'Isle of Man' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('IN' , '356' , 3 , 'India' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('IO' , '086' , 3 , 'British Indian Ocean Territory' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('IQ' , '368' , 3 , 'Iraq' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('IR' , '364' , 3 , 'Iran (Islamic Republic of)' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('IS' , '352' , 3 , 'Iceland' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('IT' , '380' , 2 , 'Italy EU' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('JE' , '832' , 3 , 'Jersey' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('JM' , '388' , 3 , 'Jamaica' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('JO' , '400' , 3 , 'Jordan' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('JP' , '392' , 3 , 'Japan' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('KE' , '404' , 3 , 'Kenya' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('KG' , '417' , 3 , 'Kyrgyzstan' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('KH' , '116' , 3 , 'Cambodia' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('KI' , '296' , 3 , 'Kiribati' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('KM' , '174' , 3 , 'Comoros' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('KN' , '659' , 3 , 'Saint Kitts and Nevis' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('KP' , '408' , 3 , 'Korea, Democratic People''s Republic of' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('KR' , '410' , 3 , 'Korea, Republic of' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('KW' , '414' , 3 , 'Kuwait' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('KY' , '136' , 3 , 'Cayman Islands' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('KZ' , '398' , 3 , 'Kazakhstan' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('LA' , '418' , 3 , 'Lao People''s Democratic Republic' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('LB' , '422' , 3 , 'Lebanon' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('LC' , '662' , 3 , 'Saint Lucia' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('LI' , '438' , 3 , 'Liechtenstein' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('LK' , '144' , 3 , 'Sri Lanka' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('LR' , '430' , 3 , 'Liberia' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('LS' , '426' , 3 , 'Lesotho' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('LT' , '440' , 2 , 'Lithuania EU' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('LU' , '442' , 2 , 'Luxembourg EU' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('LV' , '428' , 2 , 'Latvia EU' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('LY' , '434' , 3 , 'Libyan Arab Jamahiriya' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('MA' , '504' , 3 , 'Morocco' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('MC' , '492' , 2 , 'Monaco' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('MD' , '498' , 3 , 'Moldova, Republic of' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('MG' , '450' , 3 , 'Madagascar' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('MH' , '584' , 3 , 'Marshall Islands' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('MK' , '807' , 3 , 'Macedonia, the former Yugoslav Republic of' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('ML' , '466' , 3 , 'Mali' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('MM' , '104' , 3 , 'Myanmar' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('MN' , '496' , 3 , 'Mongolia' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('MO' , '446' , 3 , 'Macau' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('MP' , '580' , 3 , 'Northern Mariana Islands' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('MQ' , '474' , 3 , 'Martinique' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('MR' , '478' , 3 , 'Mauritania' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('MS' , '500' , 3 , 'Montserrat' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('MT' , '470' , 2 , 'Malta EU' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('MU' , '480' , 3 , 'Mauritius' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('MV' , '462' , 3 , 'Maldives' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('MW' , '454' , 3 , 'Malawi' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('MX' , '484' , 3 , 'Mexico' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('MY' , '458' , 3 , 'Malaysia' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('MZ' , '508' , 3 , 'Mozambique' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('NA' , '516' , 3 , 'Namibia' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('NC' , '540' , 3 , 'New Caledonia' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('NE' , '562' , 3 , 'Niger' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('NF' , '574' , 3 , 'Norfolk Island' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('NG' , '566' , 3 , 'Nigeria' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('NI' , '558' , 3 , 'Nicaragua' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('NL' , '528' , 2 , 'Netherlands EU' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('NO' , '578' , 3 , 'Norway' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('NP' , '524' , 3 , 'Nepal' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('NR' , '520' , 3 , 'Nauru' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('NU' , '570' , 3 , 'Niue' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('NZ' , '554' , 3 , 'New Zealand' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('OM' , '512' , 3 , 'Oman' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('PA' , '591' , 3 , 'Panama' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('PE' , '604' , 3 , 'Peru' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('PF' , '258' , 3 , 'French Polynesia' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('PG' , '598' , 3 , 'Papua New Guinea' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('PH' , '608' , 3 , 'Philippines' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('PK' , '586' , 3 , 'Pakistan' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('PL' , '616' , 2 , 'Poland EU' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('PM' , '666' , 3 , 'St. Pierre and Miquelon' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('PN' , '612' , 3 , 'Pitcairn' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('PR' , '630' , 3 , 'Puerto Rico' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('PS' , '275' , 3 , 'Palestinian Territory, Occupied' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('PT' , '620' , 2 , 'Portugal EU' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('PW' , '585' , 3 , 'Palau' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('PY' , '600' , 3 , 'Paraguay' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('QA' , '634' , 3 , 'Qatar' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('RE' , '638' , 3 , 'Reunion' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('RO' , '642' , 3 , 'Romania' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('RU' , '643' , 3 , 'Russian Federation' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('RW' , '646' , 3 , 'Rwanda' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('SA' , '682' , 3 , 'Saudi Arabia' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('SB' , '090' , 3 , 'Solomon Islands' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('SC' , '690' , 3 , 'Seychelles' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('SD' , '736' , 3 , 'Sudan' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('SE' , '752' , 2 , 'Sweden EU' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('SG' , '702' , 3 , 'Singapore' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('SH' , '654' , 3 , 'St. Helena' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('SI' , '705' , 2 , 'Slovenia EU' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('SJ' , '744' , 3 , 'Svalbard and Jan Mayen Islands' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('SK' , '703' , 2 , 'Slovakia (Slovak Republic) EU' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('SL' , '694' , 3 , 'Sierra Leone' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('SM' , '674' , 3 , 'San Marino' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('SN' , '686' , 3 , 'Senegal' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('SO' , '706' , 3 , 'Somalia' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('SR' , '740' , 3 , 'Suriname' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('ST' , '678' , 3 , 'Sao Tome and Principe' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('SV' , '222' , 3 , 'El Salvador' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('SY' , '760' , 3 , 'Syrian Arab Republic' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('SZ' , '748' , 3 , 'Swaziland' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('TC' , '796' , 3 , 'Turks and Caicos Islands' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('TD' , '148' , 3 , 'Chad' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('TF' , '260' , 3 , 'French Southern Territories' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('TG' , '768' , 3 , 'Togo' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('TH' , '764' , 3 , 'Thailand' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('TJ' , '762' , 3 , 'Tajikistan' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('TK' , '772' , 3 , 'Tokelau' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('TL' , '626' , 3 , 'Timor-Leste' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('TM' , '795' , 3 , 'Turkmenistan' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('TN' , '788' , 3 , 'Tunisia' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('TO' , '776' , 3 , 'Tonga' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('TR' , '792' , 3 , 'Turkey' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('TT' , '780' , 3 , 'Trinidad and Tobago' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('TV' , '798' , 3 , 'Tuvalu' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('TW' , '158' , 3 , 'Taiwan' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('TZ' , '834' , 3 , 'Tanzania, United Republic of' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('UA' , '804' , 3 , 'Ukraine' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('UG' , '800' , 3 , 'Uganda' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('UM' , '581' , 3 , 'United States Minor Outlying Islands' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('US' , '840' , 1 , 'United States' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('UY' , '858' , 3 , 'Uruguay' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('UZ' , '860' , 3 , 'Uzbekistan' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('VA' , '336' , 3 , 'Vatican City State (Holy See)' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('VC' , '670' , 3 , 'Saint Vincent and the Grenadines' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('VE' , '862' , 3 , 'Venezuela' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('VG' , '092' , 3 , 'Virgin Islands (British)' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('VI' , '850' , 3 , 'Virgin Islands (U.S.)' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('VN' , '704' , 3 , 'Vietnam' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('VU' , '548' , 3 , 'Vanuatu' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('WF' , '876' , 3 , 'Wallis And Futuna Islands' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('WS' , '882' , 3 , 'Samoa' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('YE' , '887' , 3 , 'Yemen' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('YT' , '175' , 3 , 'Mayotte' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('ZA' , '710' , 3 , 'South Africa' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('ZM' , '894' , 3 , 'Zambia' , NULL ) ;
INSERT INTO [va_countries] ([country_code],[country_iso_number],[country_order],[country_name],[currency_code]) VALUES ('ZW' , '716' , 3 , 'Zimbabwe' , NULL ) ;




INSERT INTO [va_credit_cards] ([credit_card_id],[credit_card_code],[credit_card_name]) VALUES (1 , 'Visa' , 'VISA' ) ;
INSERT INTO [va_credit_cards] ([credit_card_id],[credit_card_code],[credit_card_name]) VALUES (2 , 'Visa' , 'VISA Electron' ) ;
INSERT INTO [va_credit_cards] ([credit_card_id],[credit_card_code],[credit_card_name]) VALUES (3 , 'MC' , 'Mastercard' ) ;
INSERT INTO [va_credit_cards] ([credit_card_id],[credit_card_code],[credit_card_name]) VALUES (4 , 'AMEX' , 'American Express' ) ;
INSERT INTO [va_credit_cards] ([credit_card_id],[credit_card_code],[credit_card_name]) VALUES (5 , 'Switch' , 'Switch' ) ;
INSERT INTO [va_credit_cards] ([credit_card_id],[credit_card_code],[credit_card_name]) VALUES (6 , 'Solo' , 'Solo' ) ;
INSERT INTO [va_credit_cards] ([credit_card_id],[credit_card_code],[credit_card_name]) VALUES (7 , 'JCB' , 'JCB' ) ;
INSERT INTO [va_credit_cards] ([credit_card_id],[credit_card_code],[credit_card_name]) VALUES (8 , 'Delta' , 'Delta' ) ;
INSERT INTO [va_credit_cards] ([credit_card_id],[credit_card_code],[credit_card_name]) VALUES (9 , 'Eurocard' , 'Eurocard' ) ;
INSERT INTO [va_credit_cards] ([credit_card_id],[credit_card_code],[credit_card_name]) VALUES (10 , 'discover' , 'Discover' ) ;


INSERT INTO [va_currencies] ([currency_id],[is_default],[currency_code],[currency_value],[currency_title],[currency_image],[currency_image_active],[exchange_rate],[symbol_left],[symbol_right]) VALUES (1 , 1 , 'USD' , '840' , 'American Dollar' , 'images/flags/us.gif' , NULL , 1 , '$' , NULL ) ;
INSERT INTO [va_currencies] ([currency_id],[is_default],[currency_code],[currency_value],[currency_title],[currency_image],[currency_image_active],[exchange_rate],[symbol_left],[symbol_right]) VALUES (2 , 0 , 'AUD' , '036' , 'Australian Dollar' , 'images/flags/au.gif' , NULL , 1.3245 , '$' , NULL ) ;
INSERT INTO [va_currencies] ([currency_id],[is_default],[currency_code],[currency_value],[currency_title],[currency_image],[currency_image_active],[exchange_rate],[symbol_left],[symbol_right]) VALUES (3 , 0 , 'GBP' , '826' , 'British Pound' , 'images/flags/uk.gif' , NULL , 0.548065 , '' , NULL ) ;
INSERT INTO [va_currencies] ([currency_id],[is_default],[currency_code],[currency_value],[currency_title],[currency_image],[currency_image_active],[exchange_rate],[symbol_left],[symbol_right]) VALUES (4 , 0 , 'CAD' , '124' , 'Canadian Dollar' , 'images/flags/ca.gif' , NULL , 1.2627 , '$' , NULL ) ;
INSERT INTO [va_currencies] ([currency_id],[is_default],[currency_code],[currency_value],[currency_title],[currency_image],[currency_image_active],[exchange_rate],[symbol_left],[symbol_right]) VALUES (5 , 0 , 'DKK' , '208' , 'Danish Krone' , 'images/flags/dk.gif' , NULL , 5.9324 , 'DKK' , NULL ) ;
INSERT INTO [va_currencies] ([currency_id],[is_default],[currency_code],[currency_value],[currency_title],[currency_image],[currency_image_active],[exchange_rate],[symbol_left],[symbol_right]) VALUES (6 , 0 , 'EUR' , '978' , 'Euro' , 'images/flags/eu.gif' , NULL , 0.796622 , '' , NULL ) ;
INSERT INTO [va_currencies] ([currency_id],[is_default],[currency_code],[currency_value],[currency_title],[currency_image],[currency_image_active],[exchange_rate],[symbol_left],[symbol_right]) VALUES (7 , 0 , 'HKD' , '344' , 'Hong Kong Dollar' , 'images/flags/hk.gif' , NULL , 7.7905 , 'HK$' , NULL ) ;
INSERT INTO [va_currencies] ([currency_id],[is_default],[currency_code],[currency_value],[currency_title],[currency_image],[currency_image_active],[exchange_rate],[symbol_left],[symbol_right]) VALUES (8 , 0 , 'HUF' , '348' , 'Hungarian Forint' , 'images/flags/hu.gif' , NULL , 190.54 , 'HUF' , NULL ) ;
INSERT INTO [va_currencies] ([currency_id],[is_default],[currency_code],[currency_value],[currency_title],[currency_image],[currency_image_active],[exchange_rate],[symbol_left],[symbol_right]) VALUES (9 , 0 , 'ISK' , '352' , 'Iceland Krona' , 'images/flags/is.gif' , NULL , 61.15 , 'ISK' , NULL ) ;
INSERT INTO [va_currencies] ([currency_id],[is_default],[currency_code],[currency_value],[currency_title],[currency_image],[currency_image_active],[exchange_rate],[symbol_left],[symbol_right]) VALUES (10 , 0 , 'ILS' , '376' , 'Israeli Shekel' , 'images/flags/il.gif' , NULL , 4.366 , 'ILS' , NULL ) ;
INSERT INTO [va_currencies] ([currency_id],[is_default],[currency_code],[currency_value],[currency_title],[currency_image],[currency_image_active],[exchange_rate],[symbol_left],[symbol_right]) VALUES (11 , 0 , 'JPY' , '392' , 'Japanese Yen' , 'images/flags/jp.gif' , NULL , 108.17 , 'JPY' , NULL ) ;
INSERT INTO [va_currencies] ([currency_id],[is_default],[currency_code],[currency_value],[currency_title],[currency_image],[currency_image_active],[exchange_rate],[symbol_left],[symbol_right]) VALUES (12 , 0 , 'NZD' , '554' , 'New Zealand Dollar' , 'images/flags/nz.gif' , NULL , 1.41203 , '$' , NULL ) ;
INSERT INTO [va_currencies] ([currency_id],[is_default],[currency_code],[currency_value],[currency_title],[currency_image],[currency_image_active],[exchange_rate],[symbol_left],[symbol_right]) VALUES (13 , 0 , 'NOK' , '578' , 'Norwegian Kroner' , 'images/flags/no.gif' , NULL , 6.4656 , 'NOK' , NULL ) ;
INSERT INTO [va_currencies] ([currency_id],[is_default],[currency_code],[currency_value],[currency_title],[currency_image],[currency_image_active],[exchange_rate],[symbol_left],[symbol_right]) VALUES (14 , 0 , 'SGD' , '702' , 'Singapore Dollar' , 'images/flags/sg.gif' , NULL , 1.6635 , 'SG$' , NULL ) ;
INSERT INTO [va_currencies] ([currency_id],[is_default],[currency_code],[currency_value],[currency_title],[currency_image],[currency_image_active],[exchange_rate],[symbol_left],[symbol_right]) VALUES (15 , 0 , 'ZAR' , '710' , 'South African Rand' , 'images/flags/za.gif' , NULL , 6.5415 , 'ZAR' , NULL ) ;
INSERT INTO [va_currencies] ([currency_id],[is_default],[currency_code],[currency_value],[currency_title],[currency_image],[currency_image_active],[exchange_rate],[symbol_left],[symbol_right]) VALUES (16 , 0 , 'SEK' , '752' , 'Swedish Krona SEK' , 'images/flags/se.gif' , NULL , 7.3069 , 'SEK' , NULL ) ;
INSERT INTO [va_currencies] ([currency_id],[is_default],[currency_code],[currency_value],[currency_title],[currency_image],[currency_image_active],[exchange_rate],[symbol_left],[symbol_right]) VALUES (17 , 0 , 'CHF' , '756' , 'Swiss Franc' , 'images/flags/ch.gif' , NULL , 1.2335 , 'CHF' , NULL ) ;
INSERT INTO [va_currencies] ([currency_id],[is_default],[currency_code],[currency_value],[currency_title],[currency_image],[currency_image_active],[exchange_rate],[symbol_left],[symbol_right]) VALUES (18 , 0 , 'TWD' , '901' , 'Taiwan Dollar' , 'images/flags/tw.gif' , NULL , 31.47 , 'TW$' , NULL ) ;


INSERT INTO [va_custom_blocks] ([block_id],[block_name],[block_notes],[block_title],[block_path],[block_desc]) VALUES (2 , 'Custom' , NULL , 'Custom Block' , NULL , 'Feel free to add any text here' ) ;
INSERT INTO [va_custom_blocks] ([block_id],[block_name],[block_notes],[block_title],[block_path],[block_desc]) VALUES (3 , 'Categories' , NULL , 'All categories' , NULL , '<br>Asia\r\n<br>Europe\r\n<br>U.S.\r\n<br>WorldWorld \r\n<br>Business\r\n<br>Technology\r\n<br>Science & Space\r\n<br>Entertainment\r\n<br>World Sport\r\n<br>Travel\r\n<br>Executive\r\n<br>Education\r\n<br>Weather\r\n<br>Special Reports\r\n<br>Video\r\n\r\n' ) ;






INSERT INTO [va_features_groups] ([group_id],[group_order],[group_name]) VALUES (1 , 1 , 'General' ) ;
INSERT INTO [va_features_groups] ([group_id],[group_order],[group_name]) VALUES (2 , 2 , 'Sizes' ) ;
INSERT INTO [va_features_groups] ([group_id],[group_order],[group_name]) VALUES (3 , 3 , 'Accessories' ) ;


INSERT INTO [va_forum] ([thread_id],[forum_id],[user_id],[user_name],[user_email],[remote_address],[topic],[friendly_url],[description],[email_notification],[views],[replies],[date_added],[date_modified],[thread_updated],[admin_id_added_by],[admin_id_modified_by],[last_post_added],[last_post_user_id],[last_post_admin_id],[last_post_message_id]) VALUES (1 , 1 , 1 , 'joy' , 'jnothing@yahoo.com' , '127.0.0.1' , 'Email problem' , '' , 'Is there a problem with the email? I don''t seem to be getting emails when they are sent to me. ' , 0 , 2 , 2 , '2006-12-26 16:59:31' , '2006-12-26 17:05:13' , '2006-12-26 17:05:13' , 0 , 0 , NULL , NULL , NULL , NULL ) ;


INSERT INTO [va_forum_categories] ([category_id],[category_name],[friendly_url],[category_order],[short_description],[full_description],[allowed_view]) VALUES (1 , 'General' , NULL , 1 , 'General category' , 'General category' , 1 ) ;


INSERT INTO [va_forum_list] ([forum_id],[category_id],[forum_name],[friendly_url],[forum_order],[short_description],[full_description],[small_image],[large_image],[date_added],[threads_number],[messages_number],[last_post_added],[last_post_user_id],[last_post_admin_id],[last_post_thread_id],[last_post_message_id],[allowed_view],[allowed_view_topics],[allowed_view_topic],[allowed_post_topics],[allowed_post_replies]) VALUES (1 , 1 , 'Forum' , '' , 1 , 'General discussions' , NULL , NULL , NULL , '2006-05-23 00:00:00' , 1 , 2 , '2006-12-26 17:05:13' , 0 , NULL , 1 , NULL , 1 , 1 , 1 , 1 , 1 ) ;


INSERT INTO [va_forum_messages] ([message_id],[thread_id],[admin_id],[user_name],[user_email],[remote_address],[message_text],[date_added],[date_modified],[user_id],[admin_id_modified_by]) VALUES (1 , 1 , 1 , 'Site Administrator' , 'admin@yoursite.com' , '127.0.0.1' , '>Is there a problem with the email? I don''t seem to be getting emails when they are sent to me. \r\n\r\nthere has NOT been a problem with the email notification in general, but I know that there are some problems with AOL accounts as they consider the emails as spam, so please check your anti-spam settings you can always call our office to find more if there has been some servers'' issues.' , '2006-12-26 17:03:01' , NULL , 0 , NULL ) ;
INSERT INTO [va_forum_messages] ([message_id],[thread_id],[admin_id],[user_name],[user_email],[remote_address],[message_text],[date_added],[date_modified],[user_id],[admin_id_modified_by]) VALUES (2 , 1 , NULL , 'joy' , 'jnothing@yahoo.com' , '127.0.0.1' , 'As of today 04/03 I havent gotten any copies of email confirmations that I get after a customer places an order like I normally do and I dont have aol.' , '2006-12-26 17:05:13' , NULL , 1 , NULL ) ;


INSERT INTO [va_forum_moderators] ([admin_id],[forum_id],[is_default_forum]) VALUES (1 , 1 , 0 ) ;


INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_images' , 'image_large_height' , '300' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_images' , 'image_large_size' , '50000' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_images' , 'image_large_width' , '300' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_images' , 'image_small_height' , '100' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_images' , 'image_small_size' , '16000' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_images' , 'image_small_width' , '100' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_images' , 'images_number' , '4' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_notify' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_notify' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_notify' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_notify' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_notify' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_notify' , 'admin_message' , 'ID: {item_id}\r\nTitle: {item_title}\r\nURL: {site_url}ads_details.php?item_id={item_id}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_notify' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_notify' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_notify' , 'admin_subject' , 'Ad modifications #{item_id}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_notify' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_notify' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_notify' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_notify' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_notify' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_notify' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_notify' , 'user_message' , 'Dear {seller_name},\r\n\r\nOnce our editors have reviewed and approved your Ad we will post it on our web site.\r\n\r\nThank you.\r\nCustomer Services\r\n' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_notify' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_notify' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_notify' , 'user_subject' , 'Your ad ''{item_title}'' was received.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_request' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_request' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_request' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_request' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_request' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_request' , 'admin_message' , 'Title: {item_title} \r\nPrice: {offer_price}\r\nUser ID: {user_id}\r\nName: {user_name}\r\nEmail: {user_email}\r\n--------------------\r\n{offer_message}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_request' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_request' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_request' , 'admin_subject' , 'New offer for Ad #{item_id}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_request' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_request' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_request' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_request' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_request' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_request' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_request' , 'user_message' , 'Hi {seller_name},\r\n\r\nYou have received an offer for the item listed in your ad: {item_title}\r\n\r\nThey have offered {offer_price} and they left you this message: \r\n{offer_message}\r\n\r\nTo reply click here:\r\nReply To: {user_email}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_request' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_request' , 'user_subject' , 'New offer for you ad: {item_title}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_search' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_search' , 'price' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_search' , 'search_for' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_search' , 'search_in' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_search' , 'search_in_category' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_search' , 'user' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_search' , 'user_type_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_tell_friend' , 'default_comment' , 'Hi {friend_name} - I thought you might be interested in seeing the {item_title} at this site {item_url}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_tell_friend' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_tell_friend' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_tell_friend' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_tell_friend' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_tell_friend' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_tell_friend' , 'user_message' , 'Thought you might be interested in seeing the {item_title} at {item_url}\r\n\r\n{user_name} left you a note:\r\n{user_comment}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_tell_friend' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('ads_tell_friend' , 'user_subject' , 'You were invited by {user_name} to visit site at {site_url}!' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_1_tell_friend' , 'default_comment' , 'Hi {friend_name} - I thought you might be interested in seeing the {article_title} at this site {article_url}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_1_tell_friend' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_1_tell_friend' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_1_tell_friend' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_1_tell_friend' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_1_tell_friend' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_1_tell_friend' , 'user_message' , 'Thought you might be interested in seeing the {article_title} at {article_url}\r\n\r\n{user_name} left you a note:\r\n{user_comment}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_1_tell_friend' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_1_tell_friend' , 'user_subject' , 'You were invited by {user_name} to visit site at {site_url}!' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_3_tell_friend' , 'default_comment' , 'Hi {friend_name} - I thought you might be interested in seeing the {article_title} at this site {article_url}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_3_tell_friend' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_3_tell_friend' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_3_tell_friend' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_3_tell_friend' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_3_tell_friend' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_3_tell_friend' , 'user_message' , 'Thought you might be interested in seeing the {article_title} at {article_url}\r\n\r\n{user_name} left you a note:\r\n{user_comment}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_3_tell_friend' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_3_tell_friend' , 'user_subject' , 'You were invited by {user_name} to visit site at {site_url}!' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_30_tell_friend' , 'default_comment' , 'Hi {friend_name} - I thought you might be interested in seeing the {article_title} at this site {article_url}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_30_tell_friend' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_30_tell_friend' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_30_tell_friend' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_30_tell_friend' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_30_tell_friend' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_30_tell_friend' , 'user_message' , 'Thought you might be interested in seeing the {article_title} at {article_url}\r\n\r\n{user_name} left you a note:\r\n{user_comment}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_30_tell_friend' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_30_tell_friend' , 'user_subject' , 'You were invited by {user_name} to visit site at {site_url}!' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_4_tell_friend' , 'default_comment' , 'Hi {friend_name} - I thought you might be interested in seeing the {article_title} at this site {article_url}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_4_tell_friend' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_4_tell_friend' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_4_tell_friend' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_4_tell_friend' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_4_tell_friend' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_4_tell_friend' , 'user_message' , 'Thought you might be interested in seeing the {article_title} at {article_url}\r\n\r\n{user_name} left you a note:\r\n{user_comment}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_4_tell_friend' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_4_tell_friend' , 'user_subject' , 'You were invited by {user_name} to visit site at {site_url}!' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_5_tell_friend' , 'default_comment' , 'Hi {friend_name} - I thought you might be interested in seeing the {article_title} at this site {article_url}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_5_tell_friend' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_5_tell_friend' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_5_tell_friend' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_5_tell_friend' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_5_tell_friend' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_5_tell_friend' , 'user_message' , 'Thought you might be interested in seeing the {article_title} at {article_url}\r\n\r\n{user_name} left you a note:\r\n{user_comment}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_5_tell_friend' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_5_tell_friend' , 'user_subject' , 'You were invited by {user_name} to visit site at {site_url}!' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_6_tell_friend' , 'default_comment' , 'Hi {friend_name} - I thought you might be interested in seeing the {article_title} at this site {article_url}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_6_tell_friend' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_6_tell_friend' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_6_tell_friend' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_6_tell_friend' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_6_tell_friend' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_6_tell_friend' , 'user_message' , 'Thought you might be interested in seeing the {article_title} at {article_url}\r\n\r\n{user_name} left you a note:\r\n{user_comment}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_6_tell_friend' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('articles_6_tell_friend' , 'user_subject' , 'You were invited by {user_name} to visit site at {site_url}!' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n        Start Date: {cc_start_date}\r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n      Issue Number: {cc_issue_number}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'admin_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'cc_code_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'cc_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'cc_number_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'cc_number_split' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'cc_type_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'show_cc_issue_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'show_cc_start_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_1' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n        Start Date: {cc_start_date}\r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n      Issue Number: {cc_issue_number}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'admin_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'call_center_cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'call_center_cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'call_center_cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'call_center_cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'call_center_cc_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'call_center_cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'call_center_cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'call_center_cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'call_center_cc_type_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'call_center_pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'call_center_show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'call_center_show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'call_center_show_cc_issue_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'call_center_show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'call_center_show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'call_center_show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'call_center_show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'call_center_show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'call_center_show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'call_center_show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'cc_allowed' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'cc_code_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'cc_forbidden' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'cc_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'cc_number_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'cc_number_split' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'cc_type_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'show_cc_issue_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_10' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n        Start Date: {cc_start_date}\r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n      Issue Number: {cc_issue_number}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'admin_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'call_center_cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'call_center_cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'call_center_cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'call_center_cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'call_center_cc_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'call_center_cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'call_center_cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'call_center_cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'call_center_cc_type_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'call_center_pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'call_center_show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'call_center_show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'call_center_show_cc_issue_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'call_center_show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'call_center_show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'call_center_show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'call_center_show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'call_center_show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'call_center_show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'call_center_show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'cc_allowed' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'cc_code_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'cc_forbidden' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'cc_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'cc_number_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'cc_number_split' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'cc_type_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'show_cc_issue_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_12' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n        Start Date: {cc_start_date}\r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n      Issue Number: {cc_issue_number}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'admin_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'call_center_cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'call_center_cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'call_center_cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'call_center_cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'call_center_cc_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'call_center_cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'call_center_cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'call_center_cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'call_center_cc_type_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'call_center_pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'call_center_show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'call_center_show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'call_center_show_cc_issue_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'call_center_show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'call_center_show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'call_center_show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'call_center_show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'call_center_show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'call_center_show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'call_center_show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'cc_allowed' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'cc_code_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'cc_forbidden' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'cc_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'cc_number_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'cc_number_split' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'cc_type_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'show_cc_issue_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_16' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'admin_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'admin_message_type' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'admin_subject' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'cc_expiry_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'cc_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'cc_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'cc_number_split' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'cc_type_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'show_cc_expiry_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'show_cc_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'show_cc_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'show_cc_security_code' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'show_cc_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_17' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n        Start Date: {cc_start_date}\r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n      Issue Number: {cc_issue_number}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'admin_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'call_center_cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'call_center_cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'call_center_cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'call_center_cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'call_center_cc_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'call_center_cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'call_center_cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'call_center_cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'call_center_cc_type_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'call_center_pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'call_center_show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'call_center_show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'call_center_show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'call_center_show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'call_center_show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'call_center_show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'call_center_show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'call_center_show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'call_center_show_cc_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'call_center_show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'cc_allowed' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'cc_code_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'cc_forbidden' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'cc_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'cc_number_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'cc_number_split' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'cc_type_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'show_cc_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_18' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last}\r\n        Start Date: {cc_start_date}\r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n      Issue Number: {cc_issue_number}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'admin_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'call_center_cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'call_center_cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'call_center_cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'call_center_cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'call_center_cc_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'call_center_cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'call_center_cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'call_center_cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'call_center_cc_type_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'call_center_pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'call_center_show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'call_center_show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'call_center_show_cc_issue_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'call_center_show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'call_center_show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'call_center_show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'call_center_show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'call_center_show_cc_start_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'call_center_show_cc_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'call_center_show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'cc_allowed' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'cc_code_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'cc_forbidden' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'cc_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'cc_number_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'cc_number_split' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'cc_type_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'show_cc_issue_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'show_cc_start_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'show_cc_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_19' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'admin_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'admin_subject' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'cc_expiry_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'cc_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'cc_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'cc_number_split' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'cc_type_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'show_cc_expiry_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'show_cc_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'show_cc_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'show_cc_security_code' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'show_cc_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_2' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'admin_message' , 'First Name: {cc_first_name}\r\nLast Name: {cc_last_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'admin_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'call_center_cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'call_center_cc_first_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'call_center_cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'call_center_cc_last_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'call_center_cc_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'call_center_cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'call_center_cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'call_center_cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'call_center_cc_type_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'call_center_pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'call_center_show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'call_center_show_cc_first_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'call_center_show_cc_issue_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'call_center_show_cc_last_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'call_center_show_cc_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'call_center_show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'call_center_show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'call_center_show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'call_center_show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'call_center_show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'cc_allowed' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'cc_code_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'cc_first_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'cc_forbidden' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'cc_last_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'cc_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'cc_number_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'cc_number_split' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'cc_type_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'show_cc_first_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'show_cc_issue_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'show_cc_last_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'show_cc_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_22' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'admin_message' , 'Name: {cc_first_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'admin_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'call_center_cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'call_center_cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'call_center_cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'call_center_cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'call_center_cc_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'call_center_cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'call_center_cc_security_code_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'call_center_cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'call_center_cc_type_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'call_center_pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'call_center_show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'call_center_show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'call_center_show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'call_center_show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'call_center_show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'call_center_show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'call_center_show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'call_center_show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'call_center_show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'call_center_show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'cc_allowed' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'cc_code_security' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'cc_forbidden' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'cc_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'cc_number_security' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'cc_number_split' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'cc_security_code_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'cc_type_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_23' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n   Security Code: {cc_security_code}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'admin_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'call_center_cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'call_center_cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'call_center_cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'call_center_cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'call_center_cc_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'call_center_cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'call_center_cc_security_code_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'call_center_cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'call_center_cc_type_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'call_center_pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'call_center_show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'call_center_show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'call_center_show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'call_center_show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'call_center_show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'call_center_show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'call_center_show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'call_center_show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'call_center_show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'call_center_show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'cc_allowed' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'cc_code_security' , '2' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'cc_forbidden' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'cc_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'cc_number_security' , '2' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'cc_number_split' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'cc_security_code_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'cc_type_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_25' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n        Expiry Date: {cc_expiry_date}\r\n          Card Type: {cc_type}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'admin_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'call_center_cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'call_center_cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'call_center_cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'call_center_cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'call_center_cc_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'call_center_cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'call_center_cc_security_code_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'call_center_cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'call_center_cc_type_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'call_center_pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'call_center_show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'call_center_show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'call_center_show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'call_center_show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'call_center_show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'call_center_show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'call_center_show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'call_center_show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'call_center_show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'call_center_show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'cc_allowed' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'cc_code_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'cc_forbidden' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'cc_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'cc_number_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'cc_number_split' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'cc_security_code_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'cc_type_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_26' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'admin_message' , 'First Name: {cc_first_name}\r\nLast Name: {cc_last_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'admin_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'call_center_cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'call_center_cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'call_center_cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'call_center_cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'call_center_cc_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'call_center_cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'call_center_cc_security_code_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'call_center_cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'call_center_cc_type_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'call_center_pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'call_center_show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'call_center_show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'call_center_show_cc_issue_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'call_center_show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'call_center_show_cc_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'call_center_show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'call_center_show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'call_center_show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'call_center_show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'call_center_show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'cc_allowed' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'cc_code_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'cc_forbidden' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'cc_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'cc_number_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'cc_number_split' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'cc_security_code_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'cc_type_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'show_cc_issue_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'show_cc_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_27' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n        Start Date: {cc_start_date}\r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n      Issue Number: {cc_issue_number}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'admin_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'admin_subject' , 'Credit Card Information for Oder No: {order_id}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'call_center_cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'call_center_cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'call_center_cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'call_center_cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'call_center_cc_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'call_center_cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'call_center_cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'call_center_cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'call_center_cc_type_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'call_center_pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'call_center_show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'call_center_show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'call_center_show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'call_center_show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'call_center_show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'call_center_show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'call_center_show_cc_security_code' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'call_center_show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'call_center_show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'call_center_show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'cc_allowed' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'cc_code_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'cc_forbidden' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'cc_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'cc_number_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'cc_number_split' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'cc_type_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'show_cc_security_code' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_28' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n      Issue Number: {cc_issue_number}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'admin_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'admin_subject' , 'Credit Card Information for Oder No: {order_id}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'call_center_cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'call_center_cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'call_center_cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'call_center_cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'call_center_cc_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'call_center_cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'call_center_cc_security_code_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'call_center_cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'call_center_cc_type_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'call_center_pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'call_center_show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'call_center_show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'call_center_show_cc_issue_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'call_center_show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'call_center_show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'call_center_show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'call_center_show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'call_center_show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'call_center_show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'call_center_show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'cc_allowed' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'cc_code_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'cc_forbidden' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'cc_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'cc_number_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'cc_number_split' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'cc_security_code_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'cc_type_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'show_cc_issue_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_29' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'admin_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'admin_subject' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'cc_expiry_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'cc_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'cc_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'cc_number_split' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'cc_type_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'show_cc_expiry_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'show_cc_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'show_cc_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'show_cc_security_code' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'show_cc_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_3' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n   Security Code: {cc_security_code}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'admin_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'call_center_cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'call_center_cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'call_center_cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'call_center_cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'call_center_cc_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'call_center_cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'call_center_cc_security_code_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'call_center_cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'call_center_cc_type_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'call_center_pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'call_center_show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'call_center_show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'call_center_show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'call_center_show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'call_center_show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'call_center_show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'call_center_show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'call_center_show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'call_center_show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'call_center_show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'cc_allowed' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'cc_code_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'cc_forbidden' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'cc_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'cc_number_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'cc_number_split' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'cc_security_code_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'cc_type_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_30' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n        Expiry Date: {cc_expiry_date}\r\n          Card Type: {cc_type}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'admin_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'call_center_cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'call_center_cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'call_center_cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'call_center_cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'call_center_cc_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'call_center_cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'call_center_cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'call_center_cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'call_center_cc_type_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'call_center_pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'call_center_show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'call_center_show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'call_center_show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'call_center_show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'call_center_show_cc_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'call_center_show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'call_center_show_cc_security_code' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'call_center_show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'call_center_show_cc_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'call_center_show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'cc_allowed' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'cc_code_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'cc_forbidden' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'cc_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'cc_number_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'cc_number_split' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'cc_type_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'show_cc_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'show_cc_security_code' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'show_cc_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_31' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'admin_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'admin_message_type' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'admin_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'admin_subject' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'cc_allowed' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'cc_code_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'cc_expiry_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'cc_forbidden' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'cc_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'cc_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'cc_number_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'cc_number_split' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'cc_type_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'show_cc_expiry_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'show_cc_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'show_cc_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'show_cc_security_code' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'show_cc_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_32' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'admin_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'admin_message_type' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'admin_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'admin_subject' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'cc_allowed' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'cc_code_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'cc_expiry_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'cc_forbidden' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'cc_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'cc_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'cc_number_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'cc_number_split' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'cc_type_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'show_cc_expiry_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'show_cc_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'show_cc_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'show_cc_security_code' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'show_cc_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_33' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'admin_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'admin_message_type' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'admin_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'admin_subject' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'call_center_cc_expiry_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'call_center_cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'call_center_cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'call_center_cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'call_center_cc_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'call_center_cc_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'call_center_cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'call_center_cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'call_center_cc_type_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'call_center_pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'call_center_show_cc_expiry_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'call_center_show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'call_center_show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'call_center_show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'call_center_show_cc_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'call_center_show_cc_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'call_center_show_cc_security_code' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'call_center_show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'call_center_show_cc_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'call_center_show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'cc_allowed' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'cc_code_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'cc_expiry_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'cc_forbidden' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'cc_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'cc_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'cc_number_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'cc_number_split' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'cc_type_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'show_cc_expiry_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'show_cc_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'show_cc_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'show_cc_security_code' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'show_cc_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_34' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'admin_message' , 'Last 4 digit of CC: {cc_number_last} \r\n       Expiry Date: {cc_expiry_date}\r\n   Security Code: {cc_security_code}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'admin_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'call_center_cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'call_center_cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'call_center_cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'call_center_cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'call_center_cc_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'call_center_cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'call_center_cc_security_code_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'call_center_cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'call_center_cc_type_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'call_center_pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'call_center_show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'call_center_show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'call_center_show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'call_center_show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'call_center_show_cc_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'call_center_show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'call_center_show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'call_center_show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'call_center_show_cc_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'call_center_show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'cc_allowed' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'cc_code_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'cc_forbidden' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'cc_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'cc_number_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'cc_number_split' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'cc_security_code_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'cc_type_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'show_cc_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'show_cc_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_35' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'admin_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'admin_message_type' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'admin_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'admin_subject' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'call_center_cc_expiry_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'call_center_cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'call_center_cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'call_center_cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'call_center_cc_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'call_center_cc_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'call_center_cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'call_center_cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'call_center_cc_type_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'call_center_pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'call_center_show_cc_expiry_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'call_center_show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'call_center_show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'call_center_show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'call_center_show_cc_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'call_center_show_cc_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'call_center_show_cc_security_code' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'call_center_show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'call_center_show_cc_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'call_center_show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'cc_allowed' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'cc_code_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'cc_expiry_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'cc_forbidden' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'cc_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'cc_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'cc_number_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'cc_number_split' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'cc_type_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'show_cc_expiry_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'show_cc_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'show_cc_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'show_cc_security_code' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'show_cc_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_36' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'admin_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'admin_message_type' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'admin_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'admin_subject' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'call_center_cc_expiry_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'call_center_cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'call_center_cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'call_center_cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'call_center_cc_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'call_center_cc_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'call_center_cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'call_center_cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'call_center_cc_type_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'call_center_pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'call_center_show_cc_expiry_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'call_center_show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'call_center_show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'call_center_show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'call_center_show_cc_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'call_center_show_cc_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'call_center_show_cc_security_code' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'call_center_show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'call_center_show_cc_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'call_center_show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'cc_allowed' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'cc_code_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'cc_expiry_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'cc_forbidden' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'cc_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'cc_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'cc_number_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'cc_number_split' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'cc_type_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'show_cc_expiry_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'show_cc_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'show_cc_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'show_cc_security_code' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'show_cc_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_37' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'admin_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'admin_subject' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'cc_expiry_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'cc_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'cc_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'cc_number_split' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'cc_type_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'show_cc_expiry_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'show_cc_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'show_cc_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'show_cc_security_code' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'show_cc_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_4' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'admin_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'admin_subject' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'cc_expiry_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'cc_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'cc_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'cc_number_split' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'cc_type_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'show_cc_expiry_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'show_cc_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'show_cc_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'show_cc_security_code' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'show_cc_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_5' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'admin_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'admin_subject' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'cc_expiry_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'cc_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'cc_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'cc_number_split' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'cc_type_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'show_cc_expiry_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'show_cc_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'show_cc_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'show_cc_security_code' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'show_cc_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_6' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n        Start Date: {cc_start_date}\r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n      Issue Number: {cc_issue_number}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'admin_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'call_center_cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'call_center_cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'call_center_cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'call_center_cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'call_center_cc_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'call_center_cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'call_center_cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'call_center_cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'call_center_cc_type_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'call_center_pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'call_center_show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'call_center_show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'call_center_show_cc_issue_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'call_center_show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'call_center_show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'call_center_show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'call_center_show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'call_center_show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'call_center_show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'call_center_show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'cc_allowed' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'cc_code_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'cc_forbidden' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'cc_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'cc_number_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'cc_number_split' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'cc_type_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'show_cc_issue_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_7' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n        Start Date: {cc_start_date}\r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n      Issue Number: {cc_issue_number}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'admin_message_type' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'admin_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'call_center_cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'call_center_cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'call_center_cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'call_center_cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'call_center_cc_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'call_center_cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'call_center_cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'call_center_cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'call_center_cc_type_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'call_center_pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'call_center_show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'call_center_show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'call_center_show_cc_issue_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'call_center_show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'call_center_show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'call_center_show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'call_center_show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'call_center_show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'call_center_show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'call_center_show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'cc_allowed' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'cc_code_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'cc_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'cc_forbidden' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'cc_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'cc_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'cc_number_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'cc_number_security' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'cc_number_split' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'cc_type_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'show_cc_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'show_cc_issue_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'show_cc_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'show_cc_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'show_cc_number' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'show_cc_security_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'show_cc_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_8' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'admin_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'admin_subject' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'cc_expiry_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'cc_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'cc_number_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'cc_number_split' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'cc_security_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'cc_start_date_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'cc_type_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'show_cc_expiry_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'show_cc_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'show_cc_number' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'show_cc_security_code' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'show_cc_start_date' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'show_cc_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('credit_card_info_9' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('download_info' , 'links_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('download_info' , 'links_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('download_info' , 'links_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('download_info' , 'links_message' , 'To download product click on link below:\r\n{links}\r\n\r\nThanks for purchase,\r\nSales Team.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('download_info' , 'links_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('download_info' , 'links_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('download_info' , 'links_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('download_info' , 'links_subject' , 'Links for your Order # {order_id}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('download_info' , 'max_downloads' , '3' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('download_info' , 'serials_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('download_info' , 'serials_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('download_info' , 'serials_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('download_info' , 'serials_message' , 'To activate your product use serial numbers below:\r\n{serials}\r\n\r\nThanks for purchase,\r\nSales Team.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('download_info' , 'serials_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('download_info' , 'serials_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('download_info' , 'serials_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('download_info' , 'serials_subject' , 'Serial Numbers for your Order # {order_id}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('download_info' , 'vouchers_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('download_info' , 'vouchers_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('download_info' , 'vouchers_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('download_info' , 'vouchers_message' , 'Here the list of your gift vouhers:\r\n{vouchers}\r\n\r\nThanks for purchase,\r\nSales Team.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('download_info' , 'vouchers_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('download_info' , 'vouchers_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('download_info' , 'vouchers_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('download_info' , 'vouchers_subject' , 'Gift Vouchers for your Order # {order_id}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forgotten_password' , 'md5_message' , 'Hi,\r\n\r\nTo reset your password please use the link below:\r\n\r\n{reset_password_url}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forgotten_password' , 'md5_subject' , 'Password reset instructions' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forgotten_password' , 'md5_time_limit' , '360' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forgotten_password' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forgotten_password' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forgotten_password' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forgotten_password' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forgotten_password' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forgotten_password' , 'user_message' , 'Hi,\r\n\r\nHere are the details you requested:\r\n\r\nLogin: {login}\r\nPassword: {password}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forgotten_password' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forgotten_password' , 'user_subject' , 'Your login and password details' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forum' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forum' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forum' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forum' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forum' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forum' , 'admin_message' , 'Topic descrition:\r\n{topic_description}\r\n\r\nMessage:\r\n{message}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forum' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forum' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forum' , 'admin_subject' , 'New post at forum :: {topic}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forum' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forum' , 'reply_form' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forum' , 'sort_messages' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forum' , 'topic_information' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forum' , 'use_random_image' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forum' , 'user_info' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forum' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forum' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forum' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forum' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forum' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forum' , 'user_message' , 'Topic descrition:\r\n{topic_description}\r\n\r\nMessage:\r\n{message}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forum' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forum' , 'user_no_image' , 'images/no_photo.gif' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forum' , 'user_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('forum' , 'user_subject' , 'New post at your topic :: {topic}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'admin_email' , 'admin@example.com' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'approve_review' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'country_code' , 'GB' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'friendly_auto' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'friendly_extension' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'friendly_urls' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'google_analytics' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'google_tracking_code' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'html_below_footer' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'html_editor' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'html_on_index' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'index_description' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'index_keywords' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'index_title' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'is_sms_allowed' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'layout_id' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'logo_image' , 'images/logo.png' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'logo_image_alt' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'logo_image_height' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'logo_image_width' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'min_rating' , '4' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'min_votes' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'password_encrypt' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'php_in_custom_blocks' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'php_in_custom_pages' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'php_in_footer_body' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'php_in_index_greetings' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'review_random_image' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'reviews_per_page' , '10' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'secure_admin_login' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'secure_admin_order_create' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'secure_order_profile' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'secure_payments' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'secure_url' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'secure_user_profile' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'site_url' , 'http://localhost/' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'state_code' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'tracking_pages' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'tracking_visits' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'user_image_height' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'user_image_size' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'user_image_upload' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'user_image_width' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('global' , 'weight_measure' , 'lb' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_confirmation' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'failure_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'is_validation' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'pending_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'pending_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'success_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_1' , 'validation_php_lib' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'failure_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'is_validation' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'pending_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'pending_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'success_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_10' , 'validation_php_lib' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'failure_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'is_validation' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'pending_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'pending_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'success_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_11' , 'validation_php_lib' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'failure_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'is_validation' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'pending_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'pending_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'success_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_12' , 'validation_php_lib' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'failure_status_id' , '10' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'is_validation' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'pending_message' , 'Your transaction wasn''t finished and waiting for approval.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'pending_status_id' , '6' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'success_status_id' , '9' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_13' , 'validation_php_lib' , './payments/paypal_pdt.php' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'failure_status_id' , '10' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'is_validation' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'pending_message' , 'Your transaction wasn''t finished and waiting for approval.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'pending_status_id' , '6' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'success_status_id' , '9' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_14' , 'validation_php_lib' , './payments/paymate_express.php' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'failure_status_id' , '10' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'is_validation' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'pending_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'pending_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'success_status_id' , '9' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_15' , 'validation_php_lib' , './payments/protx_form_check.php' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'failure_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'is_validation' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'pending_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'pending_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'success_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_16' , 'validation_php_lib' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'failure_status_id' , '10' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'is_validation' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'pending_message' , 'Your transaction is still processing. Please wait for approval.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'pending_status_id' , '6' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'success_status_id' , '9' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_17' , 'validation_php_lib' , './payments/egold_check.php' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'failure_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'is_validation' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'pending_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'pending_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'success_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_18' , 'validation_php_lib' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'failure_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'is_validation' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'pending_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'pending_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'success_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_19' , 'validation_php_lib' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'failure_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'is_validation' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'pending_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'pending_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'success_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_2' , 'validation_php_lib' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'failure_status_id' , '10' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'is_validation' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'pending_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'pending_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'success_status_id' , '9' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_20' , 'validation_php_lib' , './payments/ideal_check.php' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'failure_status_id' , '10' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'is_validation' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'pending_message' , 'Your transaction wasn''t finished and is waiting for approval.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'pending_status_id' , '6' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'success_status_id' , '9' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_21' , 'validation_php_lib' , './payments/paypal_payment.php' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'failure_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'is_validation' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'pending_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'pending_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'success_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_22' , 'validation_php_lib' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'failure_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'is_validation' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'pending_message' , 'Your transaction wasn''t finished and is waiting for approval.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'pending_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'success_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_23' , 'validation_php_lib' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'failure_status_id' , '10' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'is_validation' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'pending_message' , 'Your transaction wasn''t finished and is waiting for approval.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'pending_status_id' , '6' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'success_status_id' , '9' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_24' , 'validation_php_lib' , './payments/epdq_cpi_check.php' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'failure_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'is_validation' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'pending_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'pending_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'success_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_25' , 'validation_php_lib' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'failure_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'is_validation' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'pending_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'pending_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'success_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_26' , 'validation_php_lib' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'failure_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'is_validation' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'pending_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'pending_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'success_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_27' , 'validation_php_lib' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'failure_status_id' , '10' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'is_validation' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'pending_message' , 'Your transaction wasn''t finished and is waiting for approval.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'pending_status_id' , '6' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'success_status_id' , '9' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_28' , 'validation_php_lib' , './payments/proxypay_check.php' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'failure_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'is_validation' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'pending_message' , 'Your transaction wasn''t finished and is waiting for approval.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'pending_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'success_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_29' , 'validation_php_lib' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'failure_status_id' , '10' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'is_validation' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'pending_message' , 'Your transaction wasn''t finished and is waiting for approval.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'pending_status_id' , '6' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'success_status_id' , '9' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_3' , 'validation_php_lib' , './payments/authorize_check.php' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'admin_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'failure_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'is_validation' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'pending_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'pending_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'success_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_30' , 'validation_php_lib' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'failure_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'is_validation' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'pending_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'pending_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'success_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_31' , 'validation_php_lib' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'failure_status_id' , '10' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'is_validation' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'pending_message' , 'Your transaction wasn''t finished and is waiting for approval.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'pending_status_id' , '6' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'success_status_id' , '4' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_32' , 'validation_php_lib' , './payments/chronopay_check.php' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'failure_status_id' , '10' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'is_validation' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'pending_message' , 'Your transaction wasn''t finished and is waiting for approval.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'pending_status_id' , '6' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'success_status_id' , '4' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_33' , 'validation_php_lib' , './payments/multipay_check.php' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'failure_status_id' , '10' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'is_validation' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'pending_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'pending_status_id' , '6' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'success_status_id' , '9' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_34' , 'validation_php_lib' , './payments/google_check.php' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'failure_status_id' , '10' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'is_validation' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'pending_message' , 'Your transaction wasn''t finished and is waiting for approval.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'pending_status_id' , '6' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'success_status_id' , '4' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_36' , 'validation_php_lib' , './payments/protx_server_check.php' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'failure_status_id' , '10' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'is_validation' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'pending_message' , 'Your transaction wasn''t finished and is waiting for approval.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'pending_status_id' , '6' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'success_status_id' , '4' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_37' , 'validation_php_lib' , './payments/vcs_check.php' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'failure_status_id' , '10' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'is_validation' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'pending_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'pending_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'success_status_id' , '9' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_4' , 'validation_php_lib' , './payments/worldpay_check.php' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'failure_status_id' , '10' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'is_validation' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'pending_message' , 'Your transaction wasn''t finished and is waiting for approval.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'pending_status_id' , '6' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'success_status_id' , '9' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_5' , 'validation_php_lib' , './payments/2checkout.php' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'failure_status_id' , '10' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'is_validation' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'pending_message' , 'Your transaction wasn''t finished and is waiting for approval.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'pending_status_id' , '6' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'success_status_id' , '9' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_6' , 'validation_php_lib' , './payments/paypal_pdt.php' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'failure_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'is_validation' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'pending_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'pending_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'success_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_7' , 'validation_php_lib' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'failure_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'is_validation' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'pending_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'pending_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'success_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_8' , 'validation_php_lib' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'admin_failure_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'admin_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'admin_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'admin_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'admin_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenience caused.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'failure_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'is_validation' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'pending_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'pending_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou''ll receive an immediate notification by email to tell you that we''ve got your order and we''ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'success_status_id' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'user_failure_notify' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'user_pending_notify' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'user_sms_failure' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'user_sms_pending' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'user_sms_success' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_final_9' , 'validation_php_lib' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'address1_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'address2_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'admin_message' , '{basket}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'admin_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'admin_subject' , 'New order #{order_id} submitted' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_address1_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_address2_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_cell_phone_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_city_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_company_id_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_company_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_country_code_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_daytime_phone_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_delivery_address1_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_delivery_address2_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_delivery_cell_phone_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_delivery_city_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_delivery_company_id_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_delivery_company_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_delivery_country_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_delivery_daytime_phone_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_delivery_email_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_delivery_evening_phone_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_delivery_fax_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_delivery_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_delivery_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_delivery_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_delivery_phone_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_delivery_province_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_delivery_state_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_delivery_zip_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_email_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_evening_phone_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_fax_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_phone_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_province_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_address1' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_address2' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_cell_phone' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_city' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_company_id' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_company_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_country_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_daytime_phone' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_delivery_address1' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_delivery_address2' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_delivery_cell_phone' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_delivery_city' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_delivery_company_id' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_delivery_company_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_delivery_country_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_delivery_daytime_phone' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_delivery_email' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_delivery_evening_phone' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_delivery_fax' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_delivery_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_delivery_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_delivery_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_delivery_phone' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_delivery_province' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_delivery_state_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_delivery_zip' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_email' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_evening_phone' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_fax' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_phone' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_province' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_state_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_show_zip' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_state_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'call_center_zip_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'cell_phone_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'city_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'company_id_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'company_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'country_code_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'currency_block' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'daytime_phone_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'delivery_address1_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'delivery_address2_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'delivery_cell_phone_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'delivery_city_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'delivery_company_id_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'delivery_company_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'delivery_country_code_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'delivery_daytime_phone_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'delivery_email_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'delivery_evening_phone_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'delivery_fax_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'delivery_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'delivery_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'delivery_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'delivery_phone_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'delivery_province_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'delivery_state_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'delivery_zip_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'email_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'evening_phone_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'fax_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'intro_text' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'phone_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'province_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_address1' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_address2' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_cell_phone' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_city' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_company_id' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_company_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_country_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_daytime_phone' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_delivery_address1' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_delivery_address2' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_delivery_cell_phone' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_delivery_city' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_delivery_company_id' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_delivery_company_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_delivery_country_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_delivery_daytime_phone' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_delivery_email' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_delivery_evening_phone' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_delivery_fax' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_delivery_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_delivery_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_delivery_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_delivery_phone' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_delivery_province' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_delivery_state_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_delivery_zip' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_email' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_evening_phone' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_fax' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_phone' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_province' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_state_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'show_zip' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'state_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'subscribe_block' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'user_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'user_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'user_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'user_subject' , '{name} your contact information was saved.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('order_info' , 'zip_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('printable' , 'invoice_footer' , 'Viart Limited, 24 Ellerbeck Court, Stokesley Business Park, North Yorkshire, TS9 5PT, England' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('printable' , 'invoice_header' , 'Viart Limited\r\nEllerbeck Court\r\nStokesley Business Park\r\nNorth Yorkshire\r\nTS9 5PT\r\nEngland' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('printable' , 'invoice_logo' , '../images/silver/logo.jpg' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('printable' , 'packing_footer' , 'Viart Limited, 24 Ellerbeck Court, Stokesley Business Park, North Yorkshire, TS9 5PT, England' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('printable' , 'packing_header' , 'Viart Limited\r\nEllerbeck Court\r\nStokesley Business Park\r\nNorth Yorkshire\r\nTS9 5PT\r\nEngland' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('printable' , 'packing_logo' , '../images/silver/logo.jpg' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'affiliate_commission_amount' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'affiliate_commission_type' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'affiliate_cookie_expire' , '90' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'big_image_max_height' , '300' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'big_image_max_width' , '300' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'confirm_add' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'coupons_enable' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'display_products' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'froogle_days_expiry' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'froogle_tax' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'hide_add_details' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'hide_add_list' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'hide_checkout_details' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'hide_checkout_list' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'hide_view_details' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'hide_view_list' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'hide_weight_details' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'logout_cart_clear' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'merchant_fee_amount' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'merchant_fee_type' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'min_payment_amount' , '100' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'orders_currency' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'product_code_basket' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'product_code_checkout' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'product_code_details' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'product_code_list' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'product_no_image' , 'images/no_image.gif' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'product_quantity' , 'LISTBOX' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'products_description' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'products_keywords' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'products_title' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'quantity_control' , 'LISTBOX' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'redirect_to_cart' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'resize_big_image' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'resize_small_image' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'resize_super_image' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'reviews_availability' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'small_image_max_height' , '100' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'small_image_max_width' , '100' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'super_image_max_height' , '768' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'super_image_max_width' , '1024' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'tax_note' , 'incl. VAT' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'tax_note_excl' , 'excl. VAT' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'tax_prices' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'user_generate_large_image' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'user_generate_small_image' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'user_generate_super_image' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'user_large_image_height' , '300' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'user_large_image_size' , '65536' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'user_large_image_width' , '300' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'user_registration' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'user_resize_large_image' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'user_resize_small_image' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'user_resize_super_image' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'user_small_image_height' , '100' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'user_small_image_size' , '16384' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'user_small_image_width' , '100' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'user_super_image_height' , '768' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'user_super_image_size' , '196608' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products' , 'user_super_image_width' , '1024' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products_tell_friend' , 'default_comment' , 'Hi {friend_name} - I thought you might be interested in seeing the {item_name} at this site {item_url}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products_tell_friend' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products_tell_friend' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products_tell_friend' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products_tell_friend' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products_tell_friend' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products_tell_friend' , 'user_message' , 'Thought you might be interested in seeing the {item_name} at {item_url}\r\n\r\n{user_name} left you a note:\r\n{user_comment}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products_tell_friend' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('products_tell_friend' , 'user_subject' , 'You were invited by {user_name} to visit site at {site_url}!' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('search' , 'manufacturer' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('search' , 'price' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('search' , 'search_for' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('search' , 'search_in' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('search' , 'search_in_category' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('search' , 'weight' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('site_map' , 'site_map_ad_categories' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('site_map' , 'site_map_ads' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('site_map' , 'site_map_articles_1' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('site_map' , 'site_map_articles_3' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('site_map' , 'site_map_articles_30' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('site_map' , 'site_map_articles_4' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('site_map' , 'site_map_articles_5' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('site_map' , 'site_map_articles_6' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('site_map' , 'site_map_articles_categories_1' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('site_map' , 'site_map_articles_categories_3' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('site_map' , 'site_map_articles_categories_30' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('site_map' , 'site_map_articles_categories_4' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('site_map' , 'site_map_articles_categories_5' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('site_map' , 'site_map_articles_categories_6' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('site_map' , 'site_map_categories' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('site_map' , 'site_map_custom_pages' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('site_map' , 'site_map_forum_categories' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('site_map' , 'site_map_forums' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('site_map' , 'site_map_items' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('site_map' , 'site_map_manual_categories' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('site_map' , 'site_map_manuals' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('support' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('support' , 'admin_message' , 'Request Description:\r\n{description}\r\n\r\nReply message:\r\n{message_text}\r\n\r\n{site_url}admin/admin_support_reply.php?support_id={support_id}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('support' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('support' , 'admin_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('support' , 'admin_subject' , 'Support Request :: {summary}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('support' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('support' , 'intro_text' , 'Dont hesitate to contact us if you have any questions or problems. Our Support Team try help you with your request.' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('support' , 'knowledge_article_status' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('support' , 'knowledge_category' , '30' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('support' , 'user_message' , '{message_text}\r\n\r\nUse following URL to reply\r\n{support_url}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('support' , 'user_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('support' , 'user_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('support' , 'user_subject' , 'Support Request :: {summary}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'address1_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'address2_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'admin_email' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'admin_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'admin_message' , 'Name: {name}\r\nDate: {registration_date}' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'admin_message_type' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'admin_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'admin_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'admin_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'admin_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'admin_subject' , 'New user was registered' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'cc_emails' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'cell_phone_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'city_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'company_id_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'company_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'country_code_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'daytime_phone_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'delivery_address1_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'delivery_address2_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'delivery_cell_phone_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'delivery_city_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'delivery_company_id_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'delivery_company_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'delivery_country_code_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'delivery_daytime_phone_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'delivery_email_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'delivery_evening_phone_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'delivery_fax_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'delivery_first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'delivery_last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'delivery_name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'delivery_phone_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'delivery_province_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'delivery_state_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'delivery_zip_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'email_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'evening_phone_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'fax_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'first_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'friendly_url_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'full_description_editor' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'full_description_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'intro_text_new' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'intro_text_registered' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'last_name_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'name_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'paypal_account_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'personal_image_height' , '150' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'personal_image_size' , '32000' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'personal_image_width' , '150' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'phone_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'province_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'registration_redirect' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'short_description_editor' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'short_description_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_address1' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_address2' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_cell_phone' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_city' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_company_id' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_company_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_country_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_daytime_phone' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_delivery_address1' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_delivery_address2' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_delivery_cell_phone' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_delivery_city' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_delivery_company_id' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_delivery_company_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_delivery_country_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_delivery_daytime_phone' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_delivery_email' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_delivery_evening_phone' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_delivery_fax' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_delivery_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_delivery_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_delivery_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_delivery_phone' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_delivery_province' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_delivery_state_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_delivery_zip' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_email' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_evening_phone' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_fax' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_first_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_friendly_url' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_full_description' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_last_name' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_name' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_paypal_account' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_personal_image' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_phone' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_province' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_short_description' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_state_code' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_tax_id' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'show_zip' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'state_code_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'tax_id_required' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'update_redirect' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'use_random_image' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'user_mail_bcc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'user_mail_cc' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'user_mail_from' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'user_mail_return_path' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'user_message' , 'Your login is <b>{login}</b> and password is <b>{password}</b><br>\r\n<br><br>\r\nYou can visit our site at any time at following URL: <a target="_blank" href="{site_url}">{site_url}</a>' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'user_message_type' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'user_notification' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'user_sms_message' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'user_sms_notification' , '0' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'user_sms_originator' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'user_sms_recipient' , NULL ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'user_subject' , 'Dear {name}, you were successfully registered' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('user_profile_1' , 'zip_required' , '1' ) ;
INSERT INTO [va_global_settings] ([setting_type],[setting_name],[setting_value]) VALUES ('version' , 'number' , '3.2' ) ;


INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (1 , 2 , 1 , NULL , 'MENU_HOME' , 'index.php' , NULL , 'images/curved/menu-main.gif' , NULL , 1 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (2 , 2 , 2 , NULL , 'MENU_PRODUCTS' , 'products.php' , NULL , 'images/curved/menu-products.gif' , NULL , 2 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (3 , 2 , 3 , NULL , 'MENU_BASKET' , 'basket.php' , NULL , 'images/curved/menu-basket.gif' , NULL , 3 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (4 , 2 , 4 , NULL , 'MENU_MYPROFILE' , 'user_profile.php' , NULL , 'images/curved/menu-registration.gif' , NULL , 4 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (5 , 2 , 5 , NULL , 'MENU_ADMIN' , 'admin/admin.php' , NULL , 'images/curved/menu-admin.gif' , NULL , 5 , 1 , 0 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (6 , 2 , 6 , NULL , 'MENU_EVENTS' , 'articles.php?category_id=6' , NULL , 'images/curved/menu-events.gif' , NULL , 6 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (7 , 2 , 7 , NULL , NULL , 'index.php' , NULL , 'images/curved/logo_os.gif' , NULL , 7 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (8 , 2 , 8 , NULL , 'MENU_NEWS' , 'articles.php?category_id=1' , NULL , 'images/curved/menu-news.gif' , NULL , 8 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (9 , 2 , 9 , NULL , 'MENU_USERHOME' , 'user_home.php' , NULL , 'images/curved/menu-user_home.gif' , NULL , 9 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (10 , 2 , 10 , NULL , 'MENU_SUPPORT' , 'support.php' , NULL , 'images/curved/menu-support.gif' , NULL , 10 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (11 , 2 , 11 , NULL , 'MENU_FORUM' , 'forums.php' , NULL , 'images/curved/menu-forum.gif' , NULL , 11 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (12 , 2 , 12 , NULL , 'MENU_HELP' , 'page.php?page=help' , NULL , 'images/curved/menu-help.gif' , NULL , 12 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (13 , 2 , 13 , NULL , 'MENU_ABOUT' , 'page.php?page=about' , NULL , 'images/curved/menu-about.gif' , NULL , 13 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (21 , 1 , 21 , NULL , 'MENU_HOME' , 'index.php' , NULL , NULL , NULL , 1 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (22 , 1 , 22 , NULL , 'MENU_PRODUCTS' , 'products.php' , NULL , NULL , NULL , 2 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (23 , 1 , 23 , NULL , 'MENU_BASKET' , 'basket.php' , NULL , NULL , NULL , 3 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (24 , 1 , 24 , NULL , 'MENU_SIGNIN' , 'user_login.php' , NULL , NULL , NULL , 4 , 1 , 0 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (25 , 1 , 25 , NULL , 'MENU_USERHOME' , 'user_home.php' , NULL , NULL , NULL , 5 , 0 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (26 , 1 , 26 , NULL , 'MENU_NEWS' , 'articles.php?category_id=1' , NULL , NULL , NULL , 6 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (27 , 1 , 27 , NULL , 'MENU_SUPPORT' , 'support.php' , NULL , NULL , NULL , 7 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (28 , 1 , 28 , NULL , 'MENU_FORUM' , 'forums.php' , NULL , NULL , NULL , 8 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (29 , 1 , 29 , NULL , 'MENU_EVENTS' , 'articles.php?category_id=6' , NULL , NULL , NULL , 9 , 0 , 0 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (30 , 1 , 30 , NULL , 'MENU_FAQ' , 'articles.php?category_id=4' , NULL , NULL , NULL , 10 , 0 , 0 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (31 , 1 , 31 , NULL , 'MENU_HELP' , 'page.php?page=help' , NULL , NULL , NULL , 11 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (32 , 1 , 32 , NULL , 'MENU_ABOUT' , 'page.php?page=about' , NULL , NULL , NULL , 12 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (33 , 3 , 33 , NULL , 'MENU_HOME' , 'index.php' , NULL , NULL , NULL , 1 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (34 , 3 , 34 , NULL , 'MENU_PRODUCTS' , 'products.php' , NULL , NULL , NULL , 2 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (35 , 3 , 35 , NULL , 'MENU_BASKET' , 'basket.php' , NULL , NULL , NULL , 3 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (36 , 3 , 36 , NULL , 'MENU_SIGNIN' , 'user_login.php' , NULL , NULL , NULL , 4 , 1 , 0 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (37 , 3 , 37 , NULL , 'MENU_USERHOME' , 'user_home.php' , NULL , NULL , NULL , 5 , 0 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (38 , 3 , 38 , NULL , 'MENU_NEWS' , 'articles.php?category_id=1' , NULL , NULL , NULL , 6 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (39 , 6 , 39 , NULL , 'MENU_HOME' , 'index.php' , NULL , NULL , NULL , 1 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (40 , 6 , 40 , NULL , 'MENU_PRODUCTS' , 'products.php' , NULL , NULL , NULL , 2 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (41 , 6 , 41 , NULL , 'MENU_BASKET' , 'basket.php' , NULL , NULL , NULL , 3 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (42 , 6 , 42 , NULL , 'MENU_SIGNIN' , 'user_login.php' , NULL , NULL , NULL , 4 , 1 , 0 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (44 , 6 , 44 , NULL , 'MENU_USERHOME' , 'user_home.php' , NULL , NULL , NULL , 5 , 0 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (46 , 6 , 46 , NULL , 'MENU_EVENTS' , 'articles.php?category_id=6' , NULL , NULL , NULL , 6 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (51 , 6 , 51 , NULL , 'MENU_NEWS' , 'articles.php?category_id=1' , NULL , NULL , NULL , 7 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (52 , 7 , 52 , NULL , 'MENU_HOME' , 'index.php' , NULL , NULL , NULL , 1 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (53 , 7 , 53 , NULL , 'MENU_PRODUCTS' , 'products.php' , NULL , NULL , NULL , 2 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (54 , 7 , 54 , NULL , 'MENU_BASKET' , 'basket.php' , NULL , NULL , NULL , 3 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (55 , 7 , 55 , NULL , 'MENU_SIGNIN' , 'user_login.php' , NULL , NULL , NULL , 4 , 1 , 0 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (56 , 7 , 56 , NULL , 'MENU_USERHOME' , 'user_home.php' , NULL , NULL , NULL , 5 , 0 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (62 , 7 , 62 , NULL , 'MENU_HELP' , 'page.php?page=help' , NULL , NULL , NULL , 11 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (63 , 7 , 63 , NULL , 'MENU_ABOUT' , 'page.php?page=about' , NULL , NULL , NULL , 12 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (64 , 9 , 64 , NULL , 'MENU_HOME' , 'index.php' , NULL , NULL , NULL , 1 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (65 , 9 , 65 , NULL , 'MENU_PRODUCTS' , 'products.php' , NULL , NULL , NULL , 2 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (66 , 9 , 66 , NULL , 'MENU_BASKET' , 'basket.php' , NULL , NULL , NULL , 3 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (67 , 9 , 67 , NULL , 'MENU_SIGNIN' , 'user_login.php' , NULL , NULL , NULL , 4 , 1 , 0 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (68 , 9 , 68 , NULL , 'MENU_USERHOME' , 'user_home.php' , NULL , NULL , NULL , 5 , 0 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (69 , 9 , 69 , NULL , 'MENU_ABOUT' , 'page.php?page=about' , NULL , NULL , NULL , 6 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (70 , 8 , 70 , NULL , 'MENU_HOME' , 'index.php' , NULL , NULL , NULL , 1 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (71 , 8 , 71 , NULL , 'MENU_PRODUCTS' , 'products.php' , NULL , NULL , NULL , 2 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (72 , 8 , 72 , NULL , 'MENU_BASKET' , 'basket.php' , NULL , NULL , NULL , 3 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (76 , 8 , 76 , NULL , 'MENU_MYPROFILE' , 'user_profile.php' , NULL , NULL , NULL , 5 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (78 , 8 , 78 , NULL , 'MENU_USERHOME' , 'user_home.php' , NULL , NULL , NULL , 6 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (81 , 8 , 81 , NULL , 'MENU_HELP' , 'page.php?page=help' , NULL , NULL , NULL , 7 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (82 , 8 , 82 , NULL , 'MENU_ABOUT' , 'page.php?page=about' , NULL , NULL , NULL , 8 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (83 , 4 , 83 , NULL , 'MENU_HOME' , 'index.php' , NULL , NULL , NULL , 1 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (84 , 4 , 84 , NULL , 'MENU_PRODUCTS' , 'products.php' , NULL , NULL , NULL , 2 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (85 , 4 , 85 , NULL , 'MENU_BASKET' , 'basket.php' , NULL , NULL , NULL , 3 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (86 , 4 , 86 , NULL , 'MENU_MYPROFILE' , 'user_profile.php' , NULL , NULL , NULL , 4 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (87 , 4 , 87 , NULL , 'MENU_ADMIN' , 'admin/admin.php' , NULL , NULL , NULL , 5 , 1 , 0 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (88 , 4 , 88 , NULL , 'MENU_EVENTS' , 'articles.php?category_id=6' , NULL , NULL , NULL , 6 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (90 , 4 , 90 , NULL , 'MENU_NEWS' , 'articles.php?category_id=1' , NULL , NULL , NULL , 8 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (91 , 4 , 91 , NULL , 'MENU_USERHOME' , 'user_home.php' , NULL , NULL , NULL , 9 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (94 , 4 , 94 , NULL , 'MENU_HELP' , 'page.php?page=help' , NULL , NULL , NULL , 10 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (95 , 4 , 95 , NULL , 'MENU_ABOUT' , 'page.php?page=about' , NULL , NULL , NULL , 11 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (96 , 5 , 96 , NULL , 'MENU_HOME' , 'index.php' , NULL , NULL , NULL , 1 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (97 , 5 , 97 , NULL , 'MENU_PRODUCTS' , 'products.php' , NULL , NULL , NULL , 2 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (98 , 5 , 98 , NULL , 'MENU_BASKET' , 'basket.php' , NULL , NULL , NULL , 3 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (99 , 5 , 99 , NULL , 'MENU_MYPROFILE' , 'user_profile.php' , NULL , NULL , NULL , 4 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (101 , 5 , 101 , NULL , NULL , 'index.php' , NULL , NULL , NULL , 6 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (102 , 5 , 102 , NULL , 'MENU_EVENTS' , 'articles.php?category_id=6' , NULL , NULL , NULL , 7 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (103 , 5 , 103 , NULL , 'MENU_NEWS' , 'articles.php?category_id=1' , NULL , NULL , NULL , 8 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (104 , 5 , 104 , NULL , 'MENU_USERHOME' , 'user_home.php' , NULL , NULL , NULL , 9 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (107 , 5 , 107 , NULL , 'MENU_HELP' , 'page.php?page=help' , NULL , NULL , NULL , 10 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (109 , 3 , 109 , NULL , 'MENU_ABOUT' , 'page.php?page=about' , NULL , NULL , NULL , 7 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (110 , 3 , 110 , NULL , 'MENU_FORUM' , 'forums.php' , NULL , NULL , NULL , 8 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (111 , 3 , 111 , NULL , 'MENU_SUPPORT' , 'support.php' , NULL , NULL , NULL , 9 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (112 , 6 , 112 , NULL , 'MENU_SIGNOUT' , 'user_login.php?operation=logout' , NULL , NULL , NULL , 9 , 0 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (132 , 3 , 132 , NULL , 'MENU_SIGNOUT' , 'user_login.php?operation=logout' , NULL , NULL , NULL , 10 , 0 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (133 , 6 , 133 , NULL , 'MENU_ABOUT' , 'page.php?page=about' , NULL , NULL , NULL , 8 , 1 , 1 ) ;
INSERT INTO [va_header_links] ([menu_id],[layout_id],[parent_menu_id],[menu_path],[menu_title],[menu_url],[menu_target],[menu_image],[menu_image_active],[menu_order],[show_non_logged],[show_logged]) VALUES (134 , 9 , 134 , NULL , 'MENU_SIGNOUT' , 'user_login.php?operation=logout' , NULL , NULL , NULL , 7 , 0 , 1 ) ;


INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (0 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (1 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (2 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (3 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (4 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (5 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (6 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (7 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (8 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (9 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (10 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (11 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (12 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (13 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (14 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (15 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (16 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (17 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (18 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (19 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (20 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (21 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (22 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (23 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (24 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (25 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (26 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (27 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (28 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (29 ) ;
INSERT INTO [va_issue_numbers] ([issue_number]) VALUES (30 ) ;


INSERT INTO [va_item_types] ([item_type_id],[item_type_name],[is_gift_voucher],[is_bundle],[is_user],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount]) VALUES (1 , 'Product' , 0 , 0 , 1 , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_item_types] ([item_type_id],[item_type_name],[is_gift_voucher],[is_bundle],[is_user],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount]) VALUES (2 , 'Accessory' , 0 , 0 , 1 , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_item_types] ([item_type_id],[item_type_name],[is_gift_voucher],[is_bundle],[is_user],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount]) VALUES (3 , 'Gift Voucher' , 1 , 0 , 0 , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_item_types] ([item_type_id],[item_type_name],[is_gift_voucher],[is_bundle],[is_user],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount]) VALUES (4 , 'Bundle' , 0 , 1 , 0 , NULL , NULL , NULL , NULL ) ;


INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (4 , 'Manhattan Unfurled' , NULL , 1 , 1 , NULL , NULL , 2 , '0375504915' , NULL , NULL , NULL , NULL , NULL , 'Matteo Pericoli trained as an architect in Milan and then came to work in New York in 1995. His arrival preceded by just a few days the arrival of the biggest snowstorm of the decade, and the sense of the city in its wakeespecially its silenceremained in his mind. He experienced similar feeling taking photographs of Riverside Drive from the Circle Line ferry, and decided to transpose them into a line drawing. It was then that he felt compelled to photograph the whole of New... ' , 0 , 'Matteo Pericoli trained as an architect in Milan and then came to work in New York in 1995. His arrival preceded by just a few days the arrival of the biggest snowstorm of the decade, and the sense of the city in its wakeespecially its silenceremained in his mind. He experienced similar feeling taking photographs of Riverside Drive from the Circle Line ferry, and decided to transpose them into a line drawing. It was then that he felt compelled to photograph the whole of New Yorks shoreline profilefrom Queens, Brooklyn, the Bronx, and New Jersey (which he reached by motorcycle)  and make two continuous and continuously enchanting pen-and-ink drawing of Manhattans skyline. \r\n\r\nManhattan Unfurled is published in an elegant slipcase, and the drawings fold out, accordion-style, with the West on one side and the East on the other. An introduction by distinguished New Yorker architecture critic Paul Goldberger, who first wrote bout Matteos project in The New Yorkers Talk of the Town, will accompany the drawing in a separate pamphlet. This book is both a wonderful New York City memento, perfect for gift giving, and an entirely unique work of art.\r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0375504915.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0375504915.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 29.95 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 20.96 , 0 , 30 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , '' , NULL , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (5 , 'The Artist''s Way Morning Pages Journal : A Companion Volume to the Artist''s Way' , NULL , 1 , 1 , NULL , NULL , 2 , '0874778867' , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 'The idea behind Julia Cameron''s The Artist''s Way is that by writing three pages, longhand and stream-of consciousness, first thing in the morning, you can overcome the obstacles that stop you from becoming your most creative self. This works partly because it forces you to create something (even if it is just a long list of gripes) every single day. It doesn''t take much time. You''re not even supposed to think. But the act itself gets you past all that self-defeating fretting about why you think you aren''t a creative person. Cameron sees her morning pages as "a form of meditation," as "spiritual windshield wipers."\r\nWhile Cameron touts the morning pages as a way of life, she suggests you start out doing them as part of a "twelve-week program to recover your creativity." If you would like to keep your first twelve weeks of morning pages together in one tidy place, The Artist''s Way Morning Pages Journal is a fine tool for doing so. Each nearly blank page features an inspiring quotation from The Artist''s Way: "Leap, and the net will appear," says one; "Creativity lies not in the done but in doing," reminds another. We should mention that many of these little inspirations include references to God, which may be troublesome even for spiritual atheists. --Jane Steinberg \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0874778867.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , NULL , 'http://images.amazon.com/images/P/0874778867.01.MZZZZZZZ.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 14.95 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 11.96 , 0 , 20 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , '' , NULL , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (7 , 'Rock Star' , NULL , 1 , 1 , NULL , NULL , 2 , 'B00005TPMA' , NULL , NULL , NULL , NULL , NULL , 'Watch Mark Wahlberg and Jennifer Aniston live the highs and lows of a rock  & roll fantasy come true in Rock Star.  Black leather pants recommended.\r\n' , 0 , 'This movie is a must for your collection, especially if you''re fan of BIG HAIR ROCK. I grew up with the type of music this film is based on. I thought Mark Wahlberg did an amazing job of capturing the essence of a Heavy Metal  frontman. He had the perfect swagger and look. Even if you aren''t a huge fan of Metal, I''m sure at one time you''ve fantasized about being a rock star or some type of entertainer, right? I''m sure you''ll be able to relate to the story of a guy who sings for a tribute band of his heroes, eventually getting the call to front the ACTUAL band. Jennifer Aniston and the cast of real life rockers like guitarist Zakk Wylde and Third Eye Blind''s Stephan Jenkins are all great too. Oh and by the way... the soundtrack CD is also excellent, with original music from the film''s  band, Steel Dragon and classics from KISS, Bon Jovi and others. For a fun film  ride I enthusiastically recommend ROCK STAR! Enjoy!!!' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005TPMA.01.25TRZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005TPMA.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 19.98 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 14.95 , 0 , 25 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , '' , NULL , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (9 , 'Anthony Blunt: His Lives' , NULL , 1 , 1 , NULL , NULL , 2 , '0374105316' , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 'From Publishers Weekly \r\nThis engaging and important biography examines the many masks of the infamous Anthony Blunt (1907-1983), the Cambridge art historian turned spy who worked simultaneously for British Intelligence and the Soviet Union during WWII. Why did he betray his country? Carter provides an exhaustive psychological study of Blunt''s early life. His brutalizing public school (where he was unhappy and unpopular), Carter argues, "inadvertently fostered a questioning and subversive attitude and a profound distrust of authority." When the Depression hit England in the 1930s and the specter of fascism threatened Europe, communism became fashionable among left-leaning intellectuals like Blunt and his Cambridge friend Guy Burgess. Blunt''s homosexuality, like Burgess''s, also appears to have alienated him from the establishment. During WWII, Blunt was assigned to British intelligence, giving him easy access to military secrets, which he smuggled to the Soviets. After his Cambridge spy friends Burgess, Donald MacLean and Kim Philby defected to the Soviet Union after the war, British Intelligence began investigating Blunt. In 1964, he was granted immunity in exchange for his confession and full cooperation. British intelligence worked hard to keep "the Blunt affair" a secret. He wasn''t publicly exposed until 1979, when Margaret Thatcher denounced him. The biggest challenge any Blunt biographer faces is Blunt himself, a man of almost legendary emotional detachment. Blunt revealed little about his personal life, yet Carter has managed to bring readers as close to this enigmatic man as humanly possible. Thoroughly researched and carefully crafted, this is sure to be the definitive biography. 16 pages of photos not seen by PW. (Jan.)Forecast: Blunt''s story isn''t quite the sensation here that it is in England; devotees of spy tales and contemporary British history will read this.\r\n\r\nCopyright 2001 Cahners Business Information, Inc.\r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0374105316.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0374105316.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 30 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 21 , 0 , 30 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , '' , NULL , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (10 , 'Awakening the Virgin' , NULL , 1 , 1 , NULL , NULL , 2 , '1555834566' , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/1555834566.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , NULL , 'http://images.amazon.com/images/P/1555834566.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 13.95 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 11.16 , 0 , 20 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , '' , NULL , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (11 , 'Beaches' , NULL , 1 , 1 , NULL , NULL , 2 , '0811826503' , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 'The authors of The Beach: The History of Paradise on Earth, the best-selling history of everyone''s favorite place, are back with a breathtaking visual companion. From moody, craggy coastlines to serene swathes of turquoise water and white sand, Beaches is an astounding photographic survey of the ineffable allure of paradise on earth. This spectacular collection of images from renowned photographers, including Robert Misrach, Joel Meyerowitz, and Art Wolff, stirs the spirit, capturing the mutable beauty of sand, sea, and sky. Throughout, concise and poetic pieces of historic and scientific lore unveil little-known facts and curiosities. With an astonishing range of vision, Beaches evokes the idiosyncratic beauty of the world''s most stunning coastlines. \r\n\r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0811826503.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , NULL , 'http://images.amazon.com/images/P/0811826503.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 24.95 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 17.46 , 0 , 30 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , '' , NULL , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (12 , 'Beaches of Maui County (A Kolowalu Book)' , NULL , 1 , 1 , NULL , NULL , 2 , '0824812468' , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0824812468.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , NULL , 'http://images.amazon.com/images/P/0824812468.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 14.95 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 11.96 , 0 , 20 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , '' , NULL , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (13 , 'Exploring Southern California Beaches (FalconGuide)' , NULL , 1 , 1 , NULL , NULL , 2 , '1560446323' , NULL , NULL , NULL , NULL , NULL , NULL , 0 , '"From the bustle of the Mexican border to the isolated beauty of Point Conception, sit back and enjoy the ride as veteran writer and beach bum David Crowell takes you on Safari in Exploring Southern California Beaches. Discover the diversity of life in " --This text refers to the Digital edition. ' , 1 , '"From the bustle of the Mexican border to the isolated beauty of Point Conception, sit back and enjoy the ride as veteran writer and beach bum David Crowell takes ...' , NULL , 'http://images.amazon.com/images/P/1560446323.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , NULL , 'http://images.amazon.com/images/P/1560446323.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 18.95 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 13.26 , 0 , 30 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , '' , NULL , 2 , 10 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (28 , 'The Lord of the Rings (Collector''s Edition)' , NULL , 1 , 1 , NULL , NULL , 2 , '0395193958' , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 'The New York Times \r\n"A unique, wholly realized other world, evoked from deep in the well of Time, massively detailed, absorbingly entertaining..." ' , 1 , 'The New York Times \r\n"A unique, wholly realized other world, evoked from deep in the well of Time, massively detailed, absorbingly entertaining..." ' , NULL , 'http://images.amazon.com/images/P/0395193958.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0395193958.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 75 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 52.5 , 0 , 30 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , '' , NULL , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (29 , 'The Lord of the Rings (Boxed Set)' , NULL , 4 , 1 , NULL , NULL , 2 , '0395489326' , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 'The three volumes that make up Tolkien''s epic classic The Lord of the Rings are here presented in their standard cloth editions including large format fold-out maps and an extensive appendices. Set contains The Fellowship of the Ring, The Two Towers, and The Return of the King, with jackets and a box designed by celebrated illustrator Alan Lee. \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0395489326.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0395489326.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 65 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 45.5 , 0 , 30 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , '' , NULL , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (30 , 'The Silmarillion' , NULL , 3 , 1 , NULL , NULL , 2 , '0345325818' , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 'The Silmarillion is J.R.R. Tolkien''s tragic, operatic history of the First Age of Middle-Earth, essential background material for serious readers of the classic Lord of the Rings saga. Tolkien''s work sets the standard for fantasy, and this audio version of the "Bible of Middle-Earth" does The Silmarillion justice. Martin Shaw''s reading is grave and resonant, conveying all the powerful events and emotions that shaped elven and human history long before Bilbo, Frodo, Gandalf and all the rest embarked on their quests. Beginning with the Music of the Ainur, The Silmarillion tells a tale of the Elder Days, when Elves and Men became estranged by the Dark Lord Morgoth''s lust for the Silmarils, pure and powerful magic jewels. Even the love between a human warrior and the daughter of the Elven king cannot defeat Morgoth, but the War of Wrath finally brings down the Dark Lord. Peace reigns until the evil Sauron recovers the Rings of Power and sets the stage for the events told in the Lord of the Rings. This is epic fantasy at its finest, thrillingly read and gloriously unabridged. (Running time: 14 hours, 6 CDs) --This text refers to the Audio CD edition. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0345325818.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0345325818.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 6.99 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 6.99 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , '' , NULL , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (32 , 'Dark Journey (Star Wars: The New Jedi Order, Book 10)' , NULL , 2 , 1 , NULL , NULL , 2 , '0345428692' , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 'About the Author \r\nA former music and history teacher, Elaine Cunningham has written more than a dozen fantasy novels and many short stories. She is best known for the Songs & Swords books, particularly Elfshadow, a mystery in a fantasy setting. She lives with her family in a coastal New England town.\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0345428692.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0345428692.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 6.99 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 6.99 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , '' , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (35 , 'HomeSite 5.0' , NULL , 1 , 1 , NULL , NULL , 2 , 'B00005U2FY' , NULL , NULL , NULL , NULL , NULL , 'Ever popular with professional Web developers, HomeSite 5.0 offers advanced hand-coding features, productivity enhancing wizards, and a customizable user interface to efficiently build, deploy, and manage your entire Web site. HomeSite 5.0 also includes XHTML support and new Folder Deployment settings. Check out the full or upgrade version today.\r\n' , 0 , 'Developers can create professional Web sites fast with the code editing features of Macromedia HomeSite 5. The software delivers advanced hand coding features, productivity-enhancing wizards, and a customizable user interface to efficiently build, deploy, and manage your entire Web site. Effortlessly validate, reuse, navigate, and format your code with integrated coding tools. The wizards quickly create pages, tables, frames, and JavaScript elements for you.\r\nWith XHTML support, based on the W3C specifications for XHTML 1.0, developers can build pages with the latest Web technologies. The extensibility of XHTML provides the flexibility to incorporate new Web communication and presentation ideas as they emerge. Developers can use the new Secondary Files tab to browse local and remote files simultaneously and to drag and drop files between the two Files tabs, efficiently incorporating documents and images. \r\n\r\nThe new Folder Deployment settings enable developers to determine the deployment method for individual folders and files within a project. These new settings make deployment much more accessible to the novice user while maintaining the sophistication of the feature for the high-end user. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005U2FY.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005U2FY.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 99 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 99 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , '' , NULL , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (40 , 'Microsoft Visual Studio .NET Professional Upgrade' , NULL , 1 , 1 , NULL , NULL , 2 , 'B00005RV50' , NULL , NULL , NULL , NULL , NULL , 'Visual Studio .NET Professional enables developers to build the next generation of Internet applications with XML Web services, database applications with XML, and RAD for the .NET Server. \r\nIt enables developers to build solutions for the broadest... ' , 0 , 'Visual Studio .NET Professional enables developers to build the next generation of Internet applications with XML Web services, database applications with XML, and RAD for the .NET Server. It enables developers to build solutions for the broadest range of clients--from Web applications to Windows to thin-client devices to smart devices. The RAD capabilities provide a shared IDE and a choice of programming languages, including Visual Basic, C++, C#, and Java. Visual Studio .NET Professional is RAD for the programmable Web.\r\nIn XML, Visual Studio .NET developers can build data-driven applications using built-in ADO.NET tools that target a variety of databases, including SQL Server, Oracle, or any other XML source. With support for XML, ADO.NET enables developers to share data across computing platforms. Additionally, Visual Studio .NET includes the Microsoft Data Engine (MSDE), a SQL Server-compatible database that provides programmers with a viable development database and natively supports XML.\r\n\r\nVisual Studio .NET allows programmers to create and deploy critical server-based programming. With Visual Studio .NET, developers can visually compose middle-tier components using the Visual Component Designer (VCD). The VCD enables developers to drag and drop nonvisual objects such as message queues, timers, and event logs to a design surface, automatically discovering all necessary server-based resources and configuring required components. \r\n\r\n' , 0 , NULL , 'This is an upgrade version. Any owner of Visual Studio 97 or Visual Studio 6.0 and later--except for standard versions--is eligible for the upgrade. ' , 'http://images.amazon.com/images/P/B00005RV50.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005RV50.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 549 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 544.99 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , '' , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (41 , 'Groundhog Day (Special Edition) (1993)' , NULL , 1 , 1 , NULL , NULL , 2 , 'B00005U8EM' , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 'Bill Murray does warmth in his most consistently effective post-Stripes comedy,\r\n                  a romantic fantasy about a wacky weatherman forced to relive one strange day\r\n                  over and over again, until he gets it right. Snowed in during a road-trip expedition\r\n                  to watch the famous groundhog encounter his shadow, Murray falls into a time\r\n                  warp that is never explained but pays off so richly that it doesn''t need to be. The\r\n                  elaborate loop-the-loop plot structure cooked up by screenwriter Danny Rubin is\r\n                  crystal-clear every step of the way, but it''s Murray''s world-class reactive timing\r\n                  that makes the jokes explode, and we end up looking forward to each new\r\n                  variation. He squeezes all the available juice out of every scene. Without forcing\r\n                  the issue, he makes us understand why this fly-away personality responds so\r\n                  intensely to the radiant sanity of the TV producer played by Andie MacDowell.\r\n                  The blissfully clueless Chris Elliott (Cabin Boy) is Murray''s nudnik cameraman.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005U8EM.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005U8EM.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 24.95 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 18.71 , 0 , 25 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , '' , NULL , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (44 , 'AutoCAD LT 2002' , NULL , 1 , 1 , NULL , NULL , 1 , 'B00005M0UB' , NULL , NULL , NULL , NULL , NULL , 'Product Description\r\nAutoCAD LT 2002 is design and drawing software featuring new timesaving drawing tools. Minimize the number of steps you need to take, freeing you and your team to explore more design options. Save time with true associative dimensioning. When you... ' , 0 , 'AutoCAD LT 2002 is design and drawing software featuring new timesaving drawing tools. Minimize the number of steps you need to take, freeing you and your team to explore more design options. Save time with true associative dimensioning. When you change the geometry of any drawing, the dimensions immediately change. Work smarter and faster with new layer, text, and attribute tools, such as text scaling, the enhanced attribute editor, block attribute manager, layer translator, and an extended spell checker. Robust standards-management tools make checking and adhering to drafting standards easy, whether you work from corporate or ANSI, ISO, DIN, or JIS standards. \r\nTake your designs further by sharing and accessing design data for a more productive team. Get your design information where it''s needed--quickly, easily, and accurately. With AutoCAD LT 2002, you''ll enjoy 100 percent drawing file compatibility. The AutoCAD DWG format remains unchanged from AutoCAD 2000 and AutoCAD 2000i, protecting your investment in AutoCAD 2000/2000i files already in production. You can even translate your DWG files into lightweight, read-only DWF files for maximum intranet or Internet viewing and newly updated high-fidelity plotting. \r\n\r\nSave time and money with eTransmit, which bundles all your drawing files and delivers them at Net speed. Now eTransmit even builds the appropriate design standards right in. You don''t need to be a Web expert to post your content on an intranet or any dedicated central location. Advanced Publish to Web makes it even easier to build pages and follow your corporate look and feel. Store your files online with My Files at Autodesk Point A--Autodesk''s portal for design professionals--or on any FTP or HTTP server. Plus, with simple i-drop publishing, it''s easy to use and reuse design content--from archived libraries to specs from a manufacturer''s site, and more. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005M0UB.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005M0UB.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 659 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 659 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , '' , NULL , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (68 , 'Across an Ocean of Dreams' , NULL , 1 , 1 , NULL , NULL , 2 , 'B00005UF2F' , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 'What does the ocean dream? Glimpse into the depths of jeweled waters and the fantasia within. Surrender to the siren call. Come! Be transported under the waves, flowing with 2002''s delicate strings, guitar, flute, keyboard and distant voices of angels of the deep. 2002 - Favorites on Billboard''s New Age Chart for the past five years! \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005UF2F.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005UF2F.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 17.9 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 14.99 , 0 , 17 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , '' , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (73 , 'Verdi - Messa da Requiem / Gheorghiu  Barcellona  Alagna  Konstantinov  Berliner Philharmoniker  Abbado' , NULL , 1 , 1 , NULL , NULL , 2 , 'B00005MG6F' , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 'Verdi''s Requiem--certainly one of his most moving, eloquent masterpieces--was written in honor of the great Italian poet Alessandro Manzoni, whom he admired enormously both for his writings and his political outlook. Though its text is the Latin liturgy, it has been called Verdi''s greatest opera because of its basically dramatic character, as well as his own ambivalent attitude toward organized religion. Thus, interpretations tend to emphasize its secular or its sacred aspect, though, naturally, the soloists are trained in the Verdi opera tradition.\r\nFor example, Toscanini''s legendary performance, recorded live at Carnegie Hall in 1951, takes exactly the opposite approach to this version. Inwardly expressive, noble, devout, pleading, prayerful, yet with plenty of dramatic intensity, the Toscanini encompasses every human emotion and offers a synthesis of Verdi''s vision of the earthly and the sublime. The performers on this recording, captured live on the 100th anniversary of Verdi''s death, take the theatrical view. The soloists swoop and slide, sob and sigh, and overdramatize the fear and trembling. Tenor Roberto Alagna belts out his part in the best operatic style, the bass sounds rough, the alto''s vibrato wobbles, but soprano Angela Gheorghiu soars radiantly. The choruses are good, the orchestra is wonderful, but the dynamic contrasts go from inaudible to ear-splitting. --Edith Eisler \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005MG6F.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005MG6F.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 16.9 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 15.49 , 0 , 9 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , '' , NULL , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (80 , 'Compaq Presario 2715US Notebook (1.13-MHz Pentium III, 512 MB RAM, 30 GB hard drive)' , '' , 1 , 1 , NULL , NULL , 2 , 'B00005UT2X' , NULL , NULL , 0 , 0 , NULL , 'As a notebook for business or entertainment, Compaq''s Presario 2715US offers a combination of solid features and price that is tough to beat. It boasts a 1.13 GHz Pentium III processor, 512 MB of RAM (expandable to 1,024 MB), a 15-inch,... \r\n Read more \r\n' , 1 , 'As a notebook for business or entertainment, Compaq''s Presario 2715US offers a combination of solid features and price that is tough to beat. It boasts a 1.13 GHz Pentium III processor, 512 MB of RAM (expandable to 1,024 MB), a 15-inch, active-matrix, flat-panel screen, and both an 8x (write) CD-RW and 8x DVD-ROM drive. Also included are a 30 GB hard disk, a 56K modem, and a 10/100 Mbps Ethernet NIC. To round out this Presario''s versatile package, the pre-installed operating system is Windows XP Home. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005UT2X.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005UT2X.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1099 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 999 , 0 , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , NULL , NULL , 1 , 4 , 4 , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '2007-02-15 17:25:17' ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (88 , 'Compaq Presario 5420US Desktop (Athlon XP 1700+, 512 MB RAM, 80 GB hard drive)' , NULL , 1 , 1 , NULL , NULL , 2 , 'B00005UT2S' , NULL , NULL , NULL , NULL , NULL , '1.47 GHz AMD Athlon XP, 512 MB SDRAM, 80 GB Hard Disk, 16x (write) CD-RW, 16x DVD-ROM, and Windows XP Home Edition, Microsoft Money 2001, Windows Media Player 7, Microsoft Works 6.0, Selective QuickRestore, ...  \r\n' , 0 , 'It would be hard to go wrong with a system like the Compaq Presario 5420US. Equipped with a 1.7 GHz Athlon XP processor, an 80 GB hard disk drive, and 512 MB of RAM (expandable to 1,536 MB), it has all the basics covered--and then some. For ease of use, improved multimedia, and better support of peripherals, Compaq has installed Windows XP Home Edition. To enhance multimedia applications and Internet connectivity, this system includes a 16x (write) CD-RW and 16x DVD-ROM drive, integrated graphics, a 56K modem, and a 10/100 Mbps Ethernet NIC. All these features at a price lower than most comparably equipped desktops make this system a versatile addition to any home or office. \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005UT2S.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005UT2S.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 899 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 899 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , '' , NULL , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (92 , 'NEC MultiSync FP1370 Totally Flat 22" Monitor (PC/Mac)' , NULL , 1 , 1 , NULL , NULL , 2 , 'B00004Y6C8' , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 'The NEC MultiSync FP1370 totally flat 22-inch monitor is ideal for users whose work demands high-end performance. This full-featured 22-inch (20-inch viewable) display is well suited for CAD/CAM, graphic design, desktop publishing, animation, document imaging, prepress, medical imaging, and Web design applications. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00004Y6C8.01.11TRZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00004Y6C8.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 899.99 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 799.99 , 0 , 11 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , '' , NULL , 1 , 3 , 3 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (98 , 'ViewSonic VP181 18" Flat Panel LCD Monitor' , NULL , 1 , 1 , NULL , NULL , 2 , 'B00004SYWC' , NULL , NULL , NULL , NULL , NULL , 'ViewSonic''s VP181 ViewPanel is the first 18-inch multifunctional flat panel to incorporate digital, analog, and composite video inputs into an all-in-one display. With its thin 4-inch profile, the adjustable, ergonomically designed ViewSonic VP181 fits easily into confined spaces or can be wall mounted. Its TVT active-matrix display delivers 16.7 million colors. A 1,280 x 1,024 native resolution ( maximum resolution of 1,600 x 1,200) combined with 235 nits of brightness dispense crisp images.\r\n\r\n' , 0 , 'ViewSonic''s VP181 ViewPanel is the first 18-inch multifunctional flat panel to incorporate digital, analog, and composite video inputs into an all-in-one display. With its thin 4-inch profile, the adjustable, ergonomically designed ViewSonic VP181 fits easily into confined spaces or can be wall mounted. Its TVT active-matrix display delivers 16.7 million colors. A 1,280 x 1,024 native resolution ( maximum resolution of 1,600 x 1,200) combined with 235 nits of brightness dispense crisp images.\r\n\r\nOn-demand audio, picture-in-picture capabilities, a variety of supported video formats, and analog and digital compatibility are some of the ViewSonic VP181''s many features. It is capable of accepting multiple input signals. You can hook up additional USB peripherals, such as a scanner, camcorder, or DVD player to the USB ports on the base of the display. The ViewSonic VP181 allows composite video input from your DVD or VCR to run live while working real time on other applications. The USB inputs on the base and panel allow flexible configuration.\r\n\r\nA pair of built-in two-watt speakers produce stereo sound. There are a number of advanced image and sound options for customized viewing and audio. Software drivers are included that enable you to display in both landscape and portrait modes for full-page viewing.\r\n\r\nViewSonic backs the VP181 with a three-year limited warranty on parts and labor. \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00004SYWC.01.17TRZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00004SYWC.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1935 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 1599.99 , 0 , 17 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , '' , NULL , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (106 , 'Nokia 5165 Prepaid Phone (AT&T)' , NULL , 1 , 1 , NULL , NULL , 2 , 'B00005BAUV' , NULL , NULL , NULL , NULL , NULL , 'Looking to buy a cell phone without\r\n       breaking the piggy bank? Choose a\r\n       Nokia 5165 phone with AT&T''s Free2Go\r\n       prepaid service, and score a $50 rebate\r\n       from AT&T Wireless.' , 0 , 'This Nokia 5165 model, which works with AT&T''s Wireless''s prepaid service,\r\n                   has quickly caught on in popularity. Like its predecessor, the 5160i, the 5165 is\r\n                   a lightweight personal phone with impressive talk and standby times that''s loaded\r\n                   with classic, simple-to-learn features. Its changeable faceplates, 30 different\r\n                   ringers (and room for five downloadable tones), and an expansive world of\r\n                   accessories add up to a fun general-purpose phone that''s a perfect fit for\r\n                   prepaid use. And handy refill cards allow you to purchase additional airtime\r\n                   minutes whenever you need them. \r\n\r\n                   Weighing in at 6.2 ounces (including battery), the 5165 measures 5.2 inches\r\n                   high, 1.85 inches wide, and 1.2 inches deep. It''s extremely rugged, and should\r\n                   stand up well to being thrown into bags and briefcases or occasionally dropped.\r\n                   And, its dual-band/trimode operation ensures you''ll be able to receive cellular\r\n                   service anywhere it''s available. The addition of predictive T9 text input, wireless\r\n                   business cards, and e-mail capabilities make it a viable business\r\n                   communications tool as well. \r\n\r\n                   Four buttons handle most menu navigation: a hefty "Navi" key in the middle, up\r\n                   and down arrow buttons that control volume during calls, and a key marked "C"\r\n                   for "clear". Menu navigation is very intuitive. A tap of the Navi key brings up the\r\n                   first of a series of graphical menu items. Hit Navi again for additional menu\r\n                   options, or tap the up or down arrow keys to select a different menu. Top-level\r\n                   menu choices are a phone book, messages (SMS and voice-mail alerts), call\r\n                   log, settings (for calls, phone, and security), system, games (Memory, Snake,\r\n                   and Logic), clock, tones, and keypad lock. The brightly backlit display works well\r\n                   with the control keys to simplify finding and making choices. In text mode, the\r\n                   phone provides five 16-character lines. \r\n\r\n                   The 5165 lets you choose from 30 preprogrammed ringer tones, and you can\r\n                   also download an additional five from AT&T Wireless''s Web site. Although\r\n                   there''s no internal vibration mode, an optional vibrating battery is available. You\r\n                   can store electronic business cards in your phone book. Any friend or\r\n                   associate can forward his or her name, number, and e-mail address to your\r\n                   phone, and you can automatically store the information with some deft menu\r\n                   navigation. \r\n\r\n                   One caveat regarding faceplates: In theory, all 5100-series faceplates should\r\n                   work with this phone, but in practice, only Nokia-brand faceplates seem to work.\r\n                   The problem is the keypad, the thin rubber pad inside the phone on which the\r\n                   actual keys are mounted. We tried several different faceplate models (both\r\n                   Nokia-branded and after-market models) and found the 5165''s original keypad\r\n                   will not accommodate non-Nokia faceplates. \r\n\r\n                   The 5165 supports the usual array of call and messaging features, including\r\n                   caller ID, call waiting, call forwarding, and voice-mail. A call history stores the\r\n                   last 10 numbers dialed, the 10 most recently received calls, and the last 10\r\n                   missed calls. The phone supports two-way SMS text messaging, but isn''t\r\n                   Web-enabled. \r\n\r\n                   The 5165 offers four basic security features: an initial security code, a keypad\r\n                   lock, call-restriction modes, and a lock code that can activate or deactivate\r\n                   memory and menu options. The lock-code feature lets you store numbers in a\r\n                   secret unlocked location, allowing you to make calls even if the phone is locked. \r\n\r\n                   The 5165''s NiMH battery is rated to last up to 180 minutes of digital talk time and\r\n                   200 hours of digital standby time. In our testing, we achieved 180 minutes of\r\n                   digital talk time and over 225 hours of digital standby time. \r\n\r\n                   Overall, Nokia''s 5165 is a noteworthy and reasonably priced prepaid phone.\r\n                   Choose your favorite faceplate color and ringer tone and start dialing!' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005BAUV.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005BAUV.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 99.99 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 99.99 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , '' , NULL , 1 , 3 , 3 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (107 , 'Nokia 8290 Phone (VoiceStream Wireless)' , NULL , 1 , 1 , NULL , NULL , 2 , 'B000050ZFG' , NULL , NULL , NULL , NULL , NULL , 'Did you know the Nokia 8290 is smaller and\r\n                                        lighter than its sister phone, the Nokia 8260? It\r\n                                        also boasts voice-activated dialing, excellent talk\r\n                                        and standby times, and text messaging support.\r\n                                        Don''t forget about our instant-savings offer,\r\n                                        which takes $50 off the price.' , 0 , 'With the introduction of its striking 8290 digital phone, Nokia sets a new\r\n                   standard for eye-catching style and extreme portability. \r\n\r\n                   We were impressed with the 8290''s robust construction and overall navigation.\r\n                   The phone, which is for GSM networks (like VoiceStream Wireless), also boasts\r\n                   a newly designed internal antenna, excellent talk and standby times, and a host\r\n                   of sophisticated functions including voice-activated dialing and SMS capabilities.\r\n                   The only real missing feature is Web-browsing support. \r\n\r\n                   Where did this tiny phone come from? Essentially, Nokia updated the\r\n                   electronics and boosted the antenna power of its high-end classic, the 8860; put\r\n                   the new design in a sleek, tiny package; and significantly lowered the price. The\r\n                   8290 also borrows the navigation that is a hallmark of its popular 5100-series\r\n                   phones. \r\n\r\n                   Although many of the 8290''s features are available in other premium phone\r\n                   models, its design is like nothing you''ve ever held. Weighing a mere 3.2 ounces\r\n                   and measuring 3.9 by 1.7 by 0.7 inches, the 8290 literally fits in the palm of\r\n                   your hand. It''s also slightly smaller than its sister phone, the popular 8260. \r\n\r\n                   The side-mounted volume-control keys were easy to operate while on a call, and\r\n                   we hooked up a hands-free kit to the headphone jack so we could stow the\r\n                   phone in our pocket while having conversations. One caveat: the tiny power\r\n                   button, located on top of the phone, is almost flush with the casing and hard to\r\n                   find. You won''t be likely to turn the phone on inadvertently, but at times it was a\r\n                   challenge to turn the phone on at all. Other than this quibble, the 8290 is a joy to\r\n                   use. Plus, the 8290 is shipped with a Jabra EarSet for hands-free use. \r\n\r\n                   Three buttons handle most of the menu navigation: a roller-bar navigation key\r\n                   lets you scroll through menu options, and two additional buttons let you select\r\n                   menu options as they appear. The right prompt button also provides one-touch\r\n                   access to your phone book. The top-level menu choices are: Messages (SMS\r\n                   and voice-mail alerts), Call Log, Profiles (so you can choose how your phone\r\n                   behaves in different environments), Settings (for calls, phone, and security),\r\n                   System (so you can select a service provider or opt for automatic selection),\r\n                   Games (Rotation, Memory, Snake, and Logic), Calculator, Calendar, and\r\n                   Keyguard Lock. The backlit, three-line display works well with the control keys,\r\n                   and we found it easy to locate menus and make selections. Despite the phone''s\r\n                   small size, the keypad is well spaced, and we had no problems dialing with one\r\n                   hand. \r\n\r\n                   The Nokia 8290 has a full roster of call and messaging features. If offered by\r\n                   your service plan, it supports caller ID, call waiting, SMS, voice mail, numeric\r\n                   paging, multiparty calling, and e-mail. Three different call logs maintain the last\r\n                   10 dialed numbers, 10 most recently received calls, and 10 missed calls. PIM\r\n                   functions include a clock, currency converter, calculator, calendar with room for\r\n                   50 appointments and reminders, and a 250-entry phone book. There is no\r\n                   standard method of connecting the 8290 to a PC or other device. \r\n\r\n                   A few more cool things worth noting: the 8290 supports swappable faceplates\r\n                   and it has three-NAM capability, so you can route three different numbers to the\r\n                   phone. Its built-in vibrating alert guarantees you will get your calls without\r\n                   annoying the people sitting next to you. \r\n\r\n                   The 8290 offers four basic security features: An initial security code, keypad\r\n                   lock, call restriction modes, and a lock code that can activate or deactivate\r\n                   memory and menu options. One nice thing about the lock-code feature is you\r\n                   can store numbers in a secret unlocked location, which will allow you to make\r\n                   calls even when the phone is locked. \r\n\r\n                   The 8290''s lithium-ion battery is rated to last for a maximum of 210 minutes of\r\n                   digital talk time and 192 hours of digital standby time. In our battery testing it\r\n                   came impressively close. We held an open call for just over three hours, and the\r\n                   phone lasted for nearly eight days in standby mode. \r\n\r\n                   The 8290 is one of the lightest, smallest, most stylish phones around, and it\r\n                   backs up its cool appearance with solid construction and functions. In fact, it\r\n                   one-ups its counterpart, the 8260, with its more compact design and\r\n                   voice-activated dialing feature. Unless you need a phone with a minibrowser,\r\n                   this unit is an excellent match for almost any personal or professional\r\n                   communications need.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B000050ZFG.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B000050ZFG.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 99.99 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 99.99 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , '' , NULL , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (109 , 'Samsung N200 Phone (Sprint PCS)' , NULL , 1 , 1 , NULL , NULL , 2 , 'B00005K2LZ' , NULL , NULL , NULL , NULL , NULL , 'We''re enamored with the new Samsung N-200,\r\n                                        and think it would suit just about anyone''s needs.\r\n                                        It''s highly stylized and outfitted with the right\r\n                                        features--including voice-activated dialing, an\r\n                                        organized minibrowser, and a 229-number\r\n                                        phone book.' , 0 , 'Communicate well into the 21st century with the Samsung N-200. This modern\r\n                   dual-mode marvel--an updated version of the bestselling SCH-3500 model--is\r\n                   equipped with a built-in mini-browser, PIM functions, and voice-activated dialing\r\n                   capabilities. The N-200 is smaller and lighter than its predecessor, and has a\r\n                   five-line display as well as a convenient minijoystick for menu navigation. Other\r\n                   standard features include a vibrating alert, multiple ringer options, and multiple\r\n                   language options.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005K2LZ.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005K2LZ.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 149.99 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 149.99 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , '' , NULL , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (110 , 'Motorola V2397 Prepaid Phone (AT&T)' , NULL , 1 , 1 , NULL , NULL , 2 , 'B00005BAUT' , NULL , NULL , NULL , NULL , NULL , 'Our customers love the V2397, a prepaid phone\r\n  from AT&T Wireless. And with its swappable\r\n  phone-wrap covers, SMS capabilities, and\r\n  reasonable price tag, we can see why.' , 0 , 'Flexible prepaid service, swappable "phone wrap" fashion covers, two-way SMS\r\n                   capabilities, and a reasonable price are some of the highlights of the new\r\n                   Motorola V2397, a prepaid phone offered by AT&T Wireless. \r\n\r\n                   The V2397 measures 6.5 by 2.0 by 1.1 inches, and weighs in at 5.2 ounces.\r\n                   While relatively large, the phone is lightweight, easily portable, and it sports\r\n                   dual-band/dual-mode electronics. \r\n\r\n                   Motorola''s characteristic smart-button navigation, commonly seen on the\r\n                   company''s StarTAC phones, guides you through the V2397''s menu options. The\r\n                   keypad design is less cluttered and confusing than StarTAC phones, however--a\r\n                   definite improvement. Although you still have to use the FCN (function) button to\r\n                   access menu options, all control keys (Function, Store, Clear, Recall) are well\r\n                   spaced. The raised, oval-shaped keypad buttons were quite responsive, and we\r\n                   rarely misdialed a call. The phone felt good to hold, and we could dial\r\n                   one-handed. The four-line screen (two lines of text, two lines of status icons) is\r\n                   backlit and easy to read. A standard 2.5-millimeter communication jack for\r\n                   hands-free devices is integrated into the phone. \r\n\r\n                   The V2397''s handy call management features, including scratchpad memory,\r\n                   nine assignable ringer tones, one-touch speed-dial locations, multiple call timers,\r\n                   and any-key answer, help you organize your communications. You can store up\r\n                   to 99 numbers in the V2397''s phone book, although it does not support multiple\r\n                   entries per contact. Entering phone numbers is easy. Just punch in the number\r\n                   and a unique descriptor, and assign it a memory location. The 30-incoming and\r\n                   20-outgoing call logs help you keep track of your conversations, and the\r\n                   incoming call log keeps track of missed calls to boot. The V2397 supports\r\n                   carrier-dependent features such as caller ID, call waiting, voice-mail alerts, and\r\n                   two-way SMS text messaging, which lets you send and receive alphanumeric\r\n                   messages with other devices. Unfortunately, there is no way to tether the V2397\r\n                   to a PC, so you can''t use it as a digital modem, or import your computer''s\r\n                   address book to the phone. Also, the V2397 is missing a minibrowser, PIM\r\n                   funtions, profile settings, and vibrating alert. \r\n\r\n                   To keep your V2397 secure, you can use a three-digit code to lock the whole\r\n                   phone or to restrict outgoing calls to one of 10 numbers stored in special\r\n                   memory locations. \r\n\r\n                   The V2397''s NiMH battery is rated up to 100 minutes'' talk time and 110 hours''\r\n                   standby time. In our testing, the V2397 held a call for 105 minutes, and it lasted\r\n                   for 112 hours in standby mode. \r\n\r\n                   A basic phone for everyday use, the Motorola V2397 scores high marks in\r\n                   visual design and reliability, although it lacks many desirable features. Still,\r\n                   interchangeable phone wraps, two-way text messaging, and a very reasonable\r\n                   price make the V2397 as a viable prepaid option.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005BAUT.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005BAUT.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 99.99 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 99.99 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , '' , NULL , 1 , 3 , 3 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (111 , 'Churches' , NULL , 1 , 1 , NULL , NULL , 2 , '0060194383' , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 'The physical dimensions alone would be enough to make Churches, Judith Dupre''s sumptuous chronology of Christian art and architecture, one of the most  absorbing ways possible to learn about the world''s most beautiful houses of worship. It is almost too big to fit in your lap, and each brilliantly colored page is  almost three times the width of a human head. In addition, Churches offers floor  plans, histories, and theological interpretations of almost 60 churches around the  world, from the Pantheon in Rome to La Sagrada Familia in Barcelona to the  Crystal Cathedral in Garden Grove, California. Interspersed with these chapters  are photographic essays on such topics as "Building a Gothic Cathedral" and  "Ancient Paths: Contemporary Labyrinths." All of the images and essays are  presented in a format accessible to the general reader. Those more broadly  informed about architecture will be drawn to the interview with Swiss-Italian  architect Mario Botta--his first in-depth interview published in English. In the end,  the book''s most amazing accomplishment is to provide readers with sensations  that approximate both the grandeur and the intimacy of visiting the churches it  depicts. --Michael Joseph Gross' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0060194383.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0060194383.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 40 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 28 , 0 , 30 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , '' , NULL , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (113 , 'Exploring Southern California Beaches (FalconGuide) from Amazon' , NULL , 1 , 1 , NULL , NULL , 2 , '1560446323' , NULL , NULL , NULL , NULL , NULL , NULL , 0 , '"From the bustle of the Mexican border to the isolated beauty of Point Conception, sit back and enjoy the ride as veteran writer and beach bum David Crowell takes you on Safari in Exploring Southern California Beaches. Discover the diversity of life in " --This text refers to the Digital edition. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/1560446323.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , NULL , 'http://images.amazon.com/images/P/1560446323.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 18.95 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 13.26 , 0 , 30 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , 0 , NULL , NULL , 1 , 1 , 0 , 'http://www.amazon.com/exec/obidos/ASIN/1560446323' , NULL , 2 , 10 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (120 , 'God : A Biography' , NULL , 3 , 1 , NULL , NULL , 2 , '0679743685' , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 'Is it possible to approach God not as an object of religious reverence, but as the protagonist of the world''s greatest book -- as a character who possesses all the depths, contradictions, and ambiguities of a Hamlet? How does he depend on the other characters, and how does his relationship with them show his development? Miles provides a learned, original exegesis that will send readers back to the Bible in curious amazement. Winner of the 1996 Pulitzer Prize for biography. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0679743685.01.TZZZZZZZ.gif' , NULL , 'http://images.amazon.com/images/P/0679743685.01.MZZZZZZZ.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 15 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 12 , 0 , 20 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , 'http://www.amazon.com/exec/obidos/ASIN/0679743685' , NULL , 1 , 4 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (122 , 'The Millionaires' , NULL , 1 , 1 , NULL , NULL , 2 , '0446527297' , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 'What would you steal if you couldn''t get caught? That''s the tag line of Brad Meltzer''s new thriller, which pits an ambitious young money manager against a corporate villain, whose intricate financial shenanigans accidentally put a huge chunk of dough right in front of a man who desperately needs it. Of course Oliver Caruso''s conscience troubles him, but that doesn''t keep him from letting his somewhat looser and less ethical brother convince him this is too good an opportunity to pass up. Meltzer''s in interesting territory here, but in order to buy his premise, you have to believe that it''s OK to steal if you have a good enough reason. This makes his protagonist, who narrates the novel, hard to root for and less than sympathetic. Despite this hollow ring, the book is nicely plotted and should please the author''s enthusiastic fan club. --Jane Adams ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0446527297.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0446527297.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 25.95 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 15.57 , 0 , 40 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , 'http://www.amazon.com/exec/obidos/ASIN/0446527297' , NULL , 1 , 4 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_items] ([item_id],[item_name],[friendly_url],[item_order],[item_type_id],[issue_date],[language_code],[manufacturer_id],[manufacturer_code],[author_id],[template_name],[hide_add_list],[hide_add_details],[features],[short_description],[full_desc_type],[full_description],[is_special_offer],[special_offer],[notes],[small_image],[small_image_alt],[big_image],[big_image_alt],[super_image],[preview_url],[preview_width],[preview_height],[specification],[buying_price],[price],[trade_price],[is_price_edit],[properties_price],[tax_free],[weight],[stock_level],[use_stock_level],[hide_out_of_stock],[disable_out_of_stock],[shipping_in_stock],[shipping_out_stock],[shipping_rule_id],[shipping_cost],[is_sales],[sales_price],[trade_sales],[discount_percent],[is_recurring],[recurring_period],[recurring_interval],[recurring_payments_total],[recurring_start_date],[recurring_end_date],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[downloadable],[download_period],[download_path],[download_show_terms],[download_terms_text],[generate_serial],[serial_period],[activations_number],[is_showing],[is_approved],[is_compared],[buy_link],[total_views],[votes],[points],[rating],[meta_title],[meta_keywords],[meta_description],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message],[user_id],[admin_id_added_by],[admin_id_modified_by],[date_added],[date_modified]) VALUES (124 , 'To Trust a Stranger' , NULL , 3 , 1 , NULL , NULL , 2 , '0671786539' , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 'The usual ingredients bubble and boil in Robards''s latest romantic suspense thriller. Julie Carlson, once a poor girl from the wrong side of the tracks but now the beautiful owner of a successful boutique in Charleston, S.C., seems to have it all. As the novel begins, however, a hit man circles her suburban mansion: Julie''s rich husband, Sid, has hired thugs to kill her. Unaware of the danger she is in but convinced that Sid is cheating on her, Julie slips out of the house just in time and follows her husband to the red-light district, where she serendipitously and literally runs into private detective Mac McQuarry, dressed up in drag to spy on a client''s husband. Julie isn''t sure whether she should trust a man in a dress, but she has no one else to turn to, and soon she and Mac are working together to get the goods on Julie''s crooked husband. As it happens, Mac holds a personal grudge against Sid, a prominent builder in Charleston, because Sid was involved in the disappearance of Mac''s half-brother 15 years before, and then got Mac kicked off the police force when Mac tried to prove it. Robards''s fans will enjoy the machinations before Julie and Mac get together, though cliches clutter every page ("The truth hit him like a hammer over the head: He had a galloping case of the hots for his newest client, who was not incidentally his oldest enemy''s wife"). Of course, true love solves past mysteries, while hot kisses get as much play as life-threatening confrontations. A bodice ripper at heart, the novel is the equivalent of a box of junk candy. \r\n\r\nCopyright 2001 Cahners Business Information, Inc.\r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0671786539.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0671786539.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 25 , 0 , 0 , 0 , 0 , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 17.5 , 0 , 30 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 1 , 0 , 'http://www.amazon.com/exec/obidos/ASIN/0671786539' , NULL , 1 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;




INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (4 , 0 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (4 , 2 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (5 , 0 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (5 , 2 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (7 , 5 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (9 , 2 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (10 , 2 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (11 , 8 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (12 , 8 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (13 , 8 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (28 , 0 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (28 , 11 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (29 , 11 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (30 , 11 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (32 , 11 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (35 , 13 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (40 , 13 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (41 , 5 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (44 , 13 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (68 , 5 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (73 , 5 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (80 , 35 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (88 , 35 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (92 , 35 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (98 , 0 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (98 , 35 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (106 , 43 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (107 , 43 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (109 , 43 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (110 , 43 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (111 , 2 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (113 , 47 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (120 , 47 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (122 , 47 ) ;
INSERT INTO [va_items_categories] ([item_id],[category_id]) VALUES (124 , 47 ) ;


















INSERT INTO [va_languages] ([language_code],[language_order],[language_name],[show_for_user],[language_image],[currency_code]) VALUES ('ar' , 1 , 'Arabic' , 1 , 'images/flags/sa.gif' , NULL ) ;
INSERT INTO [va_languages] ([language_code],[language_order],[language_name],[show_for_user],[language_image],[currency_code]) VALUES ('cs' , 1 , 'Czech' , 1 , 'images/flags/cz.gif' , NULL ) ;
INSERT INTO [va_languages] ([language_code],[language_order],[language_name],[show_for_user],[language_image],[currency_code]) VALUES ('de' , 1 , 'German' , 1 , 'images/flags/de.gif' , NULL ) ;
INSERT INTO [va_languages] ([language_code],[language_order],[language_name],[show_for_user],[language_image],[currency_code]) VALUES ('el' , 1 , 'Greek' , 1 , 'images/flags/gr.gif' , NULL ) ;
INSERT INTO [va_languages] ([language_code],[language_order],[language_name],[show_for_user],[language_image],[currency_code]) VALUES ('en' , 1 , 'English' , 1 , 'images/flags/gb.gif' , NULL ) ;
INSERT INTO [va_languages] ([language_code],[language_order],[language_name],[show_for_user],[language_image],[currency_code]) VALUES ('es' , 1 , 'Spanish' , 1 , 'images/flags/es.gif' , NULL ) ;
INSERT INTO [va_languages] ([language_code],[language_order],[language_name],[show_for_user],[language_image],[currency_code]) VALUES ('fi' , 1 , 'Finnish' , 1 , 'images/flags/fi.gif' , NULL ) ;
INSERT INTO [va_languages] ([language_code],[language_order],[language_name],[show_for_user],[language_image],[currency_code]) VALUES ('fr' , 1 , 'French' , 1 , 'images/flags/fr.gif' , NULL ) ;
INSERT INTO [va_languages] ([language_code],[language_order],[language_name],[show_for_user],[language_image],[currency_code]) VALUES ('hu' , 1 , 'Hungarian' , 1 , 'images/flags/hu.gif' , NULL ) ;
INSERT INTO [va_languages] ([language_code],[language_order],[language_name],[show_for_user],[language_image],[currency_code]) VALUES ('it' , 1 , 'Italian' , 1 , 'images/flags/it.gif' , NULL ) ;
INSERT INTO [va_languages] ([language_code],[language_order],[language_name],[show_for_user],[language_image],[currency_code]) VALUES ('lt' , 1 , 'Lithuanian' , 1 , 'images/flags/lt.gif' , NULL ) ;
INSERT INTO [va_languages] ([language_code],[language_order],[language_name],[show_for_user],[language_image],[currency_code]) VALUES ('lv' , 1 , 'Latvian' , 1 , 'images/flags/lv.gif' , NULL ) ;
INSERT INTO [va_languages] ([language_code],[language_order],[language_name],[show_for_user],[language_image],[currency_code]) VALUES ('nl' , 1 , 'Dutch' , 1 , 'images/flags/nl.gif' , NULL ) ;
INSERT INTO [va_languages] ([language_code],[language_order],[language_name],[show_for_user],[language_image],[currency_code]) VALUES ('pl' , 1 , 'Polish' , 1 , 'images/flags/pl.gif' , NULL ) ;
INSERT INTO [va_languages] ([language_code],[language_order],[language_name],[show_for_user],[language_image],[currency_code]) VALUES ('pt' , 1 , 'Portuguese' , 1 , 'images/flags/pt.gif' , NULL ) ;
INSERT INTO [va_languages] ([language_code],[language_order],[language_name],[show_for_user],[language_image],[currency_code]) VALUES ('ru' , 1 , 'Russian' , 1 , 'images/flags/ru.gif' , NULL ) ;
INSERT INTO [va_languages] ([language_code],[language_order],[language_name],[show_for_user],[language_image],[currency_code]) VALUES ('sk' , 1 , 'Slovak' , 1 , 'images/flags/sk.gif' , NULL ) ;
INSERT INTO [va_languages] ([language_code],[language_order],[language_name],[show_for_user],[language_image],[currency_code]) VALUES ('sv' , 1 , 'Swedish' , 1 , 'images/flags/se.gif' , NULL ) ;
INSERT INTO [va_languages] ([language_code],[language_order],[language_name],[show_for_user],[language_image],[currency_code]) VALUES ('tr' , 1 , 'Turkish' , 1 , 'images/flags/tr.gif' , NULL ) ;
INSERT INTO [va_languages] ([language_code],[language_order],[language_name],[show_for_user],[language_image],[currency_code]) VALUES ('uk' , 1 , 'Ukrainian' , 1 , 'images/flags/ua.gif' , NULL ) ;


INSERT INTO [va_layouts] ([layout_id],[layout_name],[top_menu_type],[style_name],[scheme_name],[templates_dir],[admin_templates_dir]) VALUES (1 , 'Default' , NULL , 'default' , NULL , './templates/user' , '../templates/admin' ) ;
INSERT INTO [va_layouts] ([layout_id],[layout_name],[top_menu_type],[style_name],[scheme_name],[templates_dir],[admin_templates_dir]) VALUES (2 , 'Curved' , NULL , 'curved' , NULL , './templates/user' , '../templates/admin' ) ;
INSERT INTO [va_layouts] ([layout_id],[layout_name],[top_menu_type],[style_name],[scheme_name],[templates_dir],[admin_templates_dir]) VALUES (3 , 'Silver' , NULL , 'silver' , NULL , './templates/user' , '../templates/admin' ) ;
INSERT INTO [va_layouts] ([layout_id],[layout_name],[top_menu_type],[style_name],[scheme_name],[templates_dir],[admin_templates_dir]) VALUES (4 , 'Convex' , NULL , 'convex' , NULL , './templates/user' , '../templates/admin' ) ;
INSERT INTO [va_layouts] ([layout_id],[layout_name],[top_menu_type],[style_name],[scheme_name],[templates_dir],[admin_templates_dir]) VALUES (5 , 'Fashion' , NULL , 'fashion' , NULL , './templates/user' , '../templates/admin' ) ;
INSERT INTO [va_layouts] ([layout_id],[layout_name],[top_menu_type],[style_name],[scheme_name],[templates_dir],[admin_templates_dir]) VALUES (6 , 'Rainbow' , NULL , 'rainbow' , NULL , './templates/user' , '../templates/admin' ) ;
INSERT INTO [va_layouts] ([layout_id],[layout_name],[top_menu_type],[style_name],[scheme_name],[templates_dir],[admin_templates_dir]) VALUES (7 , 'Classic' , NULL , 'classic' , NULL , './templates/user' , '../templates/admin' ) ;
INSERT INTO [va_layouts] ([layout_id],[layout_name],[top_menu_type],[style_name],[scheme_name],[templates_dir],[admin_templates_dir]) VALUES (8 , 'Marine' , NULL , 'marine' , NULL , './templates/user' , '../templates/admin' ) ;
INSERT INTO [va_layouts] ([layout_id],[layout_name],[top_menu_type],[style_name],[scheme_name],[templates_dir],[admin_templates_dir]) VALUES (9 , 'Ecommerce' , NULL , 'ecommerce' , NULL , './templates/user' , '../templates/admin' ) ;








INSERT INTO [va_manufacturers] ([manufacturer_id],[manufacturer_name],[friendly_url],[affiliate_code],[short_description],[full_description],[image_small],[image_small_alt],[image_large],[image_large_alt]) VALUES (2 , 'Amazon' , NULL , '/viartco-20/' , NULL , NULL , NULL , NULL , NULL , NULL ) ;
















INSERT INTO [va_order_statuses] ([status_id],[status_name],[is_user_cancel],[allow_user_cancel],[is_dispatch],[is_list],[show_for_user],[paid_status],[commission_action],[download_activation],[download_notify],[item_notify],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message]) VALUES (1 , 'New Order Placed' , 0 , 0 , 0 , 1 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_order_statuses] ([status_id],[status_name],[is_user_cancel],[allow_user_cancel],[is_dispatch],[is_list],[show_for_user],[paid_status],[commission_action],[download_activation],[download_notify],[item_notify],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message]) VALUES (2 , 'CC Info Added' , 0 , 0 , 0 , 1 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_order_statuses] ([status_id],[status_name],[is_user_cancel],[allow_user_cancel],[is_dispatch],[is_list],[show_for_user],[paid_status],[commission_action],[download_activation],[download_notify],[item_notify],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message]) VALUES (3 , 'Confirmed by User' , 0 , 0 , 0 , 1 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_order_statuses] ([status_id],[status_name],[is_user_cancel],[allow_user_cancel],[is_dispatch],[is_list],[show_for_user],[paid_status],[commission_action],[download_activation],[download_notify],[item_notify],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message]) VALUES (4 , 'Paid' , 0 , 0 , 0 , 1 , 1 , 1 , 1 , 1 , 0 , 1 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL ) ;
INSERT INTO [va_order_statuses] ([status_id],[status_name],[is_user_cancel],[allow_user_cancel],[is_dispatch],[is_list],[show_for_user],[paid_status],[commission_action],[download_activation],[download_notify],[item_notify],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message]) VALUES (5 , 'Goods shipped' , 0 , 0 , 0 , 1 , 1 , 1 , 1 , 1 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_order_statuses] ([status_id],[status_name],[is_user_cancel],[allow_user_cancel],[is_dispatch],[is_list],[show_for_user],[paid_status],[commission_action],[download_activation],[download_notify],[item_notify],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message]) VALUES (6 , 'Pending' , 0 , 0 , 0 , 1 , 0 , 0 , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_order_statuses] ([status_id],[status_name],[is_user_cancel],[allow_user_cancel],[is_dispatch],[is_list],[show_for_user],[paid_status],[commission_action],[download_activation],[download_notify],[item_notify],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message]) VALUES (7 , 'Closed' , 0 , 0 , 0 , 1 , 1 , 1 , 0 , 2 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_order_statuses] ([status_id],[status_name],[is_user_cancel],[allow_user_cancel],[is_dispatch],[is_list],[show_for_user],[paid_status],[commission_action],[download_activation],[download_notify],[item_notify],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message]) VALUES (8 , 'Declined' , 0 , 0 , 0 , 1 , 0 , 0 , -1 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_order_statuses] ([status_id],[status_name],[is_user_cancel],[allow_user_cancel],[is_dispatch],[is_list],[show_for_user],[paid_status],[commission_action],[download_activation],[download_notify],[item_notify],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message]) VALUES (9 , 'Validated' , 0 , 0 , 0 , 1 , 1 , 1 , 0 , 2 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_order_statuses] ([status_id],[status_name],[is_user_cancel],[allow_user_cancel],[is_dispatch],[is_list],[show_for_user],[paid_status],[commission_action],[download_activation],[download_notify],[item_notify],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message]) VALUES (10 , 'Failed' , 0 , 0 , 0 , 1 , 0 , 0 , -1 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_order_statuses] ([status_id],[status_name],[is_user_cancel],[allow_user_cancel],[is_dispatch],[is_list],[show_for_user],[paid_status],[commission_action],[download_activation],[download_notify],[item_notify],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message]) VALUES (11 , 'Dispatched' , 0 , 0 , 1 , 1 , 1 , 1 , 1 , 2 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_order_statuses] ([status_id],[status_name],[is_user_cancel],[allow_user_cancel],[is_dispatch],[is_list],[show_for_user],[paid_status],[commission_action],[download_activation],[download_notify],[item_notify],[mail_notify],[mail_to],[mail_from],[mail_cc],[mail_bcc],[mail_reply_to],[mail_return_path],[mail_type],[mail_subject],[mail_body],[sms_notify],[sms_recipient],[sms_originator],[sms_message]) VALUES (12 , 'Cancelled' , 1 , 0 , 0 , 1 , 1 , 1 , -1 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL ) ;


















INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'a_breadcrumb_1' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'a_details_1' , 1 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'a_latest_cols_1' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'a_latest_recs_1' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'a_related_1' , 2 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'a_subcats_type_1' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'ads_subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'language_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_1' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_3' , 'a_breadcrumb_3' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_3' , 'a_details_3' , 1 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_3' , 'a_latest_cols_3' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_3' , 'a_latest_recs_3' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_3' , 'a_subcats_type_3' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_3' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_3' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_3' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_3' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_3' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_3' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_3' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'a_breadcrumb_30' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'a_details_30' , 1 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'a_latest_cols_30' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'a_latest_recs_30' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'a_subcats_cols_30' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'a_subcats_subs_30' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'a_subcats_type_30' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'ads_subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'ads_subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'ads_subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'cb_admin_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'cb_admin_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'cb_params_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'cb_params_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'cb_user_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'cb_user_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'language_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_30' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_4' , 'a_details_4' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_4' , 'a_latest_cols_4' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_4' , 'a_latest_recs_4' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_4' , 'a_subcats_type_4' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_4' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_4' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_4' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_4' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_4' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_4' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_4' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_5' , 'a_details_5' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_5' , 'a_latest_cols_5' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_5' , 'a_latest_recs_5' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_5' , 'a_subcats_cols_5' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_5' , 'a_subcats_subs_5' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_5' , 'a_subcats_type_5' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_5' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_5' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_5' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_5' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_5' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_5' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_5' , 'subcategories_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_5' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_5' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_6' , 'a_breadcrumb_6' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_6' , 'a_details_6' , 1 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_6' , 'a_latest_cols_6' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_6' , 'a_latest_recs_6' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_6' , 'a_subcats_cols_6' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_6' , 'a_subcats_subs_6' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_6' , 'a_subcats_type_6' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_6' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_6' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_6' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_6' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_6' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_6' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_6' , 'subcategories_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_6' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_details_6' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'a_breadcrumb_1' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'a_hot_cols_1' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'a_hot_recs_1' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'a_latest_cols_1' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'a_latest_recs_1' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'a_list_1' , 1 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'a_list_cols_1' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'a_list_recs_1' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'a_subcats_cols_1' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'a_subcats_subs_1' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'a_subcats_type_1' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'ads_subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'ads_subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'ads_subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'language_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'subcategories_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_1' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_3' , 'a_breadcrumb_3' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_3' , 'a_cats_3' , 1 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_3' , 'a_cats_cols_3' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_3' , 'a_cats_subs_3' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_3' , 'a_cats_type_3' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_3' , 'a_hot_cols_3' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_3' , 'a_hot_recs_3' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_3' , 'a_latest_cols_3' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_3' , 'a_latest_recs_3' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_3' , 'a_list_3' , 2 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_3' , 'a_list_cols_3' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_3' , 'a_list_recs_3' , NULL , '20' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_3' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_3' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_3' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_3' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_3' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_3' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_3' , 'subcategories_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_3' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_3' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'a_breadcrumb_30' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'a_hot_cols_30' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'a_hot_recs_30' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'a_latest_cols_30' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'a_latest_recs_30' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'a_list_30' , 1 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'a_list_cols_30' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'a_list_recs_30' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'a_subcats_cols_30' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'a_subcats_subs_30' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'a_subcats_type_30' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'ads_subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'ads_subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'ads_subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'cb_admin_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'cb_admin_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'cb_params_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'cb_params_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'cb_user_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'cb_user_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'language_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_30' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_4' , 'a_content_4' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_4' , 'a_hot_cols_4' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_4' , 'a_hot_recs_4' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_4' , 'a_latest_cols_4' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_4' , 'a_latest_recs_4' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_4' , 'a_list_4' , 1 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_4' , 'a_list_cols_4' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_4' , 'a_list_recs_4' , NULL , '20' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_4' , 'a_subcats_cols_4' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_4' , 'a_subcats_subs_4' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_4' , 'a_subcats_type_4' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_4' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_4' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_4' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_4' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_4' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_4' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_4' , 'subcategories_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_4' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_4' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_5' , 'a_hot_cols_5' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_5' , 'a_hot_recs_5' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_5' , 'a_latest_cols_5' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_5' , 'a_latest_recs_5' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_5' , 'a_list_5' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_5' , 'a_list_cols_5' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_5' , 'a_list_recs_5' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_5' , 'a_subcats_cols_5' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_5' , 'a_subcats_subs_5' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_5' , 'a_subcats_type_5' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_5' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_5' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_5' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_5' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_5' , 'right_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_5' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_5' , 'subcategories_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_5' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_5' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_6' , 'a_breadcrumb_6' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_6' , 'a_hot_cols_6' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_6' , 'a_hot_recs_6' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_6' , 'a_latest_cols_6' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_6' , 'a_latest_recs_6' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_6' , 'a_list_6' , 1 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_6' , 'a_list_cols_6' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_6' , 'a_list_recs_6' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_6' , 'a_subcats_cols_6' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_6' , 'a_subcats_subs_6' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_6' , 'a_subcats_type_6' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_6' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_6' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_6' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_6' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_6' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_6' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_6' , 'subcategories_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_6' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'a_list_6' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'ads_breadcrumb' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'ads_categories' , 2 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'ads_categories_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'ads_categories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'ads_categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'ads_category_info' , 0 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'ads_details' , 1 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'ads_recently_viewed' , 3 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'ads_search' , 1 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'left_column_width' , NULL , '25%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'middle_column_width' , NULL , '75%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_details' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'ads_breadcrumb' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'ads_categories' , 1 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'ads_categories_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'ads_categories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'ads_categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'ads_category_info' , 0 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'ads_list' , 1 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'ads_search' , 2 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'left_column_width' , NULL , '25%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'middle_column_width' , NULL , '75%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'ads_list' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_cat_desc_image_1' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_cat_desc_image_3' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_cat_desc_image_30' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_cat_desc_image_4' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_cat_desc_image_5' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_cat_desc_image_6' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_cat_desc_type_1' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_cat_desc_type_3' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_cat_desc_type_30' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_cat_desc_type_4' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_cat_desc_type_5' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_cat_desc_type_6' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_cats_image_1' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_cats_image_3' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_cats_image_30' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_cats_image_4' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_cats_image_5' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_cats_image_6' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_cats_type_1' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_cats_type_3' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_cats_type_30' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_cats_type_4' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_cats_type_5' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_cats_type_6' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_hot_cols_1' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_hot_cols_3' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_hot_cols_30' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_hot_cols_4' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_hot_cols_5' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_hot_cols_6' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_hot_recs_1' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_hot_recs_3' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_hot_recs_30' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_hot_recs_4' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_hot_recs_5' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_hot_recs_6' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_cats_1' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_cats_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_cats_30' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_cats_4' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_cats_5' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_cats_6' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_cols_1' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_cols_3' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_cols_30' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_cols_4' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_cols_5' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_cols_6' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_desc_1' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_desc_3' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_desc_30' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_desc_4' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_desc_5' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_desc_6' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_group_by_1' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_group_by_3' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_group_by_30' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_group_by_4' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_group_by_5' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_group_by_6' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_image_1' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_image_3' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_image_30' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_image_4' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_image_5' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_image_6' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_recs_1' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_recs_3' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_recs_30' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_recs_4' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_recs_5' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_recs_6' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_subcats_1' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_subcats_3' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_subcats_30' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_subcats_4' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_subcats_5' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_subcats_6' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_subrecs_1' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_subrecs_3' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_subrecs_30' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_subrecs_4' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_subrecs_5' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_latest_subrecs_6' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_subcats_cols_1' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_subcats_cols_3' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_subcats_cols_30' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_subcats_cols_4' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_subcats_cols_5' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_subcats_cols_6' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_subcats_subs_1' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_subcats_subs_3' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_subcats_subs_30' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_subcats_subs_4' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_subcats_subs_5' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_subcats_subs_6' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_subcats_type_1' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_subcats_type_3' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_subcats_type_30' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_subcats_type_4' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_subcats_type_5' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_subcats_type_6' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_top_viewed_cols_1' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_top_viewed_cols_3' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_top_viewed_cols_30' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_top_viewed_cols_4' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_top_viewed_cols_5' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_top_viewed_cols_6' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_top_viewed_recs_1' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_top_viewed_recs_3' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_top_viewed_recs_30' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_top_viewed_recs_4' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_top_viewed_recs_5' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'a_top_viewed_recs_6' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'ads_cat_desc_image' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'ads_cat_desc_type' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'ads_categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'ads_categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'ads_subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'ads_subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'ads_subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'ads_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'ads_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'basket_block' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'basket_recommended_block' , 1 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'bestsellers_desc' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'bestsellers_image' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'categories_columns' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'categories_subs' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'category_description_image' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'category_description_type' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'cb_admin_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'cb_admin_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'cb_params_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'cb_params_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'cb_user_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'cb_user_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'currency_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'forum_description_image' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'forum_description_type' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'forum_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'forum_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'forum_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'forum_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'language_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'manufacturers_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'merchants_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'prod_latest_desc' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'prod_latest_image' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'prod_offers_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'prod_offers_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'prod_recom_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'prod_recom_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'prod_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'prod_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'products_columns' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'products_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'products_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'products_nav_first_last' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'products_nav_pages' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'products_nav_prev_next' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'products_nav_type' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'products_per_page' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'products_recent_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'products_recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'products_sortings' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'recent_desc' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'recent_image' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'sms_originator' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'sms_test_message' , NULL , 'SMS test message' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'top_rated_desc' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'top_rated_image' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'top_viewed_desc' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'basket' , 'top_viewed_image' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'ads_categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'ads_categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'ads_subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'ads_subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'ads_subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'ads_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'ads_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'categories_columns' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'categories_subs' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'cb_admin_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'cb_admin_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'cb_params_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'cb_params_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'cb_user_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'cb_user_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'currency_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'forum_breadcrumb' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'forum_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'forum_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'forum_list' , 1 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'forum_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'forum_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'language_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'manufacturers_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'merchants_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'prod_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'prod_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'products_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'products_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'sms_originator' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'sms_test_message' , NULL , 'SMS test message' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_list' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'ads_categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'ads_categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'ads_subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'ads_subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'ads_subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'ads_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'ads_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'categories_columns' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'categories_subs' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'cb_admin_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'cb_admin_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'cb_params_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'cb_params_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'cb_user_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'cb_user_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'currency_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'forum_breadcrumb' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'forum_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'forum_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'forum_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'forum_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'forum_view_topic' , 1 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'language_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'manufacturers_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'merchants_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'prod_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'prod_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'products_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'products_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'sms_originator' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'sms_test_message' , NULL , 'SMS test message' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topic' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'ads_categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'ads_categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'ads_subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'ads_subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'ads_subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'ads_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'ads_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'categories_columns' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'categories_subs' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'cb_admin_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'cb_admin_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'cb_params_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'cb_params_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'cb_user_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'cb_user_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'currency_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'forum_breadcrumb' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'forum_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'forum_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'forum_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'forum_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'forum_topics_block' , 1 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'language_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'manufacturers_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'merchants_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'prod_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'prod_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'products_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'products_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'sms_originator' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'sms_test_message' , NULL , 'SMS test message' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'forum_topics' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'a_hot_cols_1' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'a_hot_cols_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'a_hot_cols_30' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'a_hot_cols_4' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'a_hot_cols_5' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'a_hot_cols_6' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'a_hot_recs_1' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'a_hot_recs_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'a_hot_recs_30' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'a_hot_recs_4' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'a_hot_recs_5' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'a_hot_recs_6' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'ads_categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'ads_categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'ads_subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'ads_subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'ads_subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'categories_columns' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'categories_subs' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'cb_admin_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'cb_admin_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'cb_params_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'cb_params_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'cb_user_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'cb_user_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'currency_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'language_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'left_column_width' , NULL , '25%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'manuals_article_details' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'manuals_search' , 0 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'manufacturers_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'merchants_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'middle_column_width' , NULL , '75%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'sms_originator' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'sms_test_message' , NULL , 'SMS test message' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_article_details' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'a_hot_cols_1' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'a_hot_cols_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'a_hot_cols_30' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'a_hot_cols_4' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'a_hot_cols_5' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'a_hot_cols_6' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'a_hot_recs_1' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'a_hot_recs_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'a_hot_recs_30' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'a_hot_recs_4' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'a_hot_recs_5' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'a_hot_recs_6' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'ads_categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'ads_categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'ads_subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'ads_subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'ads_subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'categories_columns' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'categories_subs' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'cb_admin_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'cb_admin_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'cb_params_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'cb_params_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'cb_user_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'cb_user_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'currency_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'language_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'left_column_width' , NULL , '25%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'manuals_articles' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'manuals_search' , 0 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'manufacturers_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'merchants_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'middle_column_width' , NULL , '75%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'right_column_width' , NULL , '0%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'sms_originator' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'sms_test_message' , NULL , 'SMS test message' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_articles' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'a_hot_cols_1' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'a_hot_cols_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'a_hot_cols_30' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'a_hot_cols_4' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'a_hot_cols_5' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'a_hot_cols_6' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'a_hot_recs_1' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'a_hot_recs_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'a_hot_recs_30' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'a_hot_recs_4' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'a_hot_recs_5' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'a_hot_recs_6' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'ads_categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'ads_categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'ads_subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'ads_subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'ads_subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'categories_columns' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'categories_subs' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'cb_admin_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'cb_admin_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'cb_params_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'cb_params_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'cb_user_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'cb_user_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'currency_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'language_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'left_column_width' , NULL , '25%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'manuals_list' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'manuals_search' , 0 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'manufacturers_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'merchants_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'middle_column_width' , NULL , '75%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'sms_originator' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'sms_test_message' , NULL , 'SMS test message' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_list' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'a_hot_cols_1' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'a_hot_cols_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'a_hot_cols_30' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'a_hot_cols_4' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'a_hot_cols_5' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'a_hot_cols_6' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'a_hot_recs_1' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'a_hot_recs_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'a_hot_recs_30' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'a_hot_recs_4' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'a_hot_recs_5' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'a_hot_recs_6' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'ads_categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'ads_categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'ads_subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'ads_subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'ads_subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'categories_columns' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'categories_subs' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'cb_admin_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'cb_admin_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'cb_params_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'cb_params_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'cb_user_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'cb_user_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'currency_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'language_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'left_column_width' , NULL , '25%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'manuals_search' , 0 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'manuals_search_results' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'manufacturers_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'merchants_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'middle_column_width' , NULL , '75%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'sms_originator' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'sms_test_message' , NULL , 'SMS test message' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'manuals_search' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_details' , 'cart_block' , 0 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_details' , 'categories_block' , 1 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_details' , 'details_block' , 1 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_details' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_details' , 'left_column_width' , NULL , '30%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_details' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_details' , 'middle_column_width' , NULL , '70%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_details' , 'products_breadcrumb' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_details' , 'related_block' , 2 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_details' , 'related_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_details' , 'related_per_page' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_details' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_details' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_details' , 'subcategories_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_details' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_details' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'ads_categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'ads_categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'ads_subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'ads_subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'ads_subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'ads_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'ads_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'bestsellers_desc' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'bestsellers_image' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'cart_block' , 0 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'categories_block' , 1 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'categories_columns' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'categories_subs' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'cb_admin_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'cb_admin_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'cb_params_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'cb_params_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'cb_user_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'cb_user_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'currency_block' , 2 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'currency_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'forum_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'forum_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'forum_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'forum_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'language_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'left_column_width' , NULL , '30%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'manufacturers_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'merchants_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'middle_column_width' , NULL , '70%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'prod_latest_desc' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'prod_latest_image' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'prod_offers_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'prod_offers_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'prod_recom_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'prod_recom_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'prod_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'prod_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'products_block' , 1 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'products_breadcrumb' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'products_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'products_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'products_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'products_nav_first_last' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'products_nav_pages' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'products_nav_prev_next' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'products_nav_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'products_per_page' , NULL , '20' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'products_sortings' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'recent_desc' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'recent_image' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'search_block' , 3 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'sms_originator' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'sms_test_message' , NULL , 'SMS test message' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'subcategories_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'top_rated_desc' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'top_rated_image' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'top_viewed_desc' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_list' , 'top_viewed_image' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'ads_categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'ads_categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'ads_subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'ads_subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'ads_subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'ads_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'ads_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'bestsellers_desc' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'bestsellers_image' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'cart_block' , 2 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'categories_block' , 1 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'categories_columns' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'categories_subs' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'cb_admin_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'cb_admin_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'cb_params_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'cb_params_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'cb_user_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'cb_user_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'currency_block' , 3 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'currency_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'forum_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'forum_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'forum_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'forum_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'language_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'left_column_width' , NULL , '30%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'manufacturers_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'merchants_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'middle_column_width' , NULL , '70%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'prod_latest_desc' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'prod_latest_image' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'prod_offers_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'prod_offers_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'prod_recom_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'prod_recom_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'prod_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'prod_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'products_block' , 1 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'products_breadcrumb' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'products_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'products_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'products_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'products_nav_first_last' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'products_nav_pages' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'products_nav_prev_next' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'products_nav_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'products_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'products_sortings' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'recent_desc' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'recent_image' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'search_block' , 0 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'sms_originator' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'sms_test_message' , NULL , 'SMS test message' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'top_rated_desc' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'top_rated_image' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'top_viewed_desc' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'products_search' , 'top_viewed_image' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'ads_cat_desc_image' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'ads_cat_desc_type' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'ads_categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'ads_categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'ads_subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'ads_subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'ads_subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'ads_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'ads_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'bestsellers_desc' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'bestsellers_image' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'categories_columns' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'categories_subs' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'category_description_image' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'category_description_type' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'cb_admin_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'cb_admin_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'cb_params_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'cb_params_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'cb_user_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'cb_user_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'currency_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'forum_description_image' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'forum_description_type' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'forum_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'forum_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'forum_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'forum_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'language_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'manufacturers_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'merchants_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'prod_latest_desc' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'prod_latest_image' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'prod_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'prod_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'products_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'products_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'products_recent_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'products_recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'recent_desc' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'recent_image' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'site_map_block' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'sms_originator' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'sms_test_message' , NULL , 'SMS test message' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'top_rated_desc' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'top_rated_image' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'top_viewed_desc' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'site_map' , 'top_viewed_image' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_list' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_list' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_list' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_list' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_list' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_list' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_list' , 'support_block' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'ads_categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'ads_categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'ads_subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'ads_subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'ads_subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'categories_columns' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'categories_subs' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'cb_admin_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'cb_admin_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'cb_params_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'cb_params_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'cb_user_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'cb_user_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'currency_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'language_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'manufacturers_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'merchants_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'sms_originator' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'sms_test_message' , NULL , 'SMS test message' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'support_new' , 'support_block' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'ads_categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'ads_categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'ads_subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'ads_subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'ads_subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'ads_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'ads_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'bestsellers_desc' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'bestsellers_image' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'cart_block' , 0 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'categories_columns' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'categories_subs' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'cb_admin_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'cb_admin_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'cb_params_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'cb_params_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'cb_user_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'cb_user_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'currency_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'forum_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'forum_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'forum_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'forum_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'language_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'left_column_width' , NULL , '30%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'manufacturers_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'merchant_info_block' , 1 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'merchants_block' , 1 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'merchants_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'middle_column_width' , NULL , '70%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'prod_latest_desc' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'prod_latest_image' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'prod_offers_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'prod_offers_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'prod_recom_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'prod_recom_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'prod_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'prod_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'products_block' , 2 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'products_breadcrumb' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'products_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'products_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'products_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'products_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'recent_desc' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'recent_image' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'search_block' , 2 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'sms_originator' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'sms_test_message' , NULL , 'SMS test message' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'top_rated_desc' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'top_rated_image' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'top_viewed_desc' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'user_list' , 'top_viewed_image' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_cats_image_1' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_cats_image_3' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_cats_image_30' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_cats_image_4' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_cats_image_5' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_cats_image_6' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_cats_type_1' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_cats_type_3' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_cats_type_30' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_cats_type_4' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_cats_type_5' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_cats_type_6' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_hot_1' , 2 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_hot_cols_1' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_hot_cols_3' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_hot_cols_30' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_hot_cols_4' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_hot_cols_5' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_hot_cols_6' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_hot_recs_1' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_hot_recs_3' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_hot_recs_30' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_hot_recs_4' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_hot_recs_5' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_hot_recs_6' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_latest_cols_1' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_latest_cols_3' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_latest_cols_30' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_latest_cols_4' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_latest_cols_5' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_latest_cols_6' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_latest_recs_1' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_latest_recs_3' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_latest_recs_30' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_latest_recs_4' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_latest_recs_5' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_latest_recs_6' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_subcats_cols_1' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_subcats_cols_3' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_subcats_cols_30' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_subcats_cols_4' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_subcats_cols_5' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_subcats_cols_6' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_subcats_subs_1' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_subcats_subs_3' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_subcats_subs_30' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_subcats_subs_4' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_subcats_subs_5' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_subcats_subs_6' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_subcats_type_1' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_subcats_type_3' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_subcats_type_30' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_subcats_type_4' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_subcats_type_5' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_subcats_type_6' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_top_viewed_cols_1' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_top_viewed_cols_3' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_top_viewed_cols_30' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_top_viewed_cols_4' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_top_viewed_cols_5' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_top_viewed_cols_6' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_top_viewed_recs_1' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_top_viewed_recs_3' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_top_viewed_recs_30' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_top_viewed_recs_4' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_top_viewed_recs_5' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'a_top_viewed_recs_6' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'ads_categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'ads_categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'ads_subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'ads_subcategories_subs' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'ads_subcategories_type' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'ads_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'ads_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'cart_block' , 1 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'categories_columns' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'categories_image' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'categories_subs' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'categories_type' , NULL , '3' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'cb_admin_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'cb_admin_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'cb_params_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'cb_params_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'cb_user_type_2' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'cb_user_type_3' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'currency_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'forum_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'forum_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'forum_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'forum_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'language_block' , 0 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'language_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'left_column_width' , NULL , '25%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'login_block' , 4 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'manufacturers_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'merchants_selection' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'middle_column_width' , NULL , '75%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'offers_block' , 0 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'prod_offers_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'prod_offers_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'prod_recom_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'prod_recom_per_page' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'prod_top_viewed_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'prod_top_viewed_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'products_columns' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'products_latest_cols' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'products_latest_recs' , NULL , '10' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'products_per_page' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'recent_records' , NULL , '5' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'right_column_width' , NULL , '10%' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'search_block' , 2 , 'left' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'sms_originator' , NULL , NULL ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'sms_test_message' , NULL , 'SMS test message' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'subcategories_block' , 1 , 'middle' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'subcategories_columns' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'subcategories_subs' , NULL , '6' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'subcategories_type' , NULL , '2' ) ;
INSERT INTO [va_page_settings] ([layout_id],[page_name],[setting_name],[setting_order],[setting_value]) VALUES (0 , 'index' , 'top_products_block' , 3 , 'left' ) ;


INSERT INTO [va_pages] ([page_id],[page_code],[page_title],[friendly_url],[page_url],[page_order],[is_showing],[link_in_footer],[is_html],[page_type],[page_path],[page_body],[meta_title],[meta_keywords],[meta_description]) VALUES (1 , 'home' , 'Home' , NULL , 'index.php' , 1 , 1 , 0 , 1 , 1 , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_pages] ([page_id],[page_code],[page_title],[friendly_url],[page_url],[page_order],[is_showing],[link_in_footer],[is_html],[page_type],[page_path],[page_body],[meta_title],[meta_keywords],[meta_description]) VALUES (2 , 'products' , 'Products' , NULL , 'products.php' , 2 , 1 , 0 , 1 , 1 , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_pages] ([page_id],[page_code],[page_title],[friendly_url],[page_url],[page_order],[is_showing],[link_in_footer],[is_html],[page_type],[page_path],[page_body],[meta_title],[meta_keywords],[meta_description]) VALUES (3 , 'basket' , 'Basket' , NULL , 'basket.php' , 3 , 1 , 0 , 1 , 1 , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_pages] ([page_id],[page_code],[page_title],[friendly_url],[page_url],[page_order],[is_showing],[link_in_footer],[is_html],[page_type],[page_path],[page_body],[meta_title],[meta_keywords],[meta_description]) VALUES (4 , 'admin' , 'Administration' , NULL , 'admin/admin.php' , 11 , 1 , 0 , 1 , 1 , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_pages] ([page_id],[page_code],[page_title],[friendly_url],[page_url],[page_order],[is_showing],[link_in_footer],[is_html],[page_type],[page_path],[page_body],[meta_title],[meta_keywords],[meta_description]) VALUES (5 , 'registration' , 'Registration' , NULL , 'user_profile.php' , 1 , 1 , 0 , 1 , 1 , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_pages] ([page_id],[page_code],[page_title],[friendly_url],[page_url],[page_order],[is_showing],[link_in_footer],[is_html],[page_type],[page_path],[page_body],[meta_title],[meta_keywords],[meta_description]) VALUES (6 , 'news' , 'News' , NULL , 'articles.php?category_id=1' , 5 , 1 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_pages] ([page_id],[page_code],[page_title],[friendly_url],[page_url],[page_order],[is_showing],[link_in_footer],[is_html],[page_type],[page_path],[page_body],[meta_title],[meta_keywords],[meta_description]) VALUES (7 , 'help' , 'How to Shop' , '' , NULL , 8 , 1 , 0 , 1 , NULL , NULL , '<table align="center" border="0" cellpadding="5" cellspacing="5" width="75%"><tbody><tr><td class="middle"><font size="4"><b>How to Shop at Our Online Store</b></font></td></tr><tr><td><font size="2"></font><p align="justify"> Shopping online with us isa lot like shopping at a retail store you browse our catalogue of products for the items you''dlike, put them in a shopping basket, and complete your purchase at the check-outarea. The only difference is, we''re open 24 hours a day - seven days a week,...and you don''t have to put on shoes and leave the comfort of your home to shop!</p><p align="justify">So read on and find out how you can enjoy the shopping experience with Our Online Store.</p></td></tr><tr><td class="middle"><font size="3"><b>Step 1. Make Your Product Selections</b></font></td></tr><tr><td><font size="2"></font><p align="justify"> The first thing to do is browse our shop for the items you''d like. As you browse you''ll see ''Add/Buy'' link.Once you''ve found the&nbsp;&nbsp;&nbsp; first product you''d like, simply add it to your online shopping basket by clicking on the ''Add/Buy'' link.</p><p align="justify">Just like in a retail store, the shopping basket is a holding place for your items until you are ready to purchase them. You can view thecontents of your basket at any time by clicking on the ''View Basket'' link on yourshopping page. And, just like a retail store, you can always remove items from your basket and put them back on the shelves.</p></td></tr><tr><td class="middle"><font size="3"><b>Step 2.Proceed to the Check Out</b></font></td></tr><tr><td><font size="2"></font><p align="justify"> Once you''ve decided upon your selection and checked your basket, you proceed to the Ordering Stage by clicking "Check Out". At this point you must decide whether you want to register with us or just place your order without registration. Registration means that you don''t need to complete your details again if you order from us in the future. This action takes you to page where we need some extra details to complete the order.You enter your personal information, your name and address so we know where to send the goods.</p></td></tr><tr><td class="middle"><font size="3"><b>Step 3.Submit your Order</b></font></td></tr><tr><td><font size="2"></font><p align="justify"> At this point you must decide upon the payment method.You can pay online by entering your credit card information.Alternatively you can print out the form and fax it to us, <b>or</b> you can submit the form without credit card details and call us later with this information.</p><p align="justify"> We appreciate that ordering online the first time can be a little confusing so if you have any problems or are unsure of any aspects of the ordering process please contact us and we''ll try to help you out.</p> </td></tr></tbody></table>' , NULL , NULL , NULL ) ;
INSERT INTO [va_pages] ([page_id],[page_code],[page_title],[friendly_url],[page_url],[page_order],[is_showing],[link_in_footer],[is_html],[page_type],[page_path],[page_body],[meta_title],[meta_keywords],[meta_description]) VALUES (8 , 'about' , 'About Us' , NULL , NULL , 9 , 1 , 0 , 1 , 1 , NULL , '<b>Contact Us</b>\r\n<p>\r\nWondering when your order will arrive? Need to change something about an order you''ve placed? You can review and revise your order so that it''s just the way you want it by visiting Your Account.\r\n<p>\r\nIf you were unable to find your answer using our Web site''s self-service features, click one of the links to the left to contact our customer service department. We''ll be happy to assist you. Please note: \r\n<p>\r\nFor security reasons, we can only modify orders or send account information when the request comes from the e-mail address that is associated with your Amazon.com account. \r\nWe can only read and respond to messages in English. \r\n<p>\r\n<b>Not Receiving Replies?</b>\r\n<p>\r\nIf you have used our forms to contact us in the past but have not received a reply, your ISP or e-mail client may be blocking e-mail from Amazon.com. If you suspect this is happening, please consult the help section of your e-mail program to see how to relax or remove the settings that filter or block mail. Once you''ve established that you should be able to receive mail from us, please contact us again with your question.\r\n<p>\r\nWant to check if your ISP or e-mail client is blocking mail from Amazon.com? Try subscribing for a Special Occasion Reminder. If you don''t receive it on the date you specify, you will know that messages from Amazon.com are being blocked or deleted automatically.\r\n \r\n' , NULL , NULL , NULL ) ;
INSERT INTO [va_pages] ([page_id],[page_code],[page_title],[friendly_url],[page_url],[page_order],[is_showing],[link_in_footer],[is_html],[page_type],[page_path],[page_body],[meta_title],[meta_keywords],[meta_description]) VALUES (11 , 'faq' , 'FAQ' , NULL , 'articles.php?category_id=4' , 7 , 1 , 1 , 1 , 1 , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_pages] ([page_id],[page_code],[page_title],[friendly_url],[page_url],[page_order],[is_showing],[link_in_footer],[is_html],[page_type],[page_path],[page_body],[meta_title],[meta_keywords],[meta_description]) VALUES (13 , 'forum' , 'Forum' , NULL , 'forum.php' , 6 , 1 , 0 , 0 , 1 , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_pages] ([page_id],[page_code],[page_title],[friendly_url],[page_url],[page_order],[is_showing],[link_in_footer],[is_html],[page_type],[page_path],[page_body],[meta_title],[meta_keywords],[meta_description]) VALUES (14 , 'support' , 'Support' , NULL , 'support.php' , 10 , 1 , 0 , 0 , 1 , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_pages] ([page_id],[page_code],[page_title],[friendly_url],[page_url],[page_order],[is_showing],[link_in_footer],[is_html],[page_type],[page_path],[page_body],[meta_title],[meta_keywords],[meta_description]) VALUES (15 , 'links' , 'Links' , NULL , 'articles.php?category_id=3' , 12 , 1 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_pages] ([page_id],[page_code],[page_title],[friendly_url],[page_url],[page_order],[is_showing],[link_in_footer],[is_html],[page_type],[page_path],[page_body],[meta_title],[meta_keywords],[meta_description]) VALUES (16 , 'images' , 'Image Gallery' , NULL , 'articles.php?category_id=5' , 13 , 1 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_pages] ([page_id],[page_code],[page_title],[friendly_url],[page_url],[page_order],[is_showing],[link_in_footer],[is_html],[page_type],[page_path],[page_body],[meta_title],[meta_keywords],[meta_description]) VALUES (17 , 'events' , 'Events' , NULL , 'articles.php?category_id=6' , 14 , 1 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL ) ;


INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (1 , 1 , 'order_id' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (2 , 1 , 'vc' , 'VARIABLE' , 'vc' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (8 , 2 , 'PARTNER' , 'CONSTANT' , '!Your partner ID!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (9 , 2 , 'TYPE' , 'CONSTANT' , 'S' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (10 , 2 , 'LOGIN' , 'CONSTANT' , '!Your customer login!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (11 , 2 , 'DESCRIPTION' , 'VARIABLE' , 'description' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (12 , 2 , 'AMOUNT' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (13 , 2 , 'INVOICE' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (14 , 3 , 'x_login' , 'CONSTANT' , '!Your customer login!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (15 , 3 , 'x_tran_key' , 'CONSTANT' , '!Transaction key obtained from the merchant interface!' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (16 , 3 , 'x_secret' , 'CONSTANT' , '!Type here your Autorize MD5 Hash Secret!' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (17 , 3 , 'x_invoice_num' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (18 , 3 , 'x_first_name' , 'VARIABLE' , 'first_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (19 , 3 , 'x_last_name' , 'VARIABLE' , 'last_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (20 , 3 , 'x_address' , 'VARIABLE' , 'address' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (21 , 3 , 'x_city' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (22 , 3 , 'x_state' , 'VARIABLE' , 'state' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (23 , 3 , 'x_zip' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (25 , 3 , 'x_country' , 'VARIABLE' , 'country' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (26 , 3 , 'x_phone' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (27 , 3 , 'x_fax' , 'VARIABLE' , 'fax' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (28 , 4 , 'instId' , 'CONSTANT' , '!Your installation ID!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (29 , 4 , 'cartId' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (30 , 4 , 'amount' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (31 , 4 , 'currency' , 'CONSTANT' , 'USD' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (32 , 4 , 'desc' , 'VARIABLE' , 'description' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (33 , 4 , 'testMode' , 'CONSTANT' , '100' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (34 , 4 , 'email' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (35 , 4 , 'name' , 'VARIABLE' , 'name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (36 , 4 , 'address' , 'VARIABLE' , 'address' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (37 , 4 , 'postcode' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (38 , 4 , 'country' , 'VARIABLE' , 'country_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (39 , 4 , 'tel' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (40 , 5 , 'sid' , 'CONSTANT' , '!Your vendor number!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (41 , 5 , 'total' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (42 , 5 , 'cart_order_id' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (43 , 5 , 'card_holder_name' , 'VARIABLE' , 'name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (44 , 5 , 'street_address' , 'VARIABLE' , 'address' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (45 , 5 , 'city' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (46 , 5 , 'state' , 'VARIABLE' , 'state' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (47 , 5 , 'zip' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (48 , 5 , 'country' , 'VARIABLE' , 'country' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (49 , 5 , 'email' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (50 , 5 , 'phone' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (51 , 6 , 'business' , 'CONSTANT' , 'your.paypal@example.com' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (52 , 6 , 'at' , 'CONSTANT' , '!please specify your identity token!' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (53 , 6 , 'cmd' , 'CONSTANT' , '_xclick' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (54 , 6 , 'invoice' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (55 , 6 , 'item_name' , 'VARIABLE' , 'basket' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (56 , 6 , 'amount' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (57 , 6 , 'email' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (58 , 6 , 'first_name' , 'VARIABLE' , 'first_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (59 , 6 , 'last_name' , 'VARIABLE' , 'last_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (60 , 6 , 'city' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (61 , 6 , 'zip' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (62 , 6 , 'state' , 'VARIABLE' , 'state_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (63 , 3 , 'x_company' , 'VARIABLE' , 'company_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (64 , 3 , 'x_fp_timestamp' , 'VARIABLE' , 'timestamp' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (65 , 3 , 'x_fp_hash' , 'VARIABLE' , 'fingerprint' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (66 , 3 , 'x_fp_sequence' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (67 , 3 , 'x_relay_response' , 'CONSTANT' , 'TRUE' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (68 , 3 , 'x_show_form' , 'CONSTANT' , 'PAYMENT_FORM' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (69 , 5 , 'id_type' , 'CONSTANT' , '1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (70 , 5 , 'c_prod_{digit}' , 'VARIABLE' , '{item_id},{quantity}' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (71 , 5 , 'c_name_{digit}' , 'VARIABLE' , 'item_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (72 , 5 , 'c_description_{digit}' , 'VARIABLE' , 'short_description' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (73 , 5 , 'c_price_{digit}' , 'VARIABLE' , 'price' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (74 , 5 , 'c_tangible_{digit}' , 'CONSTANT' , 'Y' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (75 , 7 , 'x_version' , 'CONSTANT' , '3.1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (76 , 7 , 'x_Invoice_Num' , 'CONSTANT' , 'order_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (77 , 7 , 'x_relay_response' , 'CONSTANT' , 'False' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (78 , 7 , 'x_login' , 'VARIABLE' , '!Your Login ID!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (79 , 7 , 'x_tran_key' , 'VARIABLE' , '!Transaction key obtained from the Merchant Interface!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (80 , 7 , 'x_amount' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (81 , 7 , 'x_card_num' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (82 , 7 , 'x_exp_date' , 'VARIABLE' , '{cc_expiry_month}{cc_expiry_year}' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (83 , 7 , 'x_type' , 'CONSTANT' , 'AUTH_CAPTURE' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (84 , 7 , 'x_description' , 'VARIABLE' , 'description' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (85 , 7 , 'x_first_name' , 'VARIABLE' , 'first_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (86 , 7 , 'x_last_name' , 'VARIABLE' , 'last_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (87 , 7 , 'x_address' , 'VARIABLE' , 'address' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (88 , 7 , 'x_city' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (89 , 7 , 'x_state' , 'VARIABLE' , 'state' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (90 , 7 , 'x_zip' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (91 , 7 , 'x_country' , 'VARIABLE' , 'country' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (92 , 7 , 'x_phone' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (93 , 8 , 'MerchantID' , 'CONSTANT' , '!Your Assigned Number!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (94 , 8 , 'RegKey' , 'CONSTANT' , '!Security Key!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (95 , 8 , 'Amount' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (96 , 8 , 'REFID' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (97 , 8 , 'TaxAmount' , 'VARIABLE' , '0' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (98 , 8 , 'AccountNo' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (99 , 8 , 'CCMonth' , 'VARIABLE' , 'cc_expiry_month' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (100 , 8 , 'CCYear' , 'VARIABLE' , 'cc_expiry_year' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (101 , 8 , 'NameonAccount' , 'VARIABLE' , 'cc_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (102 , 8 , 'AVSADDR' , 'VARIABLE' , 'address' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (103 , 8 , 'AVSZIP' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (104 , 8 , 'CCRURL' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (105 , 8 , 'CVV2' , 'VARIABLE' , 'cc_security_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (106 , 7 , 'x_Ship_To_First_Name' , 'VARIABLE' , 'delivery_first_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (110 , 9 , 'storename' , 'CONSTANT' , '!fill with your store number!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (111 , 9 , 'chargetotal' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (112 , 9 , 'txnorg' , 'CONSTANT' , 'eci' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (113 , 9 , 'mode' , 'CONSTANT' , 'payplus' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (114 , 9 , 'txntype' , 'CONSTANT' , 'sale' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (115 , 9 , 'baddr1' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (116 , 9 , 'baddr2' , 'VARIABLE' , 'address2' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (117 , 9 , 'bcity' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (118 , 9 , 'bcompany' , 'VARIABLE' , 'company_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (119 , 9 , 'bcountry' , 'VARIABLE' , 'country_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (120 , 9 , 'bname' , 'VARIABLE' , 'name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (121 , 9 , 'bstate' , 'VARIABLE' , 'state_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (122 , 9 , 'bstate2' , 'VARIABLE' , 'province' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (123 , 9 , 'bzip' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (124 , 10 , 'configfile' , 'CONSTANT' , '!fill with your store id!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (125 , 10 , 'keyfile' , 'CONSTANT' , '!location of your SSL certificate file!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (126 , 10 , 'ordertype' , 'CONSTANT' , 'SALE' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (127 , 10 , 'result' , 'CONSTANT' , 'LIVE' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (128 , 10 , 'oid' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (129 , 10 , 'chargetotal' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (130 , 10 , 'cardnumber' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (131 , 10 , 'cardexpmonth' , 'VARIABLE' , 'cc_expiry_month' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (132 , 10 , 'cardexpyear' , 'VARIABLE' , 'cc_expiry_year' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (134 , 10 , 'cvmvalue' , 'VARIABLE' , 'cc_security_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (135 , 11 , 'storename' , 'CONSTANT' , '!fill with your store number!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (136 , 11 , 'chargetotal' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (137 , 11 , 'txnorg' , 'CONSTANT' , 'eci' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (138 , 11 , 'mode' , 'CONSTANT' , 'payplus' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (139 , 11 , 'txntype' , 'CONSTANT' , 'sale' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (140 , 11 , 'baddr1' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (141 , 11 , 'baddr2' , 'VARIABLE' , 'address2' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (142 , 11 , 'bcity' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (143 , 11 , 'bcompany' , 'VARIABLE' , 'company_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (144 , 11 , 'bcountry' , 'VARIABLE' , 'country_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (145 , 11 , 'bname' , 'VARIABLE' , 'name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (146 , 11 , 'bstate' , 'VARIABLE' , 'state_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (147 , 11 , 'bstate2' , 'VARIABLE' , 'province' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (148 , 11 , 'bzip' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (149 , 12 , 'configfile' , 'CONSTANT' , '!fill with your store id!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (150 , 12 , 'keyfile' , 'CONSTANT' , '!location of your SSL certificate file!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (151 , 12 , 'ordertype' , 'CONSTANT' , 'SALE' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (152 , 12 , 'result' , 'CONSTANT' , 'LIVE' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (153 , 12 , 'oid' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (154 , 12 , 'chargetotal' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (155 , 12 , 'cardnumber' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (156 , 12 , 'cardexpmonth' , 'VARIABLE' , 'cc_expiry_month' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (157 , 12 , 'cardexpyear' , 'VARIABLE' , 'cc_expiry_year' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (159 , 12 , 'cvmvalue' , 'VARIABLE' , 'cc_security_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (160 , 6 , 'country' , 'VARIABLE' , 'country_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (176 , 5 , 'secret_word' , 'CONSTANT' , '!Your secret word!' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (177 , 14 , 'mid' , 'CONSTANT' , '!Enter the username you use to log into the Paymate website!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (178 , 14 , 'amt' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (179 , 14 , 'amt_editable' , 'CONSTANT' , 'N' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (180 , 14 , 'currency' , 'CONSTANT' , 'AUD' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (181 , 14 , 'ref' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (182 , 14 , 'pmt_sender_email' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (183 , 14 , 'pmt_contact_firstname' , 'VARIABLE' , 'first_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (184 , 14 , 'pmt_contact_surname' , 'VARIABLE' , 'last_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (185 , 14 , 'pmt_contact_phone' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (186 , 14 , 'pmt_country' , 'VARIABLE' , '2country' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (187 , 14 , 'regindi_address1' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (188 , 14 , 'regindi_address2' , 'VARIABLE' , 'address2' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (189 , 14 , 'regindi_sub' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (190 , 14 , 'regindi_pcode' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (191 , 15 , 'VPSProtocol' , 'CONSTANT' , '2.22' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (192 , 15 , 'TxType' , 'CONSTANT' , 'PAYMENT' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (193 , 15 , 'Vendor' , 'CONSTANT' , '!type your vendor name here!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (194 , 15 , 'EncryptionPassword' , 'CONSTANT' , '!type your encryption password here!' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (195 , 15 , 'VendorTxCode' , 'VARIABLE' , 'order_id' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (196 , 15 , 'Amount' , 'VARIABLE' , 'order_total' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (197 , 15 , 'Currency' , 'VARIABLE' , 'currency_code' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (198 , 15 , 'Description' , 'VARIABLE' , '{total_quantity} products; Goods Total: {goods_total}; Order Total: {order_total}' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (199 , 15 , 'SuccessURL' , 'VARIABLE' , '{site_url}order_final.php' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (200 , 15 , 'FailureURL' , 'VARIABLE' , '{site_url}order_final.php' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (201 , 15 , 'CustomerName' , 'VARIABLE' , 'name' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (202 , 15 , 'CustomerEmail' , 'VARIABLE' , 'email' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (203 , 15 , 'eMailMessage' , 'CONSTANT' , NULL , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (204 , 15 , 'BillingAddress' , 'VARIABLE' , '{address1} {address2} {city} {province} {state}  {country}' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (205 , 15 , 'BillingPostCode' , 'VARIABLE' , 'zip' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (206 , 15 , 'DeliveryAddress' , 'VARIABLE' , '{delivery_address1} {delivery_address2} {delivery_city} {delivery_province} {delivery_state}  {delivery_country}' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (207 , 15 , 'DeliveryPostCode' , 'VARIABLE' , 'delivery_zip' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (208 , 15 , 'ContactNumber' , 'VARIABLE' , 'phone' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (209 , 15 , 'ContactFax' , 'VARIABLE' , 'fax' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (210 , 15 , 'Crypt' , 'VARIABLE' , 'protx_crypt' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (211 , 16 , 'VPSProtocol' , 'CONSTANT' , '2.22' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (212 , 16 , 'TxType' , 'CONSTANT' , 'PAYMENT' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (213 , 16 , 'Vendor' , 'CONSTANT' , '!type your vendor name here!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (214 , 16 , 'VendorTxCode' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (215 , 16 , 'Amount' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (216 , 16 , 'Currency' , 'VARIABLE' , 'currency_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (217 , 16 , 'Description' , 'VARIABLE' , '{total_quantity} products; Goods Total: {goods_total}; Order Total: {order_total}' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (218 , 16 , 'CardHolder' , 'VARIABLE' , 'cc_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (219 , 16 , 'CardNumber' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (220 , 16 , 'ExpiryDate' , 'VARIABLE' , '{cc_expiry_month}{cc_expiry_year}' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (221 , 16 , 'CardType' , 'VARIABLE' , 'cc_type' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (222 , 16 , 'CV2' , 'VARIABLE' , 'cc_security_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (223 , 17 , 'PAYEE_ACCOUNT' , 'CONSTANT' , '!Enter your account!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (224 , 17 , 'PAYEE_NAME' , 'CONSTANT' , '!Enter your name!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (225 , 17 , 'PAYEE_PASSPHRASE' , 'CONSTANT' , '!Enter your alternate passphrase!' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (226 , 17 , 'PAYMENT_AMOUNT' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (227 , 17 , 'PAYMENT_UNITS' , 'CONSTANT' , '1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (228 , 17 , 'PAYMENT_METAL_ID' , 'CONSTANT' , '1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (229 , 17 , 'PAYMENT_ID' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (230 , 17 , 'STATUS_URL' , 'VARIABLE' , '{site_url}payments/egold_response.php' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (231 , 17 , 'PAYMENT_URL' , 'VARIABLE' , '{site_url}order_final.php' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (232 , 17 , 'PAYMENT_URL_METHOD' , 'CONSTANT' , 'POST' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (233 , 17 , 'NOPAYMENT_URL' , 'VARIABLE' , '{site_url}order_final.php' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (234 , 17 , 'NOPAYMENT_URL_METHOD' , 'CONSTANT' , 'POST' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (235 , 17 , 'BAGGAGE_FIELDS' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (236 , 18 , 'requestType' , 'CONSTANT' , 'BACKEND' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (237 , 18 , 'merchant_id' , 'CONSTANT' , '!type your merchant_id here!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (238 , 18 , 'trnOrderNumber' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (239 , 18 , 'trnAmount' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (240 , 18 , 'trnCardOwner' , 'VARIABLE' , 'cc_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (241 , 18 , 'trnCardNumber' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (242 , 18 , 'trnExpMonth' , 'VARIABLE' , 'cc_expiry_month' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (243 , 18 , 'trnExpYear' , 'VARIABLE' , 'cc_expiry_year' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (244 , 18 , 'ordName' , 'VARIABLE' , 'name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (245 , 18 , 'ordEmailAddress' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (246 , 18 , 'ordAddress1' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (247 , 18 , 'ordAddress2' , 'VARIABLE' , 'address2' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (248 , 18 , 'ordCity' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (249 , 18 , 'ordProvince' , 'VARIABLE' , 'state_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (250 , 18 , 'ordPostalCode' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (251 , 18 , 'ordCountry' , 'VARIABLE' , 'country_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (252 , 18 , 'ordPhoneNumber' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (253 , 19 , 'merchantid' , 'CONSTANT' , '!type your merchantid here!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (254 , 19 , 'cardnumber' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (255 , 19 , 'cardholder' , 'VARIABLE' , 'cc_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (256 , 19 , 'amount' , 'VARIABLE' , 'order_total_100' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (257 , 19 , 'expmonth' , 'VARIABLE' , 'cc_expiry_month' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (258 , 19 , 'expyear' , 'VARIABLE' , 'cc_expiry_year' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (259 , 19 , 'premonth' , 'VARIABLE' , 'cc_start_month' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (260 , 19 , 'preyear' , 'VARIABLE' , 'cc_start_year' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (261 , 19 , 'issuenumber' , 'VARIABLE' , 'cc_issue_number' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (262 , 19 , 'identifier' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (263 , 19 , 'cv2' , 'VARIABLE' , 'cc_security_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (264 , 19 , 'debug' , 'CONSTANT' , 'true' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (265 , 19 , 'test' , 'CONSTANT' , 'false' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (266 , 19 , 'avspostcode' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (267 , 20 , 'MerchantID' , 'CONSTANT' , '!Your Merchant ID!' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (268 , 20 , 'SubID' , 'CONSTANT' , '0' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (269 , 20 , 'IssuerID' , 'CONSTANT' , NULL , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (270 , 20 , 'Privatekey' , 'CONSTANT' , '!full path to your private key!' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (271 , 20 , 'Privatecert' , 'CONSTANT' , '!full path to your certificate!' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (272 , 20 , 'Certificate0' , 'CONSTANT' , '!full path to default public certificate!' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (273 , 20 , 'PrivatekeyPass' , 'CONSTANT' , '!Your Private key Password!' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (274 , 20 , 'EntranceCode' , 'CONSTANT' , '!Your Entrance Code!' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (275 , 20 , 'AcquirerURL' , 'CONSTANT' , 'ssl://ideal.secure-ing.com:443/ideal/iDeal' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (276 , 20 , 'AcquirerTimeout' , 'CONSTANT' , '10' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (277 , 20 , 'AuthenticationType' , 'CONSTANT' , 'SHA1_RSA' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (278 , 20 , 'MerchantReturnURL' , 'VARIABLE' , '{site_url}order_final.php' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (279 , 20 , 'Currency' , 'CONSTANT' , 'EUR' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (280 , 20 , 'ExpirationPeriod' , 'CONSTANT' , 'PT120S' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (281 , 20 , 'Language' , 'CONSTANT' , 'en' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (282 , 20 , 'DESCRIPTION' , 'CONSTANT' , 'default description' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (283 , 4 , 'callbackPW' , 'CONSTANT' , '{site_url}order_final.php' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (285 , 6 , 'address1' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (286 , 10 , 'name' , 'VARIABLE' , 'name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (287 , 10 , 'company' , 'VARIABLE' , 'company_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (288 , 10 , 'address1' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (289 , 10 , 'address2' , 'VARIABLE' , 'address2' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (290 , 10 , 'city' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (291 , 10 , 'state' , 'VARIABLE' , 'state_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (292 , 10 , 'zip' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (293 , 10 , 'country' , 'VARIABLE' , 'country_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (294 , 10 , 'phone' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (295 , 10 , 'fax' , 'VARIABLE' , 'fax' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (296 , 10 , 'email' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (297 , 10 , 'addrnum' , 'VARIABLE' , 'address_number' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (298 , 12 , 'name' , 'VARIABLE' , 'name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (299 , 12 , 'company' , 'VARIABLE' , 'company_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (300 , 12 , 'address1' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (301 , 12 , 'address2' , 'VARIABLE' , 'address2' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (302 , 12 , 'city' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (303 , 12 , 'state' , 'VARIABLE' , 'state_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (304 , 12 , 'zip' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (305 , 12 , 'country' , 'VARIABLE' , 'country_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (306 , 12 , 'phone' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (307 , 12 , 'fax' , 'VARIABLE' , 'fax' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (308 , 12 , 'email' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (309 , 12 , 'addrnum' , 'VARIABLE' , 'address_number' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (310 , 16 , 'StartDate' , 'VARIABLE' , '{cc_start_month}{cc_start_year}' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (311 , 16 , 'BillingAddress' , 'VARIABLE' , '{address1} {address2} {city} {province} {state}  {country}' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (312 , 16 , 'BillingPostCode' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (313 , 16 , 'DeliveryAddress' , 'VARIABLE' , '{delivery_address1} {delivery_address2} {delivery_city} {delivery_province} {delivery_state}  {delivery_country}' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (314 , 16 , 'DeliveryPostCode' , 'VARIABLE' , 'delivery_zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (315 , 16 , 'CustomerName' , 'VARIABLE' , 'name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (316 , 16 , 'CustomerEmail' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (317 , 16 , 'ContactNumber' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (318 , 21 , 'Username' , 'CONSTANT' , '!Your API Account Name' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (319 , 21 , 'Password' , 'CONSTANT' , '!Your API Account Password' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (320 , 21 , 'Subject' , 'CONSTANT' , NULL , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (321 , 21 , 'SSLCert' , 'CONSTANT' , '!Absolute path to your API certificate' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (322 , 21 , 'OrderTotal' , 'VARIABLE' , 'order_total' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (323 , 21 , 'ReturnURL' , 'VARIABLE' , '{site_url}payments/paypal_details.php' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (324 , 21 , 'CancelURL' , 'VARIABLE' , '{site_url}order_final.php' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (325 , 22 , 'Username' , 'CONSTANT' , '!Your API Account Name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (326 , 22 , 'Password' , 'CONSTANT' , '!Your API Account Password' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (327 , 22 , 'Subject' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (328 , 22 , 'SSLCert' , 'CONSTANT' , '!Absolute path to your API certificate' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (329 , 22 , 'InvoiceID' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (330 , 22 , 'OrderTotal' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (331 , 22 , 'CreditCardType' , 'VARIABLE' , 'cc_type' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (332 , 22 , 'CreditCardNumber' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (333 , 22 , 'ExpMonth' , 'VARIABLE' , 'cc_expiry_month' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (334 , 22 , 'ExpYear' , 'VARIABLE' , 'cc_expiry_yyyy' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (335 , 22 , 'Payer' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (336 , 22 , 'CCFirstName' , 'VARIABLE' , 'cc_first_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (337 , 22 , 'CCLastName' , 'VARIABLE' , 'cc_last_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (338 , 22 , 'CVV2' , 'VARIABLE' , 'cc_security_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (339 , 22 , 'Name' , 'VARIABLE' , 'name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (340 , 22 , 'Street1' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (341 , 22 , 'Street2' , 'VARIABLE' , 'address2' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (342 , 22 , 'CityName' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (343 , 22 , 'StateOrProvince' , 'VARIABLE' , 'state_code_or_province' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (344 , 22 , 'Country' , 'VARIABLE' , 'country_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (345 , 22 , 'PostalCode' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (346 , 22 , 'ShipName' , 'VARIABLE' , 'delivery_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (347 , 22 , 'ShipStreet1' , 'VARIABLE' , 'delivery_address1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (348 , 22 , 'ShipStreet2' , 'VARIABLE' , 'delivery_address2' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (349 , 22 , 'ShipCityName' , 'VARIABLE' , 'delivery_city' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (350 , 22 , 'ShipStateOrProvince' , 'VARIABLE' , 'delivery_state_code_or_province' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (351 , 22 , 'ShipCountry' , 'VARIABLE' , 'delivery_country_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (352 , 22 , 'ShipPostalCode' , 'VARIABLE' , 'delivery_zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (353 , 21 , 'ShipName' , 'VARIABLE' , 'delivery_name' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (354 , 21 , 'ShipStreet1' , 'VARIABLE' , 'delivery_address1' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (355 , 21 , 'ShipStreet2' , 'VARIABLE' , 'delivery_address2' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (356 , 21 , 'ShipCityName' , 'VARIABLE' , 'delivery_city' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (357 , 21 , 'ShipStateOrProvince' , 'VARIABLE' , 'delivery_state_code_or_province' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (358 , 21 , 'ShipCountry' , 'VARIABLE' , 'delivery_country_code' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (359 , 21 , 'ShipPostalCode' , 'VARIABLE' , 'delivery_zip' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (360 , 23 , 'Binary' , 'CONSTANT' , '/path/to/your/bin/pfpro' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (361 , 23 , 'Library' , 'CONSTANT' , '/path/to/your/lib/libpfpro.so' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (362 , 23 , 'CertPath' , 'CONSTANT' , '/path/to/your/certs' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (363 , 23 , 'VENDOR' , 'VARIABLE' , '!your vendor name!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (364 , 23 , 'PARTNER' , 'VARIABLE' , '!your parner name!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (365 , 23 , 'USER' , 'VARIABLE' , '!your user name!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (366 , 23 , 'PWD' , 'VARIABLE' , '!your password!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (367 , 23 , 'TRXTYPE' , 'CONSTANT' , 'S' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (368 , 23 , 'TENDER' , 'CONSTANT' , 'C' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (369 , 23 , 'ACCT' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (370 , 23 , 'AMT' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (371 , 23 , 'EXPDATE' , 'VARIABLE' , '{cc_expiry_month}{cc_expiry_year}' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (372 , 23 , 'CVV2' , 'VARIABLE' , 'cc_security_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (373 , 23 , 'NAME' , 'VARIABLE' , 'cc_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (374 , 23 , 'INVNUM' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (375 , 23 , 'STREET' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (376 , 23 , 'ZIP' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (377 , 3 , 'x_description' , 'VARIABLE' , 'description' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (378 , 3 , 'x_version' , 'CONSTANT' , '3.1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (379 , 3 , 'x_ship_to_first_name' , 'VARIABLE' , 'delivery_first_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (380 , 3 , 'x_ship_to_last_name' , 'VARIABLE' , 'delivery_last_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (381 , 3 , 'x_ship_to_company' , 'VARIABLE' , 'delivery_company_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (382 , 3 , 'x_ship_to_address' , 'VARIABLE' , 'delivery_address' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (383 , 3 , 'x_ship_to_city' , 'VARIABLE' , 'delivery_city' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (384 , 3 , 'x_ship_to_state' , 'VARIABLE' , 'delivery_state' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (385 , 3 , 'x_ship_to_zip' , 'VARIABLE' , 'delivery_zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (386 , 3 , 'x_ship_to_country' , 'VARIABLE' , 'delivery_country' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (387 , 3 , 'x_amount' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (388 , 3 , 'x_currency_code' , 'VARIABLE' , 'currency_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (389 , 3 , 'x_method' , 'CONSTANT' , 'CC' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (390 , 3 , 'x_type' , 'CONSTANT' , 'AUTH_CAPTURE' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (391 , 6 , 'address2' , 'VARIABLE' , 'address2' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (392 , 6 , 'bn' , 'CONSTANT' , 'viart' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (393 , 24 , 'clientid' , 'CONSTANT' , '!specify your client id!' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (394 , 24 , 'password' , 'CONSTANT' , '!specify your pass-phrase!' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (395 , 24 , 'oid' , 'VARIABLE' , 'order_id' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (396 , 24 , 'chargetype' , 'CONSTANT' , 'Auth' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (397 , 24 , 'currencycode' , 'VARIABLE' , 'currency_value' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (398 , 24 , 'total' , 'VARIABLE' , 'order_total' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (399 , 24 , 'epdqdata' , 'VARIABLE' , 'epdqdata' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (400 , 24 , 'returnurl' , 'VARIABLE' , '{site_url}order_final.php' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (401 , 24 , 'merchantdisplayname' , 'CONSTANT' , '!specify you company name!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (402 , 24 , 'baddr1' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (403 , 24 , 'baddr2' , 'VARIABLE' , 'address2' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (404 , 24 , 'bcity' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (405 , 24 , 'bcountry' , 'VARIABLE' , 'country_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (406 , 24 , 'bpostalcode' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (407 , 24 , 'bstate' , 'VARIABLE' , 'state_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (408 , 24 , 'btelephonenumber' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (409 , 24 , 'email' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (410 , 24 , 'bcountyprovince' , 'VARIABLE' , 'province' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (411 , 24 , 'saddr1' , 'VARIABLE' , 'delivery_address1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (412 , 24 , 'saddr2' , 'VARIABLE' , 'delivery_address2' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (413 , 24 , 'scity' , 'VARIABLE' , 'delivery_city' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (414 , 24 , 'scountyprovince' , 'VARIABLE' , 'delivery_province' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (415 , 24 , 'scountry' , 'VARIABLE' , 'delivery_country_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (416 , 24 , 'spostalcode' , 'VARIABLE' , 'delivery_zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (417 , 24 , 'sstate' , 'VARIABLE' , 'delivery_state_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (418 , 24 , 'stelephonenumber' , 'VARIABLE' , 'delivery_phone' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (419 , 21 , 'ButtonSource' , 'CONSTANT' , 'viart' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (420 , 22 , 'StartMonth' , 'VARIABLE' , 'cc_start_month' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (421 , 25 , 'ClientId' , 'CONSTANT' , '!Enter your ClientId here!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (422 , 25 , 'Name' , 'CONSTANT' , '!Enter your user name here!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (423 , 25 , 'Password' , 'CONSTANT' , '!Enter your password here!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (424 , 25 , 'Email' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (425 , 25 , 'Mode' , 'CONSTANT' , 'P' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (426 , 25 , 'OrderId' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (427 , 25 , 'GroupId' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (428 , 25 , 'TransId' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (429 , 25 , 'UserId' , 'VARIABLE' , 'user_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (430 , 25 , 'Type' , 'CONSTANT' , 'Auth' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (431 , 25 , 'Number' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (432 , 25 , 'Expires' , 'VARIABLE' , 'cc_expiry_date' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (433 , 25 , 'Cvv2Val' , 'VARIABLE' , 'cc_security_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (434 , 25 , 'Total' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (435 , 25 , 'Currency' , 'CONSTANT' , '792' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (436 , 25 , 'Taksit' , 'CONSTANT' , '0' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (437 , 25 , 'BillToName' , 'VARIABLE' , 'name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (438 , 25 , 'BillToStreet1' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (439 , 25 , 'BillToStreet2' , 'VARIABLE' , 'address2' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (440 , 25 , 'BillToStreet3' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (441 , 25 , 'BillToCity' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (442 , 25 , 'BillToStateProv' , 'VARIABLE' , 'province' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (443 , 25 , 'BillToPostalCode' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (444 , 25 , 'BillToCountry' , 'VARIABLE' , 'country' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (445 , 25 , 'BillToCompany' , 'VARIABLE' , 'company_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (446 , 25 , 'BillToTelVoice' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (447 , 25 , 'ShipToName' , 'VARIABLE' , 'delivery_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (448 , 25 , 'ShipToStreet1' , 'VARIABLE' , 'delivery_address1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (449 , 25 , 'ShipToStreet2' , 'VARIABLE' , 'delivery_address2' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (450 , 25 , 'ShipToStreet3' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (451 , 25 , 'ShipToCity' , 'VARIABLE' , 'delivery_city' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (452 , 25 , 'ShipToStateProv' , 'VARIABLE' , 'delivery_province' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (453 , 25 , 'ShipToPostalCode' , 'VARIABLE' , 'delivery_zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (454 , 25 , 'ShipToCountry' , 'VARIABLE' , 'delivery_country' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (455 , 26 , 'username' , 'CONSTANT' , '!Enter your User Name here!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (456 , 26 , 'password' , 'CONSTANT' , '!Enter your Password here!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (457 , 26 , 'site' , 'CONSTANT' , '!Enter your Site ID here!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (458 , 26 , 'package' , 'CONSTANT' , '!Enter your Package ID here!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (459 , 26 , 'login' , 'CONSTANT' , '!Enter your Login here!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (460 , 26 , 'region_code' , 'CONSTANT' , '!Enter your Region Code here!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (461 , 26 , 'price' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (462 , 26 , 'first_name' , 'VARIABLE' , 'first_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (463 , 26 , 'last_name' , 'VARIABLE' , 'last_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (464 , 26 , 'email' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (465 , 26 , 'address' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (466 , 26 , 'zip' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (467 , 26 , 'city' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (468 , 26 , 'country_code' , 'VARIABLE' , 'country' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (469 , 26 , 'cc_number' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (470 , 26 , 'expire_month' , 'VARIABLE' , 'cc_expire_month' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (471 , 26 , 'expire_year' , 'VARIABLE' , 'cc_expire_year' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (472 , 26 , 'cvcode' , 'VARIABLE' , 'cc_security_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (473 , 27 , 'UserName' , 'CONSTANT' , '!specify your username!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (474 , 27 , 'Password' , 'CONSTANT' , '!specify your password!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (475 , 27 , 'ClientId' , 'CONSTANT' , '!specify your client id!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (476 , 27 , 'Mode' , 'CONSTANT' , 'P' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (477 , 27 , 'Type' , 'CONSTANT' , 'Auth' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (478 , 27 , 'PoNumber' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (479 , 27 , 'Currency' , 'VARIABLE' , 'currency_value' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (480 , 27 , 'OrderTotal' , 'VARIABLE' , 'order_total_100' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (481 , 27 , 'CCNumber' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (482 , 27 , 'CCExpires' , 'VARIABLE' , '{cc_expiry_month}/{cc_expiry_year}' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (483 , 27 , 'Cvv2Val' , 'VARIABLE' , 'cc_security_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (484 , 27 , 'CCStartDate' , 'VARIABLE' , '{cc_start_month}/{cc_start_year}' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (485 , 27 , 'CCType' , 'VARIABLE' , 'cc_type' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (486 , 27 , 'CCIssueNum' , 'VARIABLE' , 'cc_issue_number' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (487 , 27 , 'BillEmail' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (488 , 27 , 'BillName' , 'VARIABLE' , 'name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (489 , 27 , 'BillStreet1' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (490 , 27 , 'BillStreet2' , 'VARIABLE' , 'address2' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (491 , 27 , 'BillCity' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (492 , 27 , 'BillStateProv' , 'VARIABLE' , 'state_code_or_province' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (493 , 27 , 'BillPostalCode' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (494 , 27 , 'BillCountry' , 'VARIABLE' , 'country_number' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (495 , 27 , 'BillTelVoice' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (496 , 27 , 'BillTelFax' , 'VARIABLE' , 'fax' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (497 , 27 , 'ShipName' , 'VARIABLE' , 'delivery_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (498 , 27 , 'ShipStreet1' , 'VARIABLE' , 'delivery_address1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (499 , 27 , 'ShipStreet2' , 'VARIABLE' , 'delivery_address2' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (500 , 27 , 'ShipCity' , 'VARIABLE' , 'delivery_city' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (501 , 27 , 'ShipStateProv' , 'VARIABLE' , 'delivery_state_code_or_province' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (502 , 27 , 'ShipCountry' , 'VARIABLE' , 'delivery_country_number' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (503 , 27 , 'ShipTelVoice' , 'VARIABLE' , 'delivery_phone' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (504 , 27 , 'ShipTelFax' , 'VARIABLE' , 'delivery_fax' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (505 , 27 , 'ShipEmail' , 'VARIABLE' , 'delivery_email' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (506 , 28 , 'merchantID' , 'CONSTANT' , '!Enter your merchantID here!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (507 , 28 , 'APACScommand' , 'CONSTANT' , 'NewPayment' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (508 , 28 , 'amount' , 'VARIABLE' , 'order_total_100' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (509 , 28 , 'merchantRef' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (510 , 28 , 'merchantDesc' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (511 , 28 , 'currency' , 'CONSTANT' , '0978' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (512 , 28 , 'lang' , 'CONSTANT' , 'EN' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (513 , 28 , 'CustomerEmail' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (514 , 28 , 'Offset' , 'CONSTANT' , '0' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (515 , 28 , 'Period' , 'CONSTANT' , '0' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (516 , 28 , 'var1' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (517 , 28 , 'var2' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (518 , 28 , 'var3' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (519 , 28 , 'var4' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (520 , 28 , 'var5' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (521 , 28 , 'var6' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (522 , 28 , 'var7' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (523 , 28 , 'var8' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (524 , 28 , 'var9' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (525 , 29 , 'username' , 'CONSTANT' , '!Enter your username!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (526 , 29 , 'password' , 'CONSTANT' , '!Enter your password!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (527 , 29 , 'mid' , 'CONSTANT' , '!Enter your mid!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (528 , 29 , 'tid' , 'CONSTANT' , '!Enter your tid!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (529 , 29 , 'currencyCode' , 'CONSTANT' , 'YT' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (530 , 29 , 'installment' , 'CONSTANT' , '03' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (531 , 29 , 'extraPoint' , 'CONSTANT' , '000000' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (532 , 29 , 'multiplePoint' , 'CONSTANT' , '00' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (533 , 29 , 'amount' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (534 , 29 , 'orderID' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (535 , 29 , 'ccno' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (536 , 29 , 'cardexpyear' , 'VARIABLE' , 'cc_expiry_year' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (537 , 29 , 'cardexpmonth' , 'VARIABLE' , 'cc_expiry_month' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (538 , 29 , 'cvc' , 'VARIABLE' , 'cc_security_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (539 , 30 , 'ClientId' , 'CONSTANT' , '!Enter your ClientId here!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (540 , 30 , 'Name' , 'CONSTANT' , '!Enter your user name here!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (541 , 30 , 'Password' , 'CONSTANT' , '!Enter you password here!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (542 , 30 , 'Mode' , 'CONSTANT' , 'P' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (543 , 30 , 'GroupId' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (544 , 30 , 'TransId' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (545 , 30 , 'Type' , 'CONSTANT' , 'Auth' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (546 , 30 , 'Currency' , 'CONSTANT' , '949' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (547 , 30 , 'Taskit' , 'CONSTANT' , '0' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (548 , 30 , 'IPAddress' , 'VARIABLE' , 'user_ip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (549 , 30 , 'Email' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (550 , 30 , 'OrderId' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (551 , 30 , 'UserId' , 'VARIABLE' , 'user_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (552 , 30 , 'Number' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (553 , 30 , 'Expires' , 'VARIABLE' , 'cc_expiry_date' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (554 , 30 , 'Cvv2Val' , 'VARIABLE' , 'cc_security_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (555 , 30 , 'Total' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (556 , 30 , 'BillToName' , 'VARIABLE' , 'name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (557 , 30 , 'BillToStreet1' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (558 , 30 , 'BillToStreet2' , 'VARIABLE' , 'address2' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (559 , 30 , 'BillToStreet3' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (560 , 30 , 'BillToCity' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (561 , 30 , 'BillToStateProv' , 'VARIABLE' , 'province' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (562 , 30 , 'BillToPostalCode' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (563 , 30 , 'BillToCountry' , 'VARIABLE' , 'country' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (564 , 30 , 'BillToCompany' , 'VARIABLE' , 'company_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (565 , 30 , 'BillToTelVoice' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (566 , 30 , 'ShipToName' , 'VARIABLE' , 'delivery_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (567 , 30 , 'ShipToStreet1' , 'VARIABLE' , 'delivery_address1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (568 , 30 , 'ShipToStreet2' , 'VARIABLE' , 'delivery_address2' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (569 , 30 , 'ShipToStreet3' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (570 , 30 , 'ShipToCity' , 'VARIABLE' , 'delivery_city' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (571 , 30 , 'ShipToStateProv' , 'VARIABLE' , 'delivery_province' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (572 , 30 , 'ShipToPostalCode' , 'VARIABLE' , 'delivery_zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (573 , 30 , 'ShipToCountry' , 'VARIABLE' , 'delivery_country' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (574 , 31 , 'account_id' , 'CONSTANT' , '!Enter your Account ID here!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (575 , 31 , 'tran_type' , 'CONSTANT' , 'S' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (576 , 31 , 'pay_type' , 'CONSTANT' , 'C' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (577 , 31 , 'amount' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (578 , 31 , 'card_number' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (579 , 31 , 'cardexpyear' , 'VARIABLE' , 'cc_expiry_year' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (580 , 31 , 'cardexpmonth' , 'VARIABLE' , 'cc_expiry_month' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (581 , 32 , 'product_id' , 'CONSTANT' , '!Enter your product_id!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (582 , 32 , 'product_name' , 'CONSTANT' , '!Enter your product_name!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (583 , 32 , 'language' , 'CONSTANT' , 'En' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (584 , 32 , 'cb_url' , 'CONSTANT' , '{site_url}payments/chronopay_confirm.php' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (585 , 32 , 'cb_type' , 'CONSTANT' , 'P' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (586 , 32 , 'product_price' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (587 , 32 , 'street' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (588 , 32 , 'city' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (589 , 32 , 'state' , 'VARIABLE' , 'state' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (590 , 32 , 'zip' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (591 , 32 , 'country' , 'VARIABLE' , 'country' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (592 , 32 , 'phone' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (593 , 32 , 'email' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (594 , 32 , 'f_name' , 'VARIABLE' , 'first_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (595 , 32 , 's_name' , 'VARIABLE' , 'last_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (596 , 32 , 'cs1' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (597 , 32 , 'cs2' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (598 , 32 , 'cs3' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (599 , 3 , 'x_email' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (600 , 33 , 'mpSeller_ID' , 'CONSTANT' , '!Enter your seller ID!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (601 , 33 , 'mpType' , 'CONSTANT' , '1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (602 , 33 , 'mpAdministration_ID' , 'CONSTANT' , '1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (603 , 33 , 'mpAllow' , 'CONSTANT' , 'TEVI' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (604 , 33 , 'mpCountry' , 'CONSTANT' , 'NL' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (605 , 33 , 'mpCurrency' , 'CONSTANT' , 'NLG' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (606 , 33 , 'mpDescription' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (607 , 33 , 'mpItems' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (608 , 33 , 'mpVar1' , 'VARIABLE' , 'response' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (609 , 33 , 'mpVar2' , 'VARIABLE' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (610 , 33 , 'mpAmount' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (611 , 33 , 'mpOrder_ID' , 'VARIABLE' , 'test_{order_id}' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (612 , 33 , 'mpSuccessURL' , 'VARIABLE' , '{site_url}order_final.php' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (613 , 33 , 'mpnaw_first' , 'VARIABLE' , 'first_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (614 , 33 , 'mpnaw_last' , 'VARIABLE' , 'last_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (615 , 33 , 'mpnaw_email' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (616 , 33 , 'mpnaw_telno' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (617 , 33 , 'mpnaw_country' , 'VARIABLE' , 'country' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (618 , 33 , 'mpnaw_city' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (619 , 33 , 'mpnaw_street' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (620 , 33 , 'mpnaw_zipcode' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (621 , 33 , 'mpnaw_number' , 'VARIABLE' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (622 , 3 , 'x_test_request' , 'CONSTANT' , 'FALSE' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (623 , 3 , 'x_relay_url' , 'VARIABLE' , '{site_url}order_final.php' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (624 , 34 , 'merchant_id' , 'CONSTANT' , '!Enter here your merchant_id!' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (625 , 34 , 'merchant_key' , 'CONSTANT' , '!Enter here your merchant_key!' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (626 , 34 , 'action_url' , 'CONSTANT' , 'https://sandbox.google.com/checkout/cws/v2/Merchant/[[Your-Merchant-ID]]/checkout' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (627 , 34 , 'currency' , 'CONSTANT' , 'USD' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (628 , 34 , 'item-name' , 'VARIABLE' , NULL , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (629 , 35 , 'Clientid' , 'CONSTANT' , '!Enter here your Clientid!' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (630 , 35 , 'pan' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (631 , 35 , 'cv2' , 'VARIABLE' , 'cc_security_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (632 , 35 , 'Ecom_Payment_Card_ExpDate_Year' , 'VARIABLE' , 'cc_expiry_year' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (633 , 35 , 'Ecom_Payment_Card_ExpDate_Month' , 'VARIABLE' , 'cc_expiry_month' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (634 , 35 , 'Amount' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (635 , 35 , 'Description' , 'VARIABLE' , 'basket' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (636 , 35 , 'OkUrl' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (637 , 35 , 'FailUrl' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (639 , 6 , 'currency_code' , 'VARIABLE' , 'currency_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (640 , 6 , 'sandbox' , 'CONSTANT' , '0' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (641 , 21 , 'sandbox' , 'CONSTANT' , '0' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (642 , 22 , 'StartYear' , 'VARIABLE' , 'cc_start_year' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (643 , 22 , 'IssueNumber' , 'VARIABLE' , 'cc_issue_number' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (644 , 22 , 'ButtonSource' , 'CONSTANT' , 'viart' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (645 , 22 , 'IPAddress' , 'VARIABLE' , 'order_ip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (646 , 22 , 'sandbox' , 'CONSTANT' , '0' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (647 , 7 , 'x_Ship_To_Last_Name' , 'VARIABLE' , 'delivery_last_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (648 , 7 , 'x_Ship_To_Company' , 'VARIABLE' , 'delivery_company_name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (649 , 7 , 'x_Ship_To_Address' , 'VARIABLE' , 'delivery_address' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (650 , 7 , 'x_Ship_To_City' , 'VARIABLE' , 'delivery_city' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (651 , 7 , 'x_Ship_To_State' , 'VARIABLE' , 'delivery_state' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (652 , 7 , 'x_Ship_To_Zip' , 'VARIABLE' , 'delivery_zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (653 , 7 , 'x_Ship_To_Country' , 'VARIABLE' , 'delivery_country' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (654 , 7 , 'x_Email' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (655 , 7 , 'x_Delim_Data' , 'CONSTANT' , 'TRUE' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (656 , 7 , 'x_Delim_Char' , 'CONSTANT' , '|' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (657 , 7 , 'x_Cust_ID' , 'VARIABLE' , 'user_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (658 , 7 , 'x_Customer_IP' , 'VARIABLE' , 'user_ip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (659 , 7 , 'x_Currency_Code' , 'VARIABLE' , 'currency_code' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (660 , 3 , 'x_Cust_ID' , 'VARIABLE' , 'user_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (661 , 3 , 'x_Customer_IP' , 'VARIABLE' , 'user_ip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (662 , 14 , 'return' , 'VARIABLE' , '{site_url}order_final.php' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (663 , 14 , 'popup' , 'CONSTANT' , 'false' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (664 , 36 , 'TxType' , 'CONSTANT' , 'PAYMENT' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (665 , 36 , 'Vendor' , 'CONSTANT' , '[Enter your Vendor login name here]' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (666 , 36 , 'VPSProtocol' , 'CONSTANT' , '2.22' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (667 , 36 , 'Currency' , 'CONSTANT' , 'GBP' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (668 , 36 , 'Description' , 'CONSTANT' , 'Description' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (669 , 36 , 'VendorTxCode' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (670 , 36 , 'Amount' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (671 , 36 , 'NotificationURL' , 'VARIABLE' , '{site_url}payments/protx_server_checkout.php' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (672 , 36 , 'Basket' , 'VARIABLE' , '1:Total:{total_quantity}:---:---:---:{order_total}' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (673 , 36 , 'BillingAddress' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (674 , 36 , 'BillingPostCode' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (675 , 36 , 'DeliveryAddress' , 'VARIABLE' , 'delivery_address1' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (676 , 36 , 'DeliveryPostCode' , 'VARIABLE' , 'delivery_zip' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (677 , 36 , 'CustomerName' , 'VARIABLE' , 'name' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (678 , 36 , 'ContactNumber' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (679 , 36 , 'ContactFax' , 'VARIABLE' , 'fax' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (680 , 36 , 'CustomerEMail' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (681 , 36 , 'AllowGiftAid' , 'VARIABLE' , '0' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (682 , 36 , 'ApplyAVSCV2' , 'VARIABLE' , '0' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (683 , 36 , 'Apply3DSecure' , 'VARIABLE' , '0' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (684 , 36 , 'RedirectURL' , 'VARIABLE' , '{site_url}order_final.php' , 1 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (685 , 37 , 'p1' , 'CONSTANT' , '[enter your VCS Terminal ID here]' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (686 , 37 , 'p2' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (687 , 37 , 'p3' , 'VARIABLE' , 'basket' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (688 , 37 , 'p4' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (689 , 37 , 'p5' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (690 , 37 , 'p6' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (691 , 37 , 'p7' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (692 , 37 , 'p8' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (693 , 37 , 'p9' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (694 , 37 , 'p10' , 'VARIABLE' , '{site_url}order_info.php' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (695 , 37 , 'p11' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (696 , 37 , 'p12' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (697 , 37 , 'p13' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (698 , 37 , 'Budget' , 'CONSTANT' , 'N' , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (699 , 37 , 'NextOccurDate' , 'VARIABLE' , NULL , 0 ) ;
INSERT INTO [va_payment_parameters] ([parameter_id],[payment_id],[parameter_name],[parameter_type],[parameter_source],[not_passed]) VALUES (700 , 37 , 'pam' , 'CONSTANT' , '[Enter your pam here]' , 0 ) ;


INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (1 , 'Personal' , NULL , NULL , 'credit_card_info.php' , NULL , NULL , NULL , NULL , NULL , 'GET' , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 1 , NULL , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (2 , 'VeriSign PayFlow Link' , NULL , 'Please specify value for parameters  ''LOGIN'' and ''PARTNER''.\r\nIf you setup your Verisign PayFlow Link account directly through Verisign, than your Partner ID is likely "Verisign" (without the quotes).\r\n' , 'https://payments.verisign.com/payflowlink' , NULL , NULL , NULL , NULL , NULL , 'GET' , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (3 , 'Authorize.Net SIM' , NULL , 'Please specify values for parameters ''x_login'' and ''x_tran_key''.\r\n\r\nPlease also set parameter ''x_test_request'' to ''FALSE'' if you are ready to run live transactions or leave it as ''TRUE'' for test your site before going live.\r\n\r\nIf you want receive response from Authorize.net about submiited transactions please also specify ''x_secret'' parameter to the same value as in your Authorize settings.\r\n\r\nTo choose your MD5 Hash Secret in the Authorize.net account please do the following:\r\n- Log into your merchant menu at https://secure.authorize.net/ \r\n- Click "Settings"\r\n- Select "MD5 Hash" under the "Security" portion of your account settings\r\n- Enter the MD5 Hash Secret value that you would like to use\r\n- Confirm the MD5 Hash value\r\n- Click "Submit" to save the changes\r\n\r\nAlso you need specify response URL in your Authorize.net account:\r\n- Select "Response/Receipt URLs" under the "Transaction Response" portion of your account settings\r\n- Click on "Edit" link for "Default Relay Response URL"\r\n- Enter your response URL (for this url you can use following page ''http://your_site_url/order_final.php'')\r\n- Click "Submit" to save the changes' , 'https://secure.authorize.net/gateway/transact.dll' , NULL , NULL , NULL , NULL , NULL , 'POST' , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (4 , 'WorldPay' , NULL , 'Please specify your installation ID for parameter ''instId''.\r\nAs well you can specify callbackPW parameter if you set Callback password for your installation on the WorldPay Customer Management System. As the value of this is only known to this and your callback script it can be used as a basic security check within your script.\r\nAlways leave ''Not Passed'' checkbox checked for callbackPW parameter.\r\n\r\nA quote from WorldPay FAQ.\r\n\r\nQ: How can I configure WorldPay to use callback for an installation ID? \r\nA: You will initially need to log in to the WorldPay Customer Management System (via http://www.worldpay.com/admin). In the new window that opens you will need to scroll down to the section headed Installations and select the Configuration options button corresponding to the instId you are using. \r\nThe minimum settings you need to complete are: \r\nCallback URL - This should be set to the complete address to your callback URL, hosted on your server. \r\nCallback enabled? - This determines whether WorldPay will attempt to use the callback URL when needed. \r\nIn order to use callback you must selected at least these two settings. \r\nIf you have developed your callback script to output an HTML response and would like WorldPay to capture this for display to the shopper after the callback has completed successfully, you should also ensure Use callback response? is selected. \r\nTo commit the changes you have made, select SAVE CHANGES at the bottom of the page.\r\n' , 'https://select.worldpay.com/wcc/purchase' , NULL , NULL , NULL , NULL , NULL , 'POST' , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (5 , '2CheckOut' , NULL , 'Please specify values for parameters ''sid'' and ''secret_word''.\r\n''sid'' - it is your vendor number in system like 340000, ''secret_word'' - must be the same as in your 2CheckOut settings.\r\nFor return url you can use following page ''http://your_site_url/order_final.php''.' , 'https://www2.2checkout.com/2co/buyer/purchase' , NULL , NULL , NULL , NULL , NULL , 'POST' , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (6 , 'PayPal' , NULL , 'Please specify your business email address where it says ''your.paypal@example.com'' and specify value for ''at'' (identity token) parameter from your PayPal settings.\r\n\r\nActivating PDT.\r\nTo use PDT, you must activate PDT and Auto Return in your PayPal account profile. You must also acquire a PDT identity token, which is used in all PDT communication you send to PayPal.\r\n \r\nFollow these steps to configure your account for PDT:\r\n1. Log in to your PayPal account. \r\n2. Click the Profile sub tab. \r\n3. Click Website Payment Preferences in the Seller Preferences column. \r\n4. Under Auto Return for Website Payments, click the On radio button. \r\n5. For the Return URL, enter the URL on your site that will receive the transaction ID posted by PayPal after a customer payment as ''http://example.com/order_final.php''.\r\n6. Under Payment Data Transfer, click the On radio button. \r\n7. Click Save. \r\n8. Click Website Payment Preferences in the Seller Preferences column. \r\n9. Scroll down to the Payment Data Transfer section of the page to view your PDT identity token, copy it and paste as ''at'' parameter value.\r\n\r\nAlso it''s recommended to turn on PayPal IPN notifications. For this withing you PayPal account please go to ''Profile > Instant Payment Notification Preferences'' and turn on this setting and set ''Notification URL'' as ''http://example.com/payments/paypal_ipn.php''.\r\n\r\nIf you don''t want pass data to PayPal in multicurrencies please specify for currency_code parameter preferred currency code like ''USD''.\r\n\r\nFor testing with PayPal SandBox please change ''sandbox'' parameter value to ''1'' and specify ''Payment URL'' as https://www.sandbox.paypal.com/cgi-bin/webscr\r\n\r\nAfter testing with Sandbox please return ''sandbox'' value to ''0'' and specify production ''Payment URL'': https://www.paypal.com/cgi-bin/webscr' , 'https://www.paypal.com/cgi-bin/webscr' , NULL , NULL , NULL , NULL , NULL , 'POST' , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (7 , 'Authorize.Net AIM' , NULL , 'Please specify values for parameters ''x_login'' and ''x_tran_key'' - transaction key obtained from the Merchant Interface.\r\n\r\nFor sending test transaction add x_Test_Request parameter with TRUE value.' , 'credit_card_info.php' , NULL , NULL , NULL , NULL , NULL , 'GET' , NULL , 1 , 'https://secure.authorize.net/gateway/transact.dll' , './payments/authorize_aim.php' , 9 , NULL , 10 , NULL , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (8 , 'PRI Merchants Advanced' , NULL , 'Please specify values for parameters ''MerchantID'' and ''RegKey''.\r\nFor security purposes you also need to change Payment URL to the absolute secure path, e.g. https://your_site/credit_card_info.php' , 'credit_card_info.php' , NULL , NULL , NULL , NULL , NULL , 'GET' , NULL , 1 , 'https://webservices.primerchants.com/billing/TransactionCentral/processCC.asp' , './payments/pri_merchants.php' , 9 , NULL , 10 , NULL , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (9 , 'YourPay Connect' , NULL , 'Please specify value for parameter ''storename''.' , 'https://secure.linkpt.net/lpcentral/servlet/lppay' , NULL , NULL , NULL , NULL , NULL , 'POST' , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (10 , 'YourPay API' , NULL , 'Please specify values for parameters ''configfile'' and ''keyfile''.\r\n\r\nParameters description:\r\n\r\n''configfile'' - it is you store number in system, \r\n\r\n''keyfile'' - local path to your SSL certificate provided by YourPay.\r\n\r\n''result'' - this field puts the account in live mode or test mode. \r\nSet to LIVE for live mode, GOOD for an approved response in test mode, DECLINE for a declined reponse in test mode, or DUPLICATE for a duplicate response.\r\n\r\nFor security purposes you also need to change Payment URL to the absolute secure path, e.g. https://your_site/credit_card_info.php' , 'credit_card_info.php' , NULL , NULL , NULL , NULL , NULL , 'GET' , NULL , 1 , 'https://secure.linkpt.net:1129/LSGSXML' , './payments/linkpoint_api.php' , 4 , NULL , 10 , NULL , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (11 , 'LinkPoint Connect' , NULL , 'Please specify value for parameter ''storename''.' , 'https://www.linkpointcentral.com/lpc/servlet/lppay' , NULL , NULL , NULL , NULL , NULL , 'POST' , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (12 , 'LinkPoint API' , NULL , 'Please specify values for parameters ''configfile'' and ''keyfile''.\r\n\r\nParameters description:\r\n\r\n''configfile'' - it is you store number in system, \r\n\r\n''keyfile'' - local path to your SSL certificate provided by Linkpoint.\r\n\r\n''result'' - this field puts the account in live mode or test mode. \r\nSet to LIVE for live mode, GOOD for an approved response in test mode, DECLINE for a declined reponse in test mode, or DUPLICATE for a duplicate response.\r\n\r\nFor security purposes you also need to change Payment URL to the absolute secure path, e.g. https://your_site/credit_card_info.php' , 'credit_card_info.php' , NULL , NULL , NULL , NULL , NULL , 'GET' , NULL , 1 , 'https://secure.linkpt.net:1129/LSGSXML' , './payments/linkpoint_api.php' , 4 , NULL , 10 , NULL , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (14 , 'Paymate Express' , NULL , 'Payment URL:\r\n\r\nProduction - https://www.paymate.com.au/PayMate/ExpressPayment\r\nTesting - https://www.paymate.com.au/PayMate/TestExpressPayment\r\n\r\n\r\nParameters description:\r\n\r\n''mid'' - Your Paymate account name\r\n''amt'' -\tThe payment amount\r\n''amt_editable'' - Indicate if payment amount is editable or not\r\n''currency'' - The currency code of the payment (''AUD'', ''USD'',''EUR'',''GBP'',''NZD'')\r\n''ref'' - A seller reference number for a transaction\r\n''pmt_sender_email'' - The buyer''s email address\r\n''pmt_contact_firstname'' - The buyer''s first name\r\n''pmt_contact_surname'' - The buyer''s surname\r\n''pmt_contact_phone'' - The buyer''s phone number\r\n''pmt_country'' - The buyer''s country.\r\n''regindi_address1'' - The first address line of the buyer''s address\r\n''regindi_address2'' - The second address line of the buyer''s address\r\n''regindi_sub'' - The suburb of the buyer''s address\r\n''regindi_pcode'' - The postcode of the buyer''s address\r\n''return'' - A fully-qualified (eg: http://www.yoursite.com/order_final.php) URL to which Paymate will redirect the buyer. This redirect will occur when they click the continue button on the receipt page of the Express Payment wizard.\r\n''popup'' - Indicate if your web site has opened Paymate Express in a new window. Must be either "true" or "false", default is "true". If this value is true, the Paymate Express window will close before displaying the ''return'' URL in the browser window which opened Paymate Express. If this value is false, the ''return'' URL will be displayed in the same window as Paymate Express.\r\n\r\n\r\nThis will allow you to process test payments to a dummy account.\r\n\r\n    * mid: testuser\r\n    * The card number : 4564456445644564 will always return an approved transaction.\r\n    * The card number : 5424000000000015 will always return an declined transaction.\r\n    * Other valid card number will always return that the payment is processing.\r\n' , 'https://www.paymate.com.au/PayMate/ExpressPayment' , NULL , NULL , NULL , NULL , NULL , 'GET' , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (15 , 'Protx VSP Form' , NULL , 'Please specify your Vendor name and your EncryptionPassword. As well you can change currency_code parameter to some default value like ''USD''.\r\n-- Simulator site\r\nhttps://ukvpstest.protx.com/VSPSimulator/VSPFormGateway.asp\r\n--  Test site\r\nhttps://ukvpstest.protx.com/vps2form/submit.asp\r\n-- Live site url\r\nhttps://ukvps.protx.com/vps2form/submit.asp' , 'https://ukvps.protx.com/vps2form/submit.asp' , NULL , NULL , NULL , NULL , NULL , 'POST' , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (16 , 'Protx VSP Direct' , NULL , 'Please specify your Vendor name. As well you can change currency_code parameter to some default value like ''USD''.\r\nFor security purposes you also need to change Payment URL to the absolute secure path, e.g. https://your_site/credit_card_info.php\r\n-- Simulator site\r\nhttps://ukvpstest.protx.com/VSPSimulator/VSPDirectGateway.asp\r\n-- Test site\r\nhttps://ukvpstest.protx.com/vpsDirectAuth/PaymentGateway.asp\r\n-- Live site url\r\nhttps://ukvps.protx.com/vpsDirectAuth/PaymentGateway.asp' , 'credit_card_info.php' , NULL , NULL , NULL , NULL , NULL , 'GET' , NULL , 1 , 'https://ukvps.protx.com/vpsDirectAuth/PaymentGateway.asp' , './payments/protx_direct.php' , 4 , NULL , 10 , NULL , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (17 , 'eGold SCI' , NULL , 'Please specify your account number, name and passpharse in fields below. If you want change currency please use PAYMENT_UNITS parameter (1 - USD, 2 - CAD, 85 - EUR, 81 - JPY).' , 'https://www.e-gold.com/sci_asp/payments.asp' , NULL , NULL , NULL , NULL , NULL , 'POST' , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (18 , 'Beanstream API' , NULL , 'Please specify your merchant_id.\r\nFor security purposes you also need to change Payment URL to the absolute secure path, e.g. https://your_site/credit_card_info.php' , 'credit_card_info.php' , NULL , NULL , NULL , NULL , NULL , 'GET' , NULL , 1 , 'https://www.beanstream.com/scripts/process_transaction.asp' , './payments/beanstream_api.php' , 4 , NULL , 10 , NULL , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (19 , 'Payoffshore API' , NULL , 'Please specify your merchantid.\r\nIf you want test system before go live you can change ''test'' parameter value to ''true''.\r\nFor security purposes you also need to change Payment URL to the absolute secure path, e.g. https://your_site/credit_card_info.php' , 'credit_card_info.php' , NULL , NULL , NULL , NULL , NULL , 'GET' , NULL , 1 , 'https://secure.payoffshore.com/ecom/api.xml' , './payments/payoffshore_api.php' , 4 , NULL , 10 , NULL , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (20 , 'iDEAL' , NULL , 'Please specify your MerchanID and your certificates information.\r\nIf you will using only one Issuer you can specify it for IssuerID parameter as well.\r\nLive site: ssl://ideal.secure-ing.com:443/ideal/iDeal\r\nTest site: ssl://idealtest.secure-ing.com:443/ideal/iDeal' , './payments/ideal_process.php' , NULL , NULL , NULL , NULL , NULL , 'GET' , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (21 , 'PayPal Pro (Express Checkout)' , NULL , 'Before proceed with this method you need to request an API Certificate withing your PayPal account from ''My Account > Profile > API Access''.\r\n\r\nOn ''API Access'' page click the link ''Request API Credentials'' and on the new page select ''API SSL client-side certificate'' option and tick off the checkbox to agree to PayPal terms. On the next page you will see API Username and Password details for your account and here you can download your certificate by pressing ''Download Certificate'' button, this SSL certificate should be uploaded to your web server.\r\n\r\nThen please specify you API information like ''Username'', ''Password'' and ''SSLCert'' in the fields below.\r\n\r\nFor testing with PayPal SandBox please change ''sandbox'' parameter value to ''1''.' , 'payments/paypal_checkout.php' , NULL , NULL , NULL , NULL , NULL , 'GET' , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (22 , 'PayPal Pro (Direct API)' , NULL , 'Before proceed with this method or ''PayPal Express Checkout'' you need to request an API Certificate withing your PayPal account from ''My Account > Profile > API Access''.\r\n\r\nOn ''API Access'' page click the link ''Request API Credentials'' and on the new page select ''API SSL client-side certificate'' option and tick off the checkbox to agree to PayPal terms. On the next page you will see API Username and Password details for your account and here you can download your certificate by pressing ''Download Certificate'' button, this SSL certificate should be uploaded to your web server.\r\n\r\nAfter that you have to ''Submit Application'' from ''Merchant Tools > Business Solutions > Website Payment Pro''. (Works only for USA and UK customers)\r\n\r\nWhen you''ve finished all steps please specify you API information like ''Username'', ''Password'' and ''SSLCert'' in the fields below.\r\n\r\nPlease note that Direct Payment API is not a standalone product. You are required to use Direct Payment API and Express Checkout together as part of the Website Payments Pro solution accordingly to PayPal documentation.\r\n\r\nFor testing with PayPal SandBox please change ''sandbox'' parameter value to ''1''.' , 'credit_card_info.php' , NULL , NULL , NULL , NULL , NULL , 'GET' , NULL , 1 , 'https://api-aa.paypal.com/2.0/' , './payments/paypal_direct.php' , 4 , NULL , 10 , NULL , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (23 , 'VeriSign PayFlow Pro' , NULL , 'First of all you need to download the Payflow Pro SDK and extract the files to one of your server directory.\r\n\r\nSet PayFlow SDK parameters in the parametrs list below\r\nBinary - absolute path to PayFlow executable module pfpro or pfpro.exe\r\nLibrary - absolute path to PayFlow library\r\nCertPath - absolute path to the folder with certificates\r\n\r\nThen please specify your login information like ''VENDOR'', ''PARTNER'', ''USER'' and ''PWD'' in the fields below.' , 'credit_card_info.php' , NULL , NULL , NULL , NULL , NULL , 'GET' , NULL , 1 , 'payflow.verisign.com' , './payments/verisign_pro.php' , 4 , 6 , 10 , 0 , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (24 , 'ePDQ CPI' , NULL , 'Please specify values for parameters ''clientid'', ''password'' and ''merchantdisplayname''.\r\nPlease use for the ''password'' parameter the same value as you specified it for ''Pass-phrase'' field in your ePDQ settings.\r\n\r\nTo receive order results please specify in your ePDQ settings ''POST URL'' as ''http://your_site_url/payments/epqd_cpi_response.php'' and set parameters ''POST Order result'' to ''Yes''.\r\n\r\nIf you don''t want pass data to ePDQ in multicurrencies please specify for currencycode parameter preferred currency value like 840 for USD, 826 for GBP.' , 'https://secure2.epdq.co.uk/cgi-bin/CcxBarclaysEpdq.e' , NULL , NULL , NULL , NULL , NULL , 'GET' , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (25 , 'Garanti' , NULL , 'Please specify the following parameters:\r\nClientId - Shop Code sent you via e-mail\r\nName - Payment pages user id\r\nPassword - User password\r\nCurrency - Currency code' , 'credit_card_info.php' , NULL , NULL , NULL , NULL , NULL , 'GET' , NULL , 1 , 'https://ccpos.garanti.com.tr/servlet/cc5ApiServer' , './payments/garanti.php' , 4 , NULL , 10 , 0 , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (26 , 'VXSBill.com' , NULL , 'Please specify values for the following parameters:\r\n\r\nusername - Your user name\r\npassword - Your password\r\nsite - Site ID, integer value\r\npackage - Package ID, integer value\r\nlogin - Your login\r\nregion_code - Region code, or 0 if is not known\r\n\r\nThey are sent to you by email after registering at vxsbill.com' , 'credit_card_info.php' , NULL , NULL , NULL , NULL , NULL , 'GET' , NULL , 1 , 'https://secure.vxsbill.com/create_transaction.php3' , './payments/vxsbill.php' , 4 , NULL , 10 , 0 , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (27 , 'ePDQ MPI' , NULL , 'Please specify values for parameters ''UserName'', ''Password'' and ''ClientId''.\r\nAs well you can change currency to some default value\r\n840 - US Dollar\r\n826 - British Pound' , 'credit_card_info.php' , NULL , NULL , NULL , NULL , NULL , 'GET' , NULL , 1 , 'https://secure2.epdq.co.uk:11500/' , './payments/epdq_mpi.php' , 4 , NULL , 10 , NULL , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (28 , 'ProxyPay' , NULL , 'Please specify the following parameters:\r\nmerchantID - your merchant ID' , 'https://eptest.eurocommerce.gr/proxypay/apacs' , NULL , NULL , NULL , NULL , NULL , 'POST' , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (29 , 'Posnet' , NULL , 'Please specify the following parameters:\r\nusername - your username\r\npassword - your password\r\nmid - your mid parameter\r\ntid - your tid parameter\r\n\r\nPosnet XML service lets posnet merchants send posnet transactions by sending XML documents. Merchants send XML documents to a URL like https://www.posnet.ykb.com/PosnetWebService/XML?xmldata=XML \r\n(for test environment: \r\nhttp://setmpos.ykb.com/PosnetWebService/XML?xmldata=XML). \r\nResponse is returned to the merchant also as an XML document.\r\n\r\nDon''t forget to enter your account details in appropriate fields: username, password, mid, tid.\r\n\r\nProduction URL:\r\nhttps://www.posnet.ykb.com/PosnetWebService/XML\r\n\r\ntesting URL:\r\nhttp://setmpos.ykb.com/PosnetWebService/XML\r\n\r\nSite for more information https://www.posnet.ykb.com' , 'credit_card_info.php' , NULL , NULL , NULL , NULL , NULL , 'GET' , NULL , 1 , 'http://setmpos.ykb.com/PosnetWebService/XML' , './payments/posnet.php' , 4 , 6 , 10 , NULL , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (30 , 'Akbank' , NULL , 'Please specify the following parameters:\r\nClientId - Shop Code sent you via e-mail\r\nName - Payment pages user id\r\nPassword - User password\r\nCurrency - Currency code' , 'credit_card_info.php' , NULL , NULL , NULL , NULL , NULL , 'GET' , NULL , 1 , 'https://vpos.est.com.tr/servlet/cc5ApiServer' , './payments/akbank.php' , 4 , 6 , 10 , 0 , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (31 , 'Netbilling' , NULL , 'Please specify this parameter:\r\naccount_id - set it to your account ID\r\n\r\nInsecure testing URL:\r\nhttp://secure.netbilling.com:1401/gw/sas/direct3.1\r\n\r\nSecure production URL:\r\nhttps://secure.netbilling.com:1402/gw/sas/direct3.1' , 'credit_card_info.php' , NULL , NULL , NULL , NULL , NULL , 'GET' , NULL , 1 , 'http://secure.netbilling.com:1401/gw/sas/direct3.1' , './payments/netbilling.php' , 4 , 6 , 10 , 0 , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (32 , 'Chronopay' , NULL , 'Please specify values for the following parameters:\r\n- product_id\r\n- product_name\r\n- cb_url = "{your_site_url}payments/chronopay_confirm.php"' , 'https://secure.chronopay.com/index_shop.cgi' , NULL , NULL , NULL , NULL , NULL , 'POST' , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (33 , 'Multipay' , NULL , 'Parameters description:\r\n\r\nmpSeller_ID - Fill in your Seller ID\r\nmpDescription - some description\r\nmpItems - some order info\r\nmpAdministration_ID - Free admin id for yourself\r\nmpVar1 - Free (session id or something else)\r\nmpVar2 - Free (session id or something else)\r\nmpAllow V = Visa\r\n              E = Mastercard\r\n              T = Teletik safepay\r\n              O = Overboeking\r\n              I = Incasso\r\n              C = Acceptgiro\r\n              R = Rabodirect\r\n              L = iDeal\r\nmpCountry - NL, US ..\r\nmpCurrency - NLG = Nederlandse Gulden\r\n                      USD = US Dollar\r\n                      GBP = United Kingdom Pound\r\n                      EUR = Euro' , 'https://multipay.net/transaction/mpmain.php' , NULL , NULL , NULL , NULL , NULL , 'POST' , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (34 , 'Google Checkout API' , NULL , 'Parameters description:\r\n\r\n''action_url'' must be\r\nFor testing purposes: https://sandbox.google.com/checkout/cws/v2/Merchant/[[Your-Merchant-ID]]/checkout\r\nFor production site: https://checkout.google.com/cws/v2/Merchant/[[Your-Merchant-ID]]/checkout\r\nProduction URL example: https://checkout.google.com/cws/v2/Merchant/1234567890/checkout\r\n\r\nFor full Integration you must go to ''Settings, Profile'' in your Google Checkout account\r\nTesting account\r\nhttps://sandbox.google.com/checkout/sell/settings?section=Profile\r\nor live one\r\nhttps://checkout.google.com/sell/settings?section=Profile\r\nand set in field ''Public business website'' your URL to order_final.php \r\nFor example: http://www.your_site.com/order_final.php.\r\n\r\nAlso you have to go to ''Settings, Integration'' and set in field ''API callback URL'' your URL to google_checkout.php\r\nFor example: http://www.your_site.com/payments/google_checkout.php\r\nand set ''Callback method'' to ''XML''.' , './payments/google_process.php' , NULL , NULL , NULL , NULL , NULL , 'GET' , NULL , 0 , NULL , NULL , 4 , 6 , 10 , NULL , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (35 , 'Akbank 3D secure' , NULL , 'Parameters description.\r\n\r\nPlease fill in filed ''Clientid'' by th Client ID issued for you by Akbank 3D secure system.' , 'credit_card_info.php' , NULL , NULL , NULL , NULL , NULL , 'GET' , NULL , 1 , 'https://vpos.est.com.tr/servlet/ThreeDGate' , './payments/akbank_3d.php' , 4 , 6 , 10 , NULL , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (36 , 'Protx VSP Server' , NULL , 'TxType - ''PAYMENT'', ''DEFERRED'' or ''PREAUTH''\r\nCurrency - ''GBP'', ''EUR'' and ''USD''\r\n\r\nAllowGiftAid:\r\n0 = No Gift Aid Box displayed (default)\r\n1 = Display Gift Aid Box on payment screen.\r\n\r\nApplyAVSCV2:\r\n0 = If AVC/CV2 enabled then check them. If rules apply, use rules. (default)\r\n1 = Force NO AVC/CV2 checks even if not enabled for the account. If rules apply, use rules.\r\n2 = Force NO AVC/CV2 checks even if enabled on account.\r\n3 = Force NO AVC/CV2 checks even if not enabled for the account but DON''T apply any rules.\r\n\r\nApply3DSecure:\r\n0 = If 3D-Secure checks are possible and rules allow, perform the checks and apply the authorisation rules. (default) \r\n1 = Force 3D-Secure checks for this transaction if possible and apply rules for authorisation.\r\n2 = Do not perform 3D-Secure checks for this transaction and always authorise.\r\n3 = Forse 3D-Secure checks for this transaction if possible but ALWAYS obtain an auth code, irrespective of rule base.' , 'credit_card_info.php' , NULL , NULL , NULL , NULL , NULL , 'GET' , 0 , 1 , 'https://ukvpstest.protx.com/VSPSimulator/VSPServerGateway.asp?Service=VendorRegisterTx' , './payments/protx_server_process.php' , 4 , 6 , 10 , 1 , 0 , 0 , 0 ) ;
INSERT INTO [va_payment_systems] ([payment_id],[payment_name],[payment_info],[payment_notes],[payment_url],[processing_time],[processing_fee],[fee_type],[fee_min_goods],[fee_max_goods],[submit_method],[recurring_method],[is_advanced],[advanced_url],[advanced_php_lib],[success_status_id],[pending_status_id],[failure_status_id],[failure_action],[is_active],[is_default],[is_call_center]) VALUES (37 , 'VCS' , NULL , 'p1 - VCS Terminal ID allocated by VCS.\r\np2 - Unique Transaction Reference Number with no spaces, generated by you. This reference number MUST ONLY BE USED ONCE. If for some reason you do not get a response, then re-try the transaction with the same reference number, our system will return the response that we got from the bank the first time the transaction was presented. We will not re-try the authorisation request if it has already been presented to the bank and we have received a response. We will merely return the response we already have. If you did get a response but it was declined and now you wish to try again then you must change the reference number. Refer p2 logic diagram.\r\np3 - Description of Goods.\r\np4 - Transaction Amount.\r\np5 - Currency, ZAR is the only valid currency.\r\np6 - Occur Count, 1  99 or U for an unlimited number of occurrences. Include only if transaction should re-occur.\r\np7 - Occur Frequency. Include only if transaction should re-occur. \r\nD Daily \r\nW Weekly \r\nM Monthly \r\nQ Quarterly (3-monthly) \r\n6 Bi-annually (6-monthly)  \r\nY Annually\r\np8 - Cell phone Number for SMS message. We can send a message to a cell phone on any network. Request registration from support@vcs.co.za. Include only if registered.\r\np9 -Message for SMS. This message will be sent to the above cell phone. We will add the response we get from the bank after this message. Include only if registered.\r\np10 - URL for Cancelled Transactions. If your customer gets to our credit card details entry page and then presses the cancel button we will return him to this URL. If this URL is omitted the customer will be returned to the previous page by default.\r\np11 - Occurrence E-mail Address. If you include an e-mail address VCS will send a transaction receipt to the cardholder after each occurrence. Include only if transaction should re-occur.\r\np12- Delayed Settlement. \r\nY Settlement delayed until manually released by merchant.\r\nN Settle today - automatic process. The default option.\r\np13 - Occur Amount, with a decimal point. If you do not include the decimal point we will assume one at the end of the amount, i.e. 10 is 10.00. If this amount is omitted then the actual amount will be used by default. Include only if the transaction should re-occur.\r\nBudget - Budget Allowed. \r\nY Budget is allowed. The default option.\r\nN Budget is not allowed.\r\nNextOccurDate - Next Occurrence Date. This is the date that the next occurrence of this transaction will be presented irrespective of what the occurrence frequency is. This date must be greater than the date that the transaction is presented. Format: ccyy/mm/dd Include only if transaction should re-occur.\r\npam - Personal Authentication Message, a security feature to confirm that the response is from VCS. The merchant enters the Merchant PAM in his Merchant Settings and VCS returns that PAM with the response.' , 'https://www.vcs.co.za/vvonline/ccform.asp' , NULL , NULL , NULL , NULL , NULL , 'POST' , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 ) ;


INSERT INTO [va_polls] ([poll_id],[poll_type],[question],[is_active],[date_added],[total_votes]) VALUES (1 , 1 , 'As gas prices continue to escalate, how close are you to purchasing an electric car or a gas/electric hybrid car?' , 1 , '2005-09-06 20:00:00' , 0 ) ;


INSERT INTO [va_polls_options] ([poll_option_id],[poll_id],[option_description],[is_default_value]) VALUES (1 , 1 , 'An electric or hybrid car will definitely be my next auto purchase. ' , 0 ) ;
INSERT INTO [va_polls_options] ([poll_option_id],[poll_id],[option_description],[is_default_value]) VALUES (2 , 1 , 'I will purchase one provided they are comparably priced to gasoline cars. ' , 0 ) ;
INSERT INTO [va_polls_options] ([poll_option_id],[poll_id],[option_description],[is_default_value]) VALUES (3 , 1 , 'I doubt this will be a viable technology for some time to come. ' , 0 ) ;
INSERT INTO [va_polls_options] ([poll_option_id],[poll_id],[option_description],[is_default_value]) VALUES (4 , 1 , 'I like the size, style and horsepower of gas-powered cars; I don''t intend to ever go electric.  ' , 0 ) ;
INSERT INTO [va_polls_options] ([poll_option_id],[poll_id],[option_description],[is_default_value]) VALUES (5 , 1 , 'I already own one of these cars. ' , 0 ) ;
INSERT INTO [va_polls_options] ([poll_option_id],[poll_id],[option_description],[is_default_value]) VALUES (6 , 1 , 'Not sure. ' , 0 ) ;










INSERT INTO [va_quotes_statuses] ([quote_status_id],[quote_status],[start_tag],[end_tag],[image_path],[notes]) VALUES (1 , 'New' , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_quotes_statuses] ([quote_status_id],[quote_status],[start_tag],[end_tag],[image_path],[notes]) VALUES (2 , 'Quoted' , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_quotes_statuses] ([quote_status_id],[quote_status],[start_tag],[end_tag],[image_path],[notes]) VALUES (3 , 'Paid' , NULL , NULL , NULL , NULL ) ;
INSERT INTO [va_quotes_statuses] ([quote_status_id],[quote_status],[start_tag],[end_tag],[image_path],[notes]) VALUES (4 , 'In progress' , NULL , NULL , NULL , NULL ) ;


INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (1 , 1 , 1 , '2003-05-23 00:00:00' , 'Fixed bug when FAQ articles has some redundant spaces in HTML \r\n' , 1 ) ;
INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (2 , 1 , 1 , '2003-05-23 00:00:00' , 'Fixed bug when News articles maintenance didn''t allow entering large title containing HTML tags' , 1 ) ;
INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (3 , 1 , 2 , '2003-01-10 00:00:00' , 'Added Postgre SQL and ODBC support ' , 1 ) ;
INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (4 , 1 , 2 , '2003-01-10 00:00:00' , 'Added search box to Sales Orders maintenance ' , 1 ) ;
INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (5 , 1 , 2 , '2003-01-10 00:00:00' , 'Added ''Page sources'' options for Web pages maintenance \r\n' , 1 ) ;
INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (6 , 1 , 2 , '2003-01-10 00:00:00' , 'Added ''Remember me'' option to Login page ' , 1 ) ;
INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (7 , 1 , 2 , '2003-01-10 00:00:00' , 'Added search box to ''Countries maintenance'' ' , 1 ) ;
INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (8 , 1 , 1 , '2003-01-10 00:00:00' , 'Fixed bug when countries listbox wasn''t sorted by ''Country Order'' ' , 1 ) ;
INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (9 , 1 , 1 , '2003-01-10 00:00:00' , 'Fixed typo in Web pages section of Administration \r\n' , 1 ) ;
INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (10 , 1 , 1 , '2003-01-10 00:00:00' , 'Fixed bug when two Administrators could not access Administration simultaneously ' , 1 ) ;
INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (11 , 1 , 1 , '2003-01-10 00:00:00' , 'Fixed bug when Final Checkout page sent two Administrator notifications instead of one \r\n' , 1 ) ;
INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (12 , 1 , 2 , '2003-01-23 00:00:00' , 'Added Forum system \r\n' , 1 ) ;
INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (13 , 1 , 2 , '2003-01-24 00:00:00' , 'Added Customizable Layouts support' , 1 ) ;
INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (14 , 1 , 2 , '2003-01-24 00:00:00' , 'Added ''Downloadable'' products support \r\n' , 1 ) ;
INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (15 , 1 , 2 , '2003-01-25 00:00:00' , 'Added ability to assign one product to multiple categories ' , 1 ) ;
INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (16 , 1 , 2 , '2003-01-25 00:00:00' , 'Added ability to reassign cases within Support System (only Enterprise Edition) ' , 1 ) ;
INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (17 , 1 , 2 , '2003-01-25 00:00:00' , 'Added customizable payment systems support ' , 1 ) ;
INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (18 , 1 , 2 , '2003-01-26 00:00:00' , 'Added ability to submit POST payment systems parameters ' , 1 ) ;
INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (19 , 1 , 2 , '2003-01-26 00:00:00' , 'Added option that allows hiding Reviews section at Product details page ' , 1 ) ;
INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (20 , 1 , 2 , '2003-01-27 00:00:00' , 'Added custom tags support to email notifications ' , 1 ) ;
INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (21 , 1 , 2 , '2003-01-27 00:00:00' , 'Added ''free shipping'' rules to Shipping settings ' , 1 ) ;
INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (22 , 1 , 1 , '2003-01-28 00:00:00' , 'Fixed bug when footer menu didn''t hide when there were no menu items ' , 1 ) ;
INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (23 , 1 , 1 , '2003-01-28 00:00:00' , 'Fixed bug when sorting order wasn''t preserved in ''Countries'' maintenance ' , 1 ) ;
INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (24 , 1 , 1 , '2003-01-28 00:00:00' , 'Fixed bug with complex date formats masks processing ' , 1 ) ;
INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (25 , 1 , 1 , '2003-01-28 00:00:00' , 'Fixed bug when product description had illegal characters ' , 1 ) ;
INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (26 , 1 , 1 , '2003-01-28 00:00:00' , 'Fixed bug when sending emails from some domains took more time then from others ' , 1 ) ;
INSERT INTO [va_release_changes] ([change_id],[release_id],[change_type_id],[change_date],[change_desc],[is_showing]) VALUES (27 , 1 , 1 , '2003-01-29 00:00:00' , 'Fixed bug when some phone numbers were not considered to be valid during user registration ' , 1 ) ;


INSERT INTO [va_release_types] ([type_id],[type_name]) VALUES (1 , 'Upgrade' ) ;
INSERT INTO [va_release_types] ([type_id],[type_name]) VALUES (2 , 'Update' ) ;
INSERT INTO [va_release_types] ([type_id],[type_name]) VALUES (3 , 'New Version' ) ;


INSERT INTO [va_releases] ([release_id],[item_id],[release_type_id],[release_date],[release_title],[version],[release_desc],[download_type],[path_to_file],[is_showing],[show_on_index]) VALUES (1 , 1 , 1 , '2003-12-24 00:00:00' , 'New Upgrade for C2S' , '2.0.1.11' , NULL , 1 , '/etc/c2s/c2s.tgz' , 0 , 0 ) ;










INSERT INTO [va_search_engines] ([engine_id],[engine_name],[keywords_parameter],[referer_regexp],[user_agent_regexp],[ip_regexp]) VALUES (1 , 'Google' , 'q' , '/http:\/\/www\.google\.\w{2,4}(\.\w{2})?\//i' , '/Googlebot.*google\.com/i' , NULL ) ;
INSERT INTO [va_search_engines] ([engine_id],[engine_name],[keywords_parameter],[referer_regexp],[user_agent_regexp],[ip_regexp]) VALUES (2 , 'Yahoo' , 'p' , '/search\.yahoo\.com\//i' , '/Yahoo.*Slurp.*yahoo\.com/i' , NULL ) ;
INSERT INTO [va_search_engines] ([engine_id],[engine_name],[keywords_parameter],[referer_regexp],[user_agent_regexp],[ip_regexp]) VALUES (3 , 'MSN' , 'q' , '/search(\.\w+)?\.msn\.\w{2,4}(\.\w{2})?\//i' , '/msnbot.*msn\.com/i' , NULL ) ;
INSERT INTO [va_search_engines] ([engine_id],[engine_name],[keywords_parameter],[referer_regexp],[user_agent_regexp],[ip_regexp]) VALUES (4 , 'Ask.com' , 'q' , '/\.ask\.com\//i' , '/Ask.*Jeeves\/Teoma.*ask\.com/i' , NULL ) ;
INSERT INTO [va_search_engines] ([engine_id],[engine_name],[keywords_parameter],[referer_regexp],[user_agent_regexp],[ip_regexp]) VALUES (5 , 'Gigablast' , 'q' , '/gigablast\.com\//i' , '/Gigabot.*gigablast\.com/i' , NULL ) ;
INSERT INTO [va_search_engines] ([engine_id],[engine_name],[keywords_parameter],[referer_regexp],[user_agent_regexp],[ip_regexp]) VALUES (6 , 'Exalead' , 'q' , '/exalead\.com\//i' , '/Exabot/i' , NULL ) ;
INSERT INTO [va_search_engines] ([engine_id],[engine_name],[keywords_parameter],[referer_regexp],[user_agent_regexp],[ip_regexp]) VALUES (7 , 'LookSmart' , 'qt' , '/looksmart\.(com|net)\//i' , '/ZyBorg.*looksmart.*WISEnutbot\.com/i' , NULL ) ;
INSERT INTO [va_search_engines] ([engine_id],[engine_name],[keywords_parameter],[referer_regexp],[user_agent_regexp],[ip_regexp]) VALUES (8 , 'Zibb' , 'q' , '/zibb\.com\//i' , '/Zibber.*zibb\.com/i' , NULL ) ;
INSERT INTO [va_search_engines] ([engine_id],[engine_name],[keywords_parameter],[referer_regexp],[user_agent_regexp],[ip_regexp]) VALUES (9 , 'Entireweb' , 'q' , '/entireweb\.com\//i' , '/Speedy.*Spider.*entireweb\.com/i' , NULL ) ;
INSERT INTO [va_search_engines] ([engine_id],[engine_name],[keywords_parameter],[referer_regexp],[user_agent_regexp],[ip_regexp]) VALUES (10 , 'Seekport' , 'query' , '/seekport\.\w{2,4}(\.\w{2})?\//i' , '/Seekbot.*Seekbot\.net/i' , NULL ) ;
INSERT INTO [va_search_engines] ([engine_id],[engine_name],[keywords_parameter],[referer_regexp],[user_agent_regexp],[ip_regexp]) VALUES (11 , 'Become' , 'q' , '/become.com\//i' , '/BecomeBot.*become\.com/i' , NULL ) ;


INSERT INTO [va_shipping_modules] ([shipping_module_id],[shipping_module_name],[module_notes],[is_external],[php_external_lib],[external_url],[tracking_url],[is_active]) VALUES (1 , 'Custom Shipping' , NULL , 0 , NULL , NULL , NULL , 1 ) ;
INSERT INTO [va_shipping_modules] ([shipping_module_id],[shipping_module_name],[module_notes],[is_external],[php_external_lib],[external_url],[tracking_url],[is_active]) VALUES (2 , 'UPS' , 'United Parcel Service (UPS)\r\n\r\nObtain UserID, Password and Developer''s Key from your country''s UPS E-Business web site. (See the\r\n''Security Elements'' section in the Product Overview chapter.)\r\n\r\nObtain Access Key. (See ''Security Elements'' in the Product Overview section.)\r\n\r\nFor Signature Tracking and Shipping, follow the product certification process identified in the Customer\r\nIntegration Environment section.\r\n\r\nFill in the parameters list below and set UPS system as active and begin receive you online shipping rates.\r\n\r\nShipperPostalCode - The shipper''s postal code. Required if country utilizes postal codes (i.e. US & PR)\r\n\r\nShipperCountryCode - The UPS billing code for the shipper''s country. See Origin Country Information\r\n table. Default = US.\r\n\r\nShipFromPostalCode - The sender''s postal code. Required if Ship To country code is US. Must supply\r\n either the sender''s city or postal code.\r\n\r\nShipFromCountryCode - The UPS billing code representing the sender''s country. See Appendix C for\r\n UPS Country Code table. Default = US.\r\n\r\nPackageWeightUnitOfMeasurement - The code representing the unit of measure associated with the \r\n package weight. LBS = Pounds (default) KGS = Kilograms\r\n\r\nPickupType:\r\n 01 - Daily Pickup\r\n 03 - Customer Counter\r\n 06 - One Time Pickup\r\n 07 - On Call Air Pickup\r\n 11 - Suggested Retail Rates (UPS Store)\r\n 19 - Letter Center\r\n 20 - Air Service Center\r\n\r\nPackagingType:\r\n 01 - UPS letter/ UPS Express Envelope\r\n 02 - Package\r\n 03 - UPS Tube\r\n 04 - UPS Pak\r\n 21 - UPS Express Box\r\n 24 - UPS 25Kg Box\r\n 25 - UPS 10Kg Box\r\n\r\nFor PackagingType 02 or 21 you must fill PackagingTypeUnitOfMeasurement, PackageLength,\r\n PackageWidth and PackageHeight. \r\n\r\nPackagingTypeUnitOfMeasurement - The code for the unit of measure associated with the package\r\n dimensions. IN = Inches (default)\r\n\r\nPackageLength - The length of the package used to determine dimensional weight. Valid values are\r\n between 1 and 108.00.\r\n\r\nPackageWidth - The width of the package used to determine dimensional weight. Valid values are\r\n between 1 and 108.00.\r\n\r\nPackageHeight - The height of the package used to determine dimensional weight. Valid values are\r\n between 1and 108.00.\r\n\r\nYou may visit your country''s UPS E-Business web site for more information about UPS Rates & Service Selection Tool. http://www.ups.com' , 1 , './shipping/ups.php' , 'https://www.ups.com/ups.app/xml/Rate' , 'http://wwwapps.ups.com/WebTracking/processInputRequest?HTMLVersion=5.0&error_carried=true&tracknums_displayed=1&TypeOfInquiryNumber=T&loc=en_US&AgreeToTermsAndConditions=yes&InquiryNumber1=' , 0 ) ;
INSERT INTO [va_shipping_modules] ([shipping_module_id],[shipping_module_name],[module_notes],[is_external],[php_external_lib],[external_url],[tracking_url],[is_active]) VALUES (3 , 'USPS V3' , 'United States Postal Service (USPS).\r\n\r\nTo use the USPS Web Tools you must be a registered user. Completing the registration process resulted in the receipt of your user ID, password, and test server URL. This test URL is already filled in.\r\n\r\nTo gain access to Live server, all users, including those registered for previous Web Tools use, must contact the Internet Customer Care Center (ICCC) for the URL to make Live calls. The ICCC will send the Live URL via e-mail. Fill live url in the field  External URL instead of present one.\r\n\r\nThis office is manned from 7:00 AM to 11:00 PM EST daily. \r\nE-mail address: icustomercare@usps.com \r\nTelephone: 1-800-344-7779 (7:00 AM to 11:00 PM EST daily)\r\n\r\nExternal URL:\r\nProduction - http://production.shippingapis.com/ShippingAPI.dll\r\nTesting - http://testing.shippingapis.com/ShippingAPITest.dll\r\n\r\nCommon parameters:\r\n  USERID - required, use user ID provided with registration.\r\n  PASSWORD - is not required now, use password provided with registration if any.\r\n\r\nDomestic parameters:\r\n  ZipOrigination - required. Your ZIP code where dispath will be made from. ZIP code must be valid. Maximum characters allowed: 5.\r\n  Container - required, is only applicable for Express Mail and Priority Mail. Must contain one of the following valid packaging type names: "Flat Rate Envelope", "Flat Rate Box", "RECTANGULAR", "NONRECTANGULAR"\r\n  Size - required, must be one of the following: "Regular", "Large", "Oversize".\r\n  Machinable - optional. Applies only to Parcel Post. For Parcel Post, the value entered must be either "True" or "False".\r\n\r\nInternational parameters:\r\n  MailType - required, the following are valid international mail types: "package", "postcards or aerogrammes", "matter for the blind", "envelope".\r\n\r\nDimensions:\r\nTo capture the dimensional weight for Large Priority Mail pieces, RateV3 will require three new dimension tags for rectangular Priority Mail pieces: Length, Width, and Height; \r\nand four new dimension tags for non-rectangular pieces: Length, Width, Height, and Girth. \r\nShippers will specify in the existing Container tag whether a Large Priority Mail piece is rectangular or non-rectangular.\r\n\r\nTesting:\r\nPlease note that for test purposes USPS permits only particular parameters'' values to be used for the query. So in the Test mode it expects to receive the following information about the package for domestic shipping:\r\n \r\nZipOrigination: 10022\r\nZipDestination: 20008 (is set during Checkout process by user)\r\nPounds: 10\r\nOunces: 5 (weight can be set for every product on  Administration > Products)\r\nSize: LARGE\r\nMachinable: TRUE\r\n\r\nTo test international shipping use the following values:\r\n\r\nPounds: 2\r\nOunces: 0\r\nMailType: Package\r\nCountry: Albania\r\n\r\nor\r\n\r\nPounds: 0\r\nOunces: 1\r\nMailType: Postcards or Aerogrammes\r\nCountry: Algeria\r\n\r\nAll other parameters'' values won''t work in the test environment.' , 1 , './shipping/usps_v3.php' , 'http://production.shippingapis.com/ShippingAPI.dll' , 'http://trkcnfrm1.smi.usps.com/PTSInternetWeb/InterLabelInquiry.do?formattedLabel=' , 0 ) ;
INSERT INTO [va_shipping_modules] ([shipping_module_id],[shipping_module_name],[module_notes],[is_external],[php_external_lib],[external_url],[tracking_url],[is_active]) VALUES (4 , 'FedEx' , 'The FedEx sign-up process requires some interaction with the company. FedEx requires that developers and their applications be certified. The first step is to register for a FedEx Ship Manager Direct account by visiting https://www.fedex.com/cgi-bin/shipapiDownload.cgi?link=4&first=y and completing the form. In addition to the standard contact information, you must indicate how you intend to use their online tools. If you''re developing e-commerce solutions for multiple clients, choose the Consultant option, otherwise select Corporate Developer. Select the communication path used - FSM Direct. Finally, you''ll need to select the Data Format desired - XML Tools. After you''ve registered, you''ll be given an address to a shipping server to be used in your testing phases, please apply it to ''External URL'' field below.\r\n\r\nYou''ll need to next contact FedEx by e-mail (websupport@fedex.com) to request to have you or your client''s account set up in a test environment. You''ll need to specify whether you''re using the Express, Ground, or both services. As well you can include source code from the shipping folder to contact the FedEx Direct. Although the company''s documentation indicates a 24 hour turn-around for approval, representatives indicate the wait can go up to 72 hours.\r\n\r\nAfter you''ve been approved, the next task is to subscribe to FedEx to get a meter number. Meter numbers are programmatically generated. Before sending subscription request please change the parameters below. \r\nAccountNumber - you FedEx account number.\r\nPersonName, CompanyName, Department, PhoneNumber, PagerNumber, FaxNumber, EmailAddress - your contact information\r\nLine1, Line2, City, StateOrProvinceCode, PostalCode, CountryCode - your address information\r\nWhen all the data are ready you can go to the page at http://your_site_url/shipping/fedex_subscription.php and send subscription request.\r\nAfter successfully running the FedEx subscription request a meter number will be returned, add this value to the MeterNumber field below.\r\n\r\nPlease update the rest of fields below.\r\nStateOrProvinceCode - Represents the state or province from which the shipment will be originating. (Required only if Sender Country Code is US or CA)\r\nPostalCode - Represents the postal code from which the shipment will be originating. (Required only if Sender Country Code is US or CA. May be required for other postal-aware countries when rating an internationally shipment.)\r\nCountryCode - Represents the country from which the shipment will be originating. (Required)\r\nReturnShipmentIndicator - NONRETURN, PRINTRETURNLABEL, EMAILLABEL\r\nDropoffType - REGULARPICKUP, REQUESTCOURIER, DROPBOX, BUSINESSSERVICECENTER, STATION\r\nPackaging - FEDEXENVELOPE, FEDEXPAK, FEDEXBOX, FEDEXTUBE, FEDEX10KGBOX, FEDEX25KGBOX, YOURPACKAGING\r\nFor YOURPACKAGING you also need specify package sizes: Length, Width, Height, Units (IN, CM)\r\nWeightUnits - LBS, KGS\r\nSet FedEx system as active and receive you online shipping rates.\r\n\r\nAfter your application testing is done, contact FedEx again by e-mail (websupport@fedex.com) or phone (800.810.9073) to initiate the certification process. For retrieving rates, you''ll be asked to state exactly how you will be using their API; you can also request to be moved to the production environment in a specific timeframe. Once certified, FedEx will provide you with a FedEx server address to be used when you re-subscribe to receive your production meter number.' , 1 , './shipping/fedex.php' , 'https://sslserver.fedex.com:443/GatewayDC' , 'http://www.fedex.com/Tracking?ascend_header=1&clienttype=dotcom&cntry_code=us&language=english&tracknumbers=' , 0 ) ;


INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (8 , 2 , 'user_id' , '!Enter your USERID here!' , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (9 , 2 , 'password' , '!Enter your PASSWORD here!' , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (10 , 2 , 'access_license_number' , '!Enter your Access License Number here!' , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (11 , 2 , 'ShipperPostalCode' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (12 , 2 , 'ShipperCountryCode' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (13 , 2 , 'ShipFromPostalCode' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (14 , 2 , 'ShipFromCountryCode' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (15 , 2 , 'PickupType' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (16 , 2 , 'PackagingType' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (21 , 2 , 'PackageWeightUnitOfMeasurement' , 'LBS' , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (22 , 4 , 'CustomerTransactionIdentifier' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (23 , 4 , 'AccountNumber' , '!Type here your account number!' , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (24 , 4 , 'MeterNumber' , '!Type here your subscription number!' , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (25 , 4 , 'CarrierCode' , 'FDXE' , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (26 , 4 , 'PersonName' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (27 , 4 , 'CompanyName' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (28 , 4 , 'Department' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (29 , 4 , 'PhoneNumber' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (30 , 4 , 'PagerNumber' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (31 , 4 , 'FaxNumber' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (32 , 4 , 'EMailAddress' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (33 , 4 , 'Line1' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (34 , 4 , 'Line2' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (35 , 4 , 'City' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (36 , 4 , 'StateOrProvinceCode' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (37 , 4 , 'PostalCode' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (38 , 4 , 'CountryCode' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (40 , 4 , 'ReturnShipmentIndicator' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (41 , 4 , 'DropoffType' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (42 , 4 , 'Packaging' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (43 , 4 , 'WeightUnits' , 'LBS' , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (44 , 4 , 'PayorType' , 'SENDER' , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (45 , 4 , 'Length' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (46 , 4 , 'Width' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (47 , 4 , 'Height' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (48 , 4 , 'Units' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (49 , 4 , 'PackageCount' , '1' , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (50 , 2 , 'PackagingTypeUnitOfMeasurement' , 'IN' , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (51 , 2 , 'PackageLength' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (52 , 2 , 'PackageWidth' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (53 , 2 , 'PackageHeight' , NULL , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (54 , 3 , 'USERID' , '!Enter your USERID here!' , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (55 , 3 , 'PASSWORD' , '!Enter your PASSWORD here!' , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (56 , 3 , 'ZipOrigination' , '!Enter your ZipOrigination here!' , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (57 , 3 , 'Container' , 'Flat Rate Box' , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (58 , 3 , 'Size' , 'Regular' , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (59 , 3 , 'Machinable' , 'true' , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (60 , 3 , 'MailType' , 'Package' , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (61 , 3 , 'Width' , '15' , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (62 , 3 , 'Length' , '30' , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (63 , 3 , 'Height' , '15' , 0 ) ;
INSERT INTO [va_shipping_modules_parameters] ([parameter_id],[shipping_module_id],[parameter_name],[parameter_source],[not_passed]) VALUES (64 , 3 , 'Girth' , NULL , 0 ) ;


INSERT INTO [va_shipping_rules] ([shipping_rule_id],[shipping_rule_desc],[is_country_restriction]) VALUES (1 , 'Can ship anywhere' , NULL ) ;
INSERT INTO [va_shipping_rules] ([shipping_rule_id],[shipping_rule_desc],[is_country_restriction]) VALUES (2 , 'Can ship only within USA' , 1 ) ;
INSERT INTO [va_shipping_rules] ([shipping_rule_id],[shipping_rule_desc],[is_country_restriction]) VALUES (3 , 'Can ship only within United Kingdom' , 1 ) ;


INSERT INTO [va_shipping_rules_countries] ([shipping_rule_id],[country_code]) VALUES (2 , 'US' ) ;
INSERT INTO [va_shipping_rules_countries] ([shipping_rule_id],[country_code]) VALUES (3 , 'GB' ) ;


INSERT INTO [va_shipping_times] ([shipping_time_id],[shipping_time_desc],[availability_time]) VALUES (1 , 'Usually ships in 2 to 3 days' , NULL ) ;
INSERT INTO [va_shipping_times] ([shipping_time_id],[shipping_time_desc],[availability_time]) VALUES (2 , 'Usually ships in 24 hours' , NULL ) ;


INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (12 , 4 , 1 , 'PRIORITYOVERNIGHT' , 'FedEx Priority Overnight' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (13 , 4 , 1 , 'STANDARDOVERNIGHT' , 'FedEx Standard Overnight' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (14 , 4 , 1 , 'FIRSTOVERNIGHT' , 'FedEx First Overnight' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (15 , 4 , 1 , 'FEDEX2DAY' , 'FedEx 2Day' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (16 , 4 , 1 , 'FEDEXEXPRESSSAVER' , 'FedEx Express Saver' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (17 , 4 , 1 , 'FEDEX1DAYFREIGHT' , 'FedEx 1Day Freight' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (18 , 4 , 1 , 'FEDEX2DAYFREIGHT' , 'FedEx 2Day Freight' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (19 , 4 , 1 , 'FEDEX3DAYFREIGHT' , 'FedEx 3Day Freight' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (20 , 4 , 1 , 'FEDEXGROUND' , 'FedEx Ground' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (21 , 4 , 1 , 'GROUNDHOMEDELIVERY' , 'FedEx Home Delivery' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (22 , 4 , 1 , 'INTERNATIONALPRIORITY' , 'FedEx International Priority' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (23 , 4 , 1 , 'INTERNATIONALECONOMY' , 'FedEx International Economy' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (24 , 4 , 1 , 'INTERNATIONALFIRST' , 'FedEx International First' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (25 , 4 , 1 , 'INTERNATIONALPRIORITYFREIGHT' , 'FedEx International Priority Freight' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (26 , 4 , 1 , 'INTERNATIONALECONOMYFREIGHT' , 'FedEx International Economy Freight' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (27 , 4 , 1 , 'EUROPEFIRSTINTERNATIONALPRIORITY' , 'FedEx Europe First' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (28 , 2 , 1 , '01' , 'UPS Next Day Air' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (29 , 2 , 1 , '02' , 'UPS 2nd Day Air' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (30 , 2 , 1 , '03' , 'UPS Ground' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (31 , 2 , 1 , '07' , 'UPS Worldwide ExpressSM' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (32 , 2 , 1 , '08' , 'UPS Worldwide ExpeditedSM' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (33 , 2 , 1 , '11' , 'UPS Standard' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (34 , 2 , 1 , '12' , 'UPS 3 Day Select' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (35 , 2 , 1 , '13' , 'UPS Next Day Air Saver' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (36 , 2 , 1 , '14' , 'UPS Next Day Air Early A.M.' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (37 , 2 , 1 , '54' , 'UPS Worldwide Express PlusSM' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (38 , 2 , 1 , '01' , 'UPS Express' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (39 , 2 , 1 , '02' , 'UPS Expedited' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (40 , 2 , 1 , '13' , 'UPS Express Saver' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (41 , 2 , 1 , '14' , 'UPS Express Early A.M.' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (42 , 2 , 1 , '07' , 'UPS Express' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (43 , 2 , 1 , '65' , 'UPS Express Saver' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (44 , 2 , 1 , '59' , 'UPS 2nd Day Air A.M.' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (45 , 2 , 1 , '08' , 'UPS Expedited' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (46 , 2 , 1 , '54' , 'UPS Express Plus' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (47 , 3 , 1 , 'Express Mail' , 'USPS Express Mail' , NULL , NULL , 0 , 10000 , 0 , 70 , NULL , NULL , NULL , 1 , 0 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (48 , 3 , 1 , 'Express Mail PO to PO' , 'USPS Express Mail PO to PO' , NULL , NULL , 0 , 10000 , 0 , 70 , NULL , NULL , NULL , 1 , 0 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (49 , 3 , 1 , 'Express Mail Flat-Rate Envelope' , 'USPS Express Mail Flat-Rate Envelope' , NULL , NULL , 0 , 10000 , 0 , 70 , NULL , NULL , NULL , 1 , 0 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (50 , 3 , 1 , 'Priority Mail' , 'USPS Priority Mail' , NULL , NULL , 0 , 10000 , 0 , 70 , NULL , NULL , NULL , 1 , 0 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (51 , 3 , 1 , 'Priority Mail Flat-Rate Envelope' , 'USPS Priority Mail Flat-Rate Envelope' , NULL , NULL , 0 , 10000 , 0 , 70 , NULL , NULL , NULL , 1 , 0 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (52 , 3 , 1 , 'Priority Mail Flat-Rate Box' , 'USPS Priority Mail Flat-Rate Box' , NULL , NULL , 0 , 10000 , 0 , 70 , NULL , NULL , NULL , 1 , 0 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (53 , 3 , 1 , 'First-Class Mail' , 'USPS First-Class Mail' , NULL , NULL , 0 , 10000 , 0 , 0.1875 , NULL , NULL , NULL , 1 , 0 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (54 , 3 , 1 , 'First-Class Mail Flat' , 'USPS First-Class Mail Flat' , NULL , NULL , 0 , 10000 , 0 , 0.8125 , NULL , NULL , NULL , 1 , 0 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (55 , 3 , 1 , 'First-Class Mail Parcel' , 'USPS First-Class Mail Parcel' , NULL , NULL , 0 , 10000 , 0 , 0.8125 , NULL , NULL , NULL , 1 , 0 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (56 , 3 , 1 , 'Media Mail' , 'USPS Media Mail' , NULL , NULL , 0 , 10000 , 0 , 70 , NULL , NULL , NULL , 1 , 0 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (57 , 3 , 1 , 'Library Mail' , 'USPS Library Mail' , NULL , NULL , 0 , 10000 , 0 , 70 , NULL , NULL , NULL , 1 , 0 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (58 , 3 , 1 , 'Parcel Post' , 'USPS Parcel Post' , NULL , NULL , 0 , 10000 , 0 , 70 , NULL , NULL , NULL , 1 , 0 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (59 , 3 , 1 , 'Bound Printed Matter' , 'USPS Bound Printed Matter' , NULL , NULL , 0 , 10000 , 0 , 15 , NULL , NULL , NULL , 1 , 0 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (60 , 3 , 1 , 'Global Express Guaranteed' , 'USPS Global Express Guaranteed' , NULL , NULL , 0 , 10000 , 0 , 70 , NULL , NULL , NULL , 1 , 0 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (61 , 3 , 1 , 'Global Express Guaranteed Non-Document Rectangular' , 'USPS Global Express Guaranteed Non-Document Rectangular' , NULL , NULL , 0 , 10000 , 0 , 70 , NULL , NULL , NULL , 1 , 0 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (62 , 3 , 1 , 'Global Express Guaranteed Non-Document Non-Rectangular' , 'USPS Global Express Guaranteed Non-Document Non-Rectangular' , NULL , NULL , 0 , 10000 , 0 , 70 , NULL , NULL , NULL , 1 , 0 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (63 , 3 , 1 , 'Priority Mail International' , 'USPS Priority Mail International' , NULL , NULL , 0 , 10000 , 0 , 44 , NULL , NULL , NULL , 1 , 0 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (64 , 3 , 1 , 'Priority Mail International Flat Rate Envelope' , 'USPS Priority Mail International Flat Rate Envelope' , NULL , NULL , 0 , 10000 , 0 , 4 , NULL , NULL , NULL , 1 , 0 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (65 , 3 , 1 , 'Priority Mail International Flat Rate Box' , 'USPS Priority Mail International Flat Rate Box' , NULL , NULL , 0 , 10000 , 0 , 20 , NULL , NULL , NULL , 1 , 0 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (66 , 3 , 1 , 'First-Class Mail International' , 'USPS First-Class Mail International' , NULL , NULL , 0 , 10000 , 0 , 64 , NULL , NULL , NULL , 1 , 0 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (67 , 3 , 1 , 'Express Mail International (EMS)' , 'USPS Express Mail International (EMS)' , NULL , NULL , 0 , 10000 , 0 , 66 , NULL , NULL , NULL , 1 , 0 ) ;
INSERT INTO [va_shipping_types] ([shipping_type_id],[shipping_module_id],[shipping_order],[shipping_type_code],[shipping_type_desc],[shipping_time],[tare_weight],[min_goods_cost],[max_goods_cost],[min_weight],[max_weight],[cost_per_order],[cost_per_product],[cost_per_weight],[is_taxable],[is_active]) VALUES (68 , 3 , 1 , 'Express Mail International (EMS) Flat Rate Envelope' , 'USPS Express Mail International (EMS) Flat Rate Envelope' , NULL , NULL , 0 , 10000 , 0 , 66 , NULL , NULL , NULL , 1 , 0 ) ;


INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'AD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'AD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'AD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'AD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'AD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'AD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'AD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'AD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'AD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'AD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'AD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'AD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'AD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'AD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'AD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'AD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'AE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'AE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'AE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'AE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'AE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'AE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'AE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'AE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'AE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'AE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'AE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'AE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'AE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'AE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'AE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'AE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'AF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'AF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'AF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'AF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'AF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'AF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'AF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'AF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'AF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'AF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'AF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'AF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'AF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'AF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'AF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'AF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'AG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'AG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'AG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'AG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'AG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'AG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'AG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'AG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'AG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'AG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'AG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'AG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'AG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'AG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'AG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'AG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'AI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'AI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'AI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'AI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'AI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'AI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'AI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'AI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'AI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'AI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'AI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'AI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'AI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'AI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'AI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'AI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'AL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'AL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'AL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'AL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'AL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'AL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'AL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'AL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'AL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'AL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'AL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'AL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'AL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'AL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'AL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'AL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'AM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'AM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'AM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'AM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'AM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'AM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'AM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'AM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'AM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'AM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'AM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'AM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'AM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'AM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'AM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'AM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'AN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'AN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'AN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'AN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'AN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'AN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'AN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'AN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'AN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'AN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'AN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'AN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'AN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'AN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'AN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'AN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'AN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'AO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'AO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'AO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'AO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'AO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'AO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'AO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'AO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'AO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'AO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'AO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'AO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'AO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'AO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'AO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'AO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'AQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'AQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'AQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'AQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'AQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'AQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'AQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'AQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'AQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'AQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'AQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'AQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'AQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'AQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'AQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'AQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'AR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'AR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'AR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'AR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'AR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'AR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'AR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'AR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'AR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'AR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'AR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'AR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'AR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'AR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'AR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'AR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'AS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'AS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'AS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'AS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'AS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'AS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'AS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'AS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'AS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'AS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'AS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'AS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'AS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'AS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'AS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'AS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'AT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'AT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'AT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'AT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (27 , 'AT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'AT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'AT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'AT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (43 , 'AT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'AT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'AT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'AT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'AT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'AT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'AT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'AT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'AT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'AT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'AU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'AU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'AU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'AU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'AU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'AU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'AU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'AU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'AU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'AU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'AU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'AU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'AU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'AU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'AU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'AU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'AW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'AW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'AW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'AW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'AW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'AW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'AW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'AW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'AW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'AW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'AW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'AW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'AW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'AW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'AW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'AW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'AZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'AZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'AZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'AZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'AZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'AZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'AZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'AZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'AZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'AZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'AZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'AZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'AZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'AZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'AZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'AZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'BA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'BA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'BA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'BA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'BA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'BA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'BA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'BA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'BA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'BA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'BA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'BA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'BA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'BA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'BA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'BA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'BB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'BB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'BB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'BB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'BB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'BB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'BB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'BB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'BB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'BB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'BB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'BB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'BB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'BB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'BB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'BB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'BD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'BD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'BD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'BD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'BD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'BD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'BD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'BD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'BD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'BD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'BD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'BD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'BD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'BD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'BD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'BD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'BE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'BE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'BE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'BE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (24 , 'BE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (27 , 'BE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'BE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'BE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'BE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (43 , 'BE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'BE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'BE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'BE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'BE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'BE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'BE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'BE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'BE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'BE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'BF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'BF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'BF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'BF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'BF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'BF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'BF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'BF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'BF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'BF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'BF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'BF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'BF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'BF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'BF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'BF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'BG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'BG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'BG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'BG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'BG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'BG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'BG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'BG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'BG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'BG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'BG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'BG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'BG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'BG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'BG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'BG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'BH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'BH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'BH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'BH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'BH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'BH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'BH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'BH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'BH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'BH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'BH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'BH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'BH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'BH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'BH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'BH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'BI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'BI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'BI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'BI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'BI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'BI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'BI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'BI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'BI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'BI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'BI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'BI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'BI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'BI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'BI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'BI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'BJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'BJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'BJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'BJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'BJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'BJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'BJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'BJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'BJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'BJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'BJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'BJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'BJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'BJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'BJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'BJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'BM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'BM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'BM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'BM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'BM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'BM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'BM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'BM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'BM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'BM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'BM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'BM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'BM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'BM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'BM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'BM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'BN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'BN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'BN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'BN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'BN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'BN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'BN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'BN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'BN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'BN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'BN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'BN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'BN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'BN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'BN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'BN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'BO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'BO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'BO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'BO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'BO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'BO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'BO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'BO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'BO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'BO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'BO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'BO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'BO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'BO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'BO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'BO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'BR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'BR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'BR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'BR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'BR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'BR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'BR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'BR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'BR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'BR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'BR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'BR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'BR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'BR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'BR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'BR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'BS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'BS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'BS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'BS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'BS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'BS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'BS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'BS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'BS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'BS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'BS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'BS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'BS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'BS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'BS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'BS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'BT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'BT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'BT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'BT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'BT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'BT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'BT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'BT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'BT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'BT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'BT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'BT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'BT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'BT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'BT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'BT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'BV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'BV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'BV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'BV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'BV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'BV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'BV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'BV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'BV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'BV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'BV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'BV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'BV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'BV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'BV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'BV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'BW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'BW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'BW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'BW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'BW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'BW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'BW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'BW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'BW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'BW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'BW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'BW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'BW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'BW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'BW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'BW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'BY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'BY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'BY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'BY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'BY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'BY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'BY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'BY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'BY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'BY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'BY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'BY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'BY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'BY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'BY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'BY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'BZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'BZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'BZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'BZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'BZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'BZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'BZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'BZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'BZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'BZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'BZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'BZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'BZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'BZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'BZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'BZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'CA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'CA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'CA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'CA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'CA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'CA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (34 , 'CA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'CA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'CA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (38 , 'CA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (39 , 'CA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (40 , 'CA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (41 , 'CA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'CA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'CA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'CA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'CA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'CA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'CA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'CA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'CA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'CA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'CC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'CC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'CC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'CC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'CC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'CC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'CC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'CC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'CC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'CC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'CC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'CC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'CC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'CC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'CC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'CC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'CF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'CF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'CF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'CF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'CF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'CF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'CF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'CF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'CF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'CF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'CF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'CF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'CF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'CF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'CF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'CF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'CG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'CG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'CG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'CG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'CG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'CG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'CG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'CG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'CG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'CG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'CG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'CG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'CG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'CG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'CG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'CG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'CH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'CH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'CH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'CH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'CH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (24 , 'CH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (27 , 'CH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'CH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'CH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'CH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (43 , 'CH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'CH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'CH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'CH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'CH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'CH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'CH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'CH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'CH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'CI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'CI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'CI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'CI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'CI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'CI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'CI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'CI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'CI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'CI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'CI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'CI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'CI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'CI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'CI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'CI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'CK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'CK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'CK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'CK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'CK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'CK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'CK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'CK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'CK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'CK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'CK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'CK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'CK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'CK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'CK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'CK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'CL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'CL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'CL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'CL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'CL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'CL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'CL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'CL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'CL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'CL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'CL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'CL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'CL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'CL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'CL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'CL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'CM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'CM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'CM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'CM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'CM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'CM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'CM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'CM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'CM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'CM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'CM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'CM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'CM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'CM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'CM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'CM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'CN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'CN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'CN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'CN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'CN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'CN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'CN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'CN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'CN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'CN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'CN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'CN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'CN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'CN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'CN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'CN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'CO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'CO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'CO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'CO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'CO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'CO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'CO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'CO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'CO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'CO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'CO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'CO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'CO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'CO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'CO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'CO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'CR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'CR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'CR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'CR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'CR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'CR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'CR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'CR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'CR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'CR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'CR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'CR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'CR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'CR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'CR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'CR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'CU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'CU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'CU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'CU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'CU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'CU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'CU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'CU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'CU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'CU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'CU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'CU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'CU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'CU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'CU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'CU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'CV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'CV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'CV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'CV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'CV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'CV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'CV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'CV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'CV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'CV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'CV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'CV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'CV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'CV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'CV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'CV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'CX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'CX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'CX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'CX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'CX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'CX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'CX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'CX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'CX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'CX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'CX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'CX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'CX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'CX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'CX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'CX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'CY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'CY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'CY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'CY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'CY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'CY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'CY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'CY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'CY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'CY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'CY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'CY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'CY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'CY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'CY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'CY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'CZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'CZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'CZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'CZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'CZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'CZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'CZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (43 , 'CZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'CZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'CZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'CZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'CZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'CZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'CZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'CZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'CZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'CZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'DE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'DE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'DE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'DE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (24 , 'DE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (27 , 'DE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'DE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'DE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'DE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (43 , 'DE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'DE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'DE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'DE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'DE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'DE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'DE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'DE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'DE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'DE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'DJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'DJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'DJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'DJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'DJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'DJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'DJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'DJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'DJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'DJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'DJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'DJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'DJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'DJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'DJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'DJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'DK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'DK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'DK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'DK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (27 , 'DK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'DK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'DK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'DK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (43 , 'DK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'DK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'DK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'DK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'DK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'DK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'DK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'DK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'DK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'DK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'DM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'DM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'DM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'DM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'DM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'DM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'DM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'DM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'DM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'DM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'DM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'DM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'DM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'DM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'DM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'DM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'DO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'DO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'DO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'DO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'DO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'DO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'DO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'DO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'DO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'DO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'DO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'DO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'DO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'DO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'DO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'DO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'DZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'DZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'DZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'DZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'DZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'DZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'DZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'DZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'DZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'DZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'DZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'DZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'DZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'DZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'DZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'DZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'EC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'EC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'EC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'EC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'EC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'EC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'EC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'EC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'EC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'EC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'EC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'EC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'EC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'EC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'EC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'EC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'EE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'EE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'EE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'EE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'EE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'EE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'EE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (43 , 'EE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'EE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'EE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'EE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'EE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'EE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'EE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'EE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'EE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'EE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'EG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'EG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'EG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'EG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'EG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'EG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'EG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'EG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'EG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'EG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'EG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'EG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'EG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'EG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'EG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'EG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'EH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'EH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'EH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'EH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'EH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'EH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'EH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'EH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'EH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'EH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'EH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'EH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'EH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'EH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'EH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'EH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'ER' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'ER' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'ER' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'ER' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'ER' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'ER' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'ER' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'ER' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'ER' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'ER' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'ER' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'ER' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'ER' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'ER' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'ER' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'ER' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'ES' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'ES' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'ES' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'ES' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (27 , 'ES' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'ES' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'ES' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'ES' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (43 , 'ES' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'ES' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'ES' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'ES' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'ES' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'ES' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'ES' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'ES' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'ES' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'ES' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'ET' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'ET' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'ET' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'ET' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'ET' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'ET' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'ET' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'ET' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'ET' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'ET' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'ET' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'ET' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'ET' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'ET' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'ET' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'ET' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'FI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'FI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'FI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'FI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (27 , 'FI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'FI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'FI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'FI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (43 , 'FI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'FI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'FI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'FI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'FI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'FI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'FI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'FI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'FI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'FI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'FJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'FJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'FJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'FJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'FJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'FJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'FJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'FJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'FJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'FJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'FJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'FJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'FJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'FJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'FJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'FJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'FK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'FK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'FK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'FK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'FK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'FK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'FK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'FK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'FK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'FK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'FK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'FK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'FK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'FK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'FK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'FK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'FM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'FM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'FM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'FM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'FM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'FM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'FM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'FM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'FM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'FM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'FM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'FM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'FM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'FM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'FM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'FM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'FO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'FO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'FO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'FO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'FO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'FO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'FO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'FO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'FO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'FO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'FO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'FO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'FO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'FO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'FO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'FO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'FR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'FR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'FR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'FR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (24 , 'FR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (27 , 'FR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'FR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'FR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'FR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (43 , 'FR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'FR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'FR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'FR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'FR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'FR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'FR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'FR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'FR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'FR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'FX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'FX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'FX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'FX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'FX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'FX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'FX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'FX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'FX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'FX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'FX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'FX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'FX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'FX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'FX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'FX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'GA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'GA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'GA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'GA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'GA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'GA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'GA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'GA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'GA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'GA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'GA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'GA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'GA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'GA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'GA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'GA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'GB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'GB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'GB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'GB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (24 , 'GB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (27 , 'GB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'GB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'GB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'GB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (43 , 'GB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'GB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'GB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'GB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'GB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'GB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'GB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'GB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'GB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'GB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'GD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'GD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'GD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'GD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'GD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'GD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'GD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'GD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'GD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'GD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'GD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'GD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'GD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'GD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'GD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'GD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'GE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'GE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'GE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'GE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'GE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'GE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'GE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'GE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'GE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'GE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'GE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'GE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'GE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'GE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'GE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'GE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'GF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'GF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'GF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'GF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'GF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'GF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'GF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'GF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'GF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'GF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'GF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'GF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'GF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'GF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'GF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'GF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'GH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'GH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'GH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'GH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'GH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'GH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'GH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'GH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'GH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'GH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'GH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'GH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'GH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'GH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'GH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'GH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'GI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'GI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'GI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'GI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'GI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'GI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'GI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'GI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'GI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'GI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'GI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'GI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'GI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'GI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'GI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'GI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'GL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'GL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'GL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'GL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'GL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'GL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'GL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'GL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'GL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'GL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'GL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'GL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'GL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'GL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'GL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'GL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'GM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'GM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'GM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'GM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'GM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'GM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'GM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'GM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'GM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'GM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'GM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'GM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'GM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'GM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'GM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'GM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'GN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'GN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'GN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'GN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'GN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'GN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'GN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'GN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'GN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'GN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'GN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'GN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'GN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'GN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'GN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'GN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'GP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'GP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'GP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'GP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'GP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'GP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'GP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'GP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'GP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'GP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'GP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'GP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'GP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'GP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'GP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'GP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'GQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'GQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'GQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'GQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'GQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'GQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'GQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'GQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'GQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'GQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'GQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'GQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'GQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'GQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'GQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'GQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'GR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'GR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'GR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'GR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (27 , 'GR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'GR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'GR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'GR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (43 , 'GR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'GR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'GR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'GR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'GR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'GR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'GR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'GR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'GR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'GR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'GT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'GT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'GT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'GT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'GT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'GT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'GT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'GT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'GT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'GT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'GT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'GT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'GT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'GT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'GT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'GT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'GU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'GU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'GU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'GU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'GU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'GU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'GU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'GU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'GU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'GU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'GU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'GU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'GU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'GU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'GU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'GU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'GW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'GW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'GW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'GW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'GW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'GW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'GW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'GW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'GW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'GW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'GW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'GW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'GW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'GW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'GW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'GW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'GY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'GY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'GY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'GY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'GY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'GY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'GY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'GY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'GY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'GY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'GY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'GY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'GY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'GY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'GY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'GY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'HK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'HK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'HK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'HK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'HK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'HK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'HK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'HK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'HK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'HK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'HK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'HK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'HK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'HK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'HK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'HK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'HM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'HM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'HM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'HM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'HM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'HM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'HM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'HM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'HM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'HM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'HM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'HM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'HM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'HM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'HM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'HM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'HN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'HN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'HN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'HN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'HN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'HN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'HN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'HN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'HN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'HN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'HN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'HN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'HN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'HN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'HN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'HN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'HR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'HR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'HR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'HR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'HR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'HR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'HR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'HR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'HR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'HR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'HR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'HR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'HR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'HR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'HR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'HR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'HT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'HT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'HT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'HT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'HT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'HT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'HT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'HT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'HT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'HT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'HT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'HT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'HT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'HT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'HT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'HT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'HU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'HU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'HU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'HU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'HU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'HU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'HU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (43 , 'HU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'HU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'HU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'HU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'HU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'HU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'HU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'HU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'HU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'HU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'ID' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'ID' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'ID' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'ID' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'ID' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'ID' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'ID' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'ID' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'ID' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'ID' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'ID' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'ID' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'ID' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'ID' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'ID' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'ID' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'IE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'IE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'IE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'IE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (27 , 'IE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'IE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'IE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'IE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (43 , 'IE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'IE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'IE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'IE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'IE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'IE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'IE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'IE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'IE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'IE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'IL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'IL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'IL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'IL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'IL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'IL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'IL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'IL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'IL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'IL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'IL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'IL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'IL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'IL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'IL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'IL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'IN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'IN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'IN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'IN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'IN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'IN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'IN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'IN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'IN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'IN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'IN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'IN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'IN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'IN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'IN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'IN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'IO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'IO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'IO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'IO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'IO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'IO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'IO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'IO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'IO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'IO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'IO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'IO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'IO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'IO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'IO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'IO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'IQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'IQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'IQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'IQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'IQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'IQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'IQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'IQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'IQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'IQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'IQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'IQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'IQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'IQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'IQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'IQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'IR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'IR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'IR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'IR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'IR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'IR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'IR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'IR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'IR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'IR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'IR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'IR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'IR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'IR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'IR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'IR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'IS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'IS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'IS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'IS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'IS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'IS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'IS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'IS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'IS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'IS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'IS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'IS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'IS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'IS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'IS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'IS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'IT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'IT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'IT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'IT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (24 , 'IT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (27 , 'IT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'IT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'IT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'IT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (43 , 'IT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'IT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'IT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'IT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'IT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'IT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'IT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'IT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'IT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'IT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'JM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'JM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'JM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'JM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'JM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'JM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'JM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'JM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'JM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'JM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'JM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'JM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'JM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'JM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'JM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'JM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'JO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'JO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'JO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'JO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'JO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'JO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'JO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'JO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'JO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'JO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'JO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'JO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'JO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'JO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'JO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'JO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'JP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'JP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'JP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'JP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'JP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'JP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'JP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'JP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'JP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'JP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'JP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'JP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'JP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'JP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'JP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'JP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'KE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'KE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'KE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'KE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'KE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'KE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'KE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'KE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'KE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'KE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'KE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'KE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'KE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'KE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'KE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'KE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'KG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'KG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'KG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'KG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'KG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'KG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'KG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'KG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'KG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'KG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'KG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'KG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'KG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'KG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'KG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'KG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'KH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'KH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'KH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'KH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'KH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'KH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'KH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'KH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'KH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'KH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'KH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'KH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'KH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'KH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'KH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'KH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'KI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'KI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'KI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'KI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'KI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'KI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'KI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'KI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'KI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'KI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'KI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'KI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'KI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'KI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'KI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'KI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'KM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'KM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'KM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'KM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'KM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'KM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'KM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'KM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'KM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'KM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'KM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'KM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'KM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'KM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'KM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'KM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'KN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'KN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'KN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'KN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'KN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'KN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'KN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'KN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'KN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'KN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'KN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'KN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'KN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'KN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'KN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'KN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'KP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'KP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'KP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'KP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'KP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'KP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'KP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'KP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'KP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'KP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'KP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'KP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'KP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'KP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'KP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'KP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'KR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'KR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'KR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'KR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'KR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'KR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'KR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'KR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'KR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'KR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'KR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'KR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'KR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'KR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'KR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'KR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'KW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'KW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'KW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'KW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'KW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'KW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'KW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'KW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'KW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'KW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'KW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'KW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'KW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'KW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'KW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'KW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'KY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'KY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'KY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'KY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'KY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'KY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'KY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'KY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'KY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'KY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'KY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'KY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'KY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'KY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'KY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'KY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'KZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'KZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'KZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'KZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'KZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'KZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'KZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'KZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'KZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'KZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'KZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'KZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'KZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'KZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'KZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'KZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'LA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'LA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'LA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'LA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'LA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'LA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'LA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'LA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'LA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'LA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'LA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'LA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'LA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'LA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'LA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'LA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'LB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'LB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'LB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'LB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'LB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'LB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'LB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'LB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'LB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'LB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'LB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'LB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'LB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'LB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'LB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'LB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'LC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'LC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'LC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'LC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'LC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'LC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'LC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'LC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'LC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'LC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'LC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'LC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'LC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'LC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'LC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'LC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'LI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'LI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'LI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'LI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'LI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'LI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'LI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'LI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'LI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'LI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'LI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'LI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'LI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'LI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'LI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'LI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'LK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'LK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'LK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'LK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'LK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'LK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'LK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'LK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'LK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'LK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'LK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'LK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'LK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'LK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'LK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'LK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'LR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'LR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'LR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'LR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'LR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'LR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'LR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'LR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'LR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'LR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'LR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'LR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'LR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'LR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'LR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'LR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'LS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'LS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'LS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'LS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'LS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'LS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'LS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'LS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'LS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'LS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'LS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'LS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'LS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'LS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'LS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'LS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'LT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'LT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'LT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'LT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'LT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'LT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'LT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (43 , 'LT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'LT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'LT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'LT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'LT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'LT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'LT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'LT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'LT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'LT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'LU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'LU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'LU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'LU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (27 , 'LU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'LU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'LU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'LU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (43 , 'LU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'LU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'LU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'LU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'LU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'LU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'LU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'LU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'LU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'LU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'LV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'LV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'LV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'LV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'LV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'LV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'LV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (43 , 'LV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'LV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'LV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'LV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'LV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'LV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'LV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'LV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'LV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'LV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'LY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'LY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'LY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'LY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'LY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'LY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'LY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'LY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'LY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'LY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'LY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'LY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'LY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'LY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'LY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'LY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'MA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'MA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'MA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'MA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'MA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'MA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'MA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'MA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'MA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'MA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'MA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'MA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'MA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'MA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'MA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'MA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'MC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'MC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'MC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'MC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'MC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'MC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'MC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'MC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'MC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'MC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'MC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'MC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'MC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'MC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'MC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'MC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'MD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'MD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'MD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'MD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'MD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'MD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'MD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'MD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'MD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'MD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'MD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'MD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'MD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'MD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'MD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'MD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'MG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'MG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'MG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'MG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'MG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'MG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'MG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'MG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'MG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'MG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'MG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'MG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'MG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'MG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'MG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'MG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'MH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'MH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'MH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'MH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'MH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'MH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'MH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'MH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'MH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'MH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'MH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'MH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'MH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'MH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'MH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'MH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'MK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'MK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'MK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'MK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'MK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'MK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'MK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'MK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'MK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'MK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'MK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'MK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'MK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'MK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'MK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'MK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'ML' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'ML' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'ML' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'ML' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'ML' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'ML' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'ML' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'ML' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'ML' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'ML' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'ML' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'ML' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'ML' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'ML' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'ML' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'ML' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'MM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'MM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'MM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'MM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'MM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'MM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'MM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'MM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'MM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'MM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'MM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'MM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'MM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'MM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'MM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'MM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'MN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'MN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'MN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'MN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'MN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'MN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'MN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'MN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'MN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'MN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'MN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'MN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'MN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'MN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'MN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'MN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'MO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'MO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'MO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'MO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'MO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'MO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'MO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'MO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'MO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'MO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'MO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'MO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'MO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'MO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'MO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'MO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'MP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'MP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'MP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'MP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'MP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'MP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'MP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'MP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'MP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'MP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'MP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'MP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'MP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'MP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'MP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'MP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'MQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'MQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'MQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'MQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'MQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'MQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'MQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'MQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'MQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'MQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'MQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'MQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'MQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'MQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'MQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'MQ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'MR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'MR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'MR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'MR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'MR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'MR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'MR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'MR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'MR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'MR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'MR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'MR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'MR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'MR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'MR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'MR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'MS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'MS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'MS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'MS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'MS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'MS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'MS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'MS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'MS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'MS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'MS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'MS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'MS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'MS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'MS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'MS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'MT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'MT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'MT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'MT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'MT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'MT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'MT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'MT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'MT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'MT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'MT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'MT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'MT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'MT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'MT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'MT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'MU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'MU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'MU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'MU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'MU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'MU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'MU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'MU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'MU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'MU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'MU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'MU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'MU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'MU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'MU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'MU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'MV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'MV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'MV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'MV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'MV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'MV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'MV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'MV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'MV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'MV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'MV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'MV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'MV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'MV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'MV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'MV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'MW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'MW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'MW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'MW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'MW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'MW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'MW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'MW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'MW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'MW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'MW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'MW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'MW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'MW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'MW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'MW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'MX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'MX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'MX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'MX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'MX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (45 , 'MX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (46 , 'MX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'MX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'MX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'MX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'MX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'MX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'MX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'MX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'MX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'MX' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'MY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'MY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'MY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'MY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'MY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'MY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'MY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'MY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'MY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'MY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'MY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'MY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'MY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'MY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'MY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'MY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'MZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'MZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'MZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'MZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'MZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'MZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'MZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'MZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'MZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'MZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'MZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'MZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'MZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'MZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'MZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'MZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'NA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'NA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'NA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'NA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'NA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'NA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'NA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'NA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'NA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'NA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'NA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'NA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'NA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'NA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'NA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'NA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'NC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'NC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'NC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'NC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'NC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'NC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'NC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'NC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'NC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'NC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'NC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'NC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'NC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'NC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'NC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'NC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'NE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'NE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'NE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'NE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'NE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'NE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'NE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'NE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'NE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'NE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'NE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'NE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'NE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'NE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'NE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'NE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'NF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'NF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'NF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'NF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'NF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'NF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'NF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'NF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'NF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'NF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'NF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'NF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'NF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'NF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'NF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'NF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'NG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'NG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'NG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'NG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'NG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'NG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'NG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'NG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'NG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'NG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'NG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'NG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'NG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'NG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'NG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'NG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'NI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'NI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'NI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'NI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'NI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'NI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'NI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'NI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'NI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'NI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'NI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'NI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'NI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'NI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'NI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'NI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'NL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'NL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'NL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'NL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (27 , 'NL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'NL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'NL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'NL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'NL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (43 , 'NL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'NL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'NL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'NL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'NL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'NL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'NL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'NL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'NL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'NL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'NO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'NO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'NO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'NO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (27 , 'NO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'NO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'NO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'NO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (43 , 'NO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'NO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'NO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'NO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'NO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'NO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'NO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'NO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'NO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'NO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'NP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'NP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'NP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'NP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'NP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'NP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'NP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'NP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'NP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'NP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'NP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'NP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'NP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'NP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'NP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'NP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'NR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'NR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'NR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'NR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'NR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'NR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'NR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'NR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'NR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'NR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'NR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'NR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'NR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'NR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'NR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'NR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'NU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'NU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'NU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'NU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'NU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'NU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'NU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'NU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'NU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'NU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'NU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'NU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'NU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'NU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'NU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'NU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'NZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'NZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'NZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'NZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'NZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'NZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'NZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'NZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'NZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'NZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'NZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'NZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'NZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'NZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'NZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'NZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'OM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'OM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'OM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'OM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'OM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'OM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'OM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'OM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'OM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'OM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'OM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'OM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'OM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'OM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'OM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'OM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'PA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'PA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'PA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'PA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'PA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'PA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'PA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'PA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'PA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'PA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'PA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'PA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'PA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'PA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'PA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'PA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'PE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'PE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'PE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'PE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'PE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'PE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'PE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'PE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'PE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'PE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'PE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'PE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'PE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'PE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'PE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'PE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'PF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'PF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'PF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'PF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'PF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'PF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'PF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'PF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'PF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'PF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'PF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'PF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'PF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'PF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'PF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'PF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'PG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'PG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'PG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'PG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'PG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'PG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'PG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'PG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'PG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'PG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'PG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'PG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'PG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'PG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'PG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'PG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'PH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'PH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'PH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'PH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'PH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'PH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'PH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'PH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'PH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'PH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'PH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'PH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'PH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'PH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'PH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'PH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'PK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'PK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'PK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'PK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'PK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'PK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'PK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'PK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'PK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'PK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'PK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'PK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'PK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'PK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'PK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'PK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'PL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'PL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'PL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'PL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'PL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'PL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'PL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (43 , 'PL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'PL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'PL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'PL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'PL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'PL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'PL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'PL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'PL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'PL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'PM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'PM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'PM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'PM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'PM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'PM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'PM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'PM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'PM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'PM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'PM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'PM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'PM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'PM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'PM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'PM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'PN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'PN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'PN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'PN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'PN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'PN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'PN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'PN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'PN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'PN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'PN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'PN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'PN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'PN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'PN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'PN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'PR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'PR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'PR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'PR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'PR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (28 , 'PR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (29 , 'PR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (30 , 'PR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'PR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (36 , 'PR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'PR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'PR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'PR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'PR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'PR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'PR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'PR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'PR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'PR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'PR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'PT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'PT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'PT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'PT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (27 , 'PT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'PT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'PT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'PT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (43 , 'PT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'PT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'PT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'PT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'PT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'PT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'PT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'PT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'PT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'PT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'PW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'PW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'PW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'PW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'PW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'PW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'PW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'PW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'PW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'PW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'PW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'PW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'PW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'PW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'PW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'PW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'PY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'PY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'PY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'PY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'PY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'PY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'PY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'PY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'PY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'PY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'PY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'PY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'PY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'PY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'PY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'PY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'QA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'QA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'QA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'QA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'QA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'QA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'QA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'QA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'QA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'QA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'QA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'QA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'QA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'QA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'QA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'QA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'RE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'RE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'RE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'RE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'RE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'RE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'RE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'RE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'RE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'RE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'RE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'RE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'RE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'RE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'RE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'RE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'RO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'RO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'RO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'RO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'RO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'RO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'RO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'RO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'RO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'RO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'RO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'RO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'RO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'RO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'RO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'RO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'RU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'RU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'RU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'RU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'RU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'RU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'RU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'RU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'RU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'RU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'RU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'RU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'RU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'RU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'RU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'RU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'RW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'RW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'RW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'RW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'RW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'RW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'RW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'RW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'RW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'RW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'RW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'RW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'RW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'RW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'RW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'RW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'SA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'SA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'SA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'SA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'SA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'SA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'SA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'SA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'SA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'SA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'SA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'SA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'SA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'SA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'SA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'SA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'SB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'SB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'SB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'SB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'SB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'SB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'SB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'SB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'SB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'SB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'SB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'SB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'SB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'SB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'SB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'SB' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'SC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'SC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'SC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'SC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'SC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'SC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'SC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'SC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'SC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'SC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'SC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'SC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'SC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'SC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'SC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'SC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'SD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'SD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'SD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'SD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'SD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'SD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'SD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'SD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'SD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'SD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'SD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'SD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'SD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'SD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'SD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'SD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'SE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'SE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'SE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'SE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (27 , 'SE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'SE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'SE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'SE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (43 , 'SE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'SE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'SE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'SE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'SE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'SE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'SE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'SE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'SE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'SE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'SG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'SG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'SG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'SG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'SG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'SG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'SG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'SG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'SG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'SG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'SG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'SG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'SG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'SG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'SG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'SG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'SH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'SH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'SH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'SH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'SH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'SH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'SH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'SH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'SH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'SH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'SH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'SH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'SH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'SH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'SH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'SH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'SI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'SI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'SI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'SI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'SI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'SI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'SI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (43 , 'SI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'SI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'SI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'SI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'SI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'SI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'SI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'SI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'SI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'SI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'SJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'SJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'SJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'SJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'SJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'SJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'SJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'SJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'SJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'SJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'SJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'SJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'SJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'SJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'SJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'SJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'SK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'SK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'SK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'SK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'SK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'SK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'SK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (43 , 'SK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'SK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'SK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'SK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'SK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'SK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'SK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'SK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'SK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'SK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'SL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'SL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'SL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'SL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'SL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'SL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'SL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'SL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'SL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'SL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'SL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'SL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'SL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'SL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'SL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'SL' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'SM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'SM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'SM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'SM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'SM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'SM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'SM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (42 , 'SM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (43 , 'SM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'SM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'SM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'SM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'SM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'SM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'SM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'SM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'SM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'SN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'SN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'SN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'SN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'SN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'SN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'SN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'SN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'SN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'SN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'SN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'SN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'SN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'SN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'SN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'SN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'SO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'SO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'SO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'SO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'SO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'SO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'SO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'SO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'SO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'SO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'SO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'SO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'SO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'SO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'SO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'SO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'SR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'SR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'SR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'SR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'SR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'SR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'SR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'SR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'SR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'SR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'SR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'SR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'SR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'SR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'SR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'SR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'ST' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'ST' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'ST' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'ST' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'ST' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'ST' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'ST' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'ST' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'ST' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'ST' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'ST' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'ST' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'ST' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'ST' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'ST' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'ST' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'SV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'SV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'SV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'SV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'SV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'SV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'SV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'SV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'SV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'SV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'SV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'SV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'SV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'SV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'SV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'SV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'SY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'SY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'SY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'SY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'SY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'SY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'SY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'SY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'SY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'SY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'SY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'SY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'SY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'SY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'SY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'SY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'SZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'SZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'SZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'SZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'SZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'SZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'SZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'SZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'SZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'SZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'SZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'SZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'SZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'SZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'SZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'SZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'TC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'TC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'TC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'TC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'TC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'TC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'TC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'TC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'TC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'TC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'TC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'TC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'TC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'TC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'TC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'TC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'TD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'TD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'TD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'TD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'TD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'TD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'TD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'TD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'TD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'TD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'TD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'TD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'TD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'TD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'TD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'TD' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'TF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'TF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'TF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'TF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'TF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'TF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'TF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'TF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'TF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'TF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'TF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'TF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'TF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'TF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'TF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'TF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'TG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'TG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'TG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'TG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'TG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'TG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'TG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'TG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'TG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'TG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'TG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'TG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'TG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'TG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'TG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'TG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'TH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'TH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'TH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'TH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'TH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'TH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'TH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'TH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'TH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'TH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'TH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'TH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'TH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'TH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'TH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'TH' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'TJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'TJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'TJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'TJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'TJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'TJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'TJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'TJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'TJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'TJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'TJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'TJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'TJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'TJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'TJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'TJ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'TK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'TK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'TK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'TK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'TK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'TK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'TK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'TK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'TK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'TK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'TK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'TK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'TK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'TK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'TK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'TK' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'TM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'TM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'TM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'TM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'TM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'TM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'TM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'TM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'TM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'TM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'TM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'TM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'TM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'TM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'TM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'TM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'TN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'TN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'TN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'TN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'TN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'TN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'TN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'TN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'TN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'TN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'TN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'TN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'TN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'TN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'TN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'TN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'TO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'TO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'TO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'TO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'TO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'TO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'TO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'TO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'TO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'TO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'TO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'TO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'TO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'TO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'TO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'TO' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'TP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'TP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'TP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'TP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'TP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'TP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'TP' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'TR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'TR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'TR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'TR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'TR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'TR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'TR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'TR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'TR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'TR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'TR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'TR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'TR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'TR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'TR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'TR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'TT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'TT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'TT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'TT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'TT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'TT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'TT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'TT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'TT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'TT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'TT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'TT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'TT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'TT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'TT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'TT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'TV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'TV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'TV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'TV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'TV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'TV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'TV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'TV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'TV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'TV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'TV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'TV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'TV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'TV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'TV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'TV' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'TW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'TW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'TW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'TW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'TW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'TW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'TW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'TW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'TW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'TW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'TW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'TW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'TW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'TW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'TW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'TW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'TZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'TZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'TZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'TZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'TZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'TZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'TZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'TZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'TZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'TZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'TZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'TZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'TZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'TZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'TZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'TZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'UA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'UA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'UA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'UA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'UA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'UA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'UA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'UA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'UA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'UA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'UA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'UA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'UA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'UA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'UA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'UA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'UG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'UG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'UG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'UG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'UG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'UG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'UG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'UG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'UG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'UG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'UG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'UG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'UG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'UG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'UG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'UG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'UM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'UM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'UM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'UM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'UM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'UM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'UM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'UM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'UM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'UM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'UM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'UM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'UM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'UM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'UM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'UM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (47 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (48 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (49 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (50 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (51 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (52 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (53 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (54 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (55 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (56 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (57 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (58 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (59 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (13 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (14 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (15 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (16 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (21 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (18 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (17 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (20 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (12 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (19 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (28 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (29 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (30 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (33 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (34 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (35 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (36 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (44 , 'US' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'UY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'UY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'UY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'UY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'UY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'UY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'UY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'UY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'UY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'UY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'UY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'UY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'UY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'UY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'UY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'UY' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'UZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'UZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'UZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'UZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'UZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'UZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'UZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'UZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'UZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'UZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'UZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'UZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'UZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'UZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'UZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'UZ' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'VA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'VA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'VA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'VA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'VA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'VA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'VA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'VA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'VA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'VA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'VA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'VA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'VA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'VA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'VA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'VA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'VC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'VC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'VC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'VC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'VC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'VC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'VC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'VC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'VC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'VC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'VC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'VC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'VC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'VC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'VC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'VC' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'VE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'VE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'VE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'VE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'VE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'VE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'VE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'VE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'VE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'VE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'VE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'VE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'VE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'VE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'VE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'VE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'VG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'VG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'VG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'VG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'VG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'VG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'VG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'VG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'VG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'VG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'VG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'VG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'VG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'VG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'VG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'VG' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'VI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'VI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'VI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'VI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'VI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'VI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'VI' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'VN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'VN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'VN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'VN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'VN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'VN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'VN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'VN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'VN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'VN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'VN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'VN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'VN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'VN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'VN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'VN' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'VU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'VU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'VU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'VU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'VU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'VU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'VU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'VU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'VU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'VU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'VU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'VU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'VU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'VU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'VU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'VU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'VU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'VU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'VU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'VU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'VU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'VU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'VU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'VU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'VU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'WF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'WF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'WF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'WF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'WF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'WF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'WF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'WF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'WF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'WF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'WF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'WF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'WF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'WF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'WF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'WF' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'WS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'WS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'WS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'WS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'WS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'WS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'WS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'WS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'WS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'WS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'WS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'WS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'WS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'WS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'WS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'WS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'WS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'WS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'WS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'WS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'WS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'WS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'WS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'WS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'WS' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'YE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'YE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'YE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'YE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'YE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'YE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'YE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'YE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'YE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'YE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'YE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'YE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'YE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'YE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'YE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'YE' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'YT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'YT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'YT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'YT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'YT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'YT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'YT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'YT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'YT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'YT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'YT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'YT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'YT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'YT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'YT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'YT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'YT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'YT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'YT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'YT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'YT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'YT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'YT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'YT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'YT' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'YU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'YU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'YU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'YU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'YU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'YU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'YU' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'ZA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'ZA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'ZA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'ZA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'ZA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'ZA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'ZA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'ZA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'ZA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'ZA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'ZA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'ZA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'ZA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'ZA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'ZA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'ZA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'ZA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'ZA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'ZA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'ZA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'ZA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'ZA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'ZA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'ZA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'ZA' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'ZM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'ZM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'ZM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'ZM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'ZM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'ZM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'ZM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'ZM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'ZM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'ZM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'ZM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'ZM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'ZM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'ZM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'ZM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'ZM' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'ZR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'ZR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'ZR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'ZR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'ZR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'ZR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'ZR' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (60 , 'ZW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (23 , 'ZW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (22 , 'ZW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (25 , 'ZW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (26 , 'ZW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (31 , 'ZW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (37 , 'ZW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (32 , 'ZW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (61 , 'ZW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (62 , 'ZW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (63 , 'ZW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (64 , 'ZW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (65 , 'ZW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (66 , 'ZW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (67 , 'ZW' ) ;
INSERT INTO [va_shipping_types_countries] ([shipping_type_id],[country_code]) VALUES (68 , 'ZW' ) ;


INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('AK' , 'Alaska' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('AL' , 'Alabama' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('AR' , 'Arkansas' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('AZ' , 'Arizona' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('CA' , 'California' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('CO' , 'Colorado' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('CT' , 'Connecticut' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('DC' , 'District of Columbia' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('DE' , 'Delaware' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('FL' , 'Florida' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('GA' , 'Georgia' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('HI' , 'Hawaii' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('IA' , 'Iowa' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('ID' , 'Idaho' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('IL' , 'Illinois' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('IN' , 'Indiana' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('KS' , 'Kansas' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('KY' , 'Kentucky' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('LA' , 'Louisiana' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('MA' , 'Massachusetts' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('MD' , 'Maryland' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('ME' , 'Maine' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('MI' , 'Michigan' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('MN' , 'Minnesota' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('MO' , 'Missouri' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('MS' , 'Mississippi' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('MT' , 'Montana' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('NC' , 'North Carolina' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('ND' , 'North Dakota' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('NE' , 'Nebraska' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('NH' , 'New Hampshire' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('NJ' , 'New Jersey' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('NM' , 'New Mexico' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('NV' , 'Nevada' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('NY' , 'New York' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('OH' , 'Ohio' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('OK' , 'Oklahoma' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('OR' , 'Oregon' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('PA' , 'Pennsylvania' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('RI' , 'Rhode Island' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('SC' , 'South Carolina' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('SD' , 'South Dakota' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('TN' , 'Tennessee' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('TX' , 'Texas' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('UT' , 'Utah' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('VA' , 'Virginia' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('VT' , 'Vermont' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('WA' , 'Washington' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('WI' , 'Wisconsin' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('WV' , 'West Virginia' ) ;
INSERT INTO [va_states] ([state_code],[state_name]) VALUES ('WY' , 'Wyoming' ) ;






INSERT INTO [va_support_departments] ([dep_id],[short_title],[full_title],[signature],[attachments_dir],[attachments_mask],[incoming_account],[incoming_type_id],[incoming_product_id],[outgoing_account],[show_for_user]) VALUES (1 , 'Support' , 'Support Department' , NULL , NULL , NULL , 'support@your_site.com' , 2 , NULL , 'support@your_site.com' , 1 ) ;






INSERT INTO [va_support_priorities] ([priority_id],[priority_name],[priority_rank],[admin_html],[is_default]) VALUES (1 , 'High' , 1 , '<img src="../images/high.gif" width="8" height="12" border="0">' , 0 ) ;
INSERT INTO [va_support_priorities] ([priority_id],[priority_name],[priority_rank],[admin_html],[is_default]) VALUES (2 , 'Normal' , 2 , NULL , 1 ) ;
INSERT INTO [va_support_priorities] ([priority_id],[priority_name],[priority_rank],[admin_html],[is_default]) VALUES (3 , 'Low' , 3 , '<img src="../images/low.gif" width="8" height="12" border="0">' , 0 ) ;


INSERT INTO [va_support_products] ([product_id],[product_name],[show_for_user]) VALUES (1 , 'The Lord of the Rings' , 1 ) ;


INSERT INTO [va_support_statuses] ([status_id],[status_name],[show_for_user],[status_caption],[status_icon],[html_start],[html_end],[is_user_new],[is_user_reply],[is_operation],[is_reassign],[is_internal],[is_list],[is_closed],[is_add_knowledge]) VALUES (1 , 'New' , 1 , 'New' , NULL , NULL , NULL , 1 , 0 , 0 , 0 , 0 , 1 , NULL , 0 ) ;
INSERT INTO [va_support_statuses] ([status_id],[status_name],[show_for_user],[status_caption],[status_icon],[html_start],[html_end],[is_user_new],[is_user_reply],[is_operation],[is_reassign],[is_internal],[is_list],[is_closed],[is_add_knowledge]) VALUES (2 , 'Proposed Solution' , 0 , 'Propose Solution' , NULL , NULL , NULL , 0 , 0 , 1 , 0 , 0 , 1 , NULL , 0 ) ;
INSERT INTO [va_support_statuses] ([status_id],[status_name],[show_for_user],[status_caption],[status_icon],[html_start],[html_end],[is_user_new],[is_user_reply],[is_operation],[is_reassign],[is_internal],[is_list],[is_closed],[is_add_knowledge]) VALUES (3 , 'Awaiting Response' , 1 , 'Reply to Customer' , NULL , NULL , NULL , 0 , 0 , 1 , 0 , 0 , 1 , NULL , 0 ) ;
INSERT INTO [va_support_statuses] ([status_id],[status_name],[show_for_user],[status_caption],[status_icon],[html_start],[html_end],[is_user_new],[is_user_reply],[is_operation],[is_reassign],[is_internal],[is_list],[is_closed],[is_add_knowledge]) VALUES (4 , 'Request More Information' , 1 , 'Request More Information' , NULL , NULL , NULL , 0 , 0 , 1 , 0 , 0 , 1 , NULL , 0 ) ;
INSERT INTO [va_support_statuses] ([status_id],[status_name],[show_for_user],[status_caption],[status_icon],[html_start],[html_end],[is_user_new],[is_user_reply],[is_operation],[is_reassign],[is_internal],[is_list],[is_closed],[is_add_knowledge]) VALUES (5 , 'Investigating' , 0 , 'Mark as "Investigating"' , NULL , NULL , NULL , 0 , 0 , 1 , 0 , 0 , 1 , NULL , 0 ) ;
INSERT INTO [va_support_statuses] ([status_id],[status_name],[show_for_user],[status_caption],[status_icon],[html_start],[html_end],[is_user_new],[is_user_reply],[is_operation],[is_reassign],[is_internal],[is_list],[is_closed],[is_add_knowledge]) VALUES (6 , 'Closed' , 0 , 'Close' , NULL , NULL , NULL , 0 , 0 , 1 , 0 , 0 , 0 , 1 , 0 ) ;
INSERT INTO [va_support_statuses] ([status_id],[status_name],[show_for_user],[status_caption],[status_icon],[html_start],[html_end],[is_user_new],[is_user_reply],[is_operation],[is_reassign],[is_internal],[is_list],[is_closed],[is_add_knowledge]) VALUES (7 , 'Assigned to Manager' , 0 , 'Reassign' , NULL , NULL , NULL , 0 , 0 , 1 , 1 , 1 , 1 , NULL , 0 ) ;
INSERT INTO [va_support_statuses] ([status_id],[status_name],[show_for_user],[status_caption],[status_icon],[html_start],[html_end],[is_user_new],[is_user_reply],[is_operation],[is_reassign],[is_internal],[is_list],[is_closed],[is_add_knowledge]) VALUES (8 , 'Customer Reply' , 0 , 'Customer Reply' , NULL , NULL , NULL , 0 , 1 , 0 , 0 , 0 , 1 , NULL , 0 ) ;
INSERT INTO [va_support_statuses] ([status_id],[status_name],[show_for_user],[status_caption],[status_icon],[html_start],[html_end],[is_user_new],[is_user_reply],[is_operation],[is_reassign],[is_internal],[is_list],[is_closed],[is_add_knowledge]) VALUES (9 , 'Added to Knowledge Base' , 0 , 'Add to KB' , NULL , NULL , NULL , 0 , 0 , 0 , 0 , 1 , 0 , 0 , 1 ) ;




INSERT INTO [va_support_types] ([type_id],[type_name],[show_for_user]) VALUES (1 , 'Bug/Issue' , 1 ) ;
INSERT INTO [va_support_types] ([type_id],[type_name],[show_for_user]) VALUES (2 , 'Question' , 1 ) ;
INSERT INTO [va_support_types] ([type_id],[type_name],[show_for_user]) VALUES (3 , 'Wish/Request' , 1 ) ;
INSERT INTO [va_support_types] ([type_id],[type_name],[show_for_user]) VALUES (4 , 'Other' , 1 ) ;
INSERT INTO [va_support_types] ([type_id],[type_name],[show_for_user]) VALUES (5 , 'Quote' , 1 ) ;


INSERT INTO [va_support_users_departments] ([admin_id],[dep_id],[is_default_dep]) VALUES (1 , 1 , 1 ) ;




INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (1 , 'VAT' , NULL , 'AT' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (2 , 'VAT' , NULL , 'BE' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (3 , 'VAT' , NULL , 'CY' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (4 , 'VAT' , NULL , 'CZ' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (5 , 'VAT' , NULL , 'DK' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (6 , 'VAT' , NULL , 'EE' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (7 , 'VAT' , NULL , 'FI' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (8 , 'VAT' , NULL , 'FR' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (9 , 'VAT' , NULL , 'DE' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (10 , 'VAT' , NULL , 'GR' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (11 , 'VAT' , NULL , 'HU' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (12 , 'VAT' , NULL , 'IE' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (13 , 'VAT' , NULL , 'IT' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (14 , 'VAT' , NULL , 'LV' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (15 , 'VAT' , NULL , 'LT' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (16 , 'VAT' , NULL , 'LU' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (17 , 'VAT' , NULL , 'MT' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (18 , 'VAT' , NULL , 'MC' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (19 , 'VAT' , NULL , 'AN' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (20 , 'VAT' , NULL , 'NL' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (21 , 'VAT' , NULL , 'PL' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (22 , 'VAT' , NULL , 'PT' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (23 , 'VAT' , NULL , 'SK' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (24 , 'VAT' , NULL , 'SI' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (25 , 'VAT' , NULL , 'ES' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (26 , 'VAT' , NULL , 'SE' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (27 , 'VAT' , NULL , 'GB' , 17.5 ) ;
INSERT INTO [va_tax_rates] ([tax_id],[tax_name],[state_code],[country_code],[tax_percent]) VALUES (28 , 'Sales Tax' , NULL , 'US' , 8.5 ) ;










INSERT INTO [va_user_profile_sections] ([section_id],[is_active],[step_number],[section_order],[section_name]) VALUES (1 , 1 , 1 , 1 , 'LOGIN_INFO_MSG' ) ;
INSERT INTO [va_user_profile_sections] ([section_id],[is_active],[step_number],[section_order],[section_name]) VALUES (2 , 1 , 1 , 2 , 'PERSONAL_DETAILS_MSG' ) ;
INSERT INTO [va_user_profile_sections] ([section_id],[is_active],[step_number],[section_order],[section_name]) VALUES (3 , 1 , 1 , 3 , 'DELIVERY_DETAILS_MSG' ) ;
INSERT INTO [va_user_profile_sections] ([section_id],[is_active],[step_number],[section_order],[section_name]) VALUES (4 , 1 , 1 , 4 , 'ADDITIONAL_DETAILS_MSG' ) ;




INSERT INTO [va_user_types] ([type_id],[type_name],[is_default],[is_active],[is_sms_allowed],[show_for_user],[price_type],[discount_type],[discount_amount],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[tax_free],[coupons_ids],[is_subscription],[is_subscription_recurring],[subscription_name],[subscription_fee],[subscription_period],[subscription_interval],[subscription_suspend]) VALUES (1 , 'Customer' , 1 , 1 , 1 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;


INSERT INTO [va_user_types_settings] ([type_id],[setting_name],[setting_value]) VALUES (1 , 'access_products' , '0' ) ;
INSERT INTO [va_user_types_settings] ([type_id],[setting_name],[setting_value]) VALUES (1 , 'add_ad' , '1' ) ;
INSERT INTO [va_user_types_settings] ([type_id],[setting_name],[setting_value]) VALUES (1 , 'add_product' , '0' ) ;
INSERT INTO [va_user_types_settings] ([type_id],[setting_name],[setting_value]) VALUES (1 , 'affiliate_join' , '0' ) ;
INSERT INTO [va_user_types_settings] ([type_id],[setting_name],[setting_value]) VALUES (1 , 'affiliate_sales' , '0' ) ;
INSERT INTO [va_user_types_settings] ([type_id],[setting_name],[setting_value]) VALUES (1 , 'approve_ad' , '0' ) ;
INSERT INTO [va_user_types_settings] ([type_id],[setting_name],[setting_value]) VALUES (1 , 'approve_product' , '0' ) ;
INSERT INTO [va_user_types_settings] ([type_id],[setting_name],[setting_value]) VALUES (1 , 'approve_profile' , '1' ) ;
INSERT INTO [va_user_types_settings] ([type_id],[setting_name],[setting_value]) VALUES (1 , 'delete_ad' , '1' ) ;
INSERT INTO [va_user_types_settings] ([type_id],[setting_name],[setting_value]) VALUES (1 , 'delete_product' , '0' ) ;
INSERT INTO [va_user_types_settings] ([type_id],[setting_name],[setting_value]) VALUES (1 , 'edit_ad' , '1' ) ;
INSERT INTO [va_user_types_settings] ([type_id],[setting_name],[setting_value]) VALUES (1 , 'edit_product' , '0' ) ;
INSERT INTO [va_user_types_settings] ([type_id],[setting_name],[setting_value]) VALUES (1 , 'edit_profile' , '1' ) ;
INSERT INTO [va_user_types_settings] ([type_id],[setting_name],[setting_value]) VALUES (1 , 'merchant_sales' , '0' ) ;
INSERT INTO [va_user_types_settings] ([type_id],[setting_name],[setting_value]) VALUES (1 , 'my_carts' , '1' ) ;
INSERT INTO [va_user_types_settings] ([type_id],[setting_name],[setting_value]) VALUES (1 , 'my_details' , '1' ) ;
INSERT INTO [va_user_types_settings] ([type_id],[setting_name],[setting_value]) VALUES (1 , 'my_forum' , '1' ) ;
INSERT INTO [va_user_types_settings] ([type_id],[setting_name],[setting_value]) VALUES (1 , 'my_orders' , '1' ) ;
INSERT INTO [va_user_types_settings] ([type_id],[setting_name],[setting_value]) VALUES (1 , 'my_payments' , '0' ) ;
INSERT INTO [va_user_types_settings] ([type_id],[setting_name],[setting_value]) VALUES (1 , 'my_support' , '1' ) ;
INSERT INTO [va_user_types_settings] ([type_id],[setting_name],[setting_value]) VALUES (1 , 'new_profile' , '1' ) ;


INSERT INTO [va_users] ([user_id],[user_type_id],[is_approved],[is_hidden],[expiry_date],[suspend_date],[registration_last_step],[registration_total_steps],[is_sms_allowed],[discount_type],[discount_amount],[affiliate_commission_type],[affiliate_commission_amount],[merchant_fee_type],[merchant_fee_amount],[tax_free],[coupons_ids],[login],[password],[nickname],[affiliate_code],[security_question],[security_answer],[personal_image],[short_description],[full_description],[friendly_url],[name],[first_name],[last_name],[company_id],[company_name],[email],[address1],[address2],[city],[province],[state_code],[zip],[country_code],[phone],[daytime_phone],[evening_phone],[cell_phone],[fax],[delivery_name],[delivery_first_name],[delivery_last_name],[delivery_company_id],[delivery_company_name],[delivery_email],[delivery_address1],[delivery_address2],[delivery_city],[delivery_province],[delivery_state_code],[delivery_zip],[delivery_country_code],[delivery_phone],[delivery_daytime_phone],[delivery_evening_phone],[delivery_cell_phone],[delivery_fax],[paypal_account],[msn_account],[icq_number],[user_site_url],[tax_id],[birth_year],[birth_month],[birth_day],[registration_ip],[registration_date],[modified_ip],[modified_date],[admin_modified_ip],[admin_modified_date],[last_logged_ip],[last_logged_date],[last_visit_ip],[last_visit_page],[last_visit_date],[reset_password_code],[reset_password_date]) VALUES (1 , 1 , 1 , 0 , NULL , NULL , 1 , 1 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , 'joy' , 'joy' , NULL , '' , '' , '' , NULL , NULL , NULL , '' , 'joy' , '' , '' , NULL , NULL , 'jnothing@yahoo.com' , '5-th Avenue' , NULL , 'New York' , NULL , 'NY' , '10002' , 'US' , NULL , '1234567890' , '1234567890' , NULL , NULL , 'joy' , NULL , NULL , NULL , NULL , NULL , '5-th Avenue' , NULL , 'New York' , NULL , 'NY' , '10002' , 'US' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , '2004-06-22 20:03:44' , '127.0.0.1' , '2007-03-20 21:26:15' , NULL , NULL , NULL , NULL , NULL , NULL , '2006-12-26 16:53:37' , NULL , NULL ) ;









